@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -46,12 +49,12 @@ import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.ProjectManager;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.Sources;
-import org.netbeans.modules.ant.freeform.spi.support.Util;
 import org.netbeans.spi.project.support.ant.AntProjectEvent;
 import org.netbeans.spi.project.support.ant.AntProjectListener;
 import org.netbeans.spi.project.support.ant.SourcesHelper;
 import org.openide.util.ChangeSupport;
 import org.openide.util.Mutex;
+import org.openide.xml.XMLUtil;
 import org.w3c.dom.Element;
 
 /**
@@ -86,32 +89,32 @@ final class FreeformSources implements Sources, AntProjectListener {
     private Sources initSources() {
         SourcesHelper h = new SourcesHelper(project, project.helper(), project.evaluator());
         Element genldata = project.getPrimaryConfigurationData();
-        Element foldersE = Util.findElement(genldata, "folders", FreeformProjectType.NS_GENERAL); // NOI18N
+        Element foldersE = XMLUtil.findElement(genldata, "folders", FreeformProjectType.NS_GENERAL); // NOI18N
         if (foldersE != null) {
-            for (Element folderE : Util.findSubElements(foldersE)) {
-                Element locationE = Util.findElement(folderE, "location", FreeformProjectType.NS_GENERAL); // NOI18N
-                String location = Util.findText(locationE);
+            for (Element folderE : XMLUtil.findSubElements(foldersE)) {
+                Element locationE = XMLUtil.findElement(folderE, "location", FreeformProjectType.NS_GENERAL); // NOI18N
+                String location = XMLUtil.findText(locationE);
                 if (folderE.getLocalName().equals("build-folder")) { // NOI18N
                     h.addNonSourceRoot(location);
                 } else if (folderE.getLocalName().equals("build-file")) { // NOI18N
                     h.addOwnedFile(location);
                 } else {
                     assert folderE.getLocalName().equals("source-folder") : folderE;
-                    Element nameE = Util.findElement(folderE, "label", FreeformProjectType.NS_GENERAL); // NOI18N
-                    String name = Util.findText(nameE);
-                    Element typeE = Util.findElement(folderE, "type", FreeformProjectType.NS_GENERAL); // NOI18N
+                    Element nameE = XMLUtil.findElement(folderE, "label", FreeformProjectType.NS_GENERAL); // NOI18N
+                    String name = XMLUtil.findText(nameE);
+                    Element typeE = XMLUtil.findElement(folderE, "type", FreeformProjectType.NS_GENERAL); // NOI18N
                     String includes = null;
-                    Element includesE = Util.findElement(folderE, "includes", FreeformProjectType.NS_GENERAL); // NOI18N
+                    Element includesE = XMLUtil.findElement(folderE, "includes", FreeformProjectType.NS_GENERAL); // NOI18N
                     if (includesE != null) {
-                        includes = Util.findText(includesE);
+                        includes = XMLUtil.findText(includesE);
                     }
                     String excludes = null;
-                    Element excludesE = Util.findElement(folderE, "excludes", FreeformProjectType.NS_GENERAL); // NOI18N
+                    Element excludesE = XMLUtil.findElement(folderE, "excludes", FreeformProjectType.NS_GENERAL); // NOI18N
                     if (excludesE != null) {
-                        excludes = Util.findText(excludesE);
+                        excludes = XMLUtil.findText(excludesE);
                     }
                     if (typeE != null) {
-                        String type = Util.findText(typeE);
+                        String type = XMLUtil.findText(typeE);
                         h.addTypedSourceRoot(location, includes, excludes, type, name, null, null);
                     } else {
                         h.addPrincipalSourceRoot(location, includes, excludes, name, null, null);
