@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -51,6 +54,7 @@ import org.netbeans.spi.project.support.ant.PropertyEvaluator;
 import org.openide.loaders.CreateFromTemplateAttributesProvider;
 import org.openide.loaders.DataFolder;
 import org.openide.loaders.DataObject;
+import org.openide.xml.XMLUtil;
 import org.w3c.dom.Element;
 
 /**
@@ -77,14 +81,14 @@ public class FreeformTemplateAttributesProvider implements CreateFromTemplateAtt
     
     public Map<String, ?> attributesFor(DataObject template, DataFolder target, String name) {
         Element primData = Util.getPrimaryConfigurationData(helper);
-        Element licenseEl = Util.findElement(primData, "project-license", Util.NAMESPACE); // NOI18N
+        Element licenseEl = XMLUtil.findElement(primData, "project-license", Util.NAMESPACE); // NOI18N
         Charset charset = encodingQuery.getEncoding(target.getPrimaryFile());
         if (licenseEl == null && charset == null) {
             return null;
         } else {
             Map<String, String> values = new HashMap<String, String>();
             if (licenseEl != null) {
-                values.put("license", evaluator.evaluate(Util.findText(licenseEl))); // NOI18N
+                values.put("license", evaluator.evaluate(XMLUtil.findText(licenseEl))); // NOI18N
             }
             if (charset != null) {
                 values.put("encoding", charset.name()); // NOI18N
