@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -70,6 +73,7 @@ import org.openide.nodes.NodeMemberEvent;
 import org.openide.nodes.NodeReorderEvent;
 import org.w3c.dom.Document;
 import org.openide.util.Lookup;
+import org.openide.xml.XMLUtil;
 import org.w3c.dom.Element;
 import org.w3c.dom.NodeList;
 
@@ -120,19 +124,19 @@ public class ViewTest extends TestBase {
         TestNL l = new TestNL();
         root.addNodeListener(l);
         Element data = extsrcroot.getPrimaryConfigurationData();
-        Element view = Util.findElement(data, "view", FreeformProjectType.NS_GENERAL);
+        Element view = XMLUtil.findElement(data, "view", FreeformProjectType.NS_GENERAL);
         assertNotNull("have <view>", view);
-        Element items = Util.findElement(view, "items", FreeformProjectType.NS_GENERAL);
+        Element items = XMLUtil.findElement(view, "items", FreeformProjectType.NS_GENERAL);
         assertNotNull("have <items>", items);
-        Element sourceFolder = Util.findElement(items, "source-folder", FreeformProjectType.NS_GENERAL);
+        Element sourceFolder = XMLUtil.findElement(items, "source-folder", FreeformProjectType.NS_GENERAL);
         assertNotNull("have <source-folder>", sourceFolder);
-        Element location = Util.findElement(sourceFolder, "location", FreeformProjectType.NS_GENERAL);
+        Element location = XMLUtil.findElement(sourceFolder, "location", FreeformProjectType.NS_GENERAL);
         assertNotNull("have <location>", location);
         NodeList nl = location.getChildNodes();
         assertEquals("one child", 1, nl.getLength());
         location.removeChild(nl.item(0));
         location.appendChild(location.getOwnerDocument().createTextNode("../src2"));
-        Element sourceFile =  Util.findElement(items, "source-file", FreeformProjectType.NS_GENERAL);
+        Element sourceFile =  XMLUtil.findElement(items, "source-file", FreeformProjectType.NS_GENERAL);
         assertNotNull("have <source-file>", sourceFile);
         items.removeChild(sourceFile);
         extsrcroot.putPrimaryConfigurationData(data);
