@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -75,12 +78,16 @@ public abstract class EditorContext {
     /** Annotation type constant. */
     public static final String FIELD_BREAKPOINT_ANNOTATION_TYPE = "FieldBreakpoint";
     /** Annotation type constant. */
+    public static final String CLASS_BREAKPOINT_ANNOTATION_TYPE = "ClassBreakpoint";
+    /** Annotation type constant. */
     public static final String DISABLED_FIELD_BREAKPOINT_ANNOTATION_TYPE = "DisabledFieldBreakpoint";
     /** Annotation type constant. */
     public static final String METHOD_BREAKPOINT_ANNOTATION_TYPE = "MethodBreakpoint";
     /** Annotation type constant. */
     public static final String DISABLED_METHOD_BREAKPOINT_ANNOTATION_TYPE = "DisabledMethodBreakpoint";
     /** Annotation type constant. */
+    public static final String DISABLED_CLASS_BREAKPOINT_ANNOTATION_TYPE = "DisabledClassBreakpoint";
+    /** Annotation type constant. */
     public static final String CURRENT_LINE_ANNOTATION_TYPE = "CurrentPC";
     /** Annotation type constant. */
     public static final String CALL_STACK_FRAME_ANNOTATION_TYPE = "CallSite";
@@ -492,6 +499,7 @@ public abstract class EditorContext {
         private Position methodStartPosition;
         private Position methodEndPosition;
         private String methodName;
+        private String methodDescriptor; // TODO: Add API get/set, accessed through reflection in the meantime.
         private String methodClassType;
         private Variable returnValue;
         
@@ -694,6 +702,8 @@ public abstract class EditorContext {
          * @param endPos Ending position of the argument in the source code
          */
         public MethodArgument(String name, String type, Position startPos, Position endPos) {
+            assert name != null;
+            assert type != null;
             this.name = name;
             this.type = type;
             this.startPos = startPos;
