@@ -113,7 +113,11 @@ public final class ActionsManager {
      * @since 1.24 */
     public static final Object              ACTION_NEW_WATCH = "newWatch";
 
-    
+    /** Action constant for Evaluate Action.
+     *  @since 1.29 */
+    public static final Object              ACTION_EVALUATE = "evaluate";
+
+
     // variables ...............................................................
     
     private Vector                  listener = new Vector ();
@@ -457,6 +461,10 @@ public final class ActionsManager {
         for (i = 0; i < k; i++) {
             LazyActionsManagerListener l = (LazyActionsManagerListener)
                 lazyListeners.get (i);
+            if (l == null) {
+                // instance could not be created.
+                continue;
+            }
             String[] props = l.getProperties ();
             if (props == null) {
                 addActionsManagerListener (l);
@@ -475,6 +483,10 @@ public final class ActionsManager {
         for (i = 0; i < k; i++) {
             LazyActionsManagerListener l = (LazyActionsManagerListener)
                 lazyListeners.get (i);
+            if (l == null) {
+                // instance could not be created.
+                continue;
+            }
             String[] props = l.getProperties ();
             if (props == null) {
                 removeActionsManagerListener (l);
