@@ -84,6 +84,7 @@ import org.openide.util.WeakListeners;
 import org.openide.util.WeakSet;
 import org.openide.util.lookup.Lookups;
 import org.openide.util.Lookup.Result;
+import org.openide.util.lookup.AbstractLookup;
 
 
 /**
@@ -100,6 +101,8 @@ abstract class Lookup implements ContextProvider {
     public static final String NOTIFY_LOAD_LAST = "load last";
     public static final String NOTIFY_UNLOAD_FIRST = "unload first";
     public static final String NOTIFY_UNLOAD_LAST = "unload last";
+
+    private static final Logger logger = Logger.getLogger(Lookup.class.getName());
     
     public <T> T lookupFirst(String folder, Class<T> service) {
         List<? extends T> l = lookup(folder, service);
@@ -225,6 +228,8 @@ abstract class Lookup implements ContextProvider {
         private String rootFolder;
         private final Map<String,List<String>> registrationCache = new HashMap<String,List<String>>();
         private final HashMap<String, Object> instanceCache = new HashMap<String, Object>();
+        private final HashMap<String, Object> origInstanceCache = new HashMap<String, Object>();
+        private final HashMap<String, Item> lookupItemsCache = new HashMap<String, Item>();
         private Lookup context;
         private org.openide.util.Lookup.Result<ModuleInfo> moduleLookupResult;
         private ModuleChangeListener modulesChangeListener;
@@ -391,6 +396,15 @@ abstract class Lookup implements ContextProvider {
                         Object instance = instanceCache.get(clazz);
                         if (instance.getClass().getClassLoader() == cl) {
                             instanceCache.remove(clazz);
+                            origInstanceCache.remove(clazz);
+                            lookupItemsCache.remove(clazz);
+                        } else {
+                            instance = origInstanceCache.get(clazz);
+                            if (instance != null && instance.getClass().getClassLoader() == cl) {
+                                instanceCache.remove(clazz);
+                                origInstanceCache.remove(clazz);
+                                lookupItemsCache.remove(clazz);
+                            }
                         }
                     }
                 }
@@ -516,7 +530,12 @@ abstract class Lookup implements ContextProvider {
                 assert service != null;
                 this.service = service;
                 fillInstances(l, lr, s);
-                listenOnDisabledModules();
+                RP.post(new Runnable() {
+                    public void run() {
+                        // This may take a while...
+                        listenOnDisabledModules();
+                    }
+                });
             }
             
             private void fillInstances(List<String> l, Result<T> lr, Set<String> s) {
@@ -532,7 +551,8 @@ abstract class Lookup implements ContextProvider {
                     //System.err.println("ID = '"+li.getId()+"' => serviceName = '"+serviceName+"'");
                     // We do not recognize method calls correctly
                     if (s != null && (s.contains (serviceName) || s.contains (serviceName+"()"))) continue;
-                    add(new LazyInstance<T>(service, li));
+                    //add(new LazyInstance<T>(service, li));
+                    fillServiceInstance(li);
                 }
                 /*
                 for (Object lri : lr.allInstances()) {
@@ -567,7 +587,7 @@ abstract class Lookup implements ContextProvider {
                     try {
                         add(service.cast(instance), className);
                     } catch (ClassCastException cce) {
-                        Logger.getLogger(Lookup.class.getName()).log(Level.WARNING, null, cce);
+                        logger.log(Level.WARNING, null, cce);
                     }
                     listenOn(instance.getClass().getClassLoader());
                 } else if (checkClassName(className)) {
@@ -575,6 +595,63 @@ abstract class Lookup implements ContextProvider {
                 }
             }
 
+            private String getClassName(Item li) {
+                String id = li.getId();
+                int i = id.lastIndexOf("/");
+                if (i >= 0) id = id.substring(i+1);
+                return id.replace('-', '.');
+            }
+
+            private void fillServiceInstance(Item<T> li) {
+                String className = getClassName(li);
+                Object instance = null;
+                synchronized(instanceCache) {
+                    instance = instanceCache.get (className);
+                    Object origInstance = origInstanceCache.get(className);
+                    Item lastItem = lookupItemsCache.get(className);
+                    if (origInstance != null && li instanceof AbstractLookup.Pair &&
+                        lastItem != null && lastItem.getId().equals(li.getId())) {
+                        // Check whether the cached original instance was created by this lookup item.
+                        // If yes, we can use it, if not, we should create a new instance.
+                        // Verify whether the item is from the same registry file,
+                        // since there can be several registrations for one class instance.
+                        try {
+                            java.lang.reflect.Method creatorOfMethod = AbstractLookup.Pair.class.getDeclaredMethod("creatorOf", Object.class);
+                            creatorOfMethod.setAccessible(true);
+                            Object isCreator = creatorOfMethod.invoke(li, origInstance);
+                            if (logger.isLoggable(Level.FINE)) {
+                                logger.fine("fillServiceInstance("+li+" [HASH = "+System.identityHashCode(li)+"]):");
+                                logger.fine("  className = \""+className+"\", orig instance = "+origInstance+", instance = "+instance+", is creator of = "+isCreator);
+                                if (lastItem != null) {
+                                    logger.fine("  last item was "+lastItem+" [HASH = "+System.identityHashCode(lastItem)+"])");
+                                }
+                                if (!Boolean.TRUE.equals(isCreator)) {
+                                    logger.fine("\n!!!\n"+li+" is not a creator of "+origInstance+" !\nCreating a new instance...");
+                                }
+                            }
+                            if (!Boolean.TRUE.equals(isCreator)) {
+                                instance = null;
+                                instanceCache.remove(className);
+                                origInstanceCache.remove(className);
+                                lookupItemsCache.remove(className);
+                            }
+                        } catch (Exception ex) {
+                            Exceptions.printStackTrace(ex);
+                        }
+                    }
+                }
+                if (instance != null) {
+                    try {
+                        add(service.cast(instance), className);
+                    } catch (ClassCastException cce) {
+                        logger.log(Level.WARNING, null, cce);
+                    }
+                    listenOn(instance.getClass().getClassLoader());
+                } else {
+                    add(new LazyInstance<T>(service, li));
+                }
+            }
+
             private boolean checkClassName(String service) {
                 //String method = null;
                 if (service.endsWith("()")) {
@@ -683,13 +760,32 @@ abstract class Lookup implements ContextProvider {
                 protected T getEntry() {
                     Object instance = null;
                     if (lookupItem != null) {
-                        instance = lookupItem.getInstance();
-                        //System.err.println("Lookup.LazyInstance.getEntry(): have instance = "+instance+" for lookupItem = "+lookupItem);
-                        if (instance instanceof ContextAwareService) {
-                            ContextAwareService cas = (ContextAwareService) instance;
-                            instance = cas.forContext(Lookup.MetaInf.this.context);
-                            //System.err.println("  "+cas+".forContext("+Lookup.MetaInf.this.context+") = "+instance);
-                            lookupItem = null;
+                        String cn = getClassName(lookupItem);
+                        synchronized (instanceCreationLock) {
+                            synchronized(instanceCache) {
+                                instance = instanceCache.get (cn);
+                            }
+                            if (instance == null) {
+                                instance = lookupItem.getInstance();
+                                Object origInstance = instance;
+                                //System.err.println("Lookup.LazyInstance.getEntry(): have instance = "+instance+" for lookupItem = "+lookupItem);
+                                Item lookupItemToCache = lookupItem;
+                                if (instance instanceof ContextAwareService) {
+                                    ContextAwareService cas = (ContextAwareService) instance;
+                                    instance = cas.forContext(Lookup.MetaInf.this.context);
+                                    //System.err.println("  "+cas+".forContext("+Lookup.MetaInf.this.context+") = "+instance);
+                                    lookupItem = null;
+                                }
+                                synchronized (instanceCache) {
+                                    instanceCache.put (cn, instance);
+                                    origInstanceCache.put(cn, origInstance);
+                                    // Hold the lookup item.
+                                    // This is holding the underlying instance data object,
+                                    // and prevents from it's GC and therefore from creating
+                                    // a new instance later on (the new Item.creatorOf() would return false)
+                                    lookupItemsCache.put(cn, lookupItemToCache);
+                                }
+                            }
                         }
                     }
                     if (instance == null) {
