@@ -69,6 +69,8 @@ import java.util.Set;
 import java.util.WeakHashMap;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import org.netbeans.api.annotations.common.CheckForNull;
+import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.modules.java.classpath.ClassPathAccessor;
 import org.netbeans.modules.java.classpath.SimplePathResourceImplementation;
 import org.netbeans.spi.java.classpath.ClassPathImplementation;
@@ -277,13 +279,50 @@ public final class ClassPath {
 
     private FileObject[] createRoots (final List<ClassPath.Entry> entries) {
         final List<FileObject> l = new ArrayList<FileObject> ();
-        final Set<URL> listenOn = new HashSet<URL>();
+        final Set<File> listenOn = new HashSet<File>();
         for (Entry entry : entries) {
-            listenOn.add(entry.getURL());
             FileObject fo = entry.getRoot();
+            File file = null;
             if (fo != null) {
                 l.add(fo);
                 root2Filter.put(fo, entry.filter);
+                FileObject fileFo = FileUtil.getArchiveFile(fo);
+                if (fileFo  == null) {
+                    fileFo = fo;
+                }
+                file = FileUtil.toFile(fileFo);
+            }
+            if (file == null) {
+                URL url = entry.getURL();
+                if ("jar".equals(url.getProtocol())) { //NOI18N
+                    url = FileUtil.getArchiveFile(url);
+                }
+                if (!"file".equals(url.getProtocol())) { // NOI18N
+                    // Try to convert nbinst to file
+                    FileObject fileFo = URLMapper.findFileObject(url);
+                    if (fileFo != null) {
+                        URL external = URLMapper.findURL(fileFo, URLMapper.EXTERNAL);
+                        if (external != null) {
+                            url = external;
+                        }
+                    }
+                }
+                try {
+                    //todo: Ignore non file urls, we can try to url->fileobject->url
+                    //if it becomes a file.
+                    if ("file".equals(url.getProtocol())) { //NOI18N
+                        file = FileUtil.normalizeFile(new File(url.toURI()));
+                    }
+                } catch (IllegalArgumentException e) {
+                    LOG.log(Level.WARNING, "Unexpected URL <{0}>: {1}", new Object[] {url, e});
+                    //pass
+                } catch (URISyntaxException e) {
+                    LOG.log(Level.WARNING, "Invalid URL: {0}", url);
+                    //pass
+                }
+            }
+            if (file != null) {
+                listenOn.add(file);
             }
         }
         final RootsListener rL = this.getRootsListener();
@@ -488,7 +527,7 @@ public final class ClassPath {
      * if the resource is not within the ClassPath contents.
      * @param resource resource to find root for.
      */
-    public final FileObject findOwnerRoot(FileObject resource) {
+    public final @CheckForNull FileObject findOwnerRoot(FileObject resource) {
 	FileObject[] roots = getRoots();
         Set<FileObject> rootsSet = new HashSet<FileObject>(Arrays.asList(roots));
         for (FileObject f = resource; f != null; f = f.getParent()) {
@@ -583,7 +622,7 @@ public final class ClassPath {
      *         there is no classpath available
      * @see ClassPathProvider
      */
-    public static ClassPath getClassPath(FileObject f, String id) {
+    public static @CheckForNull ClassPath getClassPath(@NonNull FileObject f, @NonNull String id) {
         if (f == null) {
             // What else can we do?? Backwards compatibility only.
             Thread.dumpStack();
@@ -629,12 +668,13 @@ public final class ClassPath {
         WARN,
         /**
          * {@link #toString(ClassPath.PathConversionMode)} will fail with an {@link IllegalArgumentException}.
+         * Useful for unit tests.
          */
         FAIL,
         /**
          * The entry is simply displayed as a URL.
-         * Useful for debug logging or unit tests.
-         * Used by {@link ClassPath#toString}.
+         * Useful for logging.
+         * @see ClassPath#toString()
          */
         PRINT,
     }
@@ -681,6 +721,10 @@ public final class ClassPath {
         return b.toString();
     }
 
+    /**
+     * Calls {@link #toString(ClassPath.PathConversionMode)} with {@link ClassPath.PathConversionMode#PRINT}.
+     * @return a classpath suitable for logging or debugging
+     */
     public @Override String toString() {
         return toString(PathConversionMode.PRINT);
     }
@@ -694,11 +738,12 @@ public final class ClassPath {
      * may be propagated between ClassPaths.
      */
     public final class Entry {
-
+                        
         private final URL url;
-        private FileObject root;
+        private volatile FileObject root;
         private IOException lastError;
         private FilteringPathResourceImplementation filter;
+        /*unit test*/ Boolean isDataResult;
 
         /**
          * Returns the ClassPath instance, which defines/introduces the Entry.
@@ -717,27 +762,50 @@ public final class ClassPath {
          * @return classpath entry root folder
          */
         public  FileObject  getRoot() {
-            synchronized (this) {
-                if (root != null && root.isValid()) {
+            FileObject _root = root;
+            if (_root != null && _root.isValid()) {
+                return _root;
+            }
+            for (int retryCount = 0; retryCount<=1; retryCount++) { //Bug 193086 : try to do refresh
+                _root = URLMapper.findFileObject(this.url);            
+                synchronized (this) {
+                    if (root == null || !root.isValid()) {
+                        if (_root == null) {
+                            this.lastError = new IOException(MessageFormat.format("The package root {0} does not exist or can not be read.",
+                                new Object[] {this.url}));
+                            return null;
+                        } else if (isData(_root)) {
+                            if (retryCount == 0) {
+                                _root.refresh();
+                                continue;
+                            } else {
+                                String fileState = null;
+                                try {
+                                    final File file = new File(this.url.toURI());
+                                    fileState = "(exists: " + file.exists() +           //NOI18N
+                                                " file: " + file.isFile() +             //NOI18N
+                                                " directory: "+ file.isDirectory() +    //NOI18N
+                                                " read: "+ file.canRead() +             //NOI18N
+                                                " write: "+ file.canWrite()+        //NOI18N
+                                                " root: "+ root +        //NOI18N
+                                                " _root: "+ _root +")";        //NOI18N
+                                } catch (IllegalArgumentException e) {
+                                    //Non local file - keep file null (not log file state)
+                                } catch (URISyntaxException e) {
+                                    //keep file null (not log file state)
+                                }
+                                throw new IllegalArgumentException ("Invalid ClassPath root: "+this.url+". The root must be a folder." + //NOI18N
+                                        (fileState != null ? fileState : ""));
+                            }
+                        } else {
+                            root = _root;                            
+                        }
+                    }
                     return root;
                 }
             }
-            FileObject _root = URLMapper.findFileObject(this.url);            
-            synchronized (this) {
-                if (root == null || !root.isValid()) {
-                    if (_root == null) {
-                        this.lastError = new IOException(MessageFormat.format("The package root {0} does not exist or can not be read.",
-                            new Object[] {this.url}));
-                        return null;
-                    }
-                    else if (_root.isData()) {
-                        throw new IllegalArgumentException ("Invalid ClassPath root: "+this.url+". The root must be a folder.");
-                    }
-                    root = _root;
-                }
-                return root;
-            }
-        }
+            return null;            
+        }        
 
         /**
          * @return true, iff the Entry refers to an existing and readable
@@ -859,6 +927,16 @@ public final class ClassPath {
         public int hashCode () {
             return this.url == null ? 0 : this.url.hashCode();
         }
+        
+        private synchronized boolean isData(final FileObject fo) {
+            if (isDataResult != null) {
+                boolean res = isDataResult;
+                isDataResult = null;
+                return res;
+            } else {
+                return fo.isData();
+            }
+        }
     }
 
     //-------------------- Implementation details ------------------------//
@@ -957,7 +1035,11 @@ public final class ClassPath {
                 try {
                     if (f != null) {
                         String path = FileUtil.getRelativePath(roots[ridx], f);
-                        assert path != null;
+                        assert path != null : String.format("FileUtil.getRelativePath(%s(%b),%s(%b)) returned null",
+                                FileUtil.getFileDisplayName(roots[ridx]),
+                                roots[ridx].isValid(),
+                                FileUtil.getFileDisplayName(f),
+                                f.isValid());
                         if (f.isFolder()) {
                             path += "/"; // NOI18N
                         }
@@ -1070,37 +1152,9 @@ public final class ClassPath {
             roots = new HashSet<File> ();
         }
 
-        public void addRoots (final Set<? extends URL> urls) {
-            Parameters.notNull("urls",urls);    //NOI18N
-            final Set<File> newRoots = new HashSet<File>();
-            for (URL url : urls) {
-                if ("jar".equals(url.getProtocol())) { //NOI18N
-                    url = FileUtil.getArchiveFile(url);
-                }
-                if (!"file".equals(url.getProtocol())) { // NOI18N
-                    // Try to convert nbinst to file
-                    FileObject file = URLMapper.findFileObject(url);
-                    if (file != null) {
-                        URL external = URLMapper.findURL(file, URLMapper.EXTERNAL);
-                        if (external != null) {
-                            url = external;
-                        }
-                    }
-                }
-                try {
-                    //todo: Ignore non file urls, we can try to url->fileobject->url
-                    //if it becomes a file.
-                    if ("file".equals(url.getProtocol())) { //NOI18N
-                        newRoots.add(new File(url.toURI()));
-                    }
-                } catch (IllegalArgumentException e) {
-                    LOG.log(Level.WARNING, "Unexpected URL <{0}>: {1}", new Object[] {url, e});
-                    //pass
-                } catch (URISyntaxException e) {
-                    LOG.log(Level.WARNING, "Invalid URL: {0}", url);
-                    //pass
-                }
-            }
+        public void addRoots (final Set<? extends File> newRoots) {
+            Parameters.notNull("urls",newRoots);    //NOI18N
+
             synchronized (this) {
                 final Set<File> toRemove = new HashSet<File>(roots);
                 toRemove.removeAll(newRoots);
