@@ -785,5 +785,16 @@ public class ClassPathTest extends NbTestCase {
             fail();
         } catch (IllegalArgumentException x) {/* right */}
     }
+    
+    public void testEntryGetRoot() throws Exception {
+        final File wd = getWorkDir();
+        final FileObject root = FileUtil.createFolder(new File(wd,"root"));
+        final ClassPath cp = ClassPathSupport.createClassPath(root);
+        final ClassPath.Entry entry = cp.entries().iterator().next();
+        entry.isDataResult = Boolean.TRUE;
+        final FileObject fo = entry.getRoot();
+        assertNotNull(fo);
+        assertEquals(root, fo);
+    }
 
 }
