@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -543,7 +546,7 @@ public class Widget implements Accessible {
      * @return the background paint
      */
     public final Paint getBackground () {
-        return background != null ? background : parentWidget.getBackground ();
+        return background != null ? background : parentWidget != null ? parentWidget.getBackground () : null;
     }
 
     /**
@@ -615,7 +618,7 @@ public class Widget implements Accessible {
      * @return the foreground color
      */
     public final Color getForeground () {
-        return foreground != null ? foreground : parentWidget.getForeground ();
+        return foreground != null ? foreground : parentWidget != null ? parentWidget.getForeground () : null;
     }
 
     /**
@@ -1405,7 +1408,8 @@ public class Widget implements Accessible {
             gr.clip (bounds);
         }
 
-        if (! checkClipping  ||  bounds.intersects (gr.getClipBounds ())) {
+        Rectangle clipBounds;
+        if (! checkClipping  ||  (clipBounds = gr.getClipBounds ()) == null   ||  bounds.intersects (clipBounds)) {
             if (opaque)
                 paintBackground ();
 
@@ -1450,6 +1454,8 @@ public class Widget implements Accessible {
 
     /**
      * Called to paint the widget itself only using the Graphics2D instance acquired from Scene.getGraphics method.
+     * Do not call methods which modify state of the widget (all methods which calls revalidate like setFont(),
+     * setVisible(), setLayout(),...). It can cause another repaint and result in infinite paint cycle.
      */
     protected void paintWidget () {
     }
@@ -1464,7 +1470,7 @@ public class Widget implements Accessible {
                 Point location = child.getLocation ();
                 Rectangle bounds = child.getBounds ();
                 bounds.translate (location.x, location.y);
-                if (bounds.intersects (clipBounds))
+                if (clipBounds == null  ||  bounds.intersects (clipBounds))
                     child.paint ();
             }
         } else
@@ -1476,6 +1482,7 @@ public class Widget implements Accessible {
      * Returns the object hash code.
      * @return the object hash code
      */
+    @Override
     public final int hashCode () {
         return super.hashCode ();
     }
@@ -1485,6 +1492,7 @@ public class Widget implements Accessible {
      * @param object the object
      * @return true if the object reference is the same as the widget
      */
+    @Override
     public final boolean equals (Object object) {
         return this == object;
     }
