@@ -104,6 +104,7 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
     
     public static final String CP = "cp";
     public static final String NBJDK_BOOTCLASSPATH = "nbjdk.bootclasspath";
+    static final String NBJDK_HOME = "nbjdk.home"; // NOI18N
     public static final String RUN_CP = "run.cp";
     
     private final NbModuleProject project;
@@ -358,19 +359,9 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
 
         // 'cluster' prop. evaluation without scanned ModuleList
         String codeNameBase = project.getCodeNameBase();
-        String clusterDir = null;
         PropertyEvaluator suiteEval = null;
-        try {
-            clusterDir = ModuleList.findClusterLocation(dir, nbroot, type);
-        } catch (IOException ex) {
-            Logger.getLogger(this.getClass().getName()).log(Level.INFO, null, ex);
-        }
         if (type == NbModuleProvider.SUITE_COMPONENT) {
             suiteEval = PropertyUtils.sequentialPropertyEvaluator(predefs, providers.toArray(new PropertyProvider[providers.size()]));
-            clusterDir = FileUtil.normalizeFile(new File(suiteEval.evaluate(clusterDir))).getAbsolutePath();
-        }
-        if (clusterDir != null) {
-            providers.add(PropertyUtils.fixedPropertyProvider(Collections.singletonMap("cluster", clusterDir)));
         }
 
         if (type == NbModuleProvider.SUITE_COMPONENT) {
@@ -426,23 +417,31 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
         defaults.put("module.jar", "${module.jar.dir}/${module.jar.basename}"); // NOI18N
         defaults.put("manifest.mf", "manifest.mf"); // NOI18N
         defaults.put("src.dir", "src"); // NOI18N
-        defaults.put("build.classes.dir", "build/classes"); // NOI18N
+        defaults.put("build.dir", "build"); // NOI18N
+        defaults.put("build.classes.dir", "${build.dir}/classes"); // NOI18N
+        defaults.put("release.dir", "release"); // NOI18N
         defaults.put(SingleModuleProperties.JAVAC_SOURCE, "1.4"); // NOI18N
         if (type == NbModuleProvider.NETBEANS_ORG) {
             defaults.put("test.user.dir", "${nb_all}/nbbuild/testuserdir"); // NOI18N
         } else if (type == NbModuleProvider.STANDALONE) {
-            defaults.put("test.user.dir", "build/testuserdir"); // NOI18N
+            defaults.put("test.user.dir", "${build.dir}/testuserdir"); // NOI18N
         } else {
-            defaults.put("test.user.dir", "${suite.dir}/build/testuserdir"); // NOI18N
+            defaults.put("suite.build.dir", "${suite.dir}/build"); // NOI18N
+            defaults.put("test.user.dir", "${suite.build.dir}/testuserdir"); // NOI18N
         }
         Set<String> testTypes = new HashSet<String>(Arrays.asList(NbModuleProject.COMMON_TEST_TYPES));
         // XXX would be good to add in any other types defined in project.xml
         for (String testType : testTypes) {
             defaults.put("test." + testType + ".src.dir", "test/" + testType + "/src"); // NOI18N
             defaults.put("test." + testType + ".data.dir", "test/" + testType + "/data"); // NOI18N
-            defaults.put("build.test." + testType + ".classes.dir", "build/test/" + testType + "/classes"); // NOI18N
+            defaults.put("build.test." + testType + ".classes.dir", "${build.dir}/test/" + testType + "/classes"); // NOI18N
         }
         providers.add(PropertyUtils.fixedPropertyProvider(defaults));
+        try {
+            providers.add(PropertyUtils.fixedPropertyProvider(Collections.singletonMap("cluster", ModuleList.findClusterLocation(dir, nbroot, type)))); // NOI18N
+        } catch (IOException ex) {
+            Logger.getLogger(this.getClass().getName()).log(Level.INFO, null, ex);
+        }
         if (ml != null) {
             providers.add(PropertyUtils.fixedPropertyProvider(Collections.singletonMap("module.classpath", computeModuleClasspath(ml)))); // NOI18N
             providers.add(PropertyUtils.fixedPropertyProvider(Collections.singletonMap("module.run.classpath", computeRuntimeModuleClasspath(ml)))); // NOI18N
@@ -487,13 +486,13 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
         
         public @Override final Map<String,String> getProperties() {
             Map<String,String> props = new HashMap<String,String>();
-            String home = eval.getProperty("nbjdk.home"); // NOI18N
+            String home = eval.getProperty(NBJDK_HOME);
             if (home == null) {
                 String active = eval.getProperty("nbjdk.active"); // NOI18N
                 if (active != null && !active.equals("default")) { // NOI18N
                     home = eval.getProperty("platforms." + active + ".home"); // NOI18N
                     if (home != null) {
-                        props.put("nbjdk.home", home); // NOI18N
+                        props.put(NBJDK_HOME, home);
                     }
                 }
             }
@@ -523,7 +522,7 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
                 }
                 if (bootcp == null) {
                     if (Utilities.isMac()) {
-                        bootcp = "${nbjdk.home}/../Classes/classes.jar";    //NOI18N
+                        bootcp = "${" + NBJDK_HOME + "}/../Classes/classes.jar";    //NOI18N
                     }
                     else {
                         File jHome;
@@ -539,11 +538,11 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
                                 if (sb.length() > 0) {
                                     sb.append(File.pathSeparator);
                                 }
-                                sb.append("${nbjdk.home}/jre/lib/").append(jar);
+                                sb.append("${" + NBJDK_HOME + "}/jre/lib/").append(jar);
                             }
                             bootcp = sb.toString().replace('/', File.separatorChar); // NOI18N
                         } else {
-                            bootcp = "${nbjdk.home}/jre/lib/rt.jar".replace('/', File.separatorChar); // NOI18N
+                            bootcp = "${" + NBJDK_HOME + "}/jre/lib/rt.jar".replace('/', File.separatorChar); // NOI18N
                         }
                     }
                 }
@@ -712,14 +711,14 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
                 String nball = evaluator.getProperty("nb_all"); // NOI18N
                 testDistDir = nball + File.separatorChar + "nbbuild" + File.separatorChar + "build" + File.separatorChar + "testdist"; // NOI18N
             } else if ( type == NbModuleProvider.SUITE_COMPONENT) {
-                // test.dist.dir = ${suite.dir}/build/testdist
-                String suiteDir = evaluator.getProperty("suite.dir"); // NOI18N
-                testDistDir = suiteDir + File.separatorChar + "build" + File.separatorChar + "testdist"; // NOI18N
+                // test.dist.dir = ${suite.build.dir}/testdist
+                String suiteDir = evaluator.getProperty("suite.build.dir"); // NOI18N
+                testDistDir = suiteDir + File.separatorChar + "testdist"; // NOI18N
             } else {
                 // standalone module
-                // test.dist.dir = ${module.dir}/build/testdist
-                String moduleDir = evaluator.getProperty("module.dir"); // NOI18N
-                testDistDir = moduleDir + File.separatorChar + "build" + File.separatorChar + "testdist"; // NOI18N
+                // test.dist.dir = ${build.dir}/testdist
+                String moduleDir = evaluator.getProperty("build.dir"); // NOI18N
+                testDistDir = moduleDir + File.separatorChar + "testdist"; // NOI18N
             }
         }
         for (Map.Entry<String,Set<TestModuleDependency>> entry : testDependencies.entrySet()) {
@@ -802,32 +801,6 @@ public final class Evaluator implements PropertyEvaluator, PropertyChangeListene
             }
         }
 
-        /* debug print
-         if (ttName.equals("unit")) {
-            StringBuilder debugCPs = new StringBuilder();
-            String[] labels = {"compile", "run", "TEST compile", "TEST run"};
-            Set<?>[] cps = new Set<?>[]{compileCnbs, runtimeCnbs, testCompileCnbs, testRuntimeCnbs};
-
-            Map<String, String> processed = new HashMap<String, String>();
-            for (int i = 0; i < cps.length; i++) {
-                Set<?> cpSet = cps[i];
-                for (Object entry : cpSet) {
-                    String se = (String) entry;
-                    if (processed.containsKey(se))
-                        processed.put(se, processed.get(se) + ", " + labels[i]);
-                    else
-                        processed.put(se, labels[i]);
-                }
-            }
-            for (Map.Entry<String, String> entry : processed.entrySet()) {
-                debugCPs.append(entry.getKey());
-                debugCPs.append(": ");
-                debugCPs.append(entry.getValue());
-                debugCPs.append("\n  ");
-            }
-            Logger.getLogger(Evaluator.class.getName()).info("'" + ttName + "' CPs for '" + project.getCodeNameBase() + "':\n" + debugCPs);
-        }*/
-        
         StringBuilder extra = new StringBuilder();
         TestClasspath testClasspath = new TestClasspath(
                 mergePaths(compileCnbs,false,ttName,testDistDir, ml) + extra,
