@@ -81,6 +81,8 @@ import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.xml.namespace.NamespaceContext;
 import javax.xml.xpath.XPath;
+import org.netbeans.api.annotations.common.CheckForNull;
+import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.api.java.project.JavaProjectConstants;
 import org.netbeans.api.project.Project;
@@ -546,15 +548,12 @@ public final class Util {
     }
     
     private static URL normalizeURL(URL url) {
-        // not sure - in some private tests it seems that input
-        // jar:file:/home/..../NetBeansAPIs.zip!/..../index.html result in:
-        // http://localhost:8082/..../index.html
-//        URL resolvedURL = null;
-//        FileObject fo = URLMapper.findFileObject(url);
-//        if (fo != null) {
-//            resolvedURL = URLMapper.findURL(fo, URLMapper.EXTERNAL);
-//        }
-        return URLMapper.findFileObject(url) == null ? null : url;
+        FileObject fo = URLMapper.findFileObject(url);
+        if (fo != null) {
+            return URLMapper.findURL(fo, URLMapper.EXTERNAL);
+        } else {
+            return null;
+        }
     }
     
     private static Iterable<String> getPossibleResources(String locBundleResource) {
@@ -576,7 +575,7 @@ public final class Util {
         return resources;
     }
     
-    public static Manifest getManifest(FileObject manifestFO) {
+    public static @CheckForNull Manifest getManifest(@NullAllowed FileObject manifestFO) {
         if (manifestFO != null) {
             try {
                 InputStream is = manifestFO.getInputStream();
