@@ -2,7 +2,6 @@ package org.netbeans.modules.apisupport.project.layers;
 
 import java.io.IOException;
 import java.util.Locale;
-import org.netbeans.api.java.classpath.ClassPath;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.MultiFileSystem;
@@ -11,10 +10,9 @@ class LayerFileSystem extends MultiFileSystem {
 
     protected final BadgingSupport status;
 
-    public LayerFileSystem(final FileSystem[] layers, final ClassPath cp) {
+    public LayerFileSystem(final FileSystem[] layers) {
         super(layers);
         status = new BadgingSupport(this);
-        status.setClasspath(cp);
         status.setSuffix("_" + Locale.getDefault());
         setPropagateMasks(true);
     }
