@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -50,11 +53,11 @@ import java.util.logging.Logger;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.java.queries.SourceForBinaryQuery;
 import org.netbeans.modules.apisupport.project.NbModuleProject;
-import org.netbeans.modules.apisupport.project.Util;
 import org.netbeans.modules.apisupport.project.universe.TestEntry;
 import org.netbeans.spi.java.queries.SourceForBinaryQueryImplementation;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
+import org.openide.xml.XMLUtil;
 import org.w3c.dom.Element;
 
 /**
@@ -78,13 +81,17 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
             File binaryJarF = FileUtil.archiveOrDirForURL(binaryRoot);
             if (binaryJarF != null) {
                 FileObject srcDir = null;
+                File genSrcDirF = null;
                 if (binaryJarF.getAbsolutePath().endsWith(project.evaluator().getProperty("module.jar").replace('/', File.separatorChar))) {
                     srcDir = project.getSourceDirectory();
+                    genSrcDirF = project.getGeneratedClassesDirectory();
                 } else {
                     // maybe tests.jar in testdistribution
                     TestEntry entry = TestEntry.get(binaryJarF);
                     if (entry != null && project.getCodeNameBase().equals(entry.getCodeNameBase())) {
-                        srcDir = project.getTestSourceDirectory(entry.getTestType());
+                        String type = entry.getTestType();
+                        srcDir = project.getTestSourceDirectory(type);
+                        genSrcDirF = project.getTestGeneratedClassesDirectory(type);
                     } else {
                         // try classpath-extension
                         // // convention-over-cfg per mkleint's suggestion: <jarname>-src(.zip) folder or ZIP first
@@ -94,13 +101,13 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
                             File jFolder = new File(binaryJarF.getParentFile(),
                                     n.substring(0, n.length() - ".jar".length()) + "-src");
                             if (jFolder.isDirectory()) {
-                                res = new Result(FileUtil.toFileObject(jFolder));
+                                res = new Result(FileUtil.toFileObject(jFolder), null);
                                 cache.put(binaryRoot,res);
                                 return res;
                             } else {
                                 File jZip = new File(jFolder.getAbsolutePath() + ".zip");
                                 if (jZip.isFile()) {
-                                    res = new Result(FileUtil.getArchiveRoot(FileUtil.toFileObject(jZip)));
+                                    res = new Result(FileUtil.getArchiveRoot(FileUtil.toFileObject(jZip)), null);
                                     cache.put(binaryRoot,res);
                                     return res;
                                 }
@@ -109,7 +116,7 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
                     }
                 }
                 if (srcDir != null) {
-                    res = new Result(srcDir);
+                    res = new Result(srcDir, genSrcDirF);
                     cache.put(binaryRoot,res);
                     return res;
                 }
@@ -117,14 +124,14 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
             if (binaryRoot.equals(getClassesUrl())) {
                 FileObject srcDir = project.getSourceDirectory();
                 if (srcDir != null) {
-                    res = new Result(srcDir);
+                    res = new Result(srcDir, project.getGeneratedClassesDirectory());
                 }
             } else {
                 for (String testType : project.supportedTestTypes()) {
                     if (binaryRoot.equals(getTestClassesUrl(testType))) {
                         FileObject testSrcDir = project.getTestSourceDirectory(testType);
                         if (testSrcDir != null) {
-                            res = new Result(testSrcDir);
+                            res = new Result(testSrcDir, project.getTestGeneratedClassesDirectory(testType));
                             break;
                         }
                     }
@@ -132,11 +139,11 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
                 if (res == null) {
                 // Check extra compilation units.
                 ECUS: for (Map.Entry<FileObject,Element> entry : project.getExtraCompilationUnits().entrySet()) {
-                    for (Element kid : Util.findSubElements(entry.getValue())) {
+                    for (Element kid : XMLUtil.findSubElements(entry.getValue())) {
                         if (!kid.getLocalName().equals("built-to")) { // NOI18N
                             continue;
                         }
-                        String rawtext = Util.findText(kid);
+                        String rawtext = XMLUtil.findText(kid);
                         assert rawtext != null : "Null content for <built-to> in " + project;
                         String text = project.evaluator().evaluate(rawtext);
                         if (text == null) {
@@ -149,7 +156,7 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
                                     "In " + FileUtil.getFileDisplayName(project.getProjectDirectory()) +
                                     " " + loc + " is neither a directory nor a JAR");
                         } else if (u.equals(binaryRoot)) {
-                            res = new Result(entry.getKey());
+                            res = new Result(entry.getKey(), null);
                             break ECUS;
                         }
                     }
@@ -182,15 +189,20 @@ public final class SourceForBinaryImpl implements SourceForBinaryQueryImplementa
     
     private static class Result implements SourceForBinaryQuery.Result {
                
-        private FileObject res;
+        private FileObject[] res;
         
-        public Result(FileObject res) {
+        public Result(FileObject res, File other) {
             assert res != null;
-            this.res = res;
+            FileObject otherFO = other != null ? FileUtil.toFileObject(other) : null;
+            if (otherFO != null) {
+                this.res = new FileObject[] {res, otherFO};
+            } else {
+                this.res = new FileObject[] {res};
+            }
         }
         
         public FileObject[] getRoots () {
-            return new FileObject[] {res};
+            return res;
         }
         
         public void addChangeListener (ChangeListener l) {
