@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,9 +44,15 @@
 
 package org.netbeans.modules.apisupport.project.queries;
 
+import java.io.IOException;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
+import org.netbeans.api.project.Project;
+import org.netbeans.modules.apisupport.project.NbModuleProject;
+import org.netbeans.modules.apisupport.project.spi.NbModuleProvider.NbModuleType;
+import org.netbeans.modules.apisupport.project.suite.SuiteProject;
+import org.netbeans.modules.apisupport.project.ui.customizer.SuiteUtils;
 import org.netbeans.spi.project.support.ant.AntProjectHelper;
 import org.netbeans.spi.project.support.ant.EditableProperties;
 import org.openide.loaders.CreateFromTemplateAttributesProvider;
@@ -54,21 +63,36 @@ import org.openide.loaders.DataObject;
  * Specifies license header for module and suite projects.
  */
 public class TemplateAttributesProvider implements CreateFromTemplateAttributesProvider {
-
+    private final NbModuleProject project;
     private final AntProjectHelper helper;
-    private final boolean netBeansOrg;
+    private final boolean netbeansOrg;
 
-    public TemplateAttributesProvider(AntProjectHelper helper, boolean netBeansOrg) {
+    public TemplateAttributesProvider(NbModuleProject p, AntProjectHelper helper, boolean netbeansOrg) {
+        this.project = p;
         this.helper = helper;
-        this.netBeansOrg = netBeansOrg;
+        this.netbeansOrg = netbeansOrg;
     }
 
+    @Override
     public Map<String,?> attributesFor(DataObject template, DataFolder target, String name) {
         EditableProperties props = helper.getProperties(AntProjectHelper.PROJECT_PROPERTIES_PATH);
         String license = props.getProperty("project.license"); // NOI18N
-        if (license == null && netBeansOrg) {
+
+        if (license == null && netbeansOrg) {
             license = "cddl-netbeans-sun"; // NOI18N
         }
+        if (license == null && project != null) {
+            SuiteProject sp;
+            try {
+                sp = SuiteUtils.findSuite(project);
+                if (sp != null) {
+                    TemplateAttributesProvider tap = sp.getLookup().lookup(TemplateAttributesProvider.class);
+                    return tap.attributesFor(template, target, name);
+                }
+            } catch (IOException ex) {
+                // OK, ignore
+            }
+        }
         Map<String, String> values = new HashMap<String, String>();
         if (license != null) {
             values.put("license", license); // NOI18N
