@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -61,6 +64,8 @@ import org.openide.util.RequestProcessor;
  * Would be nice to have available as a separate API. Here used for ImportantFilesNode.
  */
 class AnnotatedNode extends AbstractNode implements Runnable, FileStatusListener {
+
+    private static final RequestProcessor RP = new RequestProcessor(AnnotatedNode.class.getName());
     
     private Set<FileObject> files;
     private Set<FileStatusListener> fileSystemListeners;
@@ -138,7 +143,7 @@ class AnnotatedNode extends AbstractNode implements Runnable, FileStatusListener
     
     public final void annotationChanged(FileStatusEvent event) {
         if (task == null) {
-            task = RequestProcessor.getDefault().create(this);
+            task = RP.create(this);
         }
         
         boolean changed = false;
