@@ -46,6 +46,7 @@ package org.netbeans.modules.apisupport.project.ui;
 import java.awt.Dialog;
 import java.awt.Image;
 import java.awt.event.ActionEvent;
+import java.io.CharConversionException;
 import java.io.File;
 import java.io.IOException;
 import java.net.URL;
@@ -109,6 +110,7 @@ import org.openide.util.actions.CookieAction;
 import org.openide.util.actions.SystemAction;
 import org.openide.util.lookup.Lookups;
 import org.openide.util.lookup.ProxyLookup;
+import org.openide.xml.XMLUtil;
 
 /**
  * @author Martin Krauskopf
@@ -116,6 +118,7 @@ import org.openide.util.lookup.ProxyLookup;
 final class LibrariesNode extends AbstractNode {
 
     private static final Logger LOG = Logger.getLogger(LibrariesNode.class.getName());
+    private static final RequestProcessor RP = new RequestProcessor(LibrariesNode.class);
 
     static final String LIBRARIES_NAME = "libraries"; // NOI18N
     private static final String DISPLAY_NAME = getMessage("LBL_libraries");
@@ -355,6 +358,17 @@ final class LibrariesNode extends AbstractNode {
             setShortDescription(LibrariesNode.createHtmlDescription(dep));
         }
 
+        public @Override String getHtmlDisplayName() {
+            if (dep.getModuleEntry().isDeprecated()) {
+                try {
+                    return "<s>" + XMLUtil.toElementContent(getDisplayName()) + "</s>"; // NOI18N
+                } catch (CharConversionException x) {
+                    // ignore
+                }
+            }
+            return null;
+        }
+
         public Action[] getActions(boolean context) {
             return new Action[]{
                         SystemAction.get(OpenProjectAction.class),
@@ -390,6 +404,17 @@ final class LibrariesNode extends AbstractNode {
             setShortDescription(LibrariesNode.createHtmlDescription(dep));
         }
 
+        public @Override String getHtmlDisplayName() {
+            if (dep.getModuleEntry().isDeprecated()) {
+                try {
+                    return "<s>" + XMLUtil.toElementContent(getDisplayName()) + "</s>"; // NOI18N
+                } catch (CharConversionException x) {
+                    // ignore
+                }
+            }
+            return null;
+        }
+
         public Action[] getActions(boolean context) {
             return new Action[]{
                         new EditDependencyAction(dep.getModuleEntry().getCodeNameBase(), project),
@@ -547,9 +572,8 @@ final class LibrariesNode extends AbstractNode {
                     assert project != null;
                     projects[i] = project;
                 }
-                RequestProcessor.getDefault().post(new Runnable() {
-
-                    public void run() {
+                RP.post(new Runnable() {
+                    public @Override void run() {
                         StatusDisplayer.getDefault().setStatusText(
                                 getMessage("MSG_OpeningProjects"));
                         OpenProjects.getDefault().open(projects, false);
