@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.modules.apisupport.project.ui.customizer;
 
+import org.netbeans.modules.apisupport.project.ModuleDependency;
 import java.text.Collator;
 import java.util.ArrayList;
 import java.util.LinkedHashSet;
@@ -66,6 +70,9 @@ final class AddModuleFilter {
         this.dependingModuleCNB = dependingModuleCNB;
         // Prime the cache:
         for (ModuleDependency dep : universe) {
+            if (Thread.interrupted()) {
+                break;
+            }
             dep.getFilterTokens(dependingModuleCNB);
         }
         // To test "Please wait" use:
@@ -83,6 +90,9 @@ final class AddModuleFilter {
             matches.add(new TreeSet<ModuleDependency>(ModuleDependency.LOCALIZED_NAME_COMPARATOR));
         }
         for (ModuleDependency dep : universe) {
+            if (Thread.interrupted()) {
+                break;
+            }
             int matchLevel = 3;
             for (String tok : dep.getFilterTokens(dependingModuleCNB)) {
                 String token = tok.toLowerCase(Locale.ENGLISH);
