@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.modules.apisupport.project.ui.customizer;
 
+import org.netbeans.modules.apisupport.project.ModuleDependency;
 import java.awt.Color;
 import java.awt.Dialog;
 import java.awt.EventQueue;
@@ -86,6 +90,7 @@ import org.openide.util.RequestProcessor;
 public final class AddModulePanel extends JPanel {
     
     private static final String FILTER_DESCRIPTION = getMessage("LBL_FilterDescription");
+    private static final RequestProcessor RP = new RequestProcessor(AddModulePanel.class.getName(), 1, true);
     private static Rectangle lastSize;
     
     private CustomizerComponentFactory.DependencyListModel universeModules;
@@ -195,7 +200,7 @@ public final class AddModulePanel extends JPanel {
             }
         }
     }
-    
+
     private void fillUpUniverseModules() {
         filterValue.setEnabled(false);
         moduleList.setEnabled(false);
@@ -292,12 +297,22 @@ public final class AddModulePanel extends JPanel {
         }
         return deps;
     }
+
+    public @Override void removeNotify() {
+        super.removeNotify();
+        cancelFilterTask();
+    }
     
-    private void search() {
+    private synchronized void cancelFilterTask() {
         if (filterTask != null) {
             filterTask.cancel();
             filterTask = null;
+            filterer = null;
         }
+    }
+
+    private void search() {
+        cancelFilterTask();
         final String text = filterValue.getText();
         if (text.length() == 0) {
             moduleList.setModel(universeModules);
@@ -305,11 +320,16 @@ public final class AddModulePanel extends JPanel {
             moduleList.ensureIndexIsVisible(0);
         } else {
             final Runnable compute = new Runnable() {
-                public void run() {
+                public @Override void run() {
+                    if (filterer == null) {
+                        return;
+                    }
                     final Set<ModuleDependency> matches = filterer.getMatches(text);
-                    filterTask = null;
+                    synchronized (AddModulePanel.this) {
+                        filterTask = null;
+                    }
                     Mutex.EVENT.readAccess(new Runnable() {
-                        public void run() {
+                        public @Override void run() {
                             // XXX would be better to have more fine-grained control over the thread
                             if (!text.equals(filterValue.getText())) {
                                 return; // no longer valid, don't apply
@@ -325,14 +345,16 @@ public final class AddModulePanel extends JPanel {
             if (filterer == null) {
                 // Slow to create it, so show Please wait...
                 moduleList.setModel(CustomizerComponentFactory.createListWaitModel());
-                filterTask = RequestProcessor.getDefault().post(new Runnable() {
-                    public void run() {
-                        if (filterer == null) {
-                            filterer = new AddModuleFilter(universeModules.getDependencies(), props.getCodeNameBase());
+                synchronized (this) {
+                    filterTask = RP.post(new Runnable() {
+                        public @Override void run() {
+                            if (filterer == null) {
+                                filterer = new AddModuleFilter(universeModules.getDependencies(), props.getCodeNameBase());
+                            }
                             compute.run();
                         }
-                    }
-                });
+                    });
+                }
             } else {
                 // Pretty fast once we have it, so do right now and avoid flickering.
                 compute.run();
@@ -360,7 +382,7 @@ public final class AddModulePanel extends JPanel {
      * WARNING: Do NOT modify this code. The content of this method is
      * always regenerated by the Form Editor.
      */
-    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
+    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
     private void initComponents() {
         java.awt.GridBagConstraints gridBagConstraints;
 
@@ -375,20 +397,21 @@ public final class AddModulePanel extends JPanel {
         showJavadocButton = new javax.swing.JButton();
         showNonAPIModules = new javax.swing.JCheckBox();
 
+        setBorder(javax.swing.BorderFactory.createEmptyBorder(6, 6, 6, 6));
+        setPreferredSize(new java.awt.Dimension(500, 450));
         setLayout(new java.awt.GridBagLayout());
 
-        setBorder(javax.swing.BorderFactory.createEmptyBorder(6, 6, 6, 6));
-        setPreferredSize(new java.awt.Dimension(400, 400));
         moduleLabel.setLabelFor(moduleList);
-        org.openide.awt.Mnemonics.setLocalizedText(moduleLabel, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "LBL_Module"));
+        org.openide.awt.Mnemonics.setLocalizedText(moduleLabel, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "LBL_Module")); // NOI18N
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 2;
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTHWEST;
-        gridBagConstraints.insets = new java.awt.Insets(24, 0, 0, 0);
+        gridBagConstraints.insets = new java.awt.Insets(12, 0, 0, 0);
         add(moduleLabel, gridBagConstraints);
 
+        moduleSP.setPreferredSize(new java.awt.Dimension(450, 116));
         moduleSP.setViewportView(moduleList);
 
         gridBagConstraints = new java.awt.GridBagConstraints();
@@ -400,24 +423,23 @@ public final class AddModulePanel extends JPanel {
         add(moduleSP, gridBagConstraints);
 
         descLabel.setLabelFor(descValue);
-        org.openide.awt.Mnemonics.setLocalizedText(descLabel, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "LBL_Description"));
+        org.openide.awt.Mnemonics.setLocalizedText(descLabel, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "LBL_Description")); // NOI18N
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 4;
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
-        gridBagConstraints.insets = new java.awt.Insets(24, 0, 0, 0);
+        gridBagConstraints.insets = new java.awt.Insets(12, 0, 0, 0);
         add(descLabel, gridBagConstraints);
 
         filter.setLabelFor(filterValue);
-        org.openide.awt.Mnemonics.setLocalizedText(filter, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "LBL_Filter"));
+        org.openide.awt.Mnemonics.setLocalizedText(filter, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "LBL_Filter")); // NOI18N
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 0;
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
-        gridBagConstraints.insets = new java.awt.Insets(0, 0, 0, 12);
+        gridBagConstraints.insets = new java.awt.Insets(0, 0, 0, 8);
         add(filter, gridBagConstraints);
-
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 1;
         gridBagConstraints.gridy = 0;
@@ -427,6 +449,8 @@ public final class AddModulePanel extends JPanel {
         gridBagConstraints.weightx = 1.0;
         add(filterValue, gridBagConstraints);
 
+        descValueSP.setPreferredSize(new java.awt.Dimension(450, 116));
+
         descValue.setEditable(false);
         descValue.setPreferredSize(new java.awt.Dimension(6, 100));
         descValueSP.setViewportView(descValue);
@@ -439,39 +463,36 @@ public final class AddModulePanel extends JPanel {
         gridBagConstraints.weighty = 1.0;
         add(descValueSP, gridBagConstraints);
 
-        org.openide.awt.Mnemonics.setLocalizedText(showJavadocButton, java.util.ResourceBundle.getBundle("org/netbeans/modules/apisupport/project/ui/customizer/Bundle").getString("CTL_ShowJavadoc"));
+        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("org/netbeans/modules/apisupport/project/ui/customizer/Bundle"); // NOI18N
+        org.openide.awt.Mnemonics.setLocalizedText(showJavadocButton, bundle.getString("CTL_ShowJavadoc")); // NOI18N
         showJavadocButton.setEnabled(false);
         showJavadocButton.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 showJavadoc(evt);
             }
         });
-
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 6;
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
-        gridBagConstraints.insets = new java.awt.Insets(24, 0, 0, 0);
+        gridBagConstraints.insets = new java.awt.Insets(12, 0, 0, 0);
         add(showJavadocButton, gridBagConstraints);
 
-        org.openide.awt.Mnemonics.setLocalizedText(showNonAPIModules, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "CTL_ShowNonAPIModules"));
+        org.openide.awt.Mnemonics.setLocalizedText(showNonAPIModules, org.openide.util.NbBundle.getMessage(AddModulePanel.class, "CTL_ShowNonAPIModules")); // NOI18N
         showNonAPIModules.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
-        showNonAPIModules.setMargin(new java.awt.Insets(0, 0, 0, 0));
         showNonAPIModules.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(java.awt.event.ActionEvent evt) {
                 showNonAPIModulesActionPerformed(evt);
             }
         });
-
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 0;
         gridBagConstraints.gridy = 1;
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
-        gridBagConstraints.insets = new java.awt.Insets(12, 0, 0, 0);
+        gridBagConstraints.insets = new java.awt.Insets(8, 0, 0, 0);
         add(showNonAPIModules, gridBagConstraints);
-
     }// </editor-fold>//GEN-END:initComponents
     
     private void showNonAPIModulesActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showNonAPIModulesActionPerformed
