@@ -47,7 +47,6 @@ package org.netbeans.modules.apisupport.project.ui.customizer;
 import org.netbeans.modules.apisupport.project.ui.branding.BasicBrandingModel;
 import javax.swing.event.ChangeListener;
 import org.netbeans.modules.apisupport.project.universe.ClusterUtils;
-import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -59,7 +58,9 @@ import java.util.Set;
 import java.util.SortedSet;
 import java.util.StringTokenizer;
 import java.util.TreeSet;
+import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
+import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.java.platform.JavaPlatform;
 import org.netbeans.api.project.ProjectManager;
 import org.netbeans.modules.apisupport.project.NbModuleProject;
@@ -90,14 +91,13 @@ public final class SuiteProperties extends ModuleProperties {
     
     public static final String NB_PLATFORM_PROPERTY = "nbPlatform"; // NOI18N
     public static final String JAVA_PLATFORM_PROPERTY = "nbjdk.active"; // NOI18N
-    public static final String CLUSTER_DIR = "build/cluster";    // NOI18N
     public static final String ACTIVE_NB_PLATFORM_PROPERTY = "nbplatform.active";    // NOI18N
     public static final String ACTIVE_NB_PLATFORM_DIR_PROPERTY = "nbplatform.active.dir";    // NOI18N
     public static final String CLUSTER_PATH_PROPERTY = "cluster.path";    // NOI18N
     public static final String CLUSTER_PATH_WDC_PROPERTY = "cluster.path.with.disabled.clusters";    // NOI18N
     public static final String CLUSTER_SRC_PREFIX = "extcluster.";    // NOI18N
 
-    private NbPlatform activePlatform;
+    private @NullAllowed NbPlatform activePlatform;
     private JavaPlatform activeJavaPlatform;
     
     /** Project the current properties represents. */
@@ -135,7 +135,7 @@ public final class SuiteProperties extends ModuleProperties {
         refresh(subModules);
         this.disabledModules = getArrayProperty(evaluator, DISABLED_MODULES_PROPERTY);
         this.enabledClusters = getArrayProperty(evaluator, ENABLED_CLUSTERS_PROPERTY);
-        if (enabledClusters.length == 0) {
+        if (enabledClusters.length == 0 && activePlatform != null) {
             // Compatibility.
             SortedSet<String> clusters = new TreeSet<String>();
             for (ModuleEntry module : activePlatform.getModules()) {
@@ -164,15 +164,15 @@ public final class SuiteProperties extends ModuleProperties {
         return project;
     }
     
-    Map<String,String> getDefaultValues() {
+    @Override Map<String,String> getDefaultValues() {
         return Collections.emptyMap(); // no default value (yet)
     }
     
-    public NbPlatform getActivePlatform() {
+    public @CheckForNull NbPlatform getActivePlatform() {
         return activePlatform;
     }
     
-    void setActivePlatform(NbPlatform newPlaf) {
+    void setActivePlatform(@NonNull NbPlatform newPlaf) {
         NbPlatform oldPlaf = this.activePlatform;
         this.activePlatform = newPlaf;
         if (clusterPath != null) {
@@ -182,18 +182,13 @@ public final class SuiteProperties extends ModuleProperties {
             PropertyEvaluator pe = PropertyUtils.sequentialPropertyEvaluator(null,
                     PropertyUtils.fixedPropertyProvider(ep),
                     new PropertyProvider() {
-
-                        public Map<String, String> getProperties() {
+                        public @Override Map<String, String> getProperties() {
                             return getEvaluator().getProperties();
                         }
-
-                        public void addChangeListener(ChangeListener l) {
-                        }
-
-                        public void removeChangeListener(ChangeListener l) {
-                        }
+                        public @Override void addChangeListener(ChangeListener l) {}
+                        public @Override void removeChangeListener(ChangeListener l) {}
                     });
-            clusterPath = ClusterUtils.evaluateClusterPath(getProjectDirectoryFile(), pe, getActivePlatform().getDestDir());
+            clusterPath = ClusterUtils.evaluateClusterPath(getProjectDirectoryFile(), pe, newPlaf.getDestDir());
         }
         firePropertyChange(NB_PLATFORM_PROPERTY, oldPlaf, newPlaf);
     }
@@ -222,7 +217,7 @@ public final class SuiteProperties extends ModuleProperties {
         if (Arrays.asList(enabledClusters).equals(Arrays.asList(value))) {
             return;
         }
-        this.enabledClusters = value;
+        this.enabledClusters = value.clone();
         this.changedEnabledClusters = true;
     }
     
@@ -230,7 +225,7 @@ public final class SuiteProperties extends ModuleProperties {
         if (Arrays.asList(disabledModules).equals(Arrays.asList(value))) {
             return;
         }
-        this.disabledModules = value;
+        this.disabledModules = value.clone();
         this.changedDisabledModules = true;
     }
     
@@ -247,7 +242,7 @@ public final class SuiteProperties extends ModuleProperties {
         return arr == null ? new String[0] : arr;
     }
     
-    public void storeProperties() throws IOException {
+    public @Override void storeProperties() throws IOException {
         assert ProjectManager.mutex().isWriteAccess();
         NbPlatform plaf = getActivePlatform();
         ModuleProperties.storePlatform(getHelper(), plaf);
@@ -281,7 +276,7 @@ public final class SuiteProperties extends ModuleProperties {
                 }
                 ep.setProperty(ENABLED_CLUSTERS_PROPERTY, separated);
                 setProperty(ENABLED_CLUSTERS_PROPERTY, (String) null);
-                if (plaf == null || plaf.getHarnessVersion().compareTo(HarnessVersion.V50u1) < 0) {
+                if ((plaf == null || plaf.getHarnessVersion().compareTo(HarnessVersion.V50u1) < 0) && activePlatform != null) {
                     // Compatibility.
                     SortedSet<String> disabledClusters = new TreeSet<String>();
                     Set<ModuleEntry> modules = activePlatform.getModules();
@@ -338,15 +333,19 @@ public final class SuiteProperties extends ModuleProperties {
      */
     public Set<ClusterInfo> getClusterPath() {
         if (clusterPath == null) {
-            clusterPath = ClusterUtils.evaluateClusterPath(getProjectDirectoryFile(), getEvaluator(), getActivePlatform().getDestDir());
+            NbPlatform plaf = activePlatform;
+            if (plaf != null) {
+                clusterPath = ClusterUtils.evaluateClusterPath(getProjectDirectoryFile(), getEvaluator(), plaf.getDestDir());
+            }
         }
         return clusterPath;
     }
 
     public void setClusterPath(List<ClusterInfo> clusterPathList) {
         Set<ClusterInfo> newClusterPath = new LinkedHashSet<ClusterInfo>(clusterPathList);
-        if (newClusterPath.equals(getClusterPath()))
+        if (newClusterPath.equals(getClusterPath())) {
             return;
+        }
         if (clusterPath.isEmpty()) {
             // setting cluster.path for the 1st time, needs to adjust build-impl.xml of all sub-projects
             refreshBuildScripts = true;
@@ -359,17 +358,6 @@ public final class SuiteProperties extends ModuleProperties {
         return "${" + ACTIVE_NB_PLATFORM_DIR_PROPERTY + "}/" + SingleModuleProperties.clusterBaseName(cluster);
     }
 
-
-    /**
-     * Converts "raw" cluster.path entry (possibly with nbplatform.active.dir,
-     * bare cluster names and project dir-relative path) into valid absolute file path.
-     * @param rawEntry
-     * @return
-     */
-    File evaluateClusterPathEntry(String rawEntry) {
-        return ClusterUtils.evaluateClusterPathEntry(rawEntry, getProjectDirectoryFile(), getEvaluator(), getActivePlatform().getDestDir());
-    }
-
     Set<NbModuleProject> getSubModules() {
         return getModulesListModel().getSubModules();
     }
