@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -98,6 +101,7 @@ public class BasicInfoVisualPanel extends BasicVisualPanel.NewTemplatePanel
         initPlatformCombo(suitePlatformValue);
         initPanels();
         setComponentsVisibility();
+        mainProject.setSelected(!isLibraryWizard() && ModuleUISettings.getDefault().getSetAsMain());
         switch (data.getWizardType()) {
             case SUITE:
             case APPLICATION:
@@ -210,8 +214,6 @@ public class BasicInfoVisualPanel extends BasicVisualPanel.NewTemplatePanel
         manageSuitePlatform.setVisible(isSuiteWizard);
         mainProject.setVisible(!isLibraryWizard);
         
-        mainProject.setSelected(!isLibraryWizard);
-        
         if (typeChooserPanel != null){
             typeChooserPanel.setComponentsVisibility(isSuiteComponentWizard, isLibraryWizard);
         }
@@ -303,6 +305,7 @@ public class BasicInfoVisualPanel extends BasicVisualPanel.NewTemplatePanel
         getData().setProjectLocation(getLocationValue());
         getData().setProjectFolder(folderValue.getText());
         getData().setMainProject(mainProject.isSelected());
+        ModuleUISettings.getDefault().setSetAsMain(mainProject.isSelected());
         getData().setNetBeansOrg(isNetBeansOrgFolder());
         getData().setStandalone(ModuleTypePanel.isStandalone(getSettings()));
         getData().setSuiteRoot(ModuleTypePanel.getSuiteRoot(getSettings()));
@@ -567,7 +570,6 @@ public class BasicInfoVisualPanel extends BasicVisualPanel.NewTemplatePanel
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
         add(infoPanel, gridBagConstraints);
 
-        mainProject.setSelected(true);
         org.openide.awt.Mnemonics.setLocalizedText(mainProject, org.openide.util.NbBundle.getMessage(BasicInfoVisualPanel.class, "CTL_SetAsMainProject")); // NOI18N
         mainProject.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(java.awt.event.ActionEvent evt) {
