@@ -55,16 +55,15 @@ import javax.swing.JFileChooser;
 import javax.swing.JTextField;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
-import org.netbeans.modules.apisupport.project.Util;
 import org.netbeans.modules.apisupport.project.layers.LayerUtils;
 import org.netbeans.modules.apisupport.project.ui.UIUtil;
 import org.netbeans.modules.apisupport.project.ui.wizard.BasicWizardIterator;
 import org.netbeans.modules.apisupport.project.ui.wizard.options.NewOptionsIterator.DataModel;
+import org.netbeans.modules.apisupport.project.universe.ModuleEntry;
 import org.netbeans.modules.apisupport.project.universe.NbPlatform;
 import org.openide.WizardDescriptor;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileSystem;
-import org.openide.filesystems.FileUtil;
 import org.openide.util.HelpCtx;
 import org.openide.util.NbBundle;
 
@@ -158,9 +157,9 @@ final class OptionsPanel0 extends BasicWizardIterator.Panel {
     
     private void updateData() {
         NbPlatform platform = LayerUtils.getPlatformForProject(data.getProject());
-
+        ModuleEntry apimodule = platform != null ? platform.getModule("org.netbeans.modules.options.api") : null;
         //do not allow platforms older then 6.5
-        if (smallerThan110(platform.getModule("org.netbeans.modules.options.api").getSpecificationVersion())) { // NOI18N
+        if (apimodule == null || smallerThan110(apimodule.getSpecificationVersion())) { // NOI18N
             setError(NbBundle.getMessage(OptionsPanel0.class, "MSG_INVALID_PLATFORM")); // NOI18N
             return;
         }
@@ -175,15 +174,8 @@ final class OptionsPanel0 extends BasicWizardIterator.Panel {
         } else {
             assert optionsCategoryButton.isSelected();
             File icon = new File(iconField.getText());
-            FileObject iconFO = icon.isFile() ? FileUtil.toFileObject(FileUtil.normalizeFile(icon)) : null;
-            // XXX would be cleaner to use ret value from BasicDataModel.addCreateIconOperation for this:
-            String iconRel = iconFO != null ? FileUtil.getRelativePath(Util.getResourceDirectory(data.getProject()), iconFO) : null;
-            if (iconRel == null) {
-                iconRel = data.getPackageName().replace('.', '/') + "/" + icon.getName(); //NOI18N
-            }
             retCode = data.setDataForPrimaryPanel(
                     categoryNameField.getText(),
-                    iconRel,
                     icon,
                     allowSecondaryPanelsCheckBox.isSelected(),
                     primaryKwField.getText());
