@@ -59,6 +59,7 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.Locale;
 import java.util.Map;
+import java.util.MissingResourceException;
 import java.util.Properties;
 import java.util.Set;
 import java.util.SortedSet;
@@ -66,13 +67,15 @@ import java.util.TreeSet;
 import java.util.jar.JarFile;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import java.util.zip.ZipEntry;
+import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.project.ProjectManager;
 import org.netbeans.modules.apisupport.project.ManifestManager;
 import org.netbeans.modules.apisupport.project.Util;
 import org.netbeans.spi.project.support.ant.EditableProperties;
 import org.netbeans.spi.project.support.ant.PropertyUtils;
-import org.openide.ErrorManager;
 import org.openide.filesystems.FileUtil;
 import org.openide.modules.InstalledFileLocator;
 import org.openide.modules.SpecificationVersion;
@@ -133,7 +136,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
                         try {
                             PropertyUtils.putGlobalProperties(loadWithProcessing());
                         } catch (IOException e) {
-                            Util.err.notify(ErrorManager.INFORMATIONAL, e);
+                            LOG.log(Level.INFO, null, e);
                         }
                         inited = true;
                     }
@@ -238,9 +241,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
                         platforms.add(new NbPlatform(PLATFORM_ID_DEFAULT, null, loc, findHarness(loc), new URL[0], new URL[0]));
                     }
                 }
-                if (Util.err.isLoggable(ErrorManager.INFORMATIONAL)) {
-                    Util.err.log("NbPlatform initial list: " + platforms);
-                }
+                LOG.log(Level.FINE, "NbPlatform initial list: {0}", platforms);
             }
         }
         return platforms;
@@ -250,7 +251,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
      * Get the default platform.
      * @return the default platform, if there is one (usually should be)
      */
-    public static NbPlatform getDefaultPlatform() {
+    public static @CheckForNull NbPlatform getDefaultPlatform() {
         return NbPlatform.getPlatformByID(PLATFORM_ID_DEFAULT);
     }
     
@@ -262,29 +263,41 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
         // Semi-arbitrary platform* component.
         File bootJar = InstalledFileLocator.getDefault().locate("core/core.jar", "org.netbeans.core.startup", false); // NOI18N
         if (bootJar == null) {
-            if (Util.err.isLoggable(ErrorManager.INFORMATIONAL)) {
-                Util.err.log("no core/core.jar");
-            }
+            LOG.warning("no core/core.jar");
+            return null;
+        }
+        File platformCluster = bootJar.getParentFile().getParentFile();
+        if (!platformCluster.getName().startsWith("platform")) { // NOI18N
+            LOG.log(Level.WARNING, "{0} found in unexpected cluster", bootJar);
             return null;
         }
         // Semi-arbitrary harness component.
         File harnessJar = InstalledFileLocator.getDefault().locate("modules/org-netbeans-modules-apisupport-harness.jar", "org.netbeans.modules.apisupport.harness", false); // NOI18N
         if (harnessJar == null) {
-            ErrorManager.getDefault().log(ErrorManager.WARNING, "Cannot resolve default platform. " + // NOI18N
-                    "Probably either \"org.netbeans.modules.apisupport.harness\" module is missing or is corrupted."); // NOI18N
+            LOG.warning("Cannot resolve default platform. Probably either \"org.netbeans.modules.apisupport.harness\" module is missing or is corrupted.");
+            return null;
+        }
+        if (!harnessJar.getParentFile().getParentFile().getName().startsWith("harness")) { // NOI18N
+            LOG.log(Level.WARNING, "{0} found in unexpected cluster", harnessJar);
             return null;
         }
         File loc = harnessJar.getParentFile().getParentFile().getParentFile();
         try {
-            if (!loc.getCanonicalFile().equals(bootJar.getParentFile().getParentFile().getParentFile().getCanonicalFile())) {
-                // Unusual installation structure, punt.
-                if (Util.err.isLoggable(ErrorManager.INFORMATIONAL)) {
-                    Util.err.log("core.jar & harness.jar locations do not match: " + bootJar + " vs. " + harnessJar);
+            String netbeansHomeS = System.getProperty("netbeans.home"); // NOI18N
+            if (netbeansHomeS != null) {
+                File netbeansHome = new File(netbeansHomeS);
+                if (!platformCluster.getCanonicalFile().equals(netbeansHome.getCanonicalFile())) {
+                    LOG.log(Level.WARNING, "{0} does not match {1}", new Object[] {platformCluster, netbeansHome});
+                    return null;
                 }
+            }
+            if (!loc.getCanonicalFile().equals(platformCluster.getParentFile().getCanonicalFile())) {
+                // Unusual installation structure, punt.
+                LOG.log(Level.WARNING, "core.jar & harness.jar locations do not match: {0} vs. {1}", new Object[] {bootJar, harnessJar});
                 return null;
             }
         } catch (IOException x) {
-            ErrorManager.getDefault().notify(ErrorManager.INFORMATIONAL, x);
+            LOG.log(Level.INFO, null, x);
         }
         // Looks good.
         return FileUtil.normalizeFile(loc);
@@ -295,7 +308,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
      * @param id an ID (as in {@link #getID})
      * @return the platform with that ID, or null
      */
-    public static NbPlatform getPlatformByID(String id) {
+    public @CheckForNull static NbPlatform getPlatformByID(String id) {
         for (NbPlatform p : getPlatformsInternal()) {
             if (p.getID().equals(id)) {
                 return p;
@@ -428,9 +441,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
         NbPlatform plaf = new NbPlatform(id, label, FileUtil.normalizeFile(destdir), harness,
                 Util.findURLs(null), Util.findURLs(null));
         getPlatformsInternal().add(plaf);
-        if (Util.err.isLoggable(ErrorManager.INFORMATIONAL)) {
-            Util.err.log("NbPlatform added: " + plaf);
-        }
+        LOG.log(Level.FINE, "NbPlatform added: {0}", plaf);
         return plaf;
     }
     
@@ -468,9 +479,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
         }
         getPlatformsInternal().remove(plaf);
         ModuleList.refresh(); // #97262
-        if (Util.err.isLoggable(ErrorManager.INFORMATIONAL)) {
-            Util.err.log("NbPlatform removed: " + plaf);
-        }
+        LOG.log(Level.FINE, "NbPlatform removed: {0}", plaf);
     }
     
     private final String id;
@@ -557,17 +566,35 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
     }
 
     /**
-     * Get javadoc which should by default be associated with the default platform.
+     * Gets Javadoc which should by default be associated with a platform.
      */
-    public URL[] getDefaultJavadocRoots() {
-        if (! isDefault())
-            return null;
-        // javadoc can be built in the meantime, don't cache
-        File apidocsZip = InstalledFileLocator.getDefault().locate("docs/NetBeansAPIs.zip", "org.netbeans.modules.apisupport.apidocs", true); // NOI18N
-        if (apidocsZip != null) {
-            return new URL[] {FileUtil.urlForArchiveOrDir(apidocsZip)};
+    public @Override URL[] getDefaultJavadocRoots() {
+        if (isDefault()) {
+            File apidocsZip = InstalledFileLocator.getDefault().locate("docs/NetBeansAPIs.zip", "org.netbeans.modules.apisupport.apidocs", true); // NOI18N
+            if (apidocsZip != null) {
+                return new URL[] {FileUtil.urlForArchiveOrDir(apidocsZip)};
+            }
         }
-        return new URL[0];
+        // Use a representative module present in all 6.x versions.
+        ModuleEntry platform = getModule("org.netbeans.modules.core.kit"); // NOI18N
+        if (platform != null) {
+            String spec = platform.getSpecificationVersion();
+            if (spec != null) {
+                Matcher m = Pattern.compile("(\\d+[.]\\d+)([.]\\d+)*").matcher(spec);
+                if (m.matches()) {
+                    String trunkSpec = m.group(1);
+                    try {
+                        String loc = NbBundle.getBundle(NbPlatform.class).getString("NbPlatform.web.javadoc." + trunkSpec);
+                        return new URL[] {new URL(loc)};
+                    } catch (MissingResourceException x) {
+                        // fine, some other trunk version, ignore
+                    } catch (MalformedURLException x) {
+                        assert false : x;
+                    }
+                }
+            }
+        }
+        return null;
     }
 
     public void addJavadocRoot(URL root) throws IOException {
@@ -737,7 +764,7 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
     /**
      * Gets a module from the platform by name.
      */
-    public ModuleEntry getModule(String cnb) {
+    public @CheckForNull ModuleEntry getModule(String cnb) {
         if (nbdestdir.isDirectory()) {
             try {
                 return ModuleList.findOrCreateModuleListFromBinaries(nbdestdir).getEntry(cnb);
@@ -933,9 +960,9 @@ public final class NbPlatform implements SourceRootsProvider, JavadocRootsProvid
                     jf.close();
                 }
             } catch (IOException e) {
-                Util.err.notify(ErrorManager.INFORMATIONAL, e);
+                LOG.log(Level.INFO, null, e);
             } catch (NumberFormatException e) {
-                Util.err.notify(ErrorManager.INFORMATIONAL, e);
+                LOG.log(Level.INFO, null, e);
             }
         }
         return harnessVersion = HarnessVersion.UNKNOWN;
