@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -50,6 +53,7 @@ import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.modules.apisupport.project.NbModuleProject;
 import org.netbeans.modules.apisupport.project.Util;
+import org.netbeans.modules.apisupport.project.suite.SuiteProject;
 import org.netbeans.spi.project.SubprojectProvider;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
@@ -59,7 +63,6 @@ import org.openide.filesystems.FileUtil;
  */
 public final class TestEntry {
     
-    private static final String JAR_NAME = "tests.jar"; // NOI18N
     /** Hardcoded location of testdistribution relatively to nb source root. */
     private static final String TEST_DIST_DIR = "nbbuild/build/testdist"; // NOI18N;
     private final String codeNameBase;
@@ -84,10 +87,9 @@ public final class TestEntry {
      * @return null when the file is not jarfile with tests
      */
     public static TestEntry get(File jarFile) {
-        // testtype/cluster/codenamebase/testsjar
-        String path = jarFile.getPath().replace(File.separatorChar,'/');
-        if (path.endsWith(JAR_NAME)) {
-            String tokens[] = path.split("/");
+        if (jarFile.getName().equals("tests.jar")) { // NOI18N
+            // testtype/cluster/codenamebase/tests.jar
+            String tokens[] = jarFile.getPath().split("[/\\\\]"); // NOI18N
             int len = tokens.length;
             if (len > 3 ) {
                String cnb = tokens[len - 2].replace('-','.') ;
@@ -142,8 +144,7 @@ public final class TestEntry {
             } 
         }
         Project prj = FileOwnerQuery.getOwner(FileUtil.toFileObject(prjDir));
-        if (prj != null) {
-            // ModuleSuite
+        if (prj != null && prj.getLookup().lookup(SuiteProject.class) != null) {
             SubprojectProvider subprojects = prj.getLookup().lookup(SubprojectProvider.class);
             if (subprojects != null) {
                 for (Project p : subprojects.getSubprojects()) {
