@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,10 @@
 
 package org.netbeans.modules.apisupport.project;
 
+import org.w3c.dom.ls.LSSerializer;
+import org.w3c.dom.ls.LSOutput;
+import java.io.ByteArrayOutputStream;
+import org.w3c.dom.ls.DOMImplementationLS;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.IOException;
@@ -58,10 +65,10 @@ import java.util.TreeSet;
 import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectManager;
 import org.netbeans.modules.apisupport.project.ProjectXMLManager.CyclicDependencyException;
-import org.netbeans.modules.apisupport.project.ui.customizer.ModuleDependency;
 import org.netbeans.modules.apisupport.project.universe.ModuleEntry;
 import org.netbeans.modules.apisupport.project.universe.ModuleList;
 import org.netbeans.modules.apisupport.project.universe.NbPlatform;
+import org.netbeans.modules.apisupport.project.universe.NonexistentModuleEntry;
 import org.netbeans.modules.apisupport.project.universe.TestModuleDependency;
 import org.openide.ErrorManager;
 import org.openide.filesystems.FileObject;
@@ -109,7 +116,7 @@ public class ProjectXMLManagerTest extends TestBase {
                 findProject(nbRoot().getFileObject("libs.xerces"));
         return new ProjectXMLManager(xercesPrj);
     }
-    
+
     public void testGetCodeNameBase() throws Exception {
         NbModuleProject p = generateStandaloneModule("module1");
         assertEquals("action-project cnb", "org.example.module1", p.getCodeNameBase());
@@ -142,11 +149,11 @@ public class ProjectXMLManagerTest extends TestBase {
     public void testGetDirectDependenciesForCustomPlatform() throws Exception {
         final NbModuleProject testingProject = generateTestingProject();
         ProjectXMLManager testingPXM = new ProjectXMLManager(testingProject);
-        Set deps = testingPXM.getDirectDependencies();
+        Set<ModuleDependency> deps = testingPXM.getDirectDependencies();
         assertEquals("number of dependencies", 2, deps.size());
-        Set depsWithCustom = testingPXM.getDirectDependencies(
+        Set<ModuleDependency> depsWithCustom = testingPXM.getDirectDependencies(
                 NbPlatform.getPlatformByID("custom"));
-        assertEquals("number of dependencies", 0, depsWithCustom.size());
+        assertEquals("still have deps using NonexistentModuleEntry", 2, depsWithCustom.size());
     }
     
     public void testRemoveDependency() throws Exception {
@@ -191,7 +198,7 @@ public class ProjectXMLManagerTest extends TestBase {
                                 "2",
                                 origDep.getSpecificationVersion(),
                                 origDep.hasCompileDependency(),
-                                origDep.hasImplementationDepedendency());
+                                origDep.hasImplementationDependency());
                         testingPXM.editDependency(origDep, newDep);
                     }
                 }
@@ -258,7 +265,7 @@ public class ProjectXMLManagerTest extends TestBase {
             if ("org.netbeans.modules.java.j2seplatform".equals(md.getModuleEntry().getCodeNameBase())) {
                 assertEquals("edited release version", "1", md.getReleaseVersion());
                 assertFalse("has compile depedendency", md.hasCompileDependency());
-                assertTrue("has implementation depedendency", md.hasImplementationDepedendency());
+                assertTrue("has implementation depedendency", md.hasImplementationDependency());
             }
         }
         assertTrue("following dependencies were found: " + assumedCNBs, assumedCNBs.isEmpty());
@@ -286,7 +293,7 @@ public class ProjectXMLManagerTest extends TestBase {
         try {
             testingPXM.getDirectDependencies();
             fail("IllegalStateException was expected");
-        } catch (IllegalStateException ise) {
+        } catch (IOException x) {
             // OK, expected exception was thrown
         }
     }
@@ -303,8 +310,8 @@ public class ProjectXMLManagerTest extends TestBase {
                     Document doc = XMLUtil.parse(new InputSource(projectXML.toURI().toString()),
                             false, true, null, null);
                     Element project = doc.getDocumentElement();
-                    Element config = Util.findElement(project, "configuration", null); // NOI18N
-                    data = Util.findElement(config, "data", NbModuleProjectType.NAMESPACE_SHARED);
+                    Element config = XMLUtil.findElement(project, "configuration", null); // NOI18N
+                    data = XMLUtil.findElement(config, "data", NbModuleProject.NAMESPACE_SHARED);
                 } catch (IOException e) {
                     ErrorManager.getDefault().notify(ErrorManager.INFORMATIONAL, e);
                 } catch (SAXException e) {
@@ -335,7 +342,7 @@ public class ProjectXMLManagerTest extends TestBase {
                         "", // will be check if it is not written
                         oldOO.getSpecificationVersion(),
                         md.hasCompileDependency(),
-                        md.hasImplementationDepedendency());
+                        md.hasImplementationDependency());
                 it.remove();
                 break;
             }
@@ -382,6 +389,10 @@ public class ProjectXMLManagerTest extends TestBase {
     public void testReplacePublicPackages() throws Exception {
         final NbModuleProject testingProject = generateTestingProject();
         final ProjectXMLManager testingPXM = new ProjectXMLManager(testingProject);
+        Map<String,String> cpext = new HashMap<String,String>();
+        cpext.put("ext/a.jar", null);
+        cpext.put("ext/b.jar", null);
+        testingPXM.replaceClassPathExtensions(cpext); // exercising #184377
         ManifestManager.PackageExport[] publicPackages = testingPXM.getPublicPackages();
         assertEquals("number of public packages", 1, publicPackages.length);
         final Set<String> newPP = new HashSet<String>();
@@ -650,6 +661,50 @@ public class ProjectXMLManagerTest extends TestBase {
         assertEquals("contains two dependencies now", 2, setUnit.size());
     }
 
+    public void testNonstandardDependencies() throws Exception { // #180717
+        NbModuleProject p = generateStandaloneModule("m");
+        Element data = p.getPrimaryConfigurationData();
+        Element mds = XMLUtil.findElement(data, ProjectXMLManager.MODULE_DEPENDENCIES, NbModuleProject.NAMESPACE_SHARED);
+        Document doc = mds.getOwnerDocument();
+        boolean[] Z2 = {false, true};
+        int i = 0;
+        for (boolean buildPrerequisite : Z2) {
+            for (boolean compileDependency : Z2) {
+                for (boolean runDependency : Z2) {
+                    Element md = (Element) mds.appendChild(doc.createElementNS(NbModuleProject.NAMESPACE_SHARED, ProjectXMLManager.DEPENDENCY));
+                    Element cnb = (Element) md.appendChild(doc.createElementNS(NbModuleProject.NAMESPACE_SHARED, ProjectXMLManager.CODE_NAME_BASE));
+                    cnb.appendChild(doc.createTextNode("dep" + i++));
+                    if (buildPrerequisite) {
+                        md.appendChild(doc.createElementNS(NbModuleProject.NAMESPACE_SHARED, ProjectXMLManager.BUILD_PREREQUISITE));
+                    }
+                    if (compileDependency) {
+                        md.appendChild(doc.createElementNS(NbModuleProject.NAMESPACE_SHARED, ProjectXMLManager.COMPILE_DEPENDENCY));
+                    }
+                    if (runDependency) {
+                        md.appendChild(doc.createElementNS(NbModuleProject.NAMESPACE_SHARED, ProjectXMLManager.RUN_DEPENDENCY));
+                    }
+                }
+            }
+        }
+        String orig = elementToString(mds);
+        p.putPrimaryConfigurationData(data);
+        ProjectXMLManager pxm = new ProjectXMLManager(p);
+        ModuleDependency extra = new ModuleDependency(new NonexistentModuleEntry(("other")), null, null, true, false);
+        pxm.addDependency(extra);
+        pxm.removeDependency("other");
+        mds = XMLUtil.findElement(p.getPrimaryConfigurationData(), ProjectXMLManager.MODULE_DEPENDENCIES, NbModuleProject.NAMESPACE_SHARED);
+        assertEquals(orig, elementToString(mds));
+    }
+    private static String elementToString(Element e) {
+        ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        DOMImplementationLS ls = (DOMImplementationLS) e.getOwnerDocument().getImplementation().getFeature("LS", "3.0"); // NOI18N
+        LSOutput output = ls.createLSOutput();
+        output.setByteStream(baos);
+        LSSerializer ser = ls.createLSSerializer();
+        ser.write(e, output);
+        return baos.toString();
+    }
+
     /** add dependency from newDepProj to testingProject
      * @see org.netbeans.modules.tasklist.todo.ToDoTest
      */
