@@ -188,8 +188,8 @@ import org.openide.util.Lookup;
     }
     
     private static File initializeBuildProperties(File workDir, File dataDir, File apisZip) throws Exception {
-        File nbrootF = getTestNBRoot();
         boolean sourceAvailable = isSourceAvailable();
+        File nbrootF = sourceAvailable ? getTestNBRoot() : null;
         System.setProperty("netbeans.user", workDir.getAbsolutePath());
         File userPropertiesFile = new File(workDir, "build.properties");
         Properties p = new Properties();
@@ -227,7 +227,8 @@ import org.openide.util.Lookup;
     }
     
     private static boolean isSourceAvailable() {
-        return new File(getTestNBRoot(), "nbbuild/netbeans/" + CLUSTER_APISUPPORT
+        String nbroot = System.getProperty("test.nbroot");
+        return nbroot != null && new File(nbroot, "nbbuild/netbeans/" + CLUSTER_APISUPPORT
                 + "/modules/org-netbeans-modules-apisupport-project.jar").isFile();
     }
     
@@ -443,7 +444,7 @@ import org.openide.util.Lookup;
                 "Testing Module", // display name
                 "org/example/" + prjDir + "/resources/Bundle.properties",
                 "org/example/" + prjDir + "/resources/layer.xml",
-                NbPlatform.PLATFORM_ID_DEFAULT, osgi); // platform id
+                NbPlatform.PLATFORM_ID_DEFAULT, osgi, true); // platform id
         return FileUtil.toFileObject(prjDirF);
     }
     
@@ -501,7 +502,7 @@ import org.openide.util.Lookup;
         String prjDirDotted = prjDir.replace('/', '.');
         File suiteDir = suiteProject.getProjectDirectoryFile();
         File prjDirF = file(parentDir, prjDir);
-        NbModuleProjectGenerator.createSuiteComponentModule(prjDirF, "org.example." + prjDirDotted, "Testing Module", "org/example/" + prjDir + "/resources/Bundle.properties", "org/example/" + prjDir + "/resources/layer.xml", suiteDir, false); // suite directory
+        NbModuleProjectGenerator.createSuiteComponentModule(prjDirF, "org.example." + prjDirDotted, "Testing Module", "org/example/" + prjDir + "/resources/Bundle.properties", "org/example/" + prjDir + "/resources/layer.xml", suiteDir, false, true); // suite directory
         return FileUtil.toFileObject(prjDirF);
     }
 
