@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -60,13 +63,13 @@ import java.util.SortedSet;
 import java.util.TreeSet;
 import java.util.jar.Manifest;
 import org.netbeans.api.project.ProjectManager;
-import org.netbeans.modules.apisupport.project.ui.customizer.ModuleDependency;
 import org.netbeans.modules.apisupport.project.universe.LocalizedBundleInfo;
 import org.netbeans.modules.apisupport.project.universe.NbPlatform;
 import org.netbeans.spi.project.support.ant.AntProjectHelper;
 import org.netbeans.spi.project.support.ant.EditableProperties;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
+import org.openide.util.test.TestFileUtils;
 
 /**
  * Tests {@link Util}.
@@ -182,6 +185,16 @@ public class UtilTest extends TestBase {
         }
     }
 
+    public void testfindLocalizedBundleInfoFromOSGi() throws Exception { // #179752
+        File jar = new File(getWorkDir(), "x.zip");
+        TestFileUtils.writeZipFile(jar, "META-INF/MANIFEST.MF:Bundle-SymbolicName: foo\nBundle-Name: Foo\nBundle-Description: Does some foo stuff.\n");
+        LocalizedBundleInfo info = Util.findLocalizedBundleInfoFromJAR(jar);
+        assertNotNull(info);
+        assertEquals("Foo", info.getDisplayName());
+        assertEquals("Does some foo stuff.", info.getShortDescription());
+        // XXX improve to load Bundle-Localization also if present
+    }
+
     public void testLoadProperties() throws Exception {
         File props = file(getWorkDir(), "testing.properties");
         OutputStream propsOS = new FileOutputStream(props);
