@@ -78,6 +78,7 @@ import java.util.jar.Manifest;
 import java.util.zip.ZipEntry;
 import org.netbeans.api.project.ProjectManager;
 import org.netbeans.core.startup.layers.LayerCacheManager;
+import org.netbeans.junit.RandomlyFails;
 import org.netbeans.modules.apisupport.project.CreatedModifiedFiles;
 import org.netbeans.modules.apisupport.project.ManifestManager;
 import org.netbeans.modules.apisupport.project.NbModuleProject;
@@ -98,6 +99,7 @@ import org.openide.nodes.Node;
  * Test writing changes to layers.
  * @author Jesse Glick
  */
+@RandomlyFails
 public class LayerUtilsTest extends LayerTestBase {
     private static final String LAYER_NAME_FMT = "layer-%03d.xml";
     private static final String JAR_NAME_FMT = "module-%03d.jar";
@@ -426,6 +428,7 @@ public class LayerUtilsTest extends LayerTestBase {
         return files;
     }
 
+    @RandomlyFails // #192590: slow, loads a lot of stuff
     public void testSystemFilesystemStandaloneProject() throws Exception {
         NbModuleProject project = TestBase.generateStandaloneModule(getWorkDir(), "module");
         LayerHandle handle = LayerHandle.forProject(project);
@@ -465,7 +468,7 @@ public class LayerUtilsTest extends LayerTestBase {
                 "module1",
                 "test/module1/resources/Bundle.properties",
                 "test/module1/resources/layer.xml",
-                suiteDir, false);
+                suiteDir, false, true);
         NbModuleProject module1 = (NbModuleProject) ProjectManager.getDefault().findProject(FileUtil.toFileObject(module1Dir));
         LayerHandle handle = LayerHandle.forProject(module1);
         FileUtil.createData(handle.layer(true).getRoot(), "random/stuff");
@@ -477,7 +480,7 @@ public class LayerUtilsTest extends LayerTestBase {
                 "module2",
                 "test/module2/resources/Bundle.properties",
                 "test/module2/resources/layer.xml",
-                suiteDir, false);
+                suiteDir, false, true);
         NbModuleProject module2 = (NbModuleProject) ProjectManager.getDefault().findProject(FileUtil.toFileObject(module2Dir));
         handle = LayerHandle.forProject(module2);
         FileObject layerXML = handle.getLayerFile();
@@ -515,7 +518,7 @@ public class LayerUtilsTest extends LayerTestBase {
                 "module1",
                 "test/module1/resources/Bundle.properties",
                 "test/module1/resources/layer.xml",
-                suiteDir, false);
+                suiteDir, false, true);
         NbModuleProject module1 = (NbModuleProject) ProjectManager.getDefault().findProject(FileUtil.toFileObject(module1Dir));
         CreatedModifiedFiles cmf = new CreatedModifiedFiles(module1);
         cmf.add(cmf.createLayerEntry("foo", null, null, "Foo", null));
@@ -527,7 +530,7 @@ public class LayerUtilsTest extends LayerTestBase {
                 "module2",
                 "test/module2/resources/Bundle.properties",
                 "test/module2/resources/layer.xml",
-                suiteDir, false);
+                suiteDir, false, true);
         NbModuleProject module2 = (NbModuleProject) ProjectManager.getDefault().findProject(FileUtil.toFileObject(module2Dir));
         cmf = new CreatedModifiedFiles(module2);
         cmf.add(cmf.createLayerEntry("bar", null, null, "Bar", null));
@@ -596,7 +599,7 @@ public class LayerUtilsTest extends LayerTestBase {
                     "module",
                     "test/module/resources/Bundle.properties",
                     "test/module/resources/layer.xml",
-                    suiteDir, false);
+                    suiteDir, false, true);
             NbModuleProject module = (NbModuleProject) ProjectManager.getDefault().findProject(FileUtil.toFileObject(moduleDir));
             FileSystem fs = LayerUtils.getEffectiveSystemFilesystem(module);
             assertDisplayName(fs, "#64779: localized platform filename", "folder/file", "Japanese");
@@ -643,7 +646,7 @@ public class LayerUtilsTest extends LayerTestBase {
         assertNotNull(toolsMenu);
         for (FileObject kid : toolsMenu.getChildren()) {
             String name = kid.getNameExt();
-            if (name.indexOf("Options") != -1) {
+            if (name.contains("Options") && !name.contains("separator")) {
                 optionInstanceNames.add(name);
             }
         }
