@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -46,13 +49,8 @@ import java.util.Map;
 import javax.swing.ComboBoxModel;
 import javax.swing.KeyStroke;
 import org.netbeans.api.project.Project;
-import org.netbeans.modules.apisupport.project.NbModuleProject;
 import org.netbeans.modules.apisupport.project.TestBase;
 import org.netbeans.modules.apisupport.project.layers.LayerTestBase;
-import org.netbeans.modules.apisupport.project.layers.LayerUtils;
-import org.netbeans.modules.apisupport.project.ui.UIUtil.LayerItemPresenter;
-import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileSystem;
 
 /**
  * @author Martin Krauskopf
@@ -95,7 +93,8 @@ public class UIUtilTest extends LayerTestBase {
     private void assertKeyLogicalString(String expected, String swingKeyStroke) {
         assertEquals(swingKeyStroke + " corresponding to " + expected, expected, UIUtil.keyToLogicalString(KeyStroke.getKeyStroke(swingKeyStroke)));
     }
-    
+
+    /* XXX rewrite to not rely on nb.org:
     public void testLayerItemPresenterCompareTo() throws Exception {
         TestBase.initializeBuildProperties(getWorkDir(), getDataDir());
         NbModuleProject project = TestBase.generateStandaloneModule(getWorkDir(), "module");
@@ -113,5 +112,6 @@ public class UIUtilTest extends LayerTestBase {
         assertTrue("'Library Wrapper Module Project < 'Module Project'", libraryLIP.compareTo(moduleLIP) < 0);
         assertTrue("'Library Wrapper Module Project < 'Module Suite Project'", libraryLIP.compareTo(suiteLIP) < 0);
     }
+     */
     
 }
