@@ -66,6 +66,7 @@ import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.TreePathHandle;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectUtils;
@@ -319,9 +320,9 @@ public class NbMoveRefactoringPlugin extends AbstractRefactoringPlugin {
         private FileObject movedFile = null;
         public ManifestMoveRefactoringElement(String clazz, FileObject parentFile,
                 String attributeValue, String attributeName) {
+            super(parentFile);
             this.name = attributeValue;
             this.clazz = clazz;
-            this.parentFile = parentFile;
             attrName = attributeName;
         }
         public ManifestMoveRefactoringElement(String clazz, FileObject parentFile,
@@ -333,8 +334,8 @@ public class NbMoveRefactoringPlugin extends AbstractRefactoringPlugin {
         //for data objects that are not classes
         public ManifestMoveRefactoringElement(FileObject parentFile,
                 String attributeValue, String attributeName, FileObject movedFile) {
+            super(parentFile);
             this.name = attributeValue;
-            this.parentFile = parentFile;
             attrName = attributeName;
             this.movedFile = movedFile;
         }
@@ -549,7 +550,7 @@ public class NbMoveRefactoringPlugin extends AbstractRefactoringPlugin {
                         parameter.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
                         List<? extends Tree> trees= parameter.getCompilationUnit().getTypeDecls();
                         for (Tree t: trees) {
-                            if (t.getKind() == Tree.Kind.CLASS) {
+                            if (TreeUtilities.CLASS_TREE_KINDS.contains(t.getKind())) {
                                 if (((ClassTree) t).getSimpleName().toString().equals(filesToMove.get(j).getName())) {
                                     classes.put(filesToMove.get(j), ElementHandle.create(parameter.getTrees().getElement(TreePath.getPath(parameter.getCompilationUnit(), t))));
                                     return ;
