@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -46,11 +49,11 @@ import java.io.File;
 import java.io.FileFilter;
 import java.io.FileInputStream;
 import java.io.InputStream;
-import java.io.FileOutputStream;
 import java.io.OutputStream;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.*;
+import java.util.logging.Level;
 import java.util.zip.CRC32;
 import org.w3c.dom.*;
 import org.xml.sax.InputSource;
@@ -107,15 +110,17 @@ public final class UpdateTracking {
     private final File directory;
     private final File trackingFile;
     private String origin = NBM_ORIGIN;
+    private final UpdatingContext context;
     
     /** Private constructor.
      */
-    private UpdateTracking( File nbPath ) {
+    private UpdateTracking( File nbPath, UpdatingContext context ) {
         assert nbPath != null : "Path cannot be null";
         
         trackingFile = new File( nbPath + FILE_SEPARATOR + TRACKING_FILE_NAME);
         directory = nbPath;
         origin = UPDATER_ORIGIN;
+        this.context = context;
     }
     
     //
@@ -127,7 +132,7 @@ public final class UpdateTracking {
      * @param createIfDoesNotExists should new tracking be created if it does not exists
      * @return the tracking for that cluster
      */    
-    public static UpdateTracking getTracking (File path, boolean createIfDoesNotExists) {
+    static UpdateTracking getTracking (File path, boolean createIfDoesNotExists, UpdatingContext context) {
         synchronized (trackings) {
             UpdateTracking track = trackings.get (path);
             if (track == null) {
@@ -144,7 +149,7 @@ public final class UpdateTracking {
                     return null;
                 }
                 
-                track = new UpdateTracking (path);
+                track = new UpdateTracking (path, context);
                 trackings.put (path, track);
                 track.read ();
                 track.scanDir ();
@@ -158,11 +163,11 @@ public final class UpdateTracking {
      * @path root of a cluster
      * @return the additional information for that cluster
      */    
-    public static UpdateTracking.AdditionalInfo getAdditionalInformation (File path) {
+    static UpdateTracking.AdditionalInfo getAdditionalInformation (File path, UpdatingContext context) {
         synchronized (infos) {
             UpdateTracking.AdditionalInfo additionalInfo = infos.get (path);
             if (additionalInfo == null) {
-                getTracking (path, false);
+                getTracking (path, false, context);
                 File downloadDir = new File (path, ModuleUpdater.DOWNLOAD_DIR);
                 if (downloadDir.exists () && downloadDir.isDirectory ()) {
                     File addInfo = new File (downloadDir, ADDITIONAL_INFO_FILE_NAME);
@@ -303,13 +308,11 @@ public final class UpdateTracking {
                 is.close();
         }
         catch ( org.xml.sax.SAXException e ) {
-            System.out.println("Bad update_tracking" ); // NOI18N
-            e.printStackTrace ();
+            XMLUtil.LOG.log(Level.SEVERE, "Bad update_tracking", e); // NOI18N
             return;
         }
         catch ( java.io.IOException e ) {
-            System.out.println("Missing update_tracking" ); // NOI18N
-            e.printStackTrace ();
+            XMLUtil.LOG.log(Level.SEVERE, "Missing update_tracking", e); // NOI18N
             return;
         }
 
@@ -460,8 +463,7 @@ public final class UpdateTracking {
             if (is != null)
                 is.close();
         } catch ( org.xml.sax.SAXException e ) {
-            System.out.println("Bad update_tracking" ); // NOI18N
-            e.printStackTrace ();
+            XMLUtil.LOG.log(Level.SEVERE, "Bad update_tracking", e); // NOI18N
             return null;
         }
         catch ( java.io.IOException e ) {
@@ -508,8 +510,8 @@ public final class UpdateTracking {
             bsrc = new BufferedInputStream( new FileInputStream( file ) );
             byte[] bytes = new byte[1024];
             int i;
-            while( (i = bsrc.read()) != -1 ) {
-                crc.update( (byte)i );
+            while( (i = bsrc.read(bytes)) != -1 ) {
+                crc.update(bytes, 0, i );
             }
         }
         finally {
@@ -562,6 +564,7 @@ public final class UpdateTracking {
         
         private Version lastVersion = null;
         private Version newVersion = null;
+        private boolean osgi = false;
         
         /** Getter for property codenamebase.
          * @return Value of property codenamebase.
@@ -576,6 +579,14 @@ public final class UpdateTracking {
         void setCodenamebase(String codenamebase) {
             this.codenamebase = codenamebase;
         }
+
+        void setOSGi(boolean isOSGi) {
+            this.osgi = isOSGi;
+        }
+        boolean isOSGi() {
+            return osgi;
+        }
+
         
         /** Getter for property versions.
          * @return Value of property versions.
@@ -652,11 +663,13 @@ public final class UpdateTracking {
             
             // check module name from config file
             String replaced = name.replace ('.', '-'); // NOI18N
-            String searchFor;
+            String searchFor = null;
             
             if (replaced.indexOf (ModuleDeactivator.MODULES) > 0) { // NOI18N
                 // standard module
                 searchFor = replaced + ".jar"; // NOI18N
+            } else if(osgi) {
+                searchFor = replaced + ".jar"; // NOI18N
             } else {
                 // core module
                 searchFor = replaced.substring (replaced.lastIndexOf ('-') > 0 ? replaced.lastIndexOf ('-') + 1 : 0) + ".jar"; // NOI18N
@@ -684,7 +697,7 @@ public final class UpdateTracking {
 
                     File customConfigs = new File(new File(new File(c, "config"), "Modules"), dash + ".xml");
                     if (customConfigs.exists()) {
-                        needInfoInUserDir = true;
+                        needInfoInUserDir = lastVersion == null;
                     }
                 }
 
@@ -739,18 +752,18 @@ public final class UpdateTracking {
 
             OutputStream os = null;
             try {
-                os = new FileOutputStream(file);
+                os = context.createOS(file);
             } catch (Exception e) {
-                e.printStackTrace();
+                XMLUtil.LOG.log(Level.WARNING, "Cannot read " + file, e);
                 //#154904
                 if (!file.delete()) {
-                    new IOException("Corresponding update would not be installed since it is not possible to modify or delete update tracking file " + file).printStackTrace();
+                    XMLUtil.LOG.log(Level.SEVERE, null, new IOException("Corresponding update would not be installed since it is not possible to modify or delete update tracking file " + file));
                 } else {
-                    new IOException("Update tracking file was deleted since permissions does not allow to modify it: " + file).printStackTrace();
+                    XMLUtil.LOG.log(Level.SEVERE, null, new IOException("Update tracking file was deleted since permissions does not allow to modify it: " + file));
                     try {
-                        os = new FileOutputStream(file);
+                        os = context.createOS(file);
                     } catch (Exception ex) {
-                        ex.printStackTrace();
+                        XMLUtil.LOG.log(Level.WARNING, "Cannot read", ex);
                     }
                 }
             }
@@ -759,12 +772,12 @@ public final class UpdateTracking {
                 try {
                     XMLUtil.write(document, os);
                 } catch (IOException e) {
-                    e.printStackTrace();
+                    XMLUtil.LOG.log(Level.WARNING, "Cannot write " + file, e);
                 } finally {
                     try {
                         os.close();
                     } catch (IOException e) {
-                        e.printStackTrace();
+                        XMLUtil.LOG.log(Level.WARNING, "Cannot close " + file, e);
                     }
                 }
             }
@@ -835,7 +848,7 @@ public final class UpdateTracking {
                     File p = new File(f.getName()).getParentFile();
                     parentDir = p != null ? p.getName() : "";
                 }
-                needToWrite = needToWrite || n.indexOf(ModuleDeactivator.MODULES) >= 0;
+                needToWrite = needToWrite || n.indexOf(ModuleDeactivator.MODULES) >= 0 || osgi;
                 if (n.endsWith(".jar")) {
                     // NOI18N
                     // ok, module candidate
@@ -875,7 +888,7 @@ public final class UpdateTracking {
                 }
             }
             if (!needToWrite) {
-                System.out.println("Warning: No config file written for module " + codenamebase + ". No jar file present in \"modules\" directory.");
+                XMLUtil.LOG.log(Level.WARNING, "No config file written for module {0}. No jar file present in \"modules\" directory.", codenamebase);
                 return;
             }
             assert newCandidate != null || oldCandidate != null : "No jar file present!";
@@ -884,7 +897,7 @@ public final class UpdateTracking {
                 assert oldCandidate.equals(candidate) : "More files look as module: " + oldCandidate;
                 // only temporary
                 if (!oldCandidate.equals(candidate)) {
-                    System.out.println("NBM Error: More files look as module: " + oldCandidate);
+                    XMLUtil.LOG.log(Level.WARNING, "More files look as module: {0}", oldCandidate);
                     oldCandidate = candidate;
                 }
                 // end of temp
@@ -896,7 +909,7 @@ public final class UpdateTracking {
             String spec = newVersion.getVersion();
             OutputStream os;
             try {
-                os = new FileOutputStream(config);
+                os = context.createOS(config);
                 PrintWriter pw = new PrintWriter(new java.io.OutputStreamWriter(os, "UTF-8"));
                 // Please make sure formatting matches what the IDE actually spits
                 // out; it could matter.
@@ -916,7 +929,7 @@ public final class UpdateTracking {
                 pw.flush();
                 pw.close();
             } catch (IOException ex) {
-                ex.printStackTrace();
+                XMLUtil.LOG.log(Level.INFO, null, ex);
             }
         }
     }
@@ -1180,20 +1193,17 @@ public final class UpdateTracking {
                 is = new FileInputStream (f);
                 document = XMLUtil.parse (new InputSource (is), false, false, null, null);
             } catch (org.xml.sax.SAXException e) {
-                System.out.println ("Bad " + UpdateTracking.ADDITIONAL_INFO_FILE_NAME + " " + f); // NOI18N
-                e.printStackTrace ();
+                XMLUtil.LOG.log (Level.WARNING,"Bad " + UpdateTracking.ADDITIONAL_INFO_FILE_NAME + f, e); // NOI18N
                 return res;
             } catch (java.io.IOException e) {
-                System.out.println ("Missing " + UpdateTracking.ADDITIONAL_INFO_FILE_NAME + " " + f); // NOI18N
-                e.printStackTrace ();
+                XMLUtil.LOG.log (Level.WARNING,"Missing " + UpdateTracking.ADDITIONAL_INFO_FILE_NAME + f, e); // NOI18N
                 return res;
             } finally {
                 if (is != null) {
                     try {
                         is.close ();
                     } catch (IOException ioe) {
-                        System.out.println ("Cannot close stream for file " + f); // NOI18N
-                        ioe.printStackTrace ();
+                        XMLUtil.LOG.log (Level.INFO, "Cannot close stream for file " + f, ioe); // NOI18N
                         return res;
                     }
                 }
