@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -380,7 +383,7 @@ public final class OperationContainer<Support> {
         public UpdateElement getUpdateElement() {return impl.getUpdateElement();}
         public UpdateUnit getUpdateUnit() {return impl.getUpdateUnit();}        
         /**
-         * @return all requiered elements. Each of them represented by instance of <code>UpdateElement</code>
+         * @return all required elements. Each of them represented by instance of <code>UpdateElement</code>
          */
         public Set<UpdateElement> getRequiredElements(){return new LinkedHashSet<UpdateElement> (impl.getRequiredElements());}
         
@@ -407,4 +410,9 @@ public final class OperationContainer<Support> {
     OperationContainerImpl<Support> impl;
     private Support support;
     private boolean upToDate = false;
+    
+    @Override
+    public String toString() {
+        return super.toString() + "+" + impl;
+    }
 }
