@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,9 +44,11 @@
 
 package org.netbeans.api.autoupdate;
 
+import java.awt.Image;
 import java.util.List;
 import org.netbeans.modules.autoupdate.services.UpdateElementImpl;
 import org.netbeans.api.autoupdate.UpdateUnitProvider.CATEGORY;
+import org.netbeans.modules.autoupdate.updateprovider.ProviderCategory;
 
 /** Instances provided by the <code>UpdateUnit</code> which represents specific version
  * of update (e.g. module or feature). The <code>UpdateElement</code> can be installed,
@@ -129,12 +134,34 @@ public final class UpdateElement {
     /**
      * @return <code>UpdateUnitProvider.CATEGORY</code> for a quality classification 
      * for update represented by this instance
+     * @deprecated Use {@link #getSourceIcon()} and {@link #getSourceDescription()}.
      */
+    @Deprecated
     public CATEGORY getSourceCategory () {
         UpdateUnitProvider provider = getUpdateUnitProvider();
         return (provider != null) ? provider.getCategory() : CATEGORY.COMMUNITY;
     }
     
+    /** Provides an icon associated with the provider of this update element. 
+     * @return icon representing the provider of this element
+     * @since 1.23
+     * @see UpdateUnitProvider#getSourceIcon() 
+     */
+    public Image getSourceIcon() {
+        UpdateUnitProvider provider = getUpdateUnitProvider();
+        return provider != null ? provider.getSourceIcon() : ProviderCategory.forValue(CATEGORY.COMMUNITY).getIcon();
+    }
+    
+    /** Description of the provider of this element. 
+     * @return textual description of the provider of this element
+     * @since 1.23
+     * @see UpdateUnitProvider#getSourceDescription()
+     */
+    public String getSourceDescription() {
+        UpdateUnitProvider provider = getUpdateUnitProvider();
+        return provider != null ? provider.getSourceDescription() : ProviderCategory.forValue(CATEGORY.COMMUNITY).getDisplayName();
+    }
+    
     private UpdateUnitProvider getUpdateUnitProvider() {
         String source = getSource();
         UpdateUnitProvider retval = null;
