@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -45,11 +48,13 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
+import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
@@ -61,6 +66,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -73,10 +79,12 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
+import java.util.concurrent.atomic.AtomicLong;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.zip.CRC32;
 import org.netbeans.Module;
 import org.netbeans.api.autoupdate.InstallSupport;
 import org.netbeans.api.autoupdate.InstallSupport.Installer;
@@ -88,16 +96,19 @@ import org.netbeans.api.autoupdate.OperationException;
 import org.netbeans.api.autoupdate.UpdateElement;
 import org.netbeans.api.autoupdate.UpdateUnit;
 import org.netbeans.api.progress.ProgressHandle;
+import org.netbeans.core.startup.Main;
 import org.netbeans.modules.autoupdate.updateprovider.NetworkAccess;
 import org.netbeans.modules.autoupdate.updateprovider.NetworkAccess.Task;
 import org.netbeans.updater.ModuleDeactivator;
 import org.netbeans.updater.ModuleUpdater;
+import org.netbeans.updater.UpdateTracking;
+import org.netbeans.updater.UpdaterInternal;
 import org.openide.LifecycleManager;
 import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
+import org.openide.util.NbCollections;
 
 /**
  *
@@ -106,7 +117,7 @@ import org.openide.util.NbBundle;
 public class InstallSupportImpl {
     private InstallSupport support;
     private boolean progressRunning = false;
-    private static Logger err = Logger.getLogger (InstallSupportImpl.class.getName ());
+    private static final Logger LOG = Logger.getLogger (InstallSupportImpl.class.getName ());
     
     private static final String AUTOUPDATE_SERVICES_MODULE = "org.netbeans.modules.autoupdate.services"; // NOI18N
     
@@ -116,6 +127,7 @@ public class InstallSupportImpl {
     private int wasDownloaded = 0;
     
     private Future<Boolean> runningTask;
+    private final Object LOCK = new Object();
     
     private static enum STEP {
         NOTSTARTED,
@@ -144,13 +156,15 @@ public class InstallSupportImpl {
     public boolean doDownload (final ProgressHandle progress/*or null*/, boolean isGlobal) throws OperationException {
         this.isGlobal = isGlobal;
         Callable<Boolean> downloadCallable = new Callable<Boolean>() {
+            @Override
             public Boolean call() throws Exception {
-                assert support.getContainer ().listInvalid ().isEmpty () : support + ".listInvalid().isEmpty() but " + support.getContainer ().listInvalid ();
-                synchronized(this) {
+                final OperationContainer<InstallSupport> container = support.getContainer ();
+                assert container.listInvalid ().isEmpty () : support + ".listInvalid().isEmpty() but " + container.listInvalid () + " container: " + container;
+                synchronized(LOCK) {
                     currentStep = STEP.DOWNLOAD;
                 }
 
-                infos = support.getContainer ().listAll ();
+                infos = container.listAll ();
                 List <OperationInfo<?>> newInfos = new ArrayList <OperationInfo<?>>();
                 for(OperationInfo <?> i : infos) {
                     if(i.getUpdateUnit().getInstalled()!=null &&
@@ -219,7 +233,7 @@ public class InstallSupportImpl {
             runningTask = getExecutionService ().submit (downloadCallable);
             retval = runningTask.get ();
         } catch (CancellationException ex) {
-            err.log (Level.FINE, "InstallSupport.doDownload was cancelled", ex); // NOI18N
+            LOG.log (Level.FINE, "InstallSupport.doDownload was cancelled", ex); // NOI18N
             return false;
         } catch(InterruptedException iex) {
             Exceptions.printStackTrace(iex);
@@ -236,13 +250,15 @@ public class InstallSupportImpl {
     public boolean doValidate (final Validator validator, final ProgressHandle progress/*or null*/) throws OperationException {
         assert validator != null;
         Callable<Boolean> validationCallable = new Callable<Boolean>() {
+            @Override
             public Boolean call() throws Exception {
-                synchronized(this) {
+                synchronized(LOCK) {
                     assert currentStep != STEP.FINISHED;
                     if (currentStep == STEP.CANCEL) return false;
                     currentStep = STEP.VALIDATION;
                 }
-                assert support.getContainer ().listInvalid ().isEmpty () : support + ".listInvalid().isEmpty() but " + support.getContainer ().listInvalid ();
+                final OperationContainer<InstallSupport> container = support.getContainer();
+                assert container.listInvalid ().isEmpty () : support + ".listInvalid().isEmpty() but " + container.listInvalid () + "\ncontainer: " + container;
 
                 // start progress
                 if (progress != null) {
@@ -278,7 +294,7 @@ public class InstallSupportImpl {
             runningTask = getExecutionService ().submit (validationCallable);
             retval = runningTask.get ();
         } catch (CancellationException ex) {
-            err.log (Level.FINE, "InstallSupport.doValidate was cancelled", ex); // NOI18N
+            LOG.log (Level.FINE, "InstallSupport.doValidate was cancelled", ex); // NOI18N
             return false;
         } catch(InterruptedException iex) {
             if (iex.getCause() instanceof OperationException) {
@@ -300,8 +316,9 @@ public class InstallSupportImpl {
     public Boolean doInstall (final Installer installer, final ProgressHandle progress/*or null*/) throws OperationException {
         assert installer != null;
         Callable<Boolean> installCallable = new Callable<Boolean>() {
+            @Override
             public Boolean call() throws Exception {
-                synchronized(this) {
+                synchronized(LOCK) {
                     assert currentStep != STEP.FINISHED : currentStep + " != STEP.FINISHED";
                     if (currentStep == STEP.CANCEL) return false;
                     currentStep = STEP.INSTALLATION;
@@ -335,12 +352,11 @@ public class InstallSupportImpl {
                 }
                 
                 boolean needsRestart = false;
-                JarEntry updaterJarEntry = null;
-                JarFile updaterJarFile = null;
-                File updaterTargetCluster = null;
                 File targetCluster = null;
+                List <UpdaterInfo> updaterFiles = new ArrayList <UpdaterInfo> ();
+                
                 for (ModuleUpdateElementImpl moduleImpl : affectedModuleImpls) {
-                    synchronized(this) {
+                    synchronized(LOCK) {
                         if (currentStep == STEP.CANCEL) {
                             if (progress != null) progress.finish ();
                             return false;
@@ -357,47 +373,62 @@ public class InstallSupportImpl {
                     targetCluster = getTargetCluster (installed, moduleImpl, isGlobal);
                     
                     URL source = moduleImpl.getInstallInfo ().getDistribution ();
-                    err.log (Level.FINE, "Source URL for " + moduleImpl.getCodeName () + " is " + source);
+                    LOG.log (Level.FINE, "Source URL for " + moduleImpl.getCodeName () + " is " + source);
                     
-                    boolean isNbmFile = source.getFile().toLowerCase(Locale.US).endsWith(Utilities.NBM_EXTENTSION.toLowerCase(Locale.US));
-                    
-                    File dest = getDestination(targetCluster, moduleImpl.getCodeName(), isNbmFile);
+                    File dest = getDestination(targetCluster, moduleImpl.getCodeName(), source);
                     assert dest != null : "Destination file exists for " + moduleImpl + " in " + targetCluster;
                     
-                    // check if 'updater.jar' is being installed
-                    if (AUTOUPDATE_SERVICES_MODULE.equals (moduleImpl.getCodeName ())) {
-                        err.log (Level.FINEST, AUTOUPDATE_SERVICES_MODULE + " is being installed, check if contains " + ModuleUpdater.AUTOUPDATE_UPDATER_JAR_PATH);
-                        JarFile jf = new JarFile (dest);
-                        try {
-                            for (JarEntry entry : Collections.list (jf.entries ())) {
-                                if (ModuleUpdater.AUTOUPDATE_UPDATER_JAR_PATH.equals (entry.toString ())) {
-                                    err.log (Level.FINE, ModuleUpdater.AUTOUPDATE_UPDATER_JAR_PATH + " is being installed from " + moduleImpl.getCodeName ());
-                                    updaterJarEntry = entry;
-                                    updaterJarFile = jf;
-                                    updaterTargetCluster = targetCluster;
-                                    needsRestart = true;
-                                    break;
-                                }
-                            }
-                        } finally {
-                            if (jf != null && ! jf.equals (updaterJarFile)) {
-                                jf.close ();
-                            }
-                        }
+                    // check if 'updater.jar' or 'updater_<branding>_<locale>.jar' is being installed
+                    if (AUTOUPDATE_SERVICES_MODULE.equals(moduleImpl.getCodeName())) {
+                        LOG.log(Level.FINEST, AUTOUPDATE_SERVICES_MODULE + " is being installed, check if contains " + ModuleUpdater.AUTOUPDATE_UPDATER_JAR_PATH);
                     }
-                    
+
+                    JarFile jf = new JarFile(dest);
+                    boolean added = false;
+                    try {
+                       for (JarEntry entry : Collections.list(jf.entries())) {
+                            if (ModuleUpdater.AUTOUPDATE_UPDATER_JAR_PATH.equals(entry.toString()) ||
+                                    entry.toString().matches(ModuleUpdater.AUTOUPDATE_UPDATER_JAR_LOCALE_PATTERN)) {
+                                LOG.log(Level.FINE, entry.toString() + " is being installed from " + moduleImpl.getCodeName());
+                                updaterFiles.add(new UpdaterInfo(entry, jf, targetCluster));
+                                needsRestart = true;
+                                added = true;
+                             }
+                         }
+                    } finally {
+                        if (jf != null && !added) {
+                            jf.close();
+                        }
+                     }
+
+
                     needsRestart |= needsRestart(installed != null, moduleImpl, dest);
                 }
                 
                 try {
                     // store source of installed files
                     Utilities.writeAdditionalInformation (getElement2Clusters ());
-                    if (updaterJarFile != null) {
-                        Utilities.writeUpdateOfUpdaterJar (updaterJarEntry, updaterJarFile, updaterTargetCluster);
+                    for(int i=0;i<updaterFiles.size();i++) {
+                        UpdaterInfo info = updaterFiles.get(i);
+                        Utilities.writeUpdateOfUpdaterJar (info.getUpdaterJarEntry(), info.getUpdaterJarFile(), info.getUpdaterTargetCluster());
+                        boolean hasAnotherEntryInSameJarFile = false;
+                        for(int j = i + 1; j < updaterFiles.size(); j++) {
+                            if(updaterFiles.get(j).getUpdaterJarFile() == info.getUpdaterJarFile()) {
+                                hasAnotherEntryInSameJarFile = true;
+                                break;
+                            }
+                        }
+                        if (!hasAnotherEntryInSameJarFile) {
+                            try {
+                                info.getUpdaterJarFile().close();
+                            } catch (IOException e) {
+                                LOG.log(Level.INFO, "Cannot close jar file " + info.getUpdaterJarFile());
+                            }
+                        }
                     }
 
                     if (! needsRestart) {
-                        synchronized(this) {
+                        synchronized(LOCK) {
                             if (currentStep == STEP.CANCEL) {
                                 if (progress != null) progress.finish ();
                                 return false;
@@ -411,25 +442,23 @@ public class InstallSupportImpl {
                             files = new HashSet <File> (downloadedFiles);
                         }
                         if (! files.isEmpty ()) {
-
-                            // XXX: should run in single Thread
-                            Thread th = org.netbeans.updater.UpdaterFrame.runFromIDE(
+                            try {
+                                UpdaterInternal.update(
                                     files,
                                     new RefreshModulesListener (progress),
-                                    NbBundle.getBranding(), false);
-
-                            try {
-                                th.join();
+                                    NbBundle.getBranding()
+                                );
                                 for (ModuleUpdateElementImpl impl : affectedModuleImpls) {
                                     int rerunWaitCount = 0;
                                     Module module = Utilities.toModule (impl.getCodeName(), impl.getSpecificationVersion ());
                                     for (; rerunWaitCount < 100 && module == null; rerunWaitCount++) {
+                                        LOG.log(Level.FINE, "Waiting for {0}@{1} #{2}", new Object[]{ impl.getCodeName(), impl.getSpecificationVersion(), rerunWaitCount});
                                         Thread.sleep(100);
+                                        Main.getModuleSystem().refresh();
                                         module = Utilities.toModule (impl.getCodeName(), impl.getSpecificationVersion ());
                                     }
                                     if (rerunWaitCount == 100) {
-                                        err.log (Level.INFO, "Timeout waiting for loading module " + impl.getCodeName () + '/' + impl.getSpecificationVersion ());
-                                        th.interrupt();
+                                        LOG.log (Level.INFO, "Timeout waiting for loading module {0}@{1}", new Object[]{impl.getCodeName (), impl.getSpecificationVersion ()});
                                         afterInstall ();
                                         synchronized(downloadedFiles) {
                                             downloadedFiles.clear();
@@ -440,8 +469,7 @@ public class InstallSupportImpl {
                                     }
                                 }
                             } catch(InterruptedException ie) {
-                                err.log (Level.INFO, ie.getMessage (), ie);
-                                th.interrupt();
+                                LOG.log (Level.INFO, ie.getMessage (), ie);
                             }
                         }
                         afterInstall ();
@@ -466,15 +494,15 @@ public class InstallSupportImpl {
             runningTask = getExecutionService ().submit (installCallable);
             retval = runningTask.get ();
         } catch (CancellationException ex) {
-            err.log (Level.FINE, "InstallSupport.doInstall was cancelled", ex); // NOI18N
+            LOG.log (Level.FINE, "InstallSupport.doInstall was cancelled", ex); // NOI18N
             return false;
         } catch(InterruptedException iex) {
-            err.log (Level.INFO, iex.getLocalizedMessage (), iex);
+            LOG.log (Level.INFO, iex.getLocalizedMessage (), iex);
         } catch(ExecutionException iex) {
             if (iex.getCause () instanceof OperationException) {
                 throw (OperationException) iex.getCause ();
             } else {
-                err.log (Level.INFO, iex.getLocalizedMessage (), iex);
+                LOG.log (Level.INFO, iex.getLocalizedMessage (), iex);
             }
         } finally {
             if (! retval) {
@@ -507,7 +535,7 @@ public class InstallSupportImpl {
     }
 
     public void doRestart (Restarter restarter, ProgressHandle progress/*or null*/) throws OperationException {
-        synchronized(this) {
+        synchronized(LOCK) {
             assert currentStep != STEP.FINISHED;
             currentStep = STEP.RESTART;
         }        
@@ -626,7 +654,7 @@ public class InstallSupportImpl {
     }
 
     public void doCancel () throws OperationException {
-        synchronized(this) {
+        synchronized(LOCK) {
             currentStep = STEP.CANCEL;
         }
         if (runningTask != null && ! runningTask.isDone () && ! runningTask.isCancelled ()) {
@@ -699,21 +727,19 @@ public class InstallSupportImpl {
         }
 
         URL source = toUpdateImpl.getInstallInfo().getDistribution();
-        err.log (Level.FINE, "Source URL for " + toUpdateImpl.getCodeName () + " is " + source);
+        LOG.log (Level.FINE, "Source URL for " + toUpdateImpl.getCodeName () + " is " + source);
         if(source==null) {
             final String errorString = NbBundle.getMessage(InstallSupportImpl.class, 
                     "InstallSupportImpl_NullSource", toUpdateImpl.getCodeName()); // NOI18N
-            err.log (Level.INFO, errorString);
+            LOG.log (Level.INFO, errorString);
             throw new OperationException (OperationException.ERROR_TYPE.INSTALL, errorString);
         }
 
-        boolean isNbmFile = source.getFile ().toLowerCase (Locale.US).endsWith (Utilities.NBM_EXTENTSION.toLowerCase (Locale.US));
-
-        File dest = getDestination (targetCluster, toUpdateImpl.getCodeName(), isNbmFile);
+        File dest = getDestination (targetCluster, toUpdateImpl.getCodeName(), source);
         
         // skip already downloaded modules
         if (dest.exists ()) {
-            err.log (Level.FINE, "Target NBM file " + dest + " of " + toUpdateImpl.getUpdateElement () + " already downloaded.");
+            LOG.log (Level.FINE, "Target NBM file " + dest + " of " + toUpdateImpl.getUpdateElement () + " already downloaded.");
             return toUpdateImpl.getDownloadSize ();
         }
 
@@ -727,14 +753,56 @@ public class InstallSupportImpl {
                 downloadedFiles.add(normalized);
             }
             c = copy (source, dest, progress, toUpdateImpl.getDownloadSize (), aggregateDownload, totalSize, label);
+            JarFile nbm = new JarFile(dest);
+            try {
+                Enumeration<JarEntry> en = nbm.entries();
+                while (en.hasMoreElements()) {
+                    JarEntry jarEntry = en.nextElement();
+                    if (jarEntry.getName().endsWith(".external")) {
+                        InputStream is = nbm.getInputStream(jarEntry);
+                        try {
+                            AtomicLong crc = new AtomicLong();
+                            InputStream real = externalDownload(is, crc, jarEntry.getName());
+                            if (crc.get() == -1L) {
+                                throw new IOException(jarEntry.getName() + " does not contain CRC: line!");
+                            }
+                            byte[] arr = new byte[4096];
+                            CRC32 check = new CRC32();
+                            File external = new File(dest.getPath() + "." + Long.toHexString(crc.get()));
+                            FileOutputStream fos = new FileOutputStream(external);
+                            try {
+                                for (;;) {
+                                    int len = real.read(arr);
+                                    if (len == -1) {
+                                        break;
+                                    }
+                                    check.update(arr, 0, len);
+                                    fos.write(arr, 0, len);
+                                }
+                            } finally {
+                                fos.close();
+                            }
+                            real.close();
+                            if (check.getValue() != crc.get()) {
+                                external.delete();
+                                throw new IOException("Wrong CRC for " + jarEntry.getName());
+                            }
+                        } finally {
+                            is.close();
+                        }
+                    }
+                }
+            } finally {
+                nbm.close();
+            }
         } catch (UnknownHostException x) {
-            err.log (Level.INFO, x.getMessage (), x);
+            LOG.log (Level.INFO, x.getMessage (), x);
             throw new OperationException (OperationException.ERROR_TYPE.PROXY, source.toString ());
         } catch (FileNotFoundException x) {
-            err.log (Level.INFO, x.getMessage (), x);
+            LOG.log (Level.INFO, x.getMessage (), x);
             throw new OperationException (OperationException.ERROR_TYPE.INSTALL, x.getLocalizedMessage ());
         } catch (IOException x) {
-            err.log (Level.INFO, x.getMessage (), x);
+            LOG.log (Level.INFO, x.getMessage (), x);
             throw new OperationException (OperationException.ERROR_TYPE.PROXY, source.toString ());
         }
         
@@ -779,9 +847,18 @@ public class InstallSupportImpl {
         File targetCluster = getTargetCluster (installed, toUpdateImpl, isGlobal);
 
         URL source = toUpdateImpl.getInstallInfo().getDistribution();
-        boolean isNbm = source.getFile ().toLowerCase (Locale.US).endsWith (Utilities.NBM_EXTENTSION.toLowerCase (Locale.US));
-        File dest = getDestination (targetCluster, toUpdateImpl.getCodeName(), isNbm);
-        assert dest.exists () : dest.getAbsolutePath();        
+        File dest = getDestination (targetCluster, toUpdateImpl.getCodeName(), source);
+        if (!dest.exists()) {
+            StringBuilder sb = new StringBuilder();
+            sb.append("Cannot find ").append(dest).append("\n");
+            sb.append("Parent directory contains:").append(Arrays.toString(dest.getParentFile().list())).append("\n");
+            for (File f : UpdateTracking.clusters(true)) {
+                sb.append("Trying to find result in ").append(f).append(" = ");
+                File alt = getDestination (targetCluster, toUpdateImpl.getCodeName(), source);
+                sb.append(alt).append(" exists ").append(alt.exists()).append("\n");
+            }
+            throw new OperationException(OperationException.ERROR_TYPE.INSTALL, sb.toString());
+        }
         
         int wasVerified = 0;
 
@@ -791,22 +868,25 @@ public class InstallSupportImpl {
         return wasVerified;
     }
     
-    static File getDestination (File targetCluster, String codeName, boolean isNbmFile) {
-        err.log (Level.FINE, "Target cluster for " + codeName + " is " + targetCluster);
+    static File getDestination (File targetCluster, String codeName, URL source) {
+        LOG.log (Level.FINE, "Target cluster for " + codeName + " is " + targetCluster);
         File destDir = new File (targetCluster, Utilities.DOWNLOAD_DIR);
         if (! destDir.exists ()) {
             destDir.mkdirs ();
         }
         String fileName = codeName.replace ('.', '-');
-        File destFile = new File (destDir, fileName + (isNbmFile ? Utilities.NBM_EXTENTSION : ""));
-        err.log(Level.FINE, "Destination file for " + codeName + " is " + destFile);
+        String filePath = source.getFile().toLowerCase(Locale.US);
+        String ext = filePath.endsWith(Utilities.NBM_EXTENTSION.toLowerCase(Locale.US)) ?
+            Utilities.NBM_EXTENTSION : (
+            filePath.endsWith(Utilities.JAR_EXTENSION.toLowerCase(Locale.US)) ?
+                Utilities.JAR_EXTENSION : ""
+            );
+
+        File destFile = new File (destDir, fileName + ext);
+        LOG.log(Level.FINE, "Destination file for " + codeName + " is " + destFile);
         return destFile;
     }
     
-    private static File getDestination (File targetCluster, String codeName) {
-        return getDestination (targetCluster, codeName, true);
-    }
-
     private boolean cancelled() {
         synchronized (this) {
             return STEP.CANCEL == currentStep;
@@ -828,17 +908,17 @@ public class InstallSupportImpl {
             return contentLength;
         }
         public void streamOpened(InputStream stream, int contentLength) {
-            err.log(Level.FINEST, "Opened connection for " + source);
+            LOG.log(Level.FINEST, "Opened connection for " + source);
             this.stream = stream;
             this.contentLength = contentLength;
         }
 
         public void accessCanceled() {
-            err.log(Level.INFO, "Opening connection for " + source + "was cancelled");
+            LOG.log(Level.INFO, "Opening connection for " + source + "was cancelled");
         }
 
         public void accessTimeOut() {
-            err.log(Level.INFO, "Opening connection for " + source + "was finised due to timeout");
+            LOG.log(Level.INFO, "Opening connection for " + source + "was finised due to timeout");
         }
 
         public void notifyException(Exception x) {
@@ -882,20 +962,20 @@ public class InstallSupportImpl {
                 throw listener.getException();
             }
         } catch (FileNotFoundException x) {
-            err.log (Level.INFO, x.getMessage(), x);
+            LOG.log (Level.INFO, x.getMessage(), x);
             throw new IOException(NbBundle.getMessage(InstallSupportImpl.class,
                     "InstallSupportImpl_Download_Unavailable", source));            
         } catch (IOException x) {
-            err.log (Level.INFO, x.getMessage(), x);
+            LOG.log (Level.INFO, x.getMessage(), x);
             throw new IOException(NbBundle.getMessage(InstallSupportImpl.class,
                     "InstallSupportImpl_Download_Unavailable", source));            
         } catch (Exception x) {
-            err.log (Level.INFO, x.getMessage(), x);
+            LOG.log (Level.INFO, x.getMessage(), x);
             throw new IOException(NbBundle.getMessage(InstallSupportImpl.class,
                     "InstallSupportImpl_Download_Unavailable", source));
         }
         if (cancelled()) {
-            err.log(Level.FINE, "Download of " + source + " was cancelled");
+            LOG.log(Level.FINE, "Download of " + source + " was cancelled");
             throw new IOException("Download of " + source + " was cancelled");
         }
 
@@ -905,7 +985,7 @@ public class InstallSupportImpl {
         BufferedInputStream bsrc = new BufferedInputStream (is);
         BufferedOutputStream bdest = null;
         
-        err.log (Level.FINEST, "Copy " + source + " to " + dest + "[" + estimatedSize + "]");
+        LOG.log (Level.FINEST, "Copy " + source + " to " + dest + "[" + estimatedSize + "]");
         boolean canceled = false;
         int increment = 0;
         try {
@@ -936,27 +1016,27 @@ public class InstallSupportImpl {
             //assert estimatedSize == increment : "Increment (" + increment
             //        + ") of is equal to estimatedSize (" + estimatedSize + ").";
             if (estimatedSize != increment) {
-                err.log (Level.FINEST, "Increment (" + increment + ") of is not equal to estimatedSize (" + estimatedSize + ").");
+                LOG.log (Level.FINEST, "Increment (" + increment + ") of is not equal to estimatedSize (" + estimatedSize + ").");
             }            
         } catch (IOException ioe) {
-            err.log (Level.INFO, "Writing content of URL " + source + " failed.", ioe);
+            LOG.log (Level.INFO, "Writing content of URL " + source + " failed.", ioe);
         } finally {
             try {
                 if (bsrc != null) bsrc.close ();
                 if (bdest != null) bdest.flush ();
                 if (bdest != null) bdest.close ();
             } catch (IOException ioe) {
-                err.log (Level.INFO, ioe.getMessage (), ioe);
+                LOG.log (Level.INFO, ioe.getMessage (), ioe);
             }
         }
         if (contentLength != -1 && increment != contentLength) {
             if(canceled) {
-                err.log(Level.FINE, "Download of " + source + " was cancelled");
+                LOG.log(Level.FINE, "Download of " + source + " was cancelled");
             } else {
-                err.log(Level.INFO, "Content length was reported as " + contentLength + " byte(s) but read " + increment + " byte(s)");
+                LOG.log(Level.INFO, "Content length was reported as " + contentLength + " byte(s) but read " + increment + " byte(s)");
             }
             if(bdest!=null && dest.exists()) {
-                err.log(Level.INFO, "Deleting not fully downloaded file " + dest);
+                LOG.log(Level.INFO, "Deleting not fully downloaded file " + dest);
                 dest.delete();
                 File normalized = FileUtil.normalizeFile (dest);
                 synchronized(downloadedFiles) {
@@ -970,7 +1050,7 @@ public class InstallSupportImpl {
             }
         }
 
-        err.log (Level.FINE, "Destination " + dest + " is successfully wrote. Size " + dest.length());
+        LOG.log (Level.FINE, "Destination " + dest + " is successfully wrote. Size " + dest.length());
         
         return estimatedSize;
     }
@@ -1010,18 +1090,18 @@ public class InstallSupportImpl {
                 }
             }
         } catch (IOException ioe) {
-            err.log (Level.INFO, ioe.getMessage (), ioe);
+            LOG.log (Level.INFO, ioe.getMessage (), ioe);
             res = "BAD_DOWNLOAD";
             throw new OperationException (OperationException.ERROR_TYPE.INSTALL,
                     NbBundle.getMessage(InstallSupportImpl.class, "InstallSupportImpl_Validate_CorruptedNBM", nbmFile)); // NOI18N
         } catch (KeyStoreException kse) {
-            err.log (Level.INFO, kse.getMessage (), kse);
+            LOG.log (Level.INFO, kse.getMessage (), kse);
             res = "CORRUPTED";
             throw new OperationException (OperationException.ERROR_TYPE.INSTALL,
                     NbBundle.getMessage(InstallSupportImpl.class, "InstallSupportImpl_Validate_CorruptedNBM", nbmFile)); // NOI18N
         }
         
-        err.log (Level.FINE, "NBM " + nbmFile + " was verified as " + res);
+        LOG.log (Level.FINE, "NBM " + nbmFile + " was verified as " + res);
         return el.getDownloadSize ();
     }
     
@@ -1081,34 +1161,55 @@ public class InstallSupportImpl {
             this.i = 0;
         }
         
-        public void propertyChange(PropertyChangeEvent arg0) {
-            if (org.netbeans.updater.UpdaterFrame.RUNNING.equals (arg0.getPropertyName ())) {
+        @Override
+        public void propertyChange(PropertyChangeEvent ev) {
+            if (UpdaterInternal.RUNNING.equals (ev.getPropertyName ())) {
                 if (handle != null) {
                     handle.progress (i++);
                 }
-            } else if (org.netbeans.updater.UpdaterFrame.FINISHED.equals (arg0.getPropertyName ())){
+            } else if (UpdaterInternal.FINISHED.equals (ev.getPropertyName ())){
                 // XXX: the modules list should be refresh automatically when config/Modules/ changes
-                final FileObject modulesRoot = FileUtil.getConfigFile(ModuleDeactivator.MODULES);
-                err.log(Level.FINE,
-                        "It\'s a hack: Call refresh on " + modulesRoot +
-                        " file object.");
+                Map<File,Long> modifiedFiles = NbCollections.checkedMapByFilter(
+                    (Map)ev.getNewValue(), 
+                    File.class, Long.class, true
+                );
+                long now = System.currentTimeMillis();
+                for (Map.Entry<File,Long> e : modifiedFiles.entrySet()) {
+                    touch(e.getKey(), Math.max(e.getValue(), now));
+                }
+                FileUtil.getConfigRoot().refresh();
+                FileObject modulesRoot = FileUtil.getConfigFile(ModuleDeactivator.MODULES);
                 if (modulesRoot != null) {
-                    try {
-                        FileUtil.runAtomicAction(new FileSystem.AtomicAction() {
-                            public void run() throws IOException {
-                                modulesRoot.getParent().refresh();
-                                modulesRoot.refresh();
-                            }
-                        });
-                    } catch (IOException ex) {
-                        Exceptions.printStackTrace(ex);
-                    }
+                    LOG.fine("Refreshing Modules directory"); // NOI18N
+                    modulesRoot.refresh();
+                    LOG.fine("Done refreshing Modules directory"); // NOI18N
+                } else {
+                    LOG.warning("No Modules directory to refresh!"); // NOI18N
                 }
             } else {
-                assert false : "Unknown property " + arg0.getPropertyName ();
+                assert false : "Unknown property " + ev.getPropertyName ();
             }
         }
-    };
+    }
+    
+    private static void touch(File f, long minTime) {
+        for (int cnt = 0; ;cnt++) {
+            long time = f.lastModified();
+            if (time > minTime) {
+                break;
+            }
+            if (!f.exists()) {
+                LOG.log(Level.FINE, "File {0} does not exist anymore", f);
+                break;
+            }
+            LOG.log(Level.FINE, "Need to change time for {0} with delta {1}", new Object[]{f, minTime - f.lastModified()});
+            try { synchronized (InstallSupportImpl.class) {
+                InstallSupportImpl.class.wait(30);
+            }} catch (InterruptedException ex) {}
+            f.setLastModified(System.currentTimeMillis() - 1000);
+        }
+        LOG.log(Level.FINE, "Time stamp changed succcessfully {0}", f);
+    }
 
     private File getTargetCluster(UpdateElement installed, UpdateElementImpl update, boolean isGlobal) {
         File cluster = getElement2Clusters ().get (update);
@@ -1134,4 +1235,82 @@ public class InstallSupportImpl {
         }
         return es;
     }
+    
+    // copied from nbbuild/antsrc/org/netbeans/nbbuild/AutoUpdate.java:
+    private static InputStream externalDownload(InputStream is, AtomicLong crc, String pathTo) throws IOException {
+        BufferedReader br = new BufferedReader(new InputStreamReader(is));
+        URLConnection conn;
+        crc.set(-1L);
+        for (;;) {
+            String line = br.readLine();
+            if (line == null) {
+                break;
+            }
+            if (line.startsWith("CRC:")) {
+                crc.set(Long.parseLong(line.substring(4).trim()));
+            }
+            if (line.startsWith("URL:")) {
+                String url = line.substring(4).trim();
+                for (;;) {
+                    int index = url.indexOf("${");
+                    if (index == -1) {
+                        break;
+                    }
+                    int end = url.indexOf("}", index);
+                    String propName = url.substring(index + 2, end);
+                    final String propVal = System.getProperty(propName);
+                    if (propVal == null) {
+                        throw new IOException("Can't find property " + propName);
+                    }
+                    url = url.substring(0, index) + propVal + url.substring(end + 1);
+                }
+                LOG.log(Level.INFO, "Trying external URL: {0}", url);
+                try {
+                    conn = new URL(url).openConnection();
+                    conn.connect();
+                    return conn.getInputStream();
+                } catch (IOException ex) {
+                    LOG.log(Level.WARNING, "Cannot connect to {0}", url);
+                    LOG.log(Level.INFO, "Details", ex);
+                }
+            }
+        }
+        throw new FileNotFoundException("Cannot resolve external reference to " + pathTo);
+    }
+    
+    private static class UpdaterInfo {
+        private JarEntry updaterJarEntry;
+        private JarFile updaterJarFile;
+        private File updaterTargetCluster;
+
+        public UpdaterInfo(JarEntry updaterJarEntry, JarFile updaterJarFile, File updaterTargetCluster) {
+            this.updaterJarEntry = updaterJarEntry;
+            this.updaterJarFile = updaterJarFile;
+            this.updaterTargetCluster = updaterTargetCluster;
+        }
+
+        public JarEntry getUpdaterJarEntry() {
+            return updaterJarEntry;
+        }
+
+        public void setUpdaterJarEntry(JarEntry updaterJarEntry) {
+            this.updaterJarEntry = updaterJarEntry;
+        }
+
+        public JarFile getUpdaterJarFile() {
+            return updaterJarFile;
+        }
+
+        public void setUpdaterJarFile(JarFile updaterJarFile) {
+            this.updaterJarFile = updaterJarFile;
+        }
+
+        public File getUpdaterTargetCluster() {
+            return updaterTargetCluster;
+        }
+
+        public void setUpdaterTargetCluster(File updaterTargetCluster) {
+            this.updaterTargetCluster = updaterTargetCluster;
+        }
+    }
 }
