@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -46,14 +49,13 @@ import org.netbeans.modules.autoupdate.updateprovider.InstalledModuleProvider;
 import java.util.logging.Logger;
 import org.openide.filesystems.FileUtil;
 import org.openide.modules.InstalledFileLocator;
-import org.openide.util.Exceptions;
 import org.openide.xml.XMLUtil;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.CharBuffer;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.Set;
@@ -290,15 +292,41 @@ public final class ModuleDeleterImpl  {
         
         if (moduleFiles.contains (configFile)) {
             File file = InstalledFileLocator.getDefault ().locate (configFile, moduleInfo.getCodeNameBase (), false);
-            assert file == null || ! file.exists () ||
-                    getStorageFilesForDelete ().contains (file): "Config file " + configFile + " must be already removed or marked for remove.";
+            if(file!=null && file.exists() && !getStorageFilesForDelete ().contains (file)) {
+                err.log(Level.WARNING, "Config file " + configFile +
+                        " must be already removed or marked for remove but still exist as file " + file +
+                        " and not found in StorageFilesForDelete : " + getStorageFilesForDelete());
+            }
         }
         
         for (String fileName : moduleFiles) {
             if (fileName.equals (configFile)) {
                 continue;
             }
-            File file = InstalledFileLocator.getDefault ().locate (fileName, moduleInfo.getCodeNameBase (), false);
+            Set <File> files = InstalledFileLocator.getDefault ().locateAll (fileName, moduleInfo.getCodeNameBase (), false);
+            File file = null;
+            if (files.size() > 0) {
+                file = files.iterator().next();
+                if (files.size() > 1) {
+                    boolean found = false;
+                    for (File f : files) {
+                        if (f.getPath().startsWith(updateTracking.getParentFile().getParentFile().getPath())) {
+                            file = f;
+                            found = true;
+                            break;
+                        }
+                    }
+                    if (!found) {
+                        err.log(Level.WARNING,
+                                "InstalledFileLocator doesn't choose the right file with file name " + fileName
+                                + " for module " + moduleInfo.getCodeNameBase()
+                                + " since a few files were returned : " + Arrays.toString(files.toArray()) +
+                                ", and since none are in the same cluster as update tracking file " + updateTracking +
+                                " will use " + file);
+                    }
+                }
+            }
+
             if (file == null) {
                 err.log (Level.WARNING, "InstalledFileLocator doesn't locate file " + fileName + " for module " + moduleInfo.getCodeNameBase ());
                 continue;
