@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.modules.autoupdate.services;
 
+import java.awt.Image;
 import java.io.File;
 import org.netbeans.api.autoupdate.*;
 import org.netbeans.spi.autoupdate.*;
@@ -70,10 +74,11 @@ import org.openide.util.NbPreferences;
 import org.openide.util.LookupEvent;
 import org.openide.util.LookupListener;
 import org.netbeans.api.autoupdate.UpdateUnitProvider.CATEGORY;
+import org.netbeans.modules.autoupdate.updateprovider.ProviderCategory;
 import org.openide.filesystems.FileUtil;
 
 
-/** XXX <code>UpdateProvider</code> providers items for Autoupdate infrastructure. The items
+/** <code>UpdateProvider</code> providers items for Autoupdate infrastructure. The items
  * are available on e.g. Update Center. Items can represents NetBeans Module,
  * its Localization, Feature as group of NetBeans Modules or special
  * components which needs own native installer to make them accessible in NetBeans product.
@@ -83,7 +88,7 @@ import org.openide.filesystems.FileUtil;
 public final class UpdateUnitProviderImpl {
 
     private UpdateProvider provider;
-    private static Logger err = Logger.getLogger ("org.netbeans.modules.autoupdate.services.UpdateUnitProviderImpl");
+    private static final Logger err = Logger.getLogger ("org.netbeans.modules.autoupdate.services.UpdateUnitProviderImpl");
     private static final String REMOVED_MASK ="_removed";
     private static final String URL = "url";
     private static final String DISPLAY_NAME = "displayName";    
@@ -111,6 +116,22 @@ public final class UpdateUnitProviderImpl {
     public CATEGORY getCategory() {
         return getUpdateProvider().getCategory();
     }
+    public Image getSourceIcon() {
+        UpdateProvider up = getUpdateProvider();
+        if (up instanceof AutoupdateCatalogProvider) {
+            return ((AutoupdateCatalogProvider)up).getProviderCategory().getIcon();
+        }
+        return ProviderCategory.forValue(CATEGORY.COMMUNITY).getIcon();
+    }
+    public String getSourceDescription() {
+        UpdateProvider up = getUpdateProvider();
+        if (up instanceof AutoupdateCatalogProvider) {
+            return ((AutoupdateCatalogProvider) up).getProviderCategory().getDisplayName();
+        }
+        return ProviderCategory.forValue(CATEGORY.COMMUNITY).getDisplayName();
+    }
+
+    
     
     /** Display name of provider. This display name can be visualized in UI.
      * 
@@ -142,7 +163,7 @@ public final class UpdateUnitProviderImpl {
      * 
      * @param force if true then forces to reread the content from server
      * @return true if refresh succeed
-     * @throws java.io.IOException when any network problem appreared
+     * @throws java.io.IOException when any network problem is encountered
      */
     public boolean refresh (ProgressHandle handle, boolean force) throws IOException {
         boolean res = false;
@@ -198,14 +219,14 @@ public final class UpdateUnitProviderImpl {
     }
 
     public static UpdateUnitProvider createUpdateUnitProvider (String codeName, String displayName, URL url) {
-        return createUpdateUnitProvider(codeName, displayName, url, CATEGORY.COMMUNITY);
+        return createUpdateUnitProvider(codeName, displayName, url, ProviderCategory.forValue(CATEGORY.COMMUNITY));
     }
     
     // static factory methods
-    public static UpdateUnitProvider createUpdateUnitProvider (String codeName, String displayName, URL url, CATEGORY category) {
+    public static UpdateUnitProvider createUpdateUnitProvider (String codeName, String displayName, URL url, ProviderCategory category) {
         codeName = normalizeCodeName (codeName);
         // store to Preferences
-        storeProvider(codeName, displayName, url);
+        storeProvider(codeName, displayName, url, category);
         
         AutoupdateCatalogProvider catalog = new AutoupdateCatalogProvider (codeName, displayName, url, category);
         
@@ -223,30 +244,26 @@ public final class UpdateUnitProviderImpl {
         // try to load Update Center from old autoupdate for backward compatibility
         FileObject auTypeFolder = FileUtil.getConfigFile("Services/AutoupdateType");
         if (auTypeFolder != null) {
-            FileObject [] auTypes = auTypeFolder.getChildren ();
-            for (int i = 0; i < auTypes.length; i++) {
+            for (FileObject auType : auTypeFolder.getChildren()) {
                 // check first if already exist
                 try {
-                    if (! getPreferences ().nodeExists (auTypes [i].getName ())) {
+                    if (!getPreferences().nodeExists(auType.getName()) &&
+                            !getPreferences().nodeExists(auType.getName() + REMOVED_MASK)) {
                         try {
-                            String bundle = (String) auTypes [i].getAttribute ("SystemFileSystem.localizingBundle");
-                            if (bundle != null) {
-                                UpdateProvider p = AutoupdateCatalogFactory.createUpdateProvider (auTypes [i]);
-                                assert p != null : "UpdateProvider found for " + auTypes [i];
-                                getPreferences ().node (auTypes [i].getName ()).putBoolean ("loaded", Boolean.TRUE);
-                                err.log (Level.FINEST,
-                                        auTypes [i] + " loaded.");
+                            UpdateProvider p = AutoupdateCatalogFactory.createUpdateProvider(auType);
+                            if (p != null) {
+                                getPreferences().node(auType.getName()).putBoolean("loaded", true);
+                                err.log(Level.FINEST, "{0} loaded", auType);
                             } else {
-                                err.log (Level.INFO,
-                                        auTypes [i] + " cannot be loaded because doesn't contain SystemFileSystem.localizingBundle.");
-                                getPreferences ().node (auTypes [i].getName ()).putBoolean ("loaded", Boolean.FALSE);
+                                err.log(Level.INFO, "{0} cannot be loaded (missing url or url_key)", auType);
+                                getPreferences().node(auType.getName()).putBoolean("loaded", false);
                             }
                         } catch (Exception x) {
                             Exceptions.printStackTrace (x);
                         }
                     }
                 } catch (BackingStoreException bse) {
-                    err.log (Level.INFO, bse.getMessage() + " while loading " + auTypes [i], bse);
+                    err.log(Level.INFO, bse.getMessage() + " while loading " + auType, bse);
                 }
             }
         }
@@ -310,7 +327,9 @@ public final class UpdateUnitProviderImpl {
         UpdateManagerImpl.getInstance().clearCache ();
     }
     
-    private static void storeProvider (String codeName, String displayName, URL url) {
+    private static void storeProvider(
+        String codeName, String displayName, URL url, ProviderCategory c
+    ) {
         if (codeName.contains ("/")) {
             codeName = codeName.replaceAll ("/", "_");
         }
@@ -319,6 +338,8 @@ public final class UpdateUnitProviderImpl {
         
         providerPreferences.put (URL, url.toString ());
         providerPreferences.put (DISPLAY_NAME, displayName);
+        providerPreferences.put(CATEGORY_NAME, c.getDisplayName());
+        providerPreferences.put(AutoupdateCatalogFactory.ORIGINAL_CATEGORY_ICON_BASE, c.getIconBase());
     }
     
     private static Preferences getPreferences() {
@@ -326,12 +347,32 @@ public final class UpdateUnitProviderImpl {
     }    
     
     /*private because tests*/ static UpdateProvider loadProvider (String codeName) {
+        try {
+            if(getPreferences ().nodeExists(codeName + REMOVED_MASK)) {
+                return null;
+            }
+        } catch (BackingStoreException e) {
+            err.log(Level.INFO, e.getMessage(), e);
+        }
         Preferences providerPreferences = getPreferences ().node (codeName);
         assert providerPreferences != null : "Preferences node " + codeName + " found.";
         
         String toUrl = providerPreferences.get (URL, providerPreferences.get (AutoupdateCatalogFactory.ORIGINAL_URL, null));
         String displayName = providerPreferences.get (DISPLAY_NAME, providerPreferences.get (AutoupdateCatalogFactory.ORIGINAL_DISPLAY_NAME, codeName));
-        CATEGORY category = CATEGORY.valueOf(providerPreferences.get (CATEGORY_NAME, providerPreferences.get (AutoupdateCatalogFactory.ORIGINAL_CATEGORY_NAME, CATEGORY.COMMUNITY.name())));
+        String categoryName = providerPreferences.get (CATEGORY_NAME, providerPreferences.get (AutoupdateCatalogFactory.ORIGINAL_CATEGORY_NAME, CATEGORY.COMMUNITY.name()));
+        CATEGORY c;
+        try {
+            c = CATEGORY.valueOf(categoryName);
+        } catch (IllegalArgumentException ex) {
+            c = null;
+        }
+        String categoryIconBase = providerPreferences.get(AutoupdateCatalogFactory.ORIGINAL_CATEGORY_ICON_BASE, null);
+        ProviderCategory pc;
+        if (c != null) {
+            pc = ProviderCategory.forValue(c);
+        } else {
+            pc = ProviderCategory.create(categoryIconBase, categoryName);
+        }
         
         // filter Providers which store only its state
         if (toUrl == null) {
@@ -344,8 +385,7 @@ public final class UpdateUnitProviderImpl {
         } catch (MalformedURLException mue) {
             assert false : mue;
         }
-        
-        return new AutoupdateCatalogProvider (codeName, displayName, url, category);
+        return new AutoupdateCatalogProvider (codeName, displayName, url, pc);
     }
     
     private static boolean loadState (String codename) {
@@ -362,6 +402,13 @@ public final class UpdateUnitProviderImpl {
         assert providerPreferences != null : "Preferences node " + p.getName () + " found.";
         
         providerPreferences.put (ENABLED, Boolean.valueOf (isEnabled).toString ());
+        try {
+        if(getPreferences().nodeExists(p.getName() + REMOVED_MASK)) {
+            getPreferences().node(p.getName() + REMOVED_MASK).removeNode();
+        }
+        } catch (BackingStoreException x) {
+            err.log (Level.INFO, x.getMessage(), x);
+        }
     }
     
     private static String loadDisplayName (UpdateProvider p) {
@@ -430,7 +477,7 @@ public final class UpdateUnitProviderImpl {
             }
         }
     }
-    
+
     private static class LookupListenerImpl implements LookupListener {
         final Lookup.Result<UpdateProvider> result = Lookup.getDefault ().lookupResult(UpdateProvider.class);
         
@@ -464,4 +511,9 @@ public final class UpdateUnitProviderImpl {
         }
         return buf.toString ();
     }
+
+    @Override
+    public String toString() {
+        return provider.toString();
+    }
 }
