@@ -52,19 +52,33 @@ import java.io.OutputStream;
 import java.net.URL;
 import java.util.Arrays;
 import java.util.LinkedList;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import org.netbeans.api.autoupdate.DefaultTestCase;
 import org.netbeans.junit.NbTestCase;
 import org.openide.util.Lookup;
 
 public class NewClustersRebootTest extends NbTestCase {
+    private Logger LOG;
 
     public NewClustersRebootTest(String testName) {
         super(testName);
     }
 
+    @Override
+    protected int timeOut() {
+        return 30000;
+    }
+
+    @Override
+    protected Level logLevel() {
+        return Level.INFO;
+    }
+
     @Override
     protected void setUp() throws Exception {
         clearWorkDir();
+        LOG = Logger.getLogger("test." + getName());
         super.setUp();
         System.setProperty("netbeans.dirs", getWorkDirPath());
         OutputStream os2 = new FileOutputStream(new File(getWorkDir(),"nbmfortest"));
@@ -96,6 +110,7 @@ public class NewClustersRebootTest extends NbTestCase {
         assertTrue("file found: " + f, f.exists());
         File nbexec = org.openide.util.Utilities.isWindows() ? new File(f.getParent(), "nbexec.exe") : new File(f.getParent(), "nbexec");
         assertTrue("nbexec found: " + nbexec, nbexec.exists());
+        LOG.log(Level.INFO, "nbexec: {0}", nbexec);
 
         URL tu = NewClustersRebootCallback.class.getProtectionDomain().getCodeSource().getLocation();
         File testf = new File(tu.toURI());
@@ -118,15 +133,17 @@ public class NewClustersRebootTest extends NbTestCase {
         } else {
             allArgs.addFirst(nbexec.getPath());
         }
-
+        LOG.log(Level.INFO, "About to execute {0}@{1}", new Object[]{allArgs, workDir});
         Process p = Runtime.getRuntime().exec(allArgs.toArray(new String[0]), new String[0], workDir);
+        LOG.log(Level.INFO, "Process created {0}", p);
         int res = readOutput(sb, p);
+        LOG.log(Level.INFO, "Output read: {0}", res);
         String output = sb.toString();
 //        System.out.println("nbexec output is: " + output);
         assertEquals("Execution is ok: " + output, 0, res);
     }
 
-    private static int readOutput(final StringBuffer sb, final Process p) throws Exception {
+    private int readOutput(final StringBuffer sb, final Process p) throws Exception {
         class Read extends Thread {
 
             private InputStream is;
@@ -142,7 +159,9 @@ public class NewClustersRebootTest extends NbTestCase {
                 byte[] arr = new byte[4096];
                 try {
                     for (;;) {
+                        LOG.info("reading....");
                         int len = is.read(arr);
+                        LOG.log(Level.INFO, "got {0} bytes", len);
                         if (len == -1) {
                             return;
                         }
@@ -159,12 +178,17 @@ public class NewClustersRebootTest extends NbTestCase {
         out.start();
         err.start();
 
+        LOG.info("waitFor");
         int res = p.waitFor();
+        LOG.log(Level.INFO, "waitFor finished: {0}", res);
 
         out.interrupt();
         err.interrupt();
+        
+        LOG.info("Interrupting readers");
         out.join();
         err.join();
+        LOG.info("Join OK");
 
         return res;
     }
