@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.modules.autoupdate.services;
 
+import java.util.logging.Level;
 import org.netbeans.modules.autoupdate.updateprovider.InstalledModuleProvider;
 import java.io.File;
 import java.util.Arrays;
@@ -55,12 +59,13 @@ import org.netbeans.api.autoupdate.OperationSupport;
 import org.netbeans.api.autoupdate.UpdateElement;
 import org.netbeans.api.autoupdate.UpdateManager;
 import org.netbeans.api.autoupdate.UpdateUnit;
+import org.openide.filesystems.FileAttributeEvent;
 import org.openide.filesystems.FileChangeAdapter;
 import org.openide.filesystems.FileChangeListener;
 import org.openide.filesystems.FileEvent;
 import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileRenameEvent;
 import org.openide.filesystems.FileUtil;
-import org.openide.filesystems.Repository;
 import org.openide.modules.ModuleInfo;
 
 /**
@@ -69,9 +74,9 @@ import org.openide.modules.ModuleInfo;
  */
 public abstract class OperationsTestImpl extends DefaultTestCase {
     //{fileDataCreated, fileDeleted}
-    private Boolean[] fileChanges = {false,false};
-    private Thread[] fileChangeThreads = {null,null};
-    private Exception[] exceptions = {null,null};
+    private Boolean[] fileChanges = {false, false, false};
+    private Thread[] fileChangeThreads = {null,null,null};
+    private Exception[] exceptions = {null,null,null};
     
     private FileChangeListener fca;
     private FileObject modulesRoot;
@@ -84,24 +89,53 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
     protected void setUp () throws Exception {
         super.setUp ();
         getModuleInfos ();
-        Repository.getDefault ().getDefaultFileSystem ().refresh (false);
-        modulesRoot = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules"); // NOI18N
+        FileUtil.getConfigRoot().getFileSystem().refresh (false);
+        modulesRoot = FileUtil.getConfigFile("Modules"); // NOI18N
         fca = new FileChangeAdapter (){
             @Override
             public void fileDataCreated (FileEvent fe) {
                 fileChanges[0] = true;
                 fileChangeThreads[0] = Thread.currentThread ();
                 exceptions[0] = new Exception ();
+                LOG.log(Level.INFO, "fileDataCreated {0}", fe.getFile());
             }
+
+            @Override
+            public void fileChanged(FileEvent fe) {
+                fileChanges[2] = true;
+                fileChangeThreads[2] = Thread.currentThread ();
+                exceptions[2] = new Exception ();
+                LOG.log(Level.INFO, "fileChanged {0}", fe.getFile());
+            }
+
             
             @Override
             public void fileDeleted (FileEvent fe) {
                 fileChanges[1] = true;
                 fileChangeThreads[1] = Thread.currentThread ();
                 exceptions[1] = new Exception ();
+                LOG.log(Level.INFO, "fileDeleted {0}", fe.getFile());
             }
+
+            @Override
+            public void fileRenamed(FileRenameEvent fe) {
+                LOG.log(Level.INFO, "fileRenamed {0}", fe.getFile());
+            }
+
+            @Override
+            public void fileFolderCreated(FileEvent fe) {
+                LOG.log(Level.INFO, "fileFolderCreated {0}", fe.getFile());
+            }
+
+            @Override
+            public void fileAttributeChanged(FileAttributeEvent fe) {
+                LOG.log(Level.INFO, "fileAttributeChanged {0}", fe.getFile());
+            }
+            
+            
         };
         modulesRoot.addFileChangeListener (fca);
+        modulesRoot.getChildren();
     }
     
     @Override
@@ -116,7 +150,7 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         super (testName);
     }
     
-    public abstract void testSelf () throws Exception;
+    public abstract void testSelf () throws Throwable;
     
     //    static List<UpdateUnit> getUpdateUnits() {
     //        UpdateManager mgr = UpdateManager.getDefault();
@@ -151,6 +185,10 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         
         return installElement;
     }
+
+    boolean incrementNumberOfModuleConfigFiles() {
+        return true;
+    }
     
     /*public void installModuleDirect(UpdateUnit toInstall) throws Exception {
         installModuleImpl(toInstall, false);
@@ -158,15 +196,18 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
     
     
     private UpdateElement installModuleImpl (UpdateUnit toInstall, UpdateElement installElement, final boolean installSupport) throws Exception {
-        fileChanges = new Boolean[]{false,false};
+        fileChanges = new Boolean[]{false, false, false};
         installElement = (installElement != null) ? installElement : toInstall.getAvailableUpdates ().get (0);
         File f = InstallManager.findTargetDirectory(installElement.getUpdateUnit ().getInstalled (), Trampoline.API.impl(installElement),false);
-        File configModules = new File (f, "config/Modules");
+        File configModules = new File(new File (f, "config"), "Modules");
         File modules = new File (f, "modules");
         int configModulesSize = (configModules.listFiles () != null) ? configModules.listFiles ().length : 0;
         int modulesSize = (modules.listFiles () != null) ? modules.listFiles ().length : 0;
         assertFalse (fileChanges[0]);
-        FileObject foConfigModules = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules");
+        
+        Thread.sleep(1000);
+        
+        FileObject foConfigModules = FileUtil.getConfigFile("Modules");
         assertNotNull (foConfigModules);
         int foConfigModulesSize = foConfigModules.getChildren ().length;
         assertNull (getModuleInfos ().get (toInstall.getCodeName ()));
@@ -241,12 +282,19 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         assertNotNull (toInstall.getInstalled ());
         
         if (r == null) {
-            assertTrue ("Config module files are more than before Install test, " + Arrays.asList (configModules.listFiles ()), configModules.listFiles ().length > configModulesSize);
-            assertTrue ("Installed modules are more than before Install test, " + Arrays.asList (modules.listFiles ()), modules.listFiles ().length > modulesSize);
-            assertTrue (foConfigModules.getPath (), foConfigModules.getChildren ().length > foConfigModulesSize);
-            assertEquals (configModules.listFiles ()[0], FileUtil.toFile (foConfigModules.getChildren ()[0]));
-            
-            assertTrue (fileChanges[0]);
+            if (incrementNumberOfModuleConfigFiles()) {
+                assertTrue ("Config module files are more than before Install test, " + Arrays.asList (configModules.listFiles ()), configModules.listFiles ().length > configModulesSize);
+                assertTrue ("Installed modules are more than before Install test, " + Arrays.asList (modules.listFiles ()), modules.listFiles ().length > modulesSize);
+                assertTrue (foConfigModules.getPath (), foConfigModules.getChildren ().length > foConfigModulesSize);
+                assertEquals (configModules.listFiles ()[0], FileUtil.toFile (foConfigModules.getChildren ()[0]));
+            }
+
+            if (incrementNumberOfModuleConfigFiles()) {
+                assertTrue (fileChanges[0]);
+            } else {
+                assertFalse("Don't expect any changes", fileChanges[2]);
+                return installElement;
+            }
             fileChanges[0]=false;
         }
         
@@ -277,7 +325,7 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         return installElement;
     }
     
-    private void assertInstalledModule (UpdateUnit toInstallUnit) throws InterruptedException {
+    void assertInstalledModule (UpdateUnit toInstallUnit) throws InterruptedException {
         ModuleInfo info = getModuleInfos ().get (toInstallUnit.getCodeName ());
         assertNotNull (info);
         int timeout = 250;
@@ -301,7 +349,7 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         File configModules = new File (getWorkDir (), "config/Modules");
         File modules = new File (getWorkDir (), "modules");
         assertFalse (fileChanges[0]);
-        FileObject foConfigModules = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules");
+        FileObject foConfigModules = FileUtil.getConfigFile("Modules");
         assertNotNull (foConfigModules);
         assertTrue (configModules.listFiles () != null && configModules.listFiles ().length != 0);
         assertTrue (modules.listFiles () != null && modules.listFiles ().length != 0);
@@ -383,7 +431,7 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
     }
     
     void disableModule (UpdateUnit toDisable) throws Exception {
-        FileObject fo = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules");
+        FileObject fo = FileUtil.getConfigFile("Modules");
         File f = new File (getWorkDir (), "config/Modules");
         File f2 = new File (getWorkDir (), "modules");
         assertTrue (f.listFiles () != null && f.listFiles ().length != 0);
@@ -416,7 +464,7 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
     }
     
     void enableModule (UpdateUnit toEnable) throws Exception {
-        FileObject fo = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules");
+        FileObject fo = FileUtil.getConfigFile("Modules");
         File f = new File (getWorkDir (), "config/Modules");
         File f2 = new File (getWorkDir (), "modules");
         assertTrue (f.listFiles () != null && f.listFiles ().length != 0);
@@ -455,12 +503,12 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         File modules = new File (getWorkDir (), "modules");
         int configModulesSize = (configModules.listFiles () != null) ? configModules.listFiles ().length : 0;
         int modulesSize = (modules.listFiles () != null) ? modules.listFiles ().length : 0;
-        FileObject foConfigModules = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules");
+        FileObject foConfigModules = FileUtil.getConfigFile("Modules");
         assertNotNull (foConfigModules);
         int foConfigModulesSize = foConfigModules.getChildren ().length;
         
         assertFalse (fileChanges[1]);
-        FileObject fo = Repository.getDefault ().getDefaultFileSystem ().findResource ("Modules");
+        FileObject fo = FileUtil.getConfigFile("Modules");
         assertNotNull (fo);
         assertTrue (fo.getChildren ().length > 0);
         assertNotNull (getModuleInfos ().get (toUnInstall.getCodeName ()));
@@ -500,4 +548,4 @@ public abstract class OperationsTestImpl extends DefaultTestCase {
         assertNull (info);
         assertNull (Utilities.toModule (toUnInstall.getCodeName (), null));
     }
-}
\ No newline at end of file
+}
