@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.modules.autoupdate.ui;
 
+import java.awt.Image;
 import java.util.Comparator;
 import java.util.HashSet;
 import java.util.List;
@@ -50,7 +54,6 @@ import org.netbeans.api.autoupdate.OperationContainer;
 import org.netbeans.api.autoupdate.OperationContainer.OperationInfo;
 import org.netbeans.api.autoupdate.UpdateElement;
 import org.netbeans.api.autoupdate.UpdateUnit;
-import org.netbeans.api.autoupdate.UpdateUnitProvider.CATEGORY;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.NbBundle;
@@ -122,7 +125,7 @@ public class AvailableTableModel extends UnitCategoryTableModel {
             res = u.getCategoryName();
             break;
         case 3 :
-            res = u.getSourceCategory();
+            res = u.getSourceIcon();
             break;
         }
         
@@ -147,7 +150,7 @@ public class AvailableTableModel extends UnitCategoryTableModel {
             res = String.class;
             break;
         case 3 :
-            res = CATEGORY.class;
+            res = Image.class;
             break;
         }
         
@@ -186,12 +189,13 @@ public class AvailableTableModel extends UnitCategoryTableModel {
     @Override
     public String getToolTipText(int row, int col) {
         if (col == 3) {
-            CATEGORY category = (CATEGORY) getValueAt (row, 3);
-            return Utilities.getCategoryName(category);
+            Unit.Available u = (Unit.Available) getUnitAtRow(row);
+            return u.getSourceDescription();
         }
         return super.getToolTipText(row, col);
     }
 
+    @Override
     public int getPreferredWidth(JTableHeader header, int col) {
         final int minWidth = super.getMinWidth(header, col);
         switch (col) {
