@@ -47,6 +47,8 @@ package org.netbeans.modules.autoupdate.ui;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Dimension;
+import java.awt.EventQueue;
+import java.awt.Image;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
@@ -62,13 +64,13 @@ import java.util.prefs.Preferences;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.DefaultComboBoxModel;
+import javax.swing.Icon;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 import javax.swing.JScrollPane;
 import javax.swing.JTable;
 import javax.swing.ListSelectionModel;
 import javax.swing.SwingConstants;
-import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
@@ -79,7 +81,6 @@ import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumn;
 import javax.swing.table.TableColumnModel;
 import org.netbeans.api.autoupdate.UpdateUnitProvider;
-import org.netbeans.api.autoupdate.UpdateUnitProvider.CATEGORY;
 import org.netbeans.api.options.OptionsDisplayer;
 import org.netbeans.modules.autoupdate.ui.actions.AutoupdateSettings;
 import org.openide.DialogDescriptor;
@@ -380,71 +381,81 @@ private void bProxyActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:
     OptionsDisplayer.getDefault ().open ("General"); //NOI18N
 }//GEN-LAST:event_bProxyActionPerformed
 
-public SettingsTableModel getSettingsTableModel() {
-    return ((SettingsTableModel)table.getModel());
-}
+    public SettingsTableModel getSettingsTableModel() {
+        return ((SettingsTableModel) table.getModel());
+    }
 
-private class Listener implements ListSelectionListener,  TableModelListener {
-    public void valueChanged(ListSelectionEvent arg0) {
-        SwingUtilities.invokeLater (new Runnable () {
-            public void run () {
-                modelOrSelectionChanged ();
+    private class Listener implements ListSelectionListener, TableModelListener, Runnable {
+        @Override
+        public void valueChanged(ListSelectionEvent arg0) {
+            modelOrSelectionChanged();
+        }
+
+        @Override
+        public void tableChanged(TableModelEvent arg0) {
+            modelOrSelectionChanged();
+        }
+
+        private void modelOrSelectionChanged() {
+            if (!EventQueue.isDispatchThread()) {
+                EventQueue.invokeLater(this);
+                return;
             }
-        });
-    }
-       
-    public void tableChanged(TableModelEvent arg0) {
-        SwingUtilities.invokeLater (new Runnable () {
-            public void run () {
-                modelOrSelectionChanged ();
-            }
-        });
-    }
-    
-    private void modelOrSelectionChanged() {
-        int rowIndex = table.getSelectedRow();
-        if (rowIndex != -1 && table.getRowCount() > 0) {
-            UpdateUnitProvider uup = ((SettingsTableModel)table.getModel()).getUpdateUnitProvider(rowIndex);
-            if (uup != null) {
-                StringBuffer sb = new StringBuffer();
-                details.setTitle(uup.getDisplayName());
-                long lastTime = lastModification(uup);
-                if (lastTime > 0) {
-                    sb.append("<b>" + NbBundle.getMessage(UnitTab.class, "UnitTab_ReloadTime", //NOI18N
-                            "</b>")).append(new SimpleDateFormat().format(new Date(lastTime))).append("<br>");
-                } else {
-                    String never = getMessage("UnitTab_ReloadTime_Never");//NOI18N
-                    sb.append("<b>" + NbBundle.getMessage(UnitTab.class, "UnitTab_ReloadTime", "</b>")).append(never).append("<br>");//NOI18N                            
-                }                                
-                URL u = uup.getProviderURL();
-                String desc = uup.getDescription () == null ? "" : uup.getDescription ();
-                if (u != null) {
-                    if (desc.length() > 0) {
-                        sb.append("<b>" + getMessage("SettingsTab_UpdateUnitProvider_Description") + "</b><br>"); // NOI18N
-                        sb.append(desc + "<br><br>"); // NOI18N
-                    }
-                    sb.append("<b>" + getMessage("SettingsTab_UpdateUnitProvider_URL") + // NOI18N
-                            " </b><a href=\"" + u.toExternalForm() + "\">" + u.toExternalForm() + "</a><br>"); // NOI18N
-                    editAction.setEnabled (true);
-                } else {
-                    editAction.setEnabled (false);
+            int rowIndex = table.getSelectedRow();
+            if (rowIndex != -1 && table.getRowCount() > 0) {
+                uup = ((SettingsTableModel) table.getModel()).getUpdateUnitProvider(rowIndex);
+                if (uup != null) {
+                    details.setTitle(uup.getDisplayName());
+                    UnitDetails.UNIT_DETAILS_PROCESSOR.post(this);
                 }
+            } else {
+                details.setTitle(null);
+                details.setText(null);
+                details.setActionListener2(null);
+                details.setActionListener(null);
+            }
+        }
+        
+        private final StringBuffer sb = new StringBuffer();
+        private boolean sbEnabled;
+        private UpdateUnitProvider uup;
 
+        @Override
+        public void run() {
+            if (EventQueue.isDispatchThread()) {
                 details.setText(sb.toString());
                 details.setActionListener(removeAction);
                 details.setActionListener2(editAction);
+                editAction.setEnabled(sbEnabled);
+                
+                sb.setLength(0);
+                return;
             }
-        } else {
-            details.setTitle(null);
-            details.setText(null);
-            details.setActionListener2(null);            
-            details.setActionListener(null);
             
-            ListSelectionModel lsm = table.getSelectionModel();
-            lsm.setSelectionInterval(0, 0);
+            long lastTime = lastModification(uup);
+            if (lastTime > 0) {
+                sb.append("<b>").append(NbBundle.getMessage(UnitTab.class, "UnitTab_ReloadTime", //NOI18N
+                  "</b>")).append(new SimpleDateFormat().format(new Date(lastTime))).append("<br>");
+            } else {
+                String never = getMessage("UnitTab_ReloadTime_Never");//NOI18N
+                sb.append("<b>").append(NbBundle.getMessage(UnitTab.class, "UnitTab_ReloadTime", "</b>")).append(never).append("<br>"); //NOI18N                            
+            }
+            URL u = uup.getProviderURL();
+            String desc = uup.getDescription() == null ? "" : uup.getDescription();
+            if (u != null) {
+                if (desc.length() > 0) {
+                    sb.append("<b>").append(getMessage("SettingsTab_UpdateUnitProvider_Description")).append("</b><br>"); // NOI18N
+                    sb.append(desc).append("<br><br>"); // NOI18N
+                }
+                sb.append("<b>" + getMessage("SettingsTab_UpdateUnitProvider_URL") + // NOI18N
+                      " </b><a href=\"" + u.toExternalForm() + "\">" + u.toExternalForm() + "</a><br>"); // NOI18N
+                sbEnabled = true;
+            } else {
+                sbEnabled = false;
+            }
+            EventQueue.invokeLater(this);
         }
     }
-    }
 
     private long lastModification(UpdateUnitProvider unitProvider) {
         Preferences p = NbPreferences.root().node("/org/netbeans/modules/autoupdate");//NOI18N
@@ -703,14 +714,9 @@ private class Listener implements ListSelectionListener,  TableModelListener {
 
             if (value instanceof UpdateUnitProvider) {
                 UpdateUnitProvider u = (UpdateUnitProvider) value;
-                CATEGORY state = u.getCategory();
-                if (CATEGORY.BETA.equals(state)) {
-                    renderComponent.setIcon(ImageUtilities.loadImageIcon("org/netbeans/modules/autoupdate/ui/resources/icon-beta.png", false)); // NOI18N
-                } else if (CATEGORY.COMMUNITY.equals(state)) {
-                    renderComponent.setIcon(ImageUtilities.loadImageIcon("org/netbeans/modules/autoupdate/ui/resources/icon-community.png", false)); // NOI18N
-                } else if (CATEGORY.STANDARD.equals(state)) {
-                    renderComponent.setIcon(ImageUtilities.loadImageIcon("org/netbeans/modules/autoupdate/ui/resources/icon-standard.png", false)); // NOI18N
-                }
+                Image img = u.getSourceIcon();
+                final Icon icon = ImageUtilities.image2Icon(img);
+                renderComponent.setIcon(icon);
                 renderComponent.setText (u.getDisplayName());
                 renderComponent.setHorizontalAlignment(SwingConstants.LEFT);
             }
