@@ -44,15 +44,14 @@
 package org.netbeans.modules.autoupdate.ui;
 
 import java.awt.Color;
+import java.awt.Image;
 import java.io.CharConversionException;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Comparator;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.TreeSet;
 import java.util.logging.Level;
@@ -65,7 +64,7 @@ import org.netbeans.api.autoupdate.OperationContainer.OperationInfo;
 import org.netbeans.api.autoupdate.UpdateElement;
 import org.netbeans.api.autoupdate.UpdateManager;
 import org.netbeans.api.autoupdate.UpdateUnit;
-import org.netbeans.api.autoupdate.UpdateUnitProvider.CATEGORY;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.xml.XMLUtil;
@@ -78,7 +77,7 @@ public class UnitDetails extends DetailsPanel {
 
     private final Logger err = Logger.getLogger("org.netbeans.modules.autoupdate.ui.UnitDetails");
     private RequestProcessor.Task unitDetailsTask = null;
-    private static final RequestProcessor UNIT_DETAILS_PROCESSOR = new RequestProcessor("unit-details-processor", 1, true);
+    static final RequestProcessor UNIT_DETAILS_PROCESSOR = new RequestProcessor("unit-details-processor", 1, true);
 
     /** Creates a new instance of UnitDetails */
     public UnitDetails() {
@@ -133,11 +132,14 @@ public class UnitDetails extends DetailsPanel {
         StringBuilder text = new StringBuilder();
         if (u instanceof Unit.Available) {
             Unit.Available u1 = (Unit.Available) u;
-            CATEGORY c = u1.getSourceCategory();
-            String categoryName = Utilities.getCategoryName(c);
-            URL icon = Utilities.getCategoryIcon(c);
+            Image c = u1.getSourceIcon();
+            Object url = c.getProperty("url", null);
+            String categoryName = u1.getSourceDescription();
             text.append("<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\"><tr>");
-            text.append("<td><img src=\"" + icon.toExternalForm() + "\"></img></td>");
+            if (url instanceof URL) {
+                text.append("<td><img src=\"" + url + "\"></img></td>");
+            }
+            text.append("<td></td>");
             text.append("<td>&nbsp;&nbsp;</td>");
             text.append("<td><b>" + categoryName + "</b></td>");
             text.append("</tr></table><br>");
@@ -178,7 +180,12 @@ public class UnitDetails extends DetailsPanel {
 
         if (u.getDescription() != null && u.getDescription().length() > 0) {
             text.append("<br><h3>" + getBundle("UnitDetails_Plugin_Description") + "</h3>"); // NOI18N
-            text.append(u.getDescription());
+            String description = u.getDescription();
+            if(description.toLowerCase().startsWith("<html>")) {
+                text.append(description.substring(6));
+            } else {
+                text.append(description);
+            }
         }
         if (desc != null && desc.length() > 0) {
             text.append("<br><br><h4>" + getBundle("Unit_InternalUpdates_Title") + "</h4>"); // NOI18N
@@ -207,7 +214,14 @@ public class UnitDetails extends DetailsPanel {
         if (!(u instanceof Unit.InternalUpdate)) {
             OperationContainer<InstallSupport> container = OperationContainer.createForUpdate();
 
-            container.add(u.updateUnit, uu.getRelevantElement());
+            try {
+                container.add(u.updateUnit, uu.getRelevantElement());
+            } catch (IllegalArgumentException ex) {
+                Exceptions.attachMessage(ex, "Unit: " + u);
+                Exceptions.attachMessage(ex, "Unit.updateUnit: " + u.updateUnit);
+                Exceptions.attachMessage(ex, "Unit.getRelevantElement(): " + uu.getRelevantElement());
+                throw ex;
+            }
             Set<UpdateElement> required = new LinkedHashSet<UpdateElement>();
             List <OperationInfo<InstallSupport>> infos = container.listAll();
 
