@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -47,6 +50,7 @@ import org.netbeans.modules.autoupdate.ui.wizards.UninstallUnitWizard;
 import org.netbeans.modules.autoupdate.ui.wizards.InstallUnitWizard;
 import java.awt.Component;
 import java.awt.Cursor;
+import java.awt.Image;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.event.ActionEvent;
@@ -97,7 +101,6 @@ import javax.swing.table.TableModel;
 import org.netbeans.api.autoupdate.OperationContainer.OperationInfo;
 import org.netbeans.api.autoupdate.UpdateManager;
 import org.netbeans.api.autoupdate.UpdateUnit;
-import org.netbeans.api.autoupdate.UpdateUnitProvider.CATEGORY;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.modules.autoupdate.ui.wizards.OperationWizardModel.OperationType;
@@ -374,6 +377,28 @@ public class UnitTab extends javax.swing.JPanel {
             }, 150);
         }
     }
+
+    final void updateTab(final Map<String, Boolean> state) {
+        final Runnable addUpdates = new Runnable() {
+            @Override
+            public void run() {
+                final LocallyDownloadedTableModel downloadedTableModel = ((LocallyDownloadedTableModel) model);
+                List<UpdateUnit> empty = Collections.emptyList();
+                downloadedTableModel.setUnits(empty);
+                SwingUtilities.invokeLater(new Runnable()  {
+
+                    public void run() {
+                        fireUpdataUnitChange();
+                        UnitCategoryTableModel.restoreState(model.getUnits(), state, model.isMarkedAsDefault());
+                        refreshState();
+                        setWaitingState(false);
+                    }
+                });
+            }
+        };
+        setWaitingState(true);
+        Utilities.startAsWorkerThread(addUpdates, 250);
+    }
     
     private TabAction getDefaultAction () {
         return (TabAction)bTabAction.getAction ();
@@ -632,57 +657,57 @@ public class UnitTab extends javax.swing.JPanel {
             }
         });
 
-        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
+        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(layout.createSequentialGroup()
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(layout.createSequentialGroup()
                 .addContainerGap()
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-                    .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
-                        .add(topButton)
-                        .add(18, 18, 18)
-                        .add(detailView)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 375, Short.MAX_VALUE)
-                        .add(lSearch)
-                        .add(4, 4, 4)
-                        .add(tfSearch, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 114, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
-                    .add(spTab, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 712, Short.MAX_VALUE)
-                    .add(layout.createSequentialGroup()
-                        .add(bTabAction)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                        .add(bTabAction1)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                        .add(bTabAction2)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                        .add(lSelectionInfo)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
-                        .add(lWarning, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 482, Short.MAX_VALUE)
-                        .add(99, 99, 99)))
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
+                        .addComponent(topButton)
+                        .addGap(18, 18, 18)
+                        .addComponent(detailView)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 443, Short.MAX_VALUE)
+                        .addComponent(lSearch)
+                        .addGap(4, 4, 4)
+                        .addComponent(tfSearch, javax.swing.GroupLayout.PREFERRED_SIZE, 114, javax.swing.GroupLayout.PREFERRED_SIZE))
+                    .addComponent(spTab, javax.swing.GroupLayout.DEFAULT_SIZE, 776, Short.MAX_VALUE)
+                    .addGroup(layout.createSequentialGroup()
+                        .addComponent(bTabAction)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(bTabAction1)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(bTabAction2)
+                        .addGap(8, 8, 8)
+                        .addComponent(lSelectionInfo)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
+                        .addComponent(lWarning, javax.swing.GroupLayout.DEFAULT_SIZE, 542, Short.MAX_VALUE)
+                        .addGap(99, 99, 99)))
                 .addContainerGap())
         );
         layout.setVerticalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                 .addContainerGap()
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.CENTER)
-                    .add(tfSearch, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
-                    .add(lSearch)
-                    .add(topButton)
-                    .add(detailView))
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(spTab, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 73, Short.MAX_VALUE)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.CENTER, false)
-                    .add(bTabAction)
-                    .add(lSelectionInfo, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
-                    .add(lWarning)
-                    .add(bTabAction1)
-                    .add(bTabAction2))
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.CENTER)
+                    .addComponent(tfSearch, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
+                    .addComponent(lSearch)
+                    .addComponent(topButton)
+                    .addComponent(detailView))
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(spTab, javax.swing.GroupLayout.DEFAULT_SIZE, 73, Short.MAX_VALUE)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.CENTER, false)
+                    .addComponent(bTabAction)
+                    .addComponent(lSelectionInfo, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                    .addComponent(lWarning)
+                    .addComponent(bTabAction1)
+                    .addComponent(bTabAction2))
                 .addContainerGap())
         );
 
-        layout.linkSize(new java.awt.Component[] {lSelectionInfo, lWarning}, org.jdesktop.layout.GroupLayout.VERTICAL);
+        layout.linkSize(javax.swing.SwingConstants.VERTICAL, new java.awt.Component[] {lSelectionInfo, lWarning});
 
         lSearch.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(UnitTab.class, "ACD_Search")); // NOI18N
         topButton.getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(UnitTab.class, "ACN_Reload")); // NOI18N
@@ -1271,7 +1296,10 @@ public class UnitTab extends javax.swing.JPanel {
                 if (wizardFinished) {
                     reloadTask (false).schedule (10);
                 } else {
-                    UnitCategoryTableModel.restoreState (model.getUnits (), state, model.isMarkedAsDefault ());
+                    fireUpdataUnitChange ();
+                    if (!wizardFinished) {
+                        UnitCategoryTableModel.restoreState (model.getUnits (), state, model.isMarkedAsDefault ());
+                    }
                     restoreSelectedRow(row);                
                     refreshState ();
                 }
@@ -1842,28 +1870,10 @@ public class UnitTab extends javax.swing.JPanel {
         public void performerImpl () {
             final Map<String, Boolean> state = UnitCategoryTableModel.captureState (model.getUnits ());
             if (getLocalDownloadSupport ().chooseNbmFiles ()) {
-                
-                final Runnable addUpdates = new Runnable (){
-                    public void run () {
-                        final LocallyDownloadedTableModel downloadedTableModel = ((LocallyDownloadedTableModel) model);
-                        List<UpdateUnit> empty = Collections.emptyList();
-                        downloadedTableModel.setUnits(empty);
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run () {
-                                fireUpdataUnitChange();
-                                UnitCategoryTableModel.restoreState (model.getUnits (), state, model.isMarkedAsDefault ());                                
-                                refreshState ();
-                                setWaitingState (false);
-                            }
-                        });
-                    }
-                    
-                };
-                setWaitingState (true);
-                Utilities.startAsWorkerThread (addUpdates, 250);
+                updateTab (state);
             }
         }
-        
+
         @Override
         public void setEnabled (boolean enabled) {
             super.setEnabled (enabled);
@@ -1965,13 +1975,11 @@ public class UnitTab extends javax.swing.JPanel {
                 JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
             JLabel renderComponent = (JLabel)super.getTableCellRendererComponent (table, value, isSelected, hasFocus, row, column);
             
-            if (value instanceof CATEGORY) {
+            if (value instanceof Image) {
                 Unit u = model.getUnitAtRow (row);
                 if (u instanceof Unit.Available) {
                     Unit.Available a = (Unit.Available)u;
-                    CATEGORY state = a.getSourceCategory();
-                    URL icon = Utilities.getCategoryIcon(state);
-                    renderComponent.setIcon(new ImageIcon(icon));
+                    renderComponent.setIcon(ImageUtilities.image2Icon(a.getSourceIcon()));
                     renderComponent.setText ("");
                     renderComponent.setHorizontalAlignment (SwingConstants.CENTER);
                 }
