@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -86,23 +89,25 @@ public class UpdateTableModel extends UnitCategoryTableModel {
             return ;
         }
         super.setValueAt(anValue, row, col);
-        Unit.Update u = (Unit.Update) getUnitAtRow(row);
+        Unit u = getUnitAtRow(row);
         assert anValue instanceof Boolean : anValue + " must be instanceof Boolean.";
         boolean beforeMarked = u.isMarked();
-        u.setMarked(!beforeMarked);
-        if (u.isMarked() != beforeMarked) {
-            fireButtonsChange();
-        } else {
-            //TODO: message should contain spec.version
-            String message = NbBundle.getMessage(UpdateTableModel.class, "NotificationAlreadyPreparedToIntsall", u.getDisplayName()); // NOI18N
-            DialogDisplayer.getDefault().notify(new NotifyDescriptor.Message(message));
+        if ((Boolean) anValue != beforeMarked) {
+            u.setMarked(! beforeMarked);
+            if (u.isMarked() != beforeMarked) {
+                fireButtonsChange();
+            } else {
+                //TODO: message should contain spec.version
+                String message = NbBundle.getMessage(UpdateTableModel.class, "NotificationAlreadyPreparedToIntsall", u.getDisplayName()); // NOI18N
+                DialogDisplayer.getDefault().notify(new NotifyDescriptor.Message(message));
+            }
         }
     }
     
     public Object getValueAt(int row, int col) {
         Object res = null;
         if (isExpansionControlAtRow(row)) return "";//NOI18N
-        Unit.Update u = (Unit.Update) getUnitAtRow(row);
+        Unit u = getUnitAtRow(row);
         switch (col) {
         case 0 :
             res = u.isMarked() ? Boolean.TRUE : Boolean.FALSE;
@@ -246,7 +251,7 @@ public class UpdateTableModel extends UnitCategoryTableModel {
 
     @Override
     public boolean isTabEnabled() {
-        return getRawItemCount() > 0;
+        return true;//getRawItemCount() > 0;
     }
 
     public boolean needsRestart () {
