@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -135,23 +138,29 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
     private boolean wasStored = false;
     private boolean runInBg = false;
     private OperationException installException;
+    private final boolean allowRunInBackground;
     
     /** Creates a new instance of OperationDescriptionStep */
     public InstallStep (InstallUnitWizardModel model) {
         this (model, false);
     }
     public InstallStep (InstallUnitWizardModel model, boolean clearLazyUnits) {
+        this(model, clearLazyUnits, true);
+    }
+    public InstallStep (InstallUnitWizardModel model, boolean clearLazyUnits, boolean allowRunInBackground) {
         this.model = model;
         this.clearLazyUnits = clearLazyUnits;
+        this.allowRunInBackground = allowRunInBackground;
     }
     
     public boolean isFinishPanel() {
         return true;
     }
 
+    @Override
     public PanelBodyContainer getComponent() {
         if (component == null) {
-            panel = new OperationPanel (true);
+            panel = new OperationPanel(allowRunInBackground);
             panel.addPropertyChangeListener (new PropertyChangeListener () {
                     public void propertyChange (PropertyChangeEvent evt) {
                         if (OperationPanel.RUN_ACTION.equals (evt.getPropertyName ())) {
@@ -171,7 +180,8 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
     }
     
     private RequestProcessor.Task createInstallTask () {
-        return RequestProcessor.getDefault ().create (new Runnable () {
+        return org.netbeans.modules.autoupdate.ui.actions.Installer.RP.create (new Runnable () {
+            @Override
             public void run () {
                 doDownloadAndVerificationAndInstall ();
             }
@@ -204,7 +214,8 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         OperationContainer installContainer = model.getBaseContainer ();
         final InstallSupport support = model.getInstallSupport ();
         assert support != null : "OperationSupport cannot be null because OperationContainer " +
-                "contains elements: " + installContainer.listAll () + " and invalid elements " + installContainer.listInvalid ();
+                "contains elements: " + installContainer.listAll () + " and invalid elements " + installContainer.listInvalid () + "\ncontainer: " + installContainer;
+        assert installContainer.listInvalid ().isEmpty () : support + ".listInvalid().isEmpty() but " + installContainer.listInvalid () + " container: " + installContainer;
         
         boolean finish = false;
         while (! finish) {
@@ -226,17 +237,18 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         if (inBackground) {
             assert SwingUtilities.isEventDispatchThread () : "In AWT queue only.";
             Window w = SwingUtilities.getWindowAncestor (getComponent ());
+            if (spareHandle != null && !spareHandleStarted) {
+                indeterminateProgress = true;
+                spareHandle.setInitialDelay(0);
+                spareHandle.start();
+                spareHandleStarted = true;
+            }
             if (w != null) {
                 w.setVisible (false);
             }
             if (model.getPluginManager () != null) {
                 model.getPluginManager ().close ();
             }
-            if (spareHandle != null && ! spareHandleStarted) {
-                indeterminateProgress = true;
-                spareHandle.start ();
-                spareHandleStarted = true;
-            }
         } else {
             assert false : "Cannot set runInBackground to false";
         }
