@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -42,6 +45,7 @@
 package org.netbeans.modules.autoupdate.ui.wizards;
 
 import java.awt.Component;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -66,6 +70,7 @@ import org.netbeans.api.autoupdate.UpdateManager;
 import org.netbeans.api.autoupdate.UpdateUnit;
 import org.netbeans.modules.autoupdate.ui.Containers;
 import org.netbeans.modules.autoupdate.ui.Utilities;
+import org.netbeans.modules.autoupdate.ui.actions.Installer;
 import org.netbeans.modules.autoupdate.ui.wizards.OperationWizardModel.OperationType;
 import org.openide.WizardDescriptor;
 import org.openide.modules.Dependency;
@@ -177,7 +182,8 @@ public class OperationDescriptionStep implements WizardDescriptor.Panel<WizardDe
     }
     
     private void appendDependingLazy (final String tableTitle, final String dependenciesTitle) {
-        lazyDependingTask = RequestProcessor.getDefault ().post (new Runnable () {
+        lazyDependingTask = Installer.RP.post (new Runnable () {
+            @Override
             public void run () {
                 JPanel body = null;
                 // init required elements
@@ -188,33 +194,38 @@ public class OperationDescriptionStep implements WizardDescriptor.Panel<WizardDe
                     ((InstallUnitWizardModel) model).hasStandardComponents ();
                 }
                 boolean hasBrokenDependencies = model.hasBrokenDependencies ();
+                final String[] args = { null, null, null, null };
+                final boolean[] barg = { false };
                 if (hasBrokenDependencies) {
-                    body = new OperationDescriptionPanel ("", "",
-                            prepareBrokenDependenciesForShow (model),
-                            "",
-                            true);
+                    args[0] = "";
+                    args[1] = "";
+                    args[2] = prepareBrokenDependenciesForShow (model);
+                    args[3] = "";
+                    barg[0] = true;
                 } else {
-                    body = new OperationDescriptionPanel (tableTitle,
-                            preparePluginsForShow (
+                    args[0] = tableTitle;
+                    args[1] = preparePluginsForShow (
                                 model.getPrimaryUpdateElements(),
                                 model.getPrimaryVisibleUpdateElements(true),
                                 model.getCustomHandledComponents (),
                                 model.getOperation (),
-                                true),
-                            dependenciesTitle,
-                            preparePluginsForShow (
+                                true);
+                    args[2] = dependenciesTitle;
+                    args[3] = preparePluginsForShow (
                                 model.getRequiredUpdateElements(),
                                 model.getRequiredVisibleUpdateElements(),
                                 null,
                                 model.getOperation (),
-                                true),
-                            ! model.getRequiredVisibleUpdateElements().isEmpty ());
+                                true);
+                    barg[0] = !model.getRequiredVisibleUpdateElements().isEmpty();
                 }
-                final JPanel finalPanel = body;
                 readyToGo = model != null && ! hasBrokenDependencies;
                 SwingUtilities.invokeLater (new Runnable () {
                     public void run () {
-                        component.setBody (finalPanel);
+                        JPanel p = new OperationDescriptionPanel(
+                            args[0], args[1], args[2], args[3], barg[0]
+                        );
+                        component.setBody (p);
                         component.setWaitingState (false);
                         fireChange ();
                     }
@@ -425,7 +436,7 @@ public class OperationDescriptionStep implements WizardDescriptor.Panel<WizardDe
                         }
                     } else {
                         updatename += getBundle("OperationDescriptionStep_UpdatePluginVersionFormat", oldVersion, newVersion);
-                        if(checkInternalUpdates) {
+                        if(checkInternalUpdates && !el.getUpdateUnit().isPending()) {
                             container.add(el);
                         }
                     }
@@ -494,7 +505,12 @@ public class OperationDescriptionStep implements WizardDescriptor.Panel<WizardDe
                 }
                 names.add (updatename);
             }
-            Collections.sort (names);
+            Collections.sort(names, new Comparator<String>() {
+
+                public int compare(String o1, String o2) {
+                    return Collator.getInstance().compare(o1, o2);
+                }
+            });
             for (String name : names) {
                 s += name;
             }
