@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -43,7 +46,10 @@ package org.netbeans.modules.autoupdate.ui.wizards;
 
 import java.awt.BorderLayout;
 import java.awt.Dimension;
+import java.text.Collator;
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.List;
 import java.util.Set;
 import javax.swing.JComponent;
@@ -52,7 +58,7 @@ import javax.swing.JTextArea;
 import javax.swing.JTextPane;
 import javax.swing.SwingUtilities;
 import org.netbeans.api.autoupdate.UpdateElement;
-import org.openide.util.RequestProcessor;
+import org.netbeans.modules.autoupdate.ui.actions.Installer;
 
 /**
  *
@@ -76,7 +82,8 @@ public class OperationPanel extends javax.swing.JPanel {
     @Override
     public void addNotify () {
         super.addNotify ();
-        RequestProcessor.getDefault ().post(new Runnable () {
+        Installer.RP.post(new Runnable () {
+            @Override
             public void run () {
                 firePropertyChange (RUN_ACTION, null, Boolean.TRUE);
             }
@@ -153,6 +160,14 @@ public class OperationPanel extends javax.swing.JPanel {
     
     public void setBody (final String msg, final Set<UpdateElement> updateElements) {
         final List<UpdateElement> elements = new ArrayList<UpdateElement> (updateElements);
+        
+        Collections.sort(elements, new Comparator<UpdateElement>() {
+
+                public int compare(UpdateElement o1, UpdateElement o2) {
+                    return Collator.getInstance().compare(o1.getDisplayName(), o2.getDisplayName());
+                }
+            });
+        
         if (SwingUtilities.isEventDispatchThread ()) {
             setBodyInEQ (msg, elements);
         } else {
@@ -167,7 +182,8 @@ public class OperationPanel extends javax.swing.JPanel {
     private void setBodyInEQ (String msg, List<UpdateElement> elements) {
         pProgress.removeAll ();
         pProgress.add (getTitleComponent (msg), BorderLayout.NORTH);
-        pProgress.add (getElementsComponent (elements), BorderLayout.CENTER);
+        pContainerList2.add(getElementsComponent(elements), BorderLayout.CENTER);
+        pProgress.add(pContainerList1, BorderLayout.CENTER);
         pAboveSpace.setVisible(false);
         revalidate ();
     }
@@ -175,7 +191,8 @@ public class OperationPanel extends javax.swing.JPanel {
     private void setBodyInEQ (String msg, String elements) {
         pProgress.removeAll ();
         pProgress.add (getTitleComponent (msg), BorderLayout.NORTH);
-        pProgress.add (getElementsComponent (elements), BorderLayout.CENTER);
+        pContainerList2.add(getElementsComponent(elements), BorderLayout.CENTER);
+        pProgress.add (pContainerList1, BorderLayout.CENTER);
         pAboveSpace.setVisible(false);
         revalidate ();
     }
@@ -215,6 +232,9 @@ public class OperationPanel extends javax.swing.JPanel {
     private void initComponents() {
 
         bgRestartButtons = new javax.swing.ButtonGroup();
+        pContainerList1 = new javax.swing.JPanel();
+        jScrollPane1 = new javax.swing.JScrollPane();
+        pContainerList2 = new javax.swing.JPanel();
         pAboveSpace = new javax.swing.JPanel();
         pProgress = new javax.swing.JPanel();
         pbPlaceHolder = new javax.swing.JProgressBar();
@@ -224,17 +244,35 @@ public class OperationPanel extends javax.swing.JPanel {
         rbRestartLater = new javax.swing.JRadioButton();
         cbRunInBackground = new javax.swing.JCheckBox();
 
+        pContainerList2.setLayout(new java.awt.BorderLayout());
+        jScrollPane1.setViewportView(pContainerList2);
+
+        javax.swing.GroupLayout pContainerList1Layout = new javax.swing.GroupLayout(pContainerList1);
+        pContainerList1.setLayout(pContainerList1Layout);
+        pContainerList1Layout.setHorizontalGroup(
+            pContainerList1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGap(0, 156, Short.MAX_VALUE)
+            .addGroup(pContainerList1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                .addComponent(jScrollPane1, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 156, Short.MAX_VALUE))
+        );
+        pContainerList1Layout.setVerticalGroup(
+            pContainerList1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGap(0, 144, Short.MAX_VALUE)
+            .addGroup(pContainerList1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                .addComponent(jScrollPane1, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 144, Short.MAX_VALUE))
+        );
+
         pAboveSpace.setOpaque(false);
 
-        org.jdesktop.layout.GroupLayout pAboveSpaceLayout = new org.jdesktop.layout.GroupLayout(pAboveSpace);
+        javax.swing.GroupLayout pAboveSpaceLayout = new javax.swing.GroupLayout(pAboveSpace);
         pAboveSpace.setLayout(pAboveSpaceLayout);
         pAboveSpaceLayout.setHorizontalGroup(
-            pAboveSpaceLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(0, 148, Short.MAX_VALUE)
+            pAboveSpaceLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGap(0, 157, Short.MAX_VALUE)
         );
         pAboveSpaceLayout.setVerticalGroup(
-            pAboveSpaceLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(0, 65, Short.MAX_VALUE)
+            pAboveSpaceLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGap(0, 65, Short.MAX_VALUE)
         );
 
         pProgress.setLayout(new java.awt.BorderLayout());
@@ -269,33 +307,33 @@ public class OperationPanel extends javax.swing.JPanel {
             }
         });
 
-        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
+        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(layout.createSequentialGroup()
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(layout.createSequentialGroup()
                 .addContainerGap()
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-                    .add(pProgress, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 148, Short.MAX_VALUE)
-                    .add(pAboveSpace, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
-                    .add(cbRunInBackground)
-                    .add(rbRestartNow, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 148, Short.MAX_VALUE)
-                    .add(rbRestartLater, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 148, Short.MAX_VALUE))
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                    .addComponent(pProgress, javax.swing.GroupLayout.DEFAULT_SIZE, 157, Short.MAX_VALUE)
+                    .addComponent(pAboveSpace, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
+                    .addComponent(cbRunInBackground)
+                    .addComponent(rbRestartNow, javax.swing.GroupLayout.DEFAULT_SIZE, 157, Short.MAX_VALUE)
+                    .addComponent(rbRestartLater, javax.swing.GroupLayout.DEFAULT_SIZE, 157, Short.MAX_VALUE))
                 .addContainerGap())
         );
         layout.setVerticalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(layout.createSequentialGroup()
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(layout.createSequentialGroup()
                 .addContainerGap()
-                .add(pAboveSpace, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(pProgress, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(cbRunInBackground)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(rbRestartNow)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(rbRestartLater)
+                .addComponent(pAboveSpace, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(pProgress, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(cbRunInBackground)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(rbRestartNow)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(rbRestartLater)
                 .addContainerGap(45, Short.MAX_VALUE))
         );
     }// </editor-fold>//GEN-END:initComponents
@@ -316,9 +354,12 @@ private void cbRunInBackgroundActionPerformed(java.awt.event.ActionEvent evt) {/
     // Variables declaration - do not modify//GEN-BEGIN:variables
     private javax.swing.ButtonGroup bgRestartButtons;
     private javax.swing.JCheckBox cbRunInBackground;
+    private javax.swing.JScrollPane jScrollPane1;
     private javax.swing.JLabel lDetailLabel;
     private javax.swing.JLabel lMainLabel;
     private javax.swing.JPanel pAboveSpace;
+    private javax.swing.JPanel pContainerList1;
+    private javax.swing.JPanel pContainerList2;
     private javax.swing.JPanel pProgress;
     private javax.swing.JProgressBar pbPlaceHolder;
     private javax.swing.JRadioButton rbRestartLater;
