@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -59,8 +62,10 @@ import javax.swing.SwingUtilities;
 import javax.swing.Timer;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
+import org.netbeans.modules.autoupdate.ui.actions.Installer;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
+import org.openide.util.RequestProcessor.Task;
 
 /**
  *
@@ -189,25 +194,7 @@ public class PanelBodyContainer extends javax.swing.JPanel {
             handle.start ((int) friendlyEstimatedTime * 10, friendlyEstimatedTime); 
             handle.progress (progressDisplayName, 0);
 
-            RequestProcessor.getDefault ().post (new Runnable () {
-                public void run () {
-                    int i = 0;
-                    while (isWaiting) {
-                        try {
-                            if (friendlyEstimatedTime * 10 > i++) {
-                                handle.progress (progressDisplayName, i);
-                            } else {
-                                handle.switchToIndeterminate ();
-                                handle.progress (progressDisplayName);
-                                return ;
-                            }
-                            Thread.sleep (100);
-                        } catch (InterruptedException ex) {
-                            // no worries
-                        }
-                    }
-                }
-            });
+            new UpdateProgress (friendlyEstimatedTime, progressDisplayName).start();
         }
     }
 
@@ -277,25 +264,24 @@ public class PanelBodyContainer extends javax.swing.JPanel {
 
         pBodyPanel.setLayout(new java.awt.BorderLayout());
 
-        tpPanelHeader.setBackground(java.awt.SystemColor.controlLtHighlight);
         tpPanelHeader.setContentType("text/html"); // NOI18N
         tpPanelHeader.setEditable(false);
         spPanelHeader.setViewportView(tpPanelHeader);
         tpPanelHeader.getAccessibleContext().setAccessibleName(head);
 
-        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
+        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(pBodyPanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 24, Short.MAX_VALUE)
-            .add(org.jdesktop.layout.GroupLayout.TRAILING, spPanelHeader, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 24, Short.MAX_VALUE)
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addComponent(pBodyPanel, javax.swing.GroupLayout.DEFAULT_SIZE, 24, Short.MAX_VALUE)
+            .addComponent(spPanelHeader, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 24, Short.MAX_VALUE)
         );
         layout.setVerticalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(layout.createSequentialGroup()
-                .add(spPanelHeader, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 78, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(pBodyPanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(layout.createSequentialGroup()
+                .addComponent(spPanelHeader, javax.swing.GroupLayout.PREFERRED_SIZE, 78, javax.swing.GroupLayout.PREFERRED_SIZE)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(pBodyPanel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
         );
 
         getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(PanelBodyContainer.class, "PanelBodyContainer_ACN")); // NOI18N
@@ -308,5 +294,36 @@ public class PanelBodyContainer extends javax.swing.JPanel {
     private javax.swing.JScrollPane spPanelHeader;
     private javax.swing.JTextPane tpPanelHeader;
     // End of variables declaration//GEN-END:variables
+
+    private final class UpdateProgress implements Runnable {
+        private final long friendlyEstimatedTime;
+        private final String progressDisplayName;
+        private final Task task;
+
+        public UpdateProgress(long friendlyEstimatedTime, String progressDisplayName) {
+            this.friendlyEstimatedTime = friendlyEstimatedTime;
+            this.progressDisplayName = progressDisplayName;
+            this.task = Installer.RP.post(this);
+        }
+
+        @Override
+        public void run () {
+            int i = 0;
+            if (isWaiting && isShowing()) {
+                if (friendlyEstimatedTime * 10 > i++) {
+                    handle.progress (progressDisplayName, i);
+                } else {
+                    handle.switchToIndeterminate ();
+                    handle.progress (progressDisplayName);
+                    return ;
+                }
+                task.schedule(100);
+            }
+        }
+
+        final void start() {
+            task.schedule(0);
+        }
+    }
     
 }
