@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.modules.bugtracking.issuetable;
 
+import javax.swing.JButton;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.TableColumnModelEvent;
@@ -63,15 +67,18 @@ import java.awt.event.ActionListener;
 import java.awt.event.KeyListener;
 import java.beans.PropertyChangeListener;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.logging.Level;
 import javax.swing.Action;
 import javax.swing.BorderFactory;
+import javax.swing.ImageIcon;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JScrollPane;
@@ -80,6 +87,7 @@ import javax.swing.KeyStroke;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.event.TableColumnModelListener;
+import javax.swing.event.TableModelListener;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumnModel;
 import org.netbeans.modules.bugtracking.BugtrackingConfig;
@@ -87,9 +95,13 @@ import org.netbeans.modules.bugtracking.BugtrackingManager;
 import org.netbeans.modules.bugtracking.spi.Issue;
 import org.netbeans.modules.bugtracking.spi.Query;
 import org.netbeans.modules.bugtracking.spi.QueryNotifyListener;
+import org.netbeans.modules.bugtracking.ui.query.IssueTableSupport;
 import org.netbeans.modules.bugtracking.util.BugtrackingUtil;
+import org.netbeans.modules.bugtracking.util.UIUtils;
 import org.openide.awt.MouseUtils;
+import org.openide.explorer.view.TreeTableView;
 import org.openide.nodes.Node;
+import org.openide.util.ImageUtilities;
 import org.openide.util.RequestProcessor.Task;
 
 /**
@@ -103,10 +115,8 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
 
     private TableSorter     sorter;
 
-    private int seenColumnIdx = -1;
-    private int recentChangesColumnIdx = -1;
     private Query query;
-    private final ColumnDescriptor[] descriptors;
+    private ColumnDescriptor[] descriptors;
 
     private Filter filter;
     private Filter[] filters;
@@ -114,26 +124,23 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
 
     private QueryTableHeaderRenderer queryTableHeaderRenderer;
 
-    private Task storeColumnsWidthTask;
-    private final StoreColumnWidthsHandler storeColumnsWidthHandler;
+    private Task storeColumnsTask;
+    private final StoreColumnsHandler storeColumnsWidthHandler;
+    private final JButton colsButton;
+    private boolean savedQueryInitialized;
+    private SummaryTextFilter textFilter;
+
+    private static final String CONFIG_DELIMITER = "<=>";                       // NOI18N
 
     /**
-     * Returns the issue table filters
-     * @return
+     * Implement in an issue to provide access to its IssueNode
      */
-    public Filter[] getDefinedFilters() {
-        if(filters == null) {
-            filters = new Filter[] {
-                Filter.getAllFilter(query),
-                Filter.getNotSeenFilter(),
-                Filter.getObsoleteDateFilter(query),
-                Filter.getAllButObsoleteDateFilter(query)
-            };
-        }
-        return filters;
+    public static interface NodeProvider {
+        IssueNode getNode();
     }
 
     private static final Comparator<IssueProperty> NodeComparator = new Comparator<IssueProperty>() {
+        @Override
         public int compare(IssueProperty p1, IssueProperty p2) {
             Integer sk1 = (Integer) p1.getValue("sortkey"); // NOI18N
             if (sk1 != null) {
@@ -150,7 +157,6 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
     };
 
-
     public IssueTable(Query query, ColumnDescriptor[] descriptors) {
         assert query != null;
         assert descriptors != null;
@@ -163,7 +169,9 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         query.addPropertyChangeListener(this);
 
         tableModel = new NodeTableModel();
-        sorter = new TableSorter(tableModel);
+        sorter = new TableSorter(tableModel, this);
+        
+        initFilters();
 
         sorter.setColumnComparator(Node.Property.class, NodeComparator);
         table = new JTable(sorter);
@@ -174,9 +182,25 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         Color borderColor = UIManager.getColor("scrollpane_border"); // NOI18N
         if (borderColor == null) borderColor = UIManager.getColor("controlShadow"); // NOI18N
         component.setBorder(BorderFactory.createMatteBorder(1, 0, 0, 0, borderColor));
+
+        ImageIcon ic = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/bugtracking/ui/resources/columns_16.png", true)); // NOI18N
+        colsButton = new javax.swing.JButton(ic);
+        colsButton.getAccessibleContext().setAccessibleName(NbBundle.getMessage(TreeTableView.class, "ACN_ColumnsSelector")); //NOI18N
+        colsButton.getAccessibleContext().setAccessibleDescription(NbBundle.getMessage(TreeTableView.class, "ACD_ColumnsSelector")); //NOI18N
+        colsButton.addActionListener(
+            new ActionListener() {
+                public void actionPerformed(ActionEvent evt) {
+                    if(tableModel.selectVisibleColumns()) {
+                        storeColumnsTask.schedule(1000);
+                    }
+                }
+            }
+        );
+        component.setCorner(JScrollPane.UPPER_RIGHT_CORNER, colsButton);
+
         table.addMouseListener(this);
         table.addKeyListener(this);
-        table.setDefaultRenderer(Node.Property.class, new QueryTableCellRenderer(query));
+        table.setDefaultRenderer(Node.Property.class, new QueryTableCellRenderer(query, this));
         queryTableHeaderRenderer = new QueryTableHeaderRenderer(table.getTableHeader().getDefaultRenderer(), this, query);
         table.getTableHeader().setDefaultRenderer(queryTableHeaderRenderer);
         table.addAncestorListener(this);
@@ -185,54 +209,222 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
 
         initColumns();
         table.getTableHeader().addMouseListener(new MouseListener() {
+            @Override
             public void mouseClicked(MouseEvent e) {}
+            @Override
             public void mousePressed(MouseEvent e) {
                 table.getColumnModel().addColumnModelListener(tcml);
             }
+            @Override
             public void mouseReleased(MouseEvent e) {
                 table.getColumnModel().removeColumnModelListener(tcml);
             }
+            @Override
             public void mouseEntered(MouseEvent e) {}
+            @Override
             public void mouseExited(MouseEvent e) {}
         });
 
         table.getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT ).put(
                 KeyStroke.getKeyStroke(KeyEvent.VK_F10, KeyEvent.SHIFT_DOWN_MASK ), "org.openide.actions.PopupAction"); // NOI18N
-        BugtrackingUtil.fixFocusTraversalKeys(table);
+        UIUtils.fixFocusTraversalKeys(table);
 
-        storeColumnsWidthHandler = new StoreColumnWidthsHandler();
-        storeColumnsWidthTask = BugtrackingManager.getInstance()
+        storeColumnsWidthHandler = new StoreColumnsHandler();
+        storeColumnsTask = BugtrackingManager.getInstance()
                                                 .getRequestProcessor()
                                                 .create(storeColumnsWidthHandler);
+
+        IssueTableSupport.getInstance().put(query, this);
     }
 
-    int getSeenColumnIdx() {
-        return seenColumnIdx;
+    /**
+     * Returns the issue table filters
+     * @return
+     */
+    public Filter[] getDefinedFilters() {
+        return filters;
     }
 
+    /**
+     * Reset the filter criteria set in
+     * {@link #setFilterBySummary(java.lang.String, boolean, boolean, boolean) }
+     */
+    public void resetFilterBySummary() {
+        setFilterIntern(filter);
+    }
+
+    /**
+     * Switch highlighting in rows matching the filter criteria set in
+     * {@link #setFilterBySummary(java.lang.String, boolean, boolean, boolean) }
+     * @param on
+     */
+    public void switchFilterBySummaryHighlight(boolean on) {
+        assert textFilter != null;
+        if(textFilter == null) {
+            return;
+        }
+        textFilter.setHighlighting(on);
+        table.repaint();
+    }
+
+    /**
+     * Given values are used to filter the current issue hitlist
+     *
+     * @param searchText
+     * @param regular
+     * @param wholeWords
+     * @param matchCase
+     */
+    public void setFilterBySummary(String searchText, boolean regular, boolean wholeWords, boolean matchCase) {
+        if(textFilter == null) {
+            textFilter = new SummaryTextFilter();
+        }
+        textFilter.setText(searchText, regular, wholeWords, matchCase);
+        setFilterIntern(textFilter);
+    }
+
+    /**
+     * Sets the renderer in the underlying JTable
+     * @param renderer
+     */
     public void setRenderer(TableCellRenderer renderer) {
         table.setDefaultRenderer(Node.Property.class, renderer);
     }
 
+    /**
+     * Gets the renderer from the underlying JTable
+     * @return
+     */
     public TableCellRenderer getRenderer() {
         return table.getDefaultRenderer(Node.Property.class);
     }
 
+    /**
+     * Sets a filter on the current issue hitlist
+     * @param filter
+     */
     public void setFilter(Filter filter) {
         this.filter = filter;
+        setFilterIntern(filter);
+    }
+
+    @Override
+    public void propertyChange(PropertyChangeEvent evt) {
+        if(evt.getPropertyName().equals(Query.EVENT_QUERY_SAVED)) {
+            SwingUtilities.invokeLater(new Runnable() {
+                @Override
+                public void run() {
+                    initColumns();
+                }
+            });
+        }
+    }
+
+    /**
+     * Returns a UI component holding this tables visual representation
+     * @return
+     */
+    public JComponent getComponent() {
+        return component;
+    }
+
+    /**
+     * Sets visible columns in the Versioning table.
+     *
+     * @param columns array of column names, they must be one of SyncFileNode.COLUMN_NAME_XXXXX constants.
+     */
+    public final void initColumns() {
+        if(savedQueryInitialized) {
+            return;
+        }
+        setModelProperties(query);
+        if(descriptors.length > 0) {
+            Map<Integer, Integer> sorting = getColumnSorting();
+            if(descriptors.length > 1) {
+                for (int i = 0; i < descriptors.length; i++) {
+                    int visibleIdx = tableModel.getVisibleIndex(i);
+                    Integer order = sorting.get(visibleIdx);
+                    if(order != null) {
+                        sorter.setSortingStatus(visibleIdx, order); 
+                    } else {
+                        if(i == 0) {
+                            sorter.setSortingStatus(0, TableSorter.ASCENDING); // default sorting by first column
+                        } else {
+                            sorter.setColumnComparator(i, null);
+                            sorter.setSortingStatus(i, TableSorter.NOT_SORTED);
+                        }                        
+                    }
+                }
+            }
+        }
+        setDefaultColumnSizes();
+        if(query.isSaved()) {
+            savedQueryInitialized = true;
+        }
+    }
+
+    /**
+     * Callback from sorter. It also throws an event when the order is changed, unfortunatelly
+     * that also applyies for chages caused by refreshing a query and there is no way to 
+     * distinguish between those events. 
+     */
+    void sortOrderChanged() {
+        // sorting changed
+        StringBuilder sb = new StringBuilder();
+        for(int i = 0; i < sorter.getColumnCount(); i++) {
+            if(i > 0) {
+                sb.append(CONFIG_DELIMITER);
+            }
+            sb.append(i).append(CONFIG_DELIMITER).append(sorter.getSortingStatus(i));
+        }
+        BugtrackingConfig.getInstance().storeColumnSorting(getColumnsKey(), sb.toString());
+    }
+
+    private Map<Integer, Integer> getColumnSorting() {
+        String sortingString = BugtrackingConfig.getInstance().getColumnSorting(getColumnsKey());
+        if(sortingString == null || sortingString.equals("")) {
+            return Collections.EMPTY_MAP;
+        }
+        Map<Integer, Integer> map = new HashMap<Integer, Integer>();
+        String[] sortingArray = sortingString.split(CONFIG_DELIMITER);
+        for (int i = 0; i < sortingArray.length; i+=2) {
+            try {
+                map.put(Integer.parseInt(sortingArray[i]),
+                        Integer.parseInt(sortingArray[i + 1]));
+            } catch (NumberFormatException e) {
+                BugtrackingManager.LOG.log(Level.FINE, null, e);
+            } catch (ArrayIndexOutOfBoundsException e) {
+                BugtrackingManager.LOG.log(Level.FINE, null, e);
+            }
+        }
+        return map;
+    }
+
+    private void initFilters() {
+        filters = new Filter[]{Filter.getAllFilter(query), Filter.getNotSeenFilter(query), Filter.getObsoleteDateFilter(query), Filter.getAllButObsoleteDateFilter(query)};
+        filter = filters[0]; // preset the first filter as default
+    }
+    
+    int getSeenColumnIdx() {
+        return tableModel.getIndexForPropertyName(IssueNode.LABEL_NAME_SEEN);
+    }
+
+    int getRecentChangesColumnIdx() {
+        return tableModel.getIndexForPropertyName(IssueNode.LABEL_RECENT_CHANGES);
+    }
+
+    private void setFilterIntern(Filter filter) {
         List<IssueNode> issueNodes = new ArrayList<IssueNode>(issues.size());
         for (Issue issue : issues) {
-            if(filter == null || filter.accept(issue)) {
-                issueNodes.add(issue.getNode());
+            if (filter == null || filter.accept(issue)) {
+                issueNodes.add(((NodeProvider) issue).getNode());
             }
         }
         setTableModel(issueNodes.toArray(new IssueNode[issueNodes.size()]));
     }
 
-    public void propertyChange(PropertyChangeEvent evt) {
-        if(evt.getPropertyName().equals(Query.EVENT_QUERY_SAVED)) {
-            initColumns();
-        }
+    SummaryTextFilter getSummaryFilter() {
+        return textFilter;
     }
 
     private class CellAction implements ActionListener {
@@ -262,7 +454,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
         @Override
         public String toString() {
-            StringBuffer sb = new StringBuffer();
+            StringBuilder sb = new StringBuilder();
             sb.append("[");             // NOI18N
             sb.append("bounds=");       // NOI18N
             sb.append(bounds);
@@ -273,6 +465,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
             listener.actionPerformed(e);
         }
     }
+
     private class Cell {
         private final int row;
         private final int column;
@@ -303,7 +496,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
         @Override
         public String toString() {
-            StringBuffer sb = new StringBuffer();
+            StringBuilder sb = new StringBuilder();
             sb.append("[");         // NOI18N
             sb.append("row=");      // NOI18N
             sb.append(row);
@@ -314,6 +507,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
     }
     private final Map<Cell, Set<CellAction>> cellActions = new HashMap<Cell, Set<CellAction>>();
+
     public void addCellAction(int row, int column, Rectangle bounds, ActionListener l) {
         synchronized(cellActions) {
             Cell cell = new Cell(row, column);
@@ -335,9 +529,22 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
 
     void setDefaultColumnSizes() {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
-                int[] widths = BugtrackingConfig.getInstance().getColumnWidths(getColumnWidthsKey());
-                if(widths != null && widths.length > 0) {
+                int[] widths = BugtrackingConfig.getInstance().getColumnWidths(getColumnsKey());
+                Map<String, Integer> persistedColumnsMap = getPersistedColumnValues();
+                if(persistedColumnsMap.size() > 0) {
+                    final TableColumnModel columnModel = table.getColumnModel();
+                    int columnCount = columnModel.getColumnCount();
+                    for (int i = 0; i < columnCount; i++) {
+                        String id = tableModel.getColumnId(i);
+                        Integer w = persistedColumnsMap.get(id);
+                        if(w != null && w > 0) {
+                            setColumnWidth(i, w);
+                        }
+                    }
+                } else if(widths != null && widths.length > 0) {
+                    // XXX for backward comp. remove together with BugtrackingConfig.getInstance().getColumnWidths
                     int columnCount = table.getColumnModel().getColumnCount();
                     for (int i = 0; i < widths.length && i < columnCount; i++) {
                         int w = widths[i];
@@ -346,8 +553,9 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
                         }
                     }
                 } else {
-                    for (int i = 0; i < descriptors.length; i++) {
-                        ColumnDescriptor desc = descriptors[i];
+                    ColumnDescriptor[] visibleDescriptors = getVisibleDescriptors();
+                    for (int i = 0; i < visibleDescriptors.length; i++) {
+                        ColumnDescriptor desc = visibleDescriptors[i];
                         int w = desc.getWidth();
                         if(w > 0) {
                             setColumnWidth(i, w);
@@ -356,14 +564,15 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
                         }
                     }
                     if(query.isSaved()) {
-                        int w = BugtrackingUtil.getColumnWidthInPixels(25, table);
-                        setColumnWidth(recentChangesColumnIdx, w);
+                        int w = UIUtils.getColumnWidthInPixels(25, table);
+                        setColumnWidth(getRecentChangesColumnIdx(), w);
                     }
                 }
 
                 if(query.isSaved()) {
-                    table.getColumnModel().getColumn(seenColumnIdx).setMaxWidth(28);
-                    table.getColumnModel().getColumn(seenColumnIdx).setPreferredWidth(28);
+                    int seenIdx = getSeenColumnIdx();
+                    table.getColumnModel().getColumn(seenIdx).setMaxWidth(28);
+                    table.getColumnModel().getColumn(seenIdx).setPreferredWidth(28);
                 }
             }
 
@@ -384,46 +593,33 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
                     }
                 }
             }
+
         });
     }
 
+    private ColumnDescriptor[] getVisibleDescriptors() {
+        List<ColumnDescriptor> visible = new LinkedList<ColumnDescriptor>();
+        for (ColumnDescriptor d : descriptors) {
+            if(d.isVisible()) {
+                visible.add(d);
+            }
+        }
+        return visible.toArray(new ColumnDescriptor[visible.size()]);
+    }
 
-
+    @Override
     public void ancestorAdded(AncestorEvent event) {
         setDefaultColumnSizes();
     }
 
-    public void ancestorMoved(AncestorEvent event) {
-    }
+    @Override
+    public void ancestorMoved(AncestorEvent event) { }
 
-    public void ancestorRemoved(AncestorEvent event) {
-
-    }
-
-    public JComponent getComponent() {
-        return component;
-    }
-
-    /**
-     * Sets visible columns in the Versioning table.
-     *
-     * @param columns array of column names, they must be one of SyncFileNode.COLUMN_NAME_XXXXX constants.
-     */
-    public final void initColumns() {
-        setModelProperties(query);
-        for (int i = 0; i < descriptors.length; i++) {
-            sorter.setColumnComparator(i, null);
-            sorter.setSortingStatus(i, TableSorter.NOT_SORTED);
-//            if (IssueNode.COLUMN_NAME_STATUS.equals(tableColumns[i])) {
-//                sorter.setSortingStatus(i, TableSorter.ASCENDING);
-//                break;
-//            }
-        }
-        setDefaultColumnSizes();
-    }
+    @Override
+    public void ancestorRemoved(AncestorEvent event) { }
 
     private void setModelProperties(Query query) {
-        List<Node.Property> properties = new ArrayList<Node.Property>(descriptors.length + (query.isSaved() ? 2 : 0));
+        List<ColumnDescriptor> properties = new ArrayList<ColumnDescriptor>(descriptors.length + (query.isSaved() ? 2 : 0));
         int i = 0;
         for (; i < descriptors.length; i++) {
             ColumnDescriptor desc = descriptors[i];
@@ -432,11 +628,35 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         if(query.isSaved()) {
             properties.add(new RecentChangesDescriptor());
             properties.add(new SeenDescriptor());
-            recentChangesColumnIdx = i;
-            seenColumnIdx = i + 1;
         }
 
-        tableModel.setProperties(properties.toArray(new Node.Property[properties.size()]));
+        // set visibility dependeing on persisted values
+        Map<String, Integer> persistedColumnsMap = getPersistedColumnValues();
+        if(persistedColumnsMap.size() > 0) {
+            for (ColumnDescriptor cd : properties) {
+                cd.setVisible(persistedColumnsMap.containsKey(cd.getName()));
+            }
+        }
+        descriptors = properties.toArray(new ColumnDescriptor[properties.size()]);
+        tableModel.setProperties(descriptors);        
+    }
+
+    private Map<String, Integer> getPersistedColumnValues() {
+        String columns = BugtrackingConfig.getInstance().getColumns(getColumnsKey());
+        String[] visibleColumns = columns.split(CONFIG_DELIMITER);                         // NOI18N
+        if(visibleColumns.length <= 1) {
+            return Collections.EMPTY_MAP;
+        }
+        Map<String, Integer> ret = new HashMap<String, Integer>();
+        for (int i = 0; i < visibleColumns.length; i=i+2) {
+            try {
+                ret.put(visibleColumns[i], Integer.parseInt(visibleColumns[i + 1]));
+            } catch (NumberFormatException nfe) {
+                ret.put(visibleColumns[i], -1);
+                BugtrackingManager.LOG.log(Level.WARNING, visibleColumns[i], nfe);
+            }
+        }
+        return ret;
     }
 
     private void setTableModel(IssueNode[] nodes) {
@@ -447,21 +667,16 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         table.requestFocus();
     }
 
+    @Override
+    public void mouseEntered(MouseEvent e) {}
+    @Override
+    public void mouseExited(MouseEvent e) {}
+    @Override
+    public void mousePressed(MouseEvent e) {}
+    @Override
+    public void mouseReleased(MouseEvent e) {}
 
-    public void mouseEntered(MouseEvent e) {
-    }
-
-    public void mouseExited(MouseEvent e) {
-    }
-
-    public void mousePressed(MouseEvent e) {
-
-    }
-
-    public void mouseReleased(MouseEvent e) {
-
-    }
-
+    @Override
     public void mouseClicked(MouseEvent e) {
         int row = table.rowAtPoint(e.getPoint());
         int column = table.columnAtPoint(e.getPoint());
@@ -476,10 +691,11 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
             } else {
 
                 // seen column
-                if(column == seenColumnIdx) {
+                if(column == getSeenColumnIdx()) {
                     IssueNode in = (IssueNode) tableModel.getNodes()[row];
                     final Issue issue = in.getLookup().lookup(Issue.class);
                     BugtrackingManager.getInstance().getRequestProcessor().post(new Runnable() {
+                        @Override
                         public void run() {
                             IssueCacheUtils.switchSeen(issue);
                         }
@@ -501,6 +717,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
     }
 
+    @Override
     public void keyTyped(KeyEvent e) {
         if (e.getKeyChar() == '\n') {                                     // NOI18N
             int row = table.getSelectedRow();
@@ -514,6 +731,7 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
     }
 
+    @Override
     public void keyPressed(KeyEvent e) {
         if (e.getKeyChar() == '\n') {                                     // NOI18N
             int row = table.getSelectedRow();
@@ -524,41 +742,46 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         }
     }
 
-    public void keyReleased(KeyEvent e) {
-    }
+    @Override
+    public void keyReleased(KeyEvent e) { }
 
     private class NotifyListener implements QueryNotifyListener {
+        @Override
         public void notifyData(final Issue issue) {
+            assert issue instanceof NodeProvider;
             issues.add(issue);
             if(filter == null || filter.accept(issue)) {
-                final IssueNode node = issue.getNode();
+                final IssueNode node = ((NodeProvider)issue).getNode();
                 SwingUtilities.invokeLater(new Runnable() {
+                    @Override
                     public void run() {
                         tableModel.insertNode(node);
                     }
                 });
             }
         }
+        @Override
         public void started() {
             issues.clear();
             IssueTable.this.setTableModel(new IssueNode[0]);
         }
+        @Override
         public void finished() { }
     }
 
     private class SeenDescriptor extends ColumnDescriptor<Boolean> {
         public SeenDescriptor() {
-            super(IssueNode.LABEL_NAME_SEEN, Boolean.class, "", NbBundle.getBundle(Issue.class).getString("CTL_Issue_Seen_Desc")); // NOI18N
+            super(IssueNode.LABEL_NAME_SEEN, Boolean.class, "", NbBundle.getBundle(Issue.class).getString("CTL_Issue_Seen_Desc"), -1, true, true); // NOI18N
         }
     }
 
     private class RecentChangesDescriptor extends ColumnDescriptor<String> {
         public RecentChangesDescriptor() {
-            super(IssueNode.LABEL_RECENT_CHANGES, String.class, NbBundle.getBundle(Issue.class).getString("CTL_Issue_Recent"), NbBundle.getBundle(Issue.class).getString("CTL_Issue_Recent_Desc")); // NOI18N
+            super(IssueNode.LABEL_RECENT_CHANGES, String.class, NbBundle.getBundle(Issue.class).getString("CTL_Issue_Recent"), NbBundle.getBundle(Issue.class).getString("CTL_Issue_Recent_Desc"), -1, true, true); // NOI18N
         }
     }
 
-    private String getColumnWidthsKey() {
+    private String getColumnsKey() {
         String name = query.getDisplayName();
         if(name == null) {
             name = "#find#issues#hitlist#table#";               // NOI18N
@@ -566,28 +789,45 @@ public class IssueTable implements MouseListener, AncestorListener, KeyListener,
         return query.getRepository().getID() + ":" + name;      // NOI18N
     }
 
-    private class StoreColumnWidthsHandler implements Runnable {
-        int[] columnWidths = null;
-        public void run() {
-            BugtrackingConfig.getInstance().storeColumnWidths(getColumnWidthsKey(), columnWidths);
+    private class StoreColumnsHandler implements Runnable {
+        @Override
+        public void run() {            
+            TableColumnModel cm = table.getColumnModel();
+            int count = cm.getColumnCount();
+            StringBuilder sb = new StringBuilder();
+            for (int i = 0; i < count; i++) {
+                sb.append(tableModel.getColumnId(i));
+                sb.append(CONFIG_DELIMITER);                                               // NOI18N
+                sb.append(cm.getColumn(i).getWidth());
+                if(i < count - 1) {
+                    sb.append(CONFIG_DELIMITER);                                           // NOI18N
+                }
+            }
+            BugtrackingConfig.getInstance().storeColumns(getColumnsKey(), sb.toString());
         }
     }
 
     private TableColumnModelListener tcml = new TableColumnModelListener() {
+        @Override
         public void columnAdded(TableColumnModelEvent e) {}
+        @Override
         public void columnRemoved(TableColumnModelEvent e) {}
-        public void columnMoved(TableColumnModelEvent e) {}
-        public void columnSelectionChanged(ListSelectionEvent e) {}
-        public void columnMarginChanged(ChangeEvent e) {
-            TableColumnModel cm = table.getColumnModel();
-            int count = cm.getColumnCount();
-            storeColumnsWidthHandler.columnWidths = new int[count - 1];
-            for (int i = 0; i < storeColumnsWidthHandler.columnWidths.length; i++) {
-                if(i != seenColumnIdx) {
-                    storeColumnsWidthHandler.columnWidths[i] = cm.getColumn(i).getWidth();
-                }
+        @Override
+        public void columnMoved(TableColumnModelEvent e) {
+            int from = e.getFromIndex();
+            int to = e.getToIndex();
+            if(from == to) {
+                return;
             }
-            storeColumnsWidthTask.schedule(1000);
+            table.getTableHeader().getColumnModel().getColumn(from).setModelIndex(from);
+            table.getTableHeader().getColumnModel().getColumn(to).setModelIndex(to);
+            tableModel.moveColumn(from, to);
+        }
+        @Override
+        public void columnSelectionChanged(ListSelectionEvent e) {}
+        @Override
+        public void columnMarginChanged(ChangeEvent e) {
+            storeColumnsTask.schedule(1000);
         }
     };
 
