@@ -46,6 +46,7 @@ import java.awt.EventQueue;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.lang.ref.WeakReference;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -58,7 +59,9 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
+import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
+import org.netbeans.modules.bugtracking.BugtrackingManager;
 import org.netbeans.modules.bugtracking.spi.Issue;
 import org.netbeans.modules.bugtracking.spi.Repository;
 import org.netbeans.modules.bugtracking.util.BugtrackingOwnerSupport;
@@ -67,6 +70,7 @@ import org.netbeans.modules.bugtracking.spi.IssueProvider.LazyIssue;
 import org.netbeans.spi.tasklist.PushTaskScanner;
 import org.netbeans.spi.tasklist.Task;
 import org.netbeans.spi.tasklist.TaskScanningScope;
+import org.openide.filesystems.FileObject;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -131,7 +135,7 @@ public final class TaskListProvider extends PushTaskScanner {
             if (!providersInitialized) {
                 // tasklist initialization
                 for (IssueProvider provider : Lookup.getDefault().lookupAll(IssueProvider.class)) {
-                    LOG.finer("TaskListProvider.setScope: waking up " + provider.getClass().getName()); //NOI18N
+                    LOG.log(Level.FINER, "TaskListProvider.setScope: waking up {0}", provider.getClass().getName()); //NOI18N
                 }
                 providersInitialized = true;
             }
@@ -150,10 +154,10 @@ public final class TaskListProvider extends PushTaskScanner {
      */
     public void add (IssueProvider provider, boolean openTaskList, IssueProvider.LazyIssue... issuesToAdd) {
         if (provider == null || issuesToAdd == null || issuesToAdd.length == 0) {
-            LOG.fine("TaskListProvider.add: provider: " + provider + ", issuesToAdd: " + issuesToAdd); //NOI18N
+            LOG.log(Level.FINE, "TaskListProvider.add: provider: {0}, issuesToAdd: {1}", new Object[]{provider, issuesToAdd}); //NOI18N
             return;
         }
-        LOG.fine("TaskListProvider.add: adding " + issuesToAdd.length + " for " + provider + ", request to open: " + openTaskList); //NOI18N
+        LOG.log(Level.FINE, "TaskListProvider.add: adding {0} for {1}, request to open: {2}", new Object[]{issuesToAdd.length, provider, openTaskList}); //NOI18N
         synchronized (cachedIssues) {
             Set<IssueProvider.LazyIssue> issues = cachedIssues.get(provider);
             if (issues == null) {
@@ -163,7 +167,7 @@ public final class TaskListProvider extends PushTaskScanner {
                 issues.add(issue);
             }
             if (LOG.isLoggable(Level.FINER)) {
-                LOG.finer("TaskListProvider.add: issues for " + provider + ": " + issues); //NOI18N
+                LOG.log(Level.FINER, "TaskListProvider.add: issues for {0}: {1}", new Object[]{provider, issues}); //NOI18N
             }
             cachedIssues.put(provider, issues);
             // also schedule a validation of the provider's issues
@@ -172,6 +176,7 @@ public final class TaskListProvider extends PushTaskScanner {
         if (openTaskList) {
             // openning the tasklist
             EventQueue.invokeLater(new Runnable() {
+                @Override
                 public void run() {
                     if (LOG.isLoggable(Level.FINER)) {
                         LOG.finer("TaskListProvider.add: openning tasklist TC"); //NOI18N
@@ -192,10 +197,10 @@ public final class TaskListProvider extends PushTaskScanner {
      */
     public void remove (IssueProvider provider, IssueProvider.LazyIssue... issuesToRemove) {
         if (provider == null || issuesToRemove == null || issuesToRemove.length == 0) {
-            LOG.fine("TaskListProvider.remove: provider: " + provider + ", issuesToRemove: " + issuesToRemove); //NOI18N
+            LOG.log(Level.FINE, "TaskListProvider.remove: provider: {0}, issuesToRemove: {1}", new Object[]{provider, issuesToRemove}); //NOI18N
             return;
         }
-        LOG.fine("TaskListProvider.remove: removing " + issuesToRemove.length + " for " + provider); //NOI18N
+        LOG.log(Level.FINE, "TaskListProvider.remove: removing {0} for {1}", new Object[]{issuesToRemove.length, provider}); //NOI18N
         synchronized (cachedIssues) {
             Set<IssueProvider.LazyIssue> issues = cachedIssues.get(provider);
             if (issues != null) {
@@ -204,7 +209,7 @@ public final class TaskListProvider extends PushTaskScanner {
                 }
             }
             if (LOG.isLoggable(Level.FINER)) {
-                LOG.finer("TaskListProvider.remove: issues for " + provider + ": " + (issues == null ? "empty" : issues)); //NOI18N
+                LOG.log(Level.FINER, "TaskListProvider.remove: issues for {0}: {1}", new Object[]{provider, issues == null ? "empty" : issues}); //NOI18N
             }
         }
         removeCachedTasks(issuesToRemove);
@@ -226,7 +231,7 @@ public final class TaskListProvider extends PushTaskScanner {
             // clear the issues
             issues = cachedIssues.remove(provider);
             if (LOG.isLoggable(Level.FINER)) {
-                LOG.finer("TaskListProvider.removeAll: issues for " + provider + ": " + (cachedIssues.get(provider) == null ? "empty" : cachedIssues.get(provider))); //NOI18N
+                LOG.log(Level.FINER, "TaskListProvider.removeAll: issues for {0}: {1}", new Object[]{provider, cachedIssues.get(provider) == null ? "empty" : cachedIssues.get(provider)}); //NOI18N
             }
         }
         if (issues != null) {
@@ -248,7 +253,7 @@ public final class TaskListProvider extends PushTaskScanner {
                 cachedTasks.remove(issue);
             }
             if (LOG.isLoggable(Level.FINER)) {
-                LOG.finer("TaskListProvider.removeCachedTasks: cached tasks: " + cachedTasks); //NOI18N
+                LOG.log(Level.FINER, "TaskListProvider.removeCachedTasks: cached tasks: {0}", cachedTasks); //NOI18N
             }
         }
     }
@@ -257,8 +262,10 @@ public final class TaskListProvider extends PushTaskScanner {
         List<Action> actions = new LinkedList<Action>();
         // open action: a default action for the first action added by tasklist and for a dbl-click on a task
         ActionListener openIssueAL = new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
-                RequestProcessor.getDefault().post(new Runnable() {
+                BugtrackingManager.getInstance().getRequestProcessor().post(new Runnable() {
+                    @Override
                     public void run() {
                         Issue issue = lazyIssue.getIssue();
                         if (issue != null) {
@@ -274,6 +281,7 @@ public final class TaskListProvider extends PushTaskScanner {
         };
         // remove action: always added
         actions.add(new AbstractAction(NbBundle.getMessage(TaskListProvider.class, "TaskListProvider.Action.remove.name")) { //NOI18N
+            @Override
             public void actionPerformed(ActionEvent e) {
                 IssueProvider provider = providerRef.get();
                 if (provider != null) {
@@ -297,7 +305,7 @@ public final class TaskListProvider extends PushTaskScanner {
         Task task = Task.create(lazyIssue.getUrl(), TASK_GROUP_NAME, lazyIssue.getName(), openIssueAL, actions.toArray(new AbstractAction[actions.size()]));
         cachedTasks.put(lazyIssue, task);
         if (LOG.isLoggable(Level.FINER)) {
-            LOG.finer("TaskListProvider.createTasks: cached tasks: " + cachedTasks); //NOI18N
+            LOG.log(Level.FINER, "TaskListProvider.createTasks: cached tasks: {0}", cachedTasks); //NOI18N
         }
         // setting valid to true disables task re-creation in a next tasklist refresh
         lazyIssue.setValid(true);
@@ -309,7 +317,7 @@ public final class TaskListProvider extends PushTaskScanner {
      * @param cancelRunningRefresh set to true only when the scope changes, otherwise the validation inside the refreshtask can return unexpected results
      */
     private void refreshTasks (boolean cancelRunningRefresh) {
-        LOG.finer("TaskListProvider.refreshTasks: cancel=" + cancelRunningRefresh); //NOI18N
+        LOG.log(Level.FINER, "TaskListProvider.refreshTasks: cancel={0}", cancelRunningRefresh); //NOI18N
         if (cancelRunningRefresh) {
             refreshTask.cancel();
         }
@@ -419,7 +427,19 @@ public final class TaskListProvider extends PushTaskScanner {
     }
 
     private List<String> getRepositoriesFor (TaskScanningScope scope) {
-        Collection<? extends Project> projects = scope.getLookup().lookupAll(Project.class);
+        Collection<? extends Project> projects = scope.getLookup().lookupAll(Project.class);        
+        if(projects == null || projects.isEmpty()) {
+            // one file scope?
+            FileObject fo = scope.getLookup().lookup(FileObject.class);
+            if(fo != null) {
+                Project project = FileOwnerQuery.getOwner(fo);
+                if(project != null) {
+                    List<Project> list = new ArrayList<Project>(1);
+                    list.add(project);
+                    projects = list;
+                }
+            }
+        }
         LinkedList<String> repositoryUrls = new LinkedList<String>();
         if (!projects.isEmpty()) {
             for (Project p : projects) {
