@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2008-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -50,16 +53,19 @@ import java.beans.PropertyChangeListener;
 import java.util.HashSet;
 import java.util.MissingResourceException;
 import java.util.Set;
+import java.util.logging.Level;
 import javax.swing.DefaultComboBoxModel;
+import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.SwingUtilities;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.modules.bugtracking.BugtrackingManager;
-import org.netbeans.modules.bugtracking.RepositoriesSupport;
+import org.netbeans.modules.bugtracking.spi.BugtrackingConnector;
 import org.netbeans.modules.bugtracking.spi.BugtrackingController;
 import org.netbeans.modules.bugtracking.spi.Issue;
 import org.netbeans.modules.bugtracking.spi.Repository;
+import org.netbeans.modules.bugtracking.ui.search.FindSupport;
 import org.netbeans.modules.bugtracking.util.BugtrackingUtil;
 import org.netbeans.modules.bugtracking.util.RepositoryComboRenderer;
 import org.netbeans.modules.bugtracking.util.RepositoryComboSupport;
@@ -90,13 +96,20 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
      */
     public IssueTopComponent() {
         initComponents();
-        RepositoriesSupport.getInstance().addPropertyChangeListener(this);
+        BugtrackingConnector[] connectors = BugtrackingManager.getInstance().getConnectors();
+        for (BugtrackingConnector c : connectors) {
+            c.addPropertyChangeListener(this);
+        }
         preparingLabel.setVisible(false);
         newButton.addActionListener(new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 onNewClick();
             }
         });
+        JComponent findBar = FindSupport.create(this).getFindBar();
+        findBar.setVisible(false);
+        issuePanel.add(findBar, BorderLayout.PAGE_END);
     }
 
     /**
@@ -138,6 +151,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
             }
         }
         repositoryComboBox.addItemListener(new ItemListener() {
+            @Override
             public void itemStateChanged(ItemEvent e) {
                 if(e.getStateChange() == ItemEvent.SELECTED) {
                     onRepoSelected();
@@ -149,11 +163,12 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
 
     public void initNoIssue(final String issueId) {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
                 preparingLabel.setVisible(true);
                 repoPanel.setVisible(false);
                 if(issueId != null) {
-                    String desc = NbBundle.getMessage(Issue.class, "LBL_OPENING_ISSUE", new Object[]{issueId});
+                    String desc = NbBundle.getMessage(IssueTopComponent.class, "LBL_OPENING_ISSUE", new Object[]{issueId});
                     preparingLabel.setText(desc);
                     setName(NbBundle.getMessage(IssueTopComponent.class, "LBL_LOADING_ISSUE", new Object[]{issueId}));
                     setToolTipText(desc);
@@ -235,7 +250,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
                     .add(findIssuesLabel))
                 .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                 .add(jPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
-                .addContainerGap(152, Short.MAX_VALUE))
+                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
         );
         repoPanelLayout.setVerticalGroup(
             repoPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
@@ -264,14 +279,14 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         layout.setHorizontalGroup(
             layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
             .add(repoPanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
-            .add(issuePanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 598, Short.MAX_VALUE)
+            .add(issuePanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
         );
         layout.setVerticalGroup(
             layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
             .add(layout.createSequentialGroup()
                 .add(repoPanel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                 .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(issuePanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 174, Short.MAX_VALUE))
+                .add(issuePanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
         );
     }// </editor-fold>//GEN-END:initComponents
 
@@ -289,6 +304,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
             prepareTask.cancel();
         }
         Cancellable c = new Cancellable() {
+            @Override
             public boolean cancel() {
                 if(prepareTask != null) {
                     prepareTask.cancel();
@@ -298,6 +314,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         };
         final ProgressHandle handle = ProgressHandleFactory.createHandle(NbBundle.getMessage(IssueTopComponent.class, "CTL_PreparingIssue"), c); // NOI18N
         prepareTask = rp.post(new Runnable() {
+            @Override
             public void run() {
                 try {
                     handle.start();
@@ -316,10 +333,11 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
                     }
 
                     IssueAccessor.getInstance().setSelection(issue, context);
-                    controller = issue.getController();
 
                     SwingUtilities.invokeLater(new Runnable() {
+                        @Override
                         public void run() {
+                            controller = issue.getController();
                             issuePanel.add(controller.getComponent(), BorderLayout.CENTER);
                             issue.addPropertyChangeListener(IssueTopComponent.this);
                             revalidate();
@@ -377,7 +395,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         if(issue != null) {
             issue.getController().opened();
         }
-        BugtrackingManager.LOG.fine("IssueTopComponent Opened " + (issue != null ? issue.getID() : "null")); // NOI18N
+        BugtrackingManager.LOG.log(Level.FINE, "IssueTopComponent Opened {0}", (issue != null ? issue.getID() : "null")); // NOI18N
     }
 
     @Override
@@ -390,7 +408,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         if(prepareTask != null) {
             prepareTask.cancel();
         }
-        BugtrackingManager.LOG.fine("IssueTopComponent Closed " + (issue != null ? issue.getID() : "null")); // NOI18N
+        BugtrackingManager.LOG.log(Level.FINE, "IssueTopComponent Closed {0}", (issue != null ? issue.getID() : "null")); // NOI18N
     }
 
     /**
@@ -446,6 +464,7 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
 
     private void setNameAndTooltip() throws MissingResourceException {
         SwingUtilities.invokeLater(new Runnable() {
+            @Override
             public void run() {
                 if(issue != null) {
                     setName(issue.getShortenedDisplayName());
@@ -458,16 +477,18 @@ public final class IssueTopComponent extends TopComponent implements PropertyCha
         });
     }
 
+    @Override
     public void propertyChange(PropertyChangeEvent evt) {
         if(evt.getPropertyName().equals(Issue.EVENT_ISSUE_DATA_CHANGED)) {
             repoPanel.setVisible(false);
             setNameAndTooltip();
-        } else if(evt.getPropertyName().equals(RepositoriesSupport.EVENT_REPOSITORIES_CHANGED)) {
+        } else if(evt.getPropertyName().equals(BugtrackingConnector.EVENT_REPOSITORIES_CHANGED)) {
             if(!repositoryComboBox.isEnabled()) {
                 // well, looks like there shuold be only one repository available
                 return;
             }
             SwingUtilities.invokeLater(new Runnable() {
+                @Override
                 public void run() {
                     if(rs != null) {
                         rs.refreshRepositoryModel();
