@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -89,8 +92,8 @@ class IssueStorage {
     private String QUERY_SUFIX = ".q";                                  // NOI18N
     private String ISSUE_SUFIX = ".i";                                  // NOI18N
 
-    private final Map<String, Object> referenceTimeLocks = new HashMap<String, Object>();
-    
+    private FileLocks fileLocks = new FileLocks();
+
     private IssueStorage() { }
 
     public static IssueStorage getInstance() {
@@ -119,15 +122,8 @@ class IssueStorage {
         File folder = getNameSpaceFolder(nameSpace);
         File data = new File(folder, "data");
         
-        Object lock = null;
-        synchronized(referenceTimeLocks) {
-            lock = referenceTimeLocks.get(data.getAbsolutePath());
-            if(lock == null) {
-                lock = new Object();
-            }
-            referenceTimeLocks.put(data.getAbsolutePath(), lock);
-        }
-        try{
+        FileLock lock = fileLocks.getLock(data);
+        try {
             synchronized(lock) {
                 long ret = -1;
                 if(data.exists()) {
@@ -174,9 +170,7 @@ class IssueStorage {
                 }
             }
         } finally {
-            synchronized(referenceTimeLocks) {
-                referenceTimeLocks.remove(data.getAbsolutePath());
-            }
+            if(lock != null) { lock.release(); }
         }
     }
 
@@ -185,30 +179,37 @@ class IssueStorage {
         BugtrackingManager.LOG.log(Level.FINE, "start storing issue {0} - {1}", new Object[] {nameSpace, entry.getId()}); // NOI18N
         InputStream is = null;
         DataOutputStream dos = null;
+        FileLock lock = null;
         try {
-            dos = getIssueOutputStream(getNameSpaceFolder(nameSpace), entry.getId());
-            if(dos == null) {
-                return;
-            }
-            dos.writeBoolean(entry.wasSeen());
-            dos.writeLong(entry.getLastSeenModified());
-            dos.writeInt(entry.getLastUnseenStatus());
-            if(entry.getSeenAttributes() != null) {
-                for(Entry<String, String> e : entry.getSeenAttributes().entrySet()) {
-                    writeString(dos, e.getKey());
-                    writeString(dos, e.getValue());
+            File issueFile = getIssueFile(getNameSpaceFolder(nameSpace), entry.getId());
+            lock = fileLocks.getLock(issueFile);
+            synchronized(lock) {
+                dos = getIssueOutputStream(issueFile);
+                if(dos == null) {
+                    return;
+                }
+                dos.writeBoolean(entry.wasSeen());
+                dos.writeLong(entry.getLastSeenModified());
+                dos.writeInt(entry.getLastUnseenStatus());
+                if(entry.getSeenAttributes() != null) {
+                    for(Entry<String, String> e : entry.getSeenAttributes().entrySet()) {
+                        writeString(dos, e.getKey());
+                        writeString(dos, e.getValue());
+                    }
                 }
             }
-
         } catch (InterruptedException ex) {
             BugtrackingManager.LOG.log(Level.WARNING, null, ex);
             IOException ioe = new IOException(ex.getMessage());
             ioe.initCause(ex);
             throw ioe;
         } finally {
-            BugtrackingManager.LOG.log(Level.FINE, "finished storing issue {0} - {1}", new Object[] {nameSpace, entry.getId()}); // NOI18N
             try { if(dos != null) dos.close(); } catch (IOException e) {}
             try { if(is != null) is.close(); } catch (IOException e) {}
+            if(lock != null) {
+                lock.release();
+            }
+            BugtrackingManager.LOG.log(Level.FINE, "finished storing issue {0} - {1}", new Object[] {nameSpace, entry.getId()}); // NOI18N
         }
     }
 
@@ -216,52 +217,67 @@ class IssueStorage {
         assert !SwingUtilities.isEventDispatchThread() : "should not access the issue storage in awt"; // NOI18N
         BugtrackingManager.LOG.log(Level.FINE, "start reading issue {0} - {1}", new Object[] {nameSpace, entry.getId()}); // NOI18N
         DataInputStream is = null;
+        FileLock lock = null;
         try {
-            is = getIssueInputStream(getNameSpaceFolder(nameSpace), entry.getId());
-            if(is == null) {
-                return;
-            }
-            Map<String, String> m = new HashMap<String, String>();
-            boolean seen = is.readBoolean();
-            long lastModified = -1;
-            int lastStatus = IssueCache.ISSUE_STATUS_UNKNOWN;
-            if(!STORAGE_VERSION.equals(STORAGE_VERSION_1_0)) {
-                lastModified = is.readLong();
-                lastStatus = is.readInt();
-            }
-            while(true) {
-                try {
-                    String key = readString(is);
-                    String value = readString(is);
-                    m.put(key, value);
-                } catch (EOFException e) { // XXX
-                    break;
+            File issueFile = getIssueFile(getNameSpaceFolder(nameSpace), entry.getId());
+            lock = fileLocks.getLock(issueFile);
+            synchronized(lock) {
+                is = getIssueInputStream(issueFile);
+                if(is == null) {
+                    return;
                 }
+                Map<String, String> m = new HashMap<String, String>();
+                boolean seen = is.readBoolean();
+                long lastModified = -1;
+                int lastStatus = IssueCache.ISSUE_STATUS_UNKNOWN;
+                if(!STORAGE_VERSION.equals(STORAGE_VERSION_1_0)) {
+                    lastModified = is.readLong();
+                    lastStatus = is.readInt();
+                }
+                while(true) {
+                    try {
+                        String key = readString(is);
+                        String value = readString(is);
+                        m.put(key, value);
+                    } catch (EOFException e) { // XXX
+                        break;
+                    }
+                }
+                entry.setSeenAttributes(m);
+                entry.setSeen(seen);
+                entry.setLastSeenModified(lastModified);
+                entry.setLastUnseenStatus(lastStatus);
             }
-            entry.setSeenAttributes(m);
-            entry.setSeen(seen);
-            entry.setLastSeenModified(lastModified);
-            entry.setLastUnseenStatus(lastStatus);
         } catch (InterruptedException ex) {
             BugtrackingManager.LOG.log(Level.WARNING, null, ex);
             IOException ioe = new IOException(ex.getMessage());
             ioe.initCause(ex);
             throw ioe;
         } finally {
-            BugtrackingManager.LOG.log(Level.FINE, "finished reading issue {0} - {1}", new Object[] {nameSpace, entry.getId()}); // NOI18N
             if(is != null) try { is.close(); } catch(IOException e) {}
+            if(lock != null) {
+                lock.release();
+            }
+            BugtrackingManager.LOG.log(Level.FINE, "finished reading issue {0} - {1}", new Object[] {nameSpace, entry.getId()}); // NOI18N
         }
     }
 
     public List<String> readQuery(String nameSpace, String queryName) throws IOException {
         assert !SwingUtilities.isEventDispatchThread() : "should not access the issue storage in awt"; // NOI18N
         BugtrackingManager.LOG.log(Level.FINE, "start reading query {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
+
+        DataInputStream dis = null;
+        FileLock lock = null;
         try {
             File folder = getNameSpaceFolder(nameSpace);
             if(!folder.exists()) return Collections.emptyList();
 
-            DataInputStream dis = getQueryInputStream(folder, queryName, false);
-            return readQuery(dis);
+            File f = getQueryFile(folder, queryName, false);
+            lock = fileLocks.getLock(f);
+            synchronized(lock) {
+                dis = getQueryInputStream(f);
+                return readQuery(dis);
+            }
         } catch (InterruptedException ex) {
             BugtrackingManager.LOG.log(Level.WARNING, null, ex);
             IOException ioe = new IOException(ex.getMessage());
@@ -269,6 +285,10 @@ class IssueStorage {
             throw ioe;
         } finally {
             BugtrackingManager.LOG.log(Level.FINE, "finished reading query {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
+            if(dis != null) try { dis.close(); } catch(IOException e) {}
+            if(lock != null) {
+                lock.release();
+            }
         }
     }
 
@@ -298,22 +318,29 @@ class IssueStorage {
         BugtrackingManager.LOG.log(Level.FINE, "start reading archived query issues {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
         long now = System.currentTimeMillis();
         long ttl = BugtrackingConfig.getInstance().getArchivedIssuesTTL() * 1000 * 60 * 60 * 24;
+
+        FileLock lock = null;
+        DataInputStream dis = null;
         try {
             File folder = getNameSpaceFolder(nameSpace);
             if(!folder.exists()) return Collections.emptyMap();
 
-            DataInputStream dis = getQueryInputStream(folder, queryName, true);
-            if(dis == null) return Collections.emptyMap();
-            Map<String, Long> ids = readArchivedQueryIssues(dis);
-            Iterator<String> it = ids.keySet().iterator();
-            while(it.hasNext()) {
-                String id = it.next();
-                long ts = ids.get(id);
-                if(ts < now - ttl) {
-                    it.remove();
+            File f = getQueryFile(folder, queryName, true);
+            lock = fileLocks.getLock(f);
+            synchronized(lock) {
+                dis = getQueryInputStream(f);
+                if(dis == null) return Collections.emptyMap();
+                Map<String, Long> ids = readArchivedQueryIssues(dis);
+                Iterator<String> it = ids.keySet().iterator();
+                while(it.hasNext()) {
+                    String id = it.next();
+                    long ts = ids.get(id);
+                    if(ts < now - ttl) {
+                        it.remove();
+                    }
                 }
+                return ids;
             }
-            return ids;
         } catch (InterruptedException ex) {
             BugtrackingManager.LOG.log(Level.WARNING, null, ex);
             IOException ioe = new IOException(ex.getMessage());
@@ -321,6 +348,10 @@ class IssueStorage {
             throw ioe;
         } finally {
             BugtrackingManager.LOG.log(Level.FINE, "finished reading archived query issues {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
+            if(dis != null) try { dis.close(); } catch(IOException e) {}
+            if(lock != null) {
+                lock.release();
+            }
         }
     }
 
@@ -344,15 +375,31 @@ class IssueStorage {
     public void removeQuery(String nameSpace, String queryName) throws IOException {
         assert !SwingUtilities.isEventDispatchThread() : "should not access the issue storage in awt"; // NOI18N
         BugtrackingManager.LOG.log(Level.FINE, "start removing query {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
+        FileLock lock = null;
         try {
             File folder = getNameSpaceFolder(nameSpace);
-            File query = new File(folder, TextUtils.encodeURL(queryName) + QUERY_SUFIX);
+            File query = getQueryFile(folder, queryName, false);
             if(query.exists()) {
-                BugtrackingUtil.deleteRecursively(query);
+                lock = fileLocks.getLock(query);
+                try {
+                    synchronized(lock) {
+                        BugtrackingUtil.deleteRecursively(query);
+                    }
+                } finally {
+                    if(lock != null) { lock.release(); }
+                }
             }
-            File queryArchived = new File(folder, TextUtils.encodeURL(queryName) + QUERY_ARCHIVED_SUFIX);
+            lock = null;
+            File queryArchived = getQueryFile(folder, queryName, true);
             if(queryArchived.exists()) {
-                BugtrackingUtil.deleteRecursively(queryArchived);
+                lock = fileLocks.getLock(queryArchived);
+                try {
+                    synchronized(lock) {
+                        BugtrackingUtil.deleteRecursively(queryArchived);
+                    }
+                } finally {
+                    if(lock != null) {lock.release();}
+                }
             }
         } finally {
             BugtrackingManager.LOG.log(Level.FINE, "finished removing query {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
@@ -362,19 +409,19 @@ class IssueStorage {
     void storeQuery(String nameSpace, String queryName, String[] ids) throws IOException {
         assert !SwingUtilities.isEventDispatchThread() : "should not access the issue storage in awt"; // NOI18N
         BugtrackingManager.LOG.log(Level.FINE, "start storing query issues {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
+        FileLock lock = null;
+        DataOutputStream dos = null;
         try {
             File folder = getNameSpaceFolder(nameSpace);
-            DataOutputStream dos = null;
-            try {
-                dos = getQueryOutputStream(folder, queryName, false);
+            File f = getQueryFile(folder, queryName, false);
+            lock = fileLocks.getLock(f);
+            synchronized(lock) {
+                dos = getQueryOutputStream(f);
                 for (String id : ids) {
                     writeString(dos, id);
                 }
                 dos.flush();
-            } finally {
-                try { if(dos != null) dos.close(); } catch (IOException e) {}
             }
-
         } catch (InterruptedException ex) {
             BugtrackingManager.LOG.log(Level.WARNING, null, ex);
             IOException ioe = new IOException(ex.getMessage());
@@ -382,6 +429,10 @@ class IssueStorage {
             throw ioe;
         } finally {
             BugtrackingManager.LOG.log(Level.FINE, "finished storing query issues {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
+            if(dos != null) try { dos.close(); } catch(IOException e) {}
+            if(lock != null) {
+                lock.release();
+            }
         }
     }
 
@@ -390,11 +441,14 @@ class IssueStorage {
         BugtrackingManager.LOG.log(Level.FINE, "start storing archived query issues {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
         long now = System.currentTimeMillis();
         Map<String, Long> archived = readArchivedQueryIssues(nameSpace, queryName);
+        DataOutputStream dos = null;
+        FileLock lock = null;
         try {
             File folder = getNameSpaceFolder(nameSpace);
-            DataOutputStream dos = null;
-            try {
-                dos = getQueryOutputStream(folder, queryName, true);
+            File f = getQueryFile(folder, queryName, true);
+            lock = fileLocks.getLock(f);
+            synchronized(lock) {
+                dos = getQueryOutputStream(f);
                 for (String id : ids) {
                     writeString(dos, id);
                     Long ts = archived.get(id);
@@ -405,16 +459,17 @@ class IssueStorage {
                     }
                 }
                 dos.flush();
-            } finally {
-                try { if(dos != null) dos.close(); } catch (IOException e) {}
             }
-
         } catch (InterruptedException ex) {
             BugtrackingManager.LOG.log(Level.WARNING, null, ex);
             IOException ioe = new IOException(ex.getMessage());
             ioe.initCause(ex);
             throw ioe;
         } finally {
+            try { if(dos != null) dos.close(); } catch (IOException e) {}
+            if(lock != null) {
+                lock.release();
+            }
             BugtrackingManager.LOG.log(Level.FINE, "finished storing archived query issues {0} - {1}", new Object[] {nameSpace, queryName}); // NOI18N
         }
     }
@@ -457,7 +512,15 @@ class IssueStorage {
             });
             if(queries != null && queries.length > 0) {
                 for (File lq : queries) {
-                    List<String> ids = readQuery(getDataInputStream(lq));
+                    FileLock lock = fileLocks.getLock(lq);
+                    List<String> ids;
+                    try {
+                        synchronized(lock) {
+                            ids = readQuery(getDataInputStream(lq));
+                        }
+                    } finally {
+                        if(lock != null) lock.release();
+                    }
                     if(ids == null || ids.size() == 0) {
                         continue;
                     }
@@ -471,7 +534,15 @@ class IssueStorage {
             });
             if(queries != null) {
                 for (File lq : queries) {
-                    Map<String, Long> ids = readArchivedQueryIssues(getDataInputStream(lq));
+                    Map<String, Long> ids;
+                    FileLock lock = fileLocks.getLock(lq);
+                    try {
+                        synchronized(lock) {
+                            ids = readArchivedQueryIssues(getDataInputStream(lq));
+                        }
+                    } finally {
+                        if(lock != null) lock.release();
+                    }
                     if(ids == null || ids.size() == 0) {
                         continue;
                     }
@@ -490,7 +561,14 @@ class IssueStorage {
                     id = id.substring(0, id.length() - ISSUE_SUFIX.length());
                     if(!livingIssues.contains(id)) {
                         BugtrackingManager.LOG.log(Level.FINE, "removing issue {0}", new Object[] {id}); // NOI18N
-                        issue.delete();
+                        FileLock lock = fileLocks.getLock(issue);
+                        try {
+                            synchronized(lock) {
+                                issue.delete();
+                            }
+                        } finally {
+                            if(lock != null) lock.release();
+                        }
                     }
                 }
             }
@@ -548,22 +626,24 @@ class IssueStorage {
         return sb.toString();
     }
 
-    private DataOutputStream getIssueOutputStream(File folder, String id) throws IOException, InterruptedException {
-        File file = new File(folder, id + ISSUE_SUFIX);
-        ZipOutputStream zos = new ZipOutputStream(new BufferedOutputStream(getFileOutputStream(file, false)));
-        ZipEntry entry = new ZipEntry(file.getName());
+    private DataOutputStream getIssueOutputStream(File issueFile) throws IOException, InterruptedException {
+        ZipOutputStream zos = new ZipOutputStream(new BufferedOutputStream(getFileOutputStream(issueFile, false)));
+        ZipEntry entry = new ZipEntry(issueFile.getName());
         zos.putNextEntry(entry);
         return new DataOutputStream(zos);
     }
 
-    private DataInputStream getIssueInputStream(File folder, String id) throws IOException, InterruptedException {
-        File file = new File(folder, id + ISSUE_SUFIX);
+    private DataInputStream getIssueInputStream(File file) throws IOException, InterruptedException {
         if(!file.exists()) return null;
         ZipInputStream zis = new ZipInputStream(new BufferedInputStream(getFileInputStream(file)));
         zis.getNextEntry();
         return new DataInputStream(zis);
     }
 
+    private File getIssueFile(File folder, String id) {
+        return new File(folder, id + ISSUE_SUFIX);
+    }
+
     private DataOutputStream getDataOutputStream(File file, boolean append) throws IOException, InterruptedException {
         return new DataOutputStream(getFileOutputStream(file, append));
     }
@@ -619,14 +699,43 @@ class IssueStorage {
         return folder;
     }
 
-    private DataOutputStream getQueryOutputStream(File folder, String queryName, boolean archived) throws IOException, InterruptedException {
-        File f = new File(folder, TextUtils.encodeURL(queryName) + (archived ? QUERY_ARCHIVED_SUFIX : QUERY_SUFIX));
-        return getDataOutputStream(f, false);
+    private DataOutputStream getQueryOutputStream(File queryFile) throws IOException, InterruptedException {
+        return getDataOutputStream(queryFile, false);
     }
 
-    private DataInputStream getQueryInputStream(File folder, String queryName, boolean archived) throws IOException, InterruptedException {
-        File f = new File(folder, TextUtils.encodeURL(queryName) + (archived ? QUERY_ARCHIVED_SUFIX : QUERY_SUFIX));
-        if(!f.exists()) return null;
-        return getDataInputStream(f);
+    private DataInputStream getQueryInputStream(File queryFile) throws IOException, InterruptedException {
+        if(!queryFile.exists()) return null;
+        return getDataInputStream(queryFile);
     }
+
+    private File getQueryFile(File folder, String queryName, boolean archived){
+        return new File(folder, TextUtils.encodeURL(queryName) + (archived ? QUERY_ARCHIVED_SUFIX : QUERY_SUFIX));
+    }
+
+    private class FileLocks {
+        private final Map<String, FileLock> locks = new HashMap<String, FileLock>();
+        FileLock getLock(File file) {
+            synchronized(locks) {
+                FileLock fl = locks.get(file.getAbsolutePath());
+                if(fl == null) {
+                    fl = new FileLock(file);
+                }
+                locks.put(file.getAbsolutePath(), fl);
+                return fl;
+            }
+        }
+    }
+
+    class FileLock {
+        private final File file;
+        public FileLock(File file) {
+            this.file = file;
+        }
+        void release() {
+            synchronized(fileLocks.locks) {
+                fileLocks.locks.remove(file.getAbsolutePath());
+            }
+        }
+    }
+    
 }
