@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2008-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -39,6 +42,8 @@
 
 package org.netbeans.modules.bugtracking.util;
 
+import org.netbeans.modules.bugtracking.kenai.spi.RecentIssue;
+import org.netbeans.modules.bugtracking.kenai.spi.KenaiUtil;
 import java.awt.AWTKeyStroke;
 import java.awt.Component;
 import java.awt.Container;
@@ -57,8 +62,11 @@ import java.io.File;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
+import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 import java.util.Set;
 import java.util.logging.Level;
@@ -76,18 +84,22 @@ import javax.swing.JScrollPane;
 import javax.swing.JViewport;
 import javax.swing.SwingConstants;
 import org.jdesktop.layout.LayoutStyle;
+import org.netbeans.api.keyring.Keyring;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ui.OpenProjects;
 import org.netbeans.modules.bugtracking.BugtrackingManager;
 import org.netbeans.modules.bugtracking.spi.BugtrackingConnector;
+import org.netbeans.modules.bugtracking.spi.Query;
 import org.netbeans.modules.bugtracking.ui.issue.IssueTopComponent;
 import org.netbeans.modules.bugtracking.spi.Issue;
 import org.netbeans.modules.bugtracking.spi.Repository;
+import org.netbeans.modules.bugtracking.ui.issue.IssueAction;
 import org.netbeans.modules.bugtracking.ui.issue.PatchContextChooser;
+import org.netbeans.modules.bugtracking.ui.query.QueryAction;
+import org.netbeans.modules.bugtracking.ui.query.QueryTopComponent;
 import org.netbeans.modules.bugtracking.ui.search.QuickSearchComboBar;
 import org.netbeans.modules.bugtracking.ui.selectors.RepositorySelector;
-import org.netbeans.modules.kenai.ui.spi.UIUtils;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
@@ -178,6 +190,49 @@ public class BugtrackingUtil {
         return issues.toArray(new Issue[issues.size()]);
     }
 
+    /**
+     * Determines if the gives issue is opened in the editor area
+     * @param issue
+     * @return true in case the given issue is opened in the editor are, otherwise false
+     */
+    public static boolean isOpened(Issue issue) {
+        IssueTopComponent tc = IssueTopComponent.find(issue, false);
+        return tc != null ? tc.isOpened() : false;
+    }
+
+    /**
+     * Determines if the gives issue is opened in the editor area and
+     * showing on the screen
+     * @param issue
+     * @return true in case the given issue is opened in the editor area
+     *         and showing on the screen, otherwise false
+     */
+    public static boolean isShowing(Issue issue) {
+        IssueTopComponent tc = IssueTopComponent.find(issue, false);
+        return tc != null ? tc.isShowing() : false;
+    }
+
+    /**
+     * Determines if the gives query is opened in the editor area
+     * @param query
+     * @return
+     */
+    public static boolean isOpened(Query query) {
+        QueryTopComponent tc = QueryTopComponent.find(query);
+        return tc != null ? tc.isOpened() : false;
+    }
+
+    /**
+     * Determines if the gives query is opened in the editor area and
+     * showing on the screen
+     * @param query
+     * @return
+     */
+    public static boolean isShowing(Query query) {
+        QueryTopComponent tc = QueryTopComponent.find(query);
+        return tc != null ? tc.isShowing() : false;
+    }
+
     /**
      * Filters the given issue by the given criteria and returns
      * those which either case unsensitively contain the criteria
@@ -226,8 +281,8 @@ public class BugtrackingUtil {
         return editRepository(repository, null);
     }
 
-    public static Repository[] getKnownRepositories() {
-        return BugtrackingManager.getInstance().getKnownRepositories(true);
+    public static Repository[] getKnownRepositories(boolean pingOpenProjects) {
+        return BugtrackingManager.getInstance().getKnownRepositories(pingOpenProjects);
     }
 
     public static BugtrackingConnector[] getBugtrackingConnectors() {
@@ -312,28 +367,6 @@ public class BugtrackingUtil {
         }
         return context;
     }
-//
-//    public static void applyPatch(File patch, File context) {
-//        try {
-//            ContextualPatch cp = ContextualPatch.create(patch, context);
-//            cp.patch(false);
-//        } catch (PatchException ex) {
-//            BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
-//        } catch (IOException ex) {
-//            BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
-//        }
-//    }
-//
-//    public static boolean isPatch(FileObject fob) throws IOException {
-//        boolean isPatch = false;
-//        Reader reader = new BufferedReader(new InputStreamReader(fob.getInputStream()));
-//        try {
-//            isPatch = (Patch.parse(reader).length > 0);
-//        } finally {
-//            reader.close();
-//        }
-//        return isPatch;
-//    }
 
     /**
      * Recursively deletes all files and directories under a given file/directory.
@@ -350,167 +383,6 @@ public class BugtrackingUtil {
         file.delete();
     }
 
-    public static File getLargerContext() {
-        FileObject openFile = getOpenFileObj();
-        if (openFile != null) {
-            File largerContext = getLargerContext(openFile);
-            if (largerContext != null) {
-                return largerContext;
-            }
-        }
-
-        return getContextFromProjects();
-    }
-
-    public static File getContextFromProjects() {
-        final OpenProjects projects = OpenProjects.getDefault();
-
-        Project mainProject = projects.getMainProject();
-        if (mainProject != null) {
-            return getLargerContext(mainProject);       //null or non-null
-        }
-
-        Project[] openProjects = projects.getOpenProjects();
-        if ((openProjects != null) && (openProjects.length == 1)) {
-            return getLargerContext(openProjects[0]);
-        }
-
-        return null;
-    }
-
-    public static File getLargerContext(File file) {
-        return getLargerContext(file, null);
-    }
-
-    public static File getLargerContext(FileObject fileObj) {
-        return getLargerContext(null, fileObj);
-    }
-
-    public static File getLargerContext(File file, FileObject fileObj) {
-        if ((file == null) && (fileObj == null)) {
-            throw new IllegalArgumentException(
-                    "both File and FileObject are null");               //NOI18N
-        }
-
-        assert (file == null)
-               || (fileObj == null)
-               || FileUtil.toFileObject(file).equals(fileObj);
-
-        if (fileObj == null) {
-            fileObj = getFileObjForFileOrParent(file);
-        } else if (file == null) {
-            file = FileUtil.toFile(fileObj);
-        }
-
-        if (fileObj == null) {
-            return null;
-        }
-        if (!fileObj.isValid()) {
-            return null;
-        }
-
-        Project parentProject = FileOwnerQuery.getOwner(fileObj);
-        if (parentProject != null) {
-            FileObject parentProjectFolder = parentProject.getProjectDirectory();
-            if (parentProjectFolder.equals(fileObj) && (file != null)) {
-                return file;
-            }
-            File folder = FileUtil.toFile(parentProjectFolder);
-            if (folder != null) {
-                return folder;
-            }
-        }
-
-        if (fileObj.isFolder()) {
-            return file;                        //whether it is null or non-null
-        } else {
-            fileObj = fileObj.getParent();
-            assert fileObj != null;      //every non-folder should have a parent
-            return FileUtil.toFile(fileObj);    //whether it is null or non-null
-        }
-    }
-
-    private static FileObject getFileObjForFileOrParent(File file) {
-        FileObject fileObj = FileUtil.toFileObject(file);
-        if (fileObj != null) {
-            return fileObj;
-        }
-
-        File closestParentFile = file.getParentFile();
-        while (closestParentFile != null) {
-            fileObj = FileUtil.toFileObject(closestParentFile);
-            if (fileObj != null) {
-                return fileObj;
-            }
-            closestParentFile = closestParentFile.getParentFile();
-        }
-
-        return null;
-    }
-
-    public static File getLargerContext(Project project) {
-        FileObject projectFolder = project.getProjectDirectory();
-        assert projectFolder != null;
-
-        return FileUtil.toFile(projectFolder);
-    }
-
-    private static FileObject getOpenFileObj() {
-        TopComponent activatedTopComponent = TopComponent.getRegistry()
-                                             .getActivated();
-        if (activatedTopComponent == null) {
-            return null;
-        }
-
-        DataObject dataObj = activatedTopComponent.getLookup()
-                             .lookup(DataObject.class);
-        if ((dataObj == null) || !dataObj.isValid()) {
-            return null;
-        }
-
-        return dataObj.getPrimaryFile();
-    }
-
-    public static void keepFocusedComponentVisible(JScrollPane scrollPane) {
-        keepFocusedComponentVisible(scrollPane.getViewport().getView());
-    }
-
-    public static void keepFocusedComponentVisible(Component component) {
-        FocusListener listener= getScrollingFocusListener();
-        component.removeFocusListener(listener); // Making sure that it is not added twice
-        component.addFocusListener(listener);
-        if (component instanceof Container) {
-            for (Component subComponent : ((Container)component).getComponents()) {
-                keepFocusedComponentVisible(subComponent);
-            }
-        }
-    }
-
-    private static FocusListener scrollingFocusListener;
-    private static FocusListener getScrollingFocusListener() {
-        if (scrollingFocusListener == null) {
-            scrollingFocusListener = new FocusAdapter() {
-                @Override
-                public void focusGained(FocusEvent e) {
-                    if (!e.isTemporary()) {
-                        Component comp = e.getComponent();
-                        Container cont = comp.getParent();
-                        if (cont instanceof JViewport) {
-                            // comp is JViewport's view;
-                            // we want the viewport itself to be shown in this case
-                            comp = cont;
-                            cont = cont.getParent();
-                        }
-                        if (cont instanceof JComponent) {
-                            ((JComponent)cont).scrollRectToVisible(comp.getBounds());
-                        }
-                    }
-                }
-            };
-        }
-        return scrollingFocusListener;
-    }
-
     public static void logQueryEvent(String connector, String name, int count, boolean isKenai, boolean isAutoRefresh) {
         name = obfuscateQueryName(name);
         logBugtrackingEvents(USG_BUGTRACKING_QUERY, new Object[] {connector, name, count, isKenai, isAutoRefresh} );
@@ -531,7 +403,7 @@ public class BugtrackingUtil {
         }
         // log Kenai usage
         if (KenaiUtil.isKenai(repository)) {
-            UIUtils.logKenaiUsage("ISSUE_TRACKING", btType); // NOI18N
+            KenaiUtil.logKenaiUsage("ISSUE_TRACKING", btType); // NOI18N
         }
         if (operation == null) {
             return;
@@ -579,40 +451,6 @@ public class BugtrackingUtil {
         return null;
     }
 
-    public static int getColumnWidthInPixels(int widthInLeters, JComponent comp) {
-        StringBuffer sb = new StringBuffer();
-        for (int i = 0; i < widthInLeters; i++, sb.append("w"));                // NOI18N
-        return getColumnWidthInPixels(sb.toString(), comp);
-    }
-
-    public static int getColumnWidthInPixels(String str, JComponent comp) {
-        FontMetrics fm = comp.getFontMetrics(comp.getFont());
-        return fm.stringWidth(str);
-    }
-
-    public static int getLongestWordWidth(String header, List<String> values, JComponent comp) {
-        return getLongestWordWidth(header, values, comp, false);
-    }
-
-    public static int getLongestWordWidth(String header, List<String> values, JComponent comp, boolean regardIcon) {
-        String[] valuesArray = values.toArray(new String[values.size()]);
-        return getLongestWordWidth(header, valuesArray, comp, regardIcon);
-    }
-
-    public static int getLongestWordWidth(String header, String[] values, JComponent comp) {
-        return getLongestWordWidth(header, values, comp, false);
-    }
-
-    public static int getLongestWordWidth(String header, String[] values, JComponent comp, boolean regardIcon) {
-        int size = header.length();
-        for (String s : values) {
-            if(size < s.length()) {
-                size = s.length();
-            }
-        }
-        return getColumnWidthInPixels(size, comp) + (regardIcon ? 16 : 0);
-    }
-
     /**
      * Logs bugtracking events
      *
@@ -656,31 +494,6 @@ public class BugtrackingUtil {
         return name;
     }
 
-    // A11Y - Issues 163597 and 163598
-    public static void fixFocusTraversalKeys(JComponent component) {
-        Set<AWTKeyStroke> set = component.getFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS);
-        set = new HashSet<AWTKeyStroke>(set);
-        set.add(AWTKeyStroke.getAWTKeyStroke(KeyEvent.VK_TAB, InputEvent.CTRL_DOWN_MASK | InputEvent.ALT_DOWN_MASK));
-        component.setFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS, set);
-    }
-
-    public static void issue163946Hack(final JScrollPane scrollPane) {
-        MouseWheelListener listener = new MouseWheelListener() {
-            public void mouseWheelMoved(MouseWheelEvent e) {
-                if (scrollPane.getVerticalScrollBar().isShowing()) {
-                    if (e.getSource() != scrollPane) {
-                        e.setSource(scrollPane);
-                        scrollPane.dispatchEvent(e);
-                    }
-                } else {
-                    scrollPane.getParent().dispatchEvent(e);
-                }
-            }
-        };
-        scrollPane.addMouseWheelListener(listener);
-        scrollPane.getViewport().getView().addMouseWheelListener(listener);
-    }
-
     public static void openPluginManager() {
         try {
             ClassLoader cl = Lookup.getDefault ().lookup (ClassLoader.class);
@@ -711,10 +524,9 @@ public class BugtrackingUtil {
      * @return true if the given repository is the netbenas bugzilla, otherwise false
      */
     public static boolean isNbRepository(Repository repo) {
-        // XXX dummy implementation
         String url = repo.getUrl();
         return isNbRepository(url);
-}
+    }
 
     public static boolean isNbRepository(String url) {
         boolean ret = netbeansUrlPattern.matcher(url).matches();
@@ -727,4 +539,93 @@ public class BugtrackingUtil {
         }
         return url.startsWith(nbUrl);
     }
+
+    /**
+     *
+     * @param password
+     * @param prefix
+     * @param user
+     * @param url
+     * @throws MissingResourceException
+     */
+    public static void savePassword(String password, String prefix, String user, String url) throws MissingResourceException {
+        if (password != null && !password.trim().equals("")) {                  // NOI18N
+            Keyring.save(getPasswordKey(prefix, user, url), password.toCharArray(), NbBundle.getMessage(BugtrackingUtil.class, "password_keyring_description", url)); // NOI18N
+        } else {
+            Keyring.delete(getPasswordKey(prefix, user, url));
+        }
+    }
+
+    /**
+     *
+     * @param scrambledPassword
+     * @param keyPrefix
+     * @param url
+     * @param user
+     * @return
+     */
+    public static char[] readPassword(String scrambledPassword, String keyPrefix, String user, String url) {
+        if (!scrambledPassword.equals("")) {                                    // NOI18N
+            return BugtrackingUtil.descramble(scrambledPassword).toCharArray();
+        } else {
+            char[] password = Keyring.read(getPasswordKey(keyPrefix, user, url));
+            return password != null ? password : new char[0];
+        }
+    }
+    
+    private static String getPasswordKey(String prefix, String user, String url) {
+        return (prefix != null ? prefix + "-" : "") + user + "@" + url;         // NOI18N
+    }
+
+
+    /**
+     * Determines if the jira plugin is instaled or not
+     *
+     * @return true if jira plugin is installed, otherwise false
+     */
+    public static boolean isJiraInstalled() {
+        BugtrackingConnector[] connectors = BugtrackingManager.getInstance().getConnectors();
+        for (BugtrackingConnector c : connectors) {
+            // XXX hack
+            if(c.getClass().getName().startsWith("org.netbeans.modules.jira")) {    // NOI18N
+                return true;
+            }
+        }
+        return false;
+    }
+
+    public static void openQuery(final Query query, final Repository repository, final boolean suggestedSelectionOnly) {
+        QueryAction.openQuery(query, repository, suggestedSelectionOnly);
+    }
+
+    public static void openIssue(File file, String issueId) {
+        IssueAction.openIssue(file, issueId);
+    }
+
+    public static Map<String, List<RecentIssue>> getAllRecentIssues() {
+        return BugtrackingManager.getInstance().getAllRecentIssues();
+    }
+
+    public static Collection<Issue> getRecentIssues(Repository repo) {
+        return BugtrackingManager.getInstance().getRecentIssues(repo);
+    }
+
+    public static void closeQuery(Query query) {
+        QueryAction.closeQuery(query);
+    }
+
+    public static void createIssue(Repository repo) {
+        IssueAction.createIssue(repo);
+    }
+
+    public static String getPasswordLog(String psswd) {
+        if(psswd == null) {
+            return ""; // NOI18N
+        }
+        if("true".equals(System.getProperty("org.netbeans.modules.bugtracking.logPasswords", "false"))) { // NOI18N
+            return psswd; 
+        }
+        return "******"; // NOI18N
+    }
+    
 }
