@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -55,6 +58,7 @@ import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.PopupMenuEvent;
 import javax.swing.event.PopupMenuListener;
+import org.netbeans.modules.bugtracking.BugtrackingManager;
 import org.netbeans.modules.bugtracking.spi.Repository;
 import org.openide.nodes.Node;
 import org.openide.util.RequestProcessor;
@@ -168,6 +172,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
         }
         return repositoryComboSupport;
     }
+    private final RequestProcessor rp;
 
     private RepositoryComboSupport(JComboBox comboBox, Repository defaultRepo,
                                                        File refFile,
@@ -186,6 +191,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
         defaultRepoComputationPending = (defaultRepo == null);
 
         progress.set(Progress.INITIALIZED);
+        rp = BugtrackingManager.getInstance().getRequestProcessor();
     }
 
     private void checkOldComboBoxModel(JComboBox comboBox) {
@@ -237,7 +243,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
 
         updateProgress(Progress.STARTED);
 
-        RequestProcessor.getDefault().post(this);
+        rp.post(this);
     }
 
     private void shutdown() {
@@ -289,6 +295,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
         private DisplayabilityListener(Component triggerComponent) {
             this.triggerComponent = triggerComponent;
         }
+        @Override
         public void hierarchyChanged(HierarchyEvent e) {
             if ((e.getChangeFlags() & DISPLAYABILITY_CHANGED) == 0) {
                 return;
@@ -319,6 +326,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
      * @param  e  {@code ItemEvent} that holds information about the
      *            (de)selection event
      */
+    @Override
     public void itemStateChanged(ItemEvent e) {
         if ((e.getStateChange() == ItemEvent.DESELECTED)
                 && (e.getItem() == SELECT_REPOSITORY)
@@ -338,18 +346,21 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
                 comboBox.removeItemListener(this);
 
                 comboBox.addPopupMenuListener(new PopupMenuListener() {
+                    @Override
                     public void popupMenuCanceled(PopupMenuEvent e) {
                         comboBox.removePopupMenuListener(this);
 
                         /* Restore the item selection listener: */
                         comboBox.addItemListener(RepositoryComboSupport.this);
                     }
+                    @Override
                     public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
                         comboBox.removePopupMenuListener(this);
 
                         /* Restore the item selection listener: */
                         comboBox.addItemListener(RepositoryComboSupport.this);
                     }
+                    @Override
                     public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
                         comboBox.removePopupMenuListener(this);
                         if (comboBox.getSelectedItem() != SELECT_REPOSITORY) {
@@ -367,8 +378,9 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
         }
     }
 
+    @Override
     public void run() {
-        if (RequestProcessor.getDefault().isRequestProcessorThread()) {
+        if (rp.isRequestProcessorThread()) {
             loadRepositories();
 
             if (defaultRepoComputationPending) {
@@ -498,11 +510,14 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
         if (comboBox.isPopupVisible()) {
             LOG.finest(" - the popup is visible - deferred");           //NOI18N
             comboBox.addPopupMenuListener(new PopupMenuListener() {
+                @Override
                 public void popupMenuWillBecomeVisible(PopupMenuEvent e) { }
+                @Override
                 public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
                     LOG.finer("popupMenuWillBecomeInvisible()");        //NOI18N
                     comboBox.removePopupMenuListener(this);
                 }
+                @Override
                 public void popupMenuCanceled(PopupMenuEvent e) {
                     LOG.finer("popupMenuCanceled()");                   //NOI18N
                     comboBox.removePopupMenuListener(this);
@@ -567,9 +582,10 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
 
     public void refreshRepositoryModel() {
         LOG.finer("refreshRepositoryModel()");                          //NOI18N
-        RequestProcessor.getDefault().post(new Runnable() {
+        rp.post(new Runnable() {
+            @Override
             public void run() {
-                if (RequestProcessor.getDefault().isRequestProcessorThread()) {
+                if (rp.isRequestProcessorThread()) {
                     loadRepositories();
                     EventQueue.invokeLater(this);
                 } else {
@@ -581,13 +597,13 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
     }
 
     private void loadRepositories() {
-        assert RequestProcessor.getDefault().isRequestProcessorThread();
+        assert rp.isRequestProcessorThread();
         LOG.finer("loadRepositories()");                                //NOI18N
         updateProgress(Progress.WILL_LOAD_REPOS);
 
         long startTimeMillis = System.currentTimeMillis();
 
-        repositories = BugtrackingUtil.getKnownRepositories();
+        repositories = BugtrackingUtil.getKnownRepositories(true);
 
         long endTimeMillis = System.currentTimeMillis();
         if (LOG.isLoggable(FINEST)) {
@@ -598,7 +614,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
     }
 
     private void findDefaultRepository() {
-        assert RequestProcessor.getDefault().isRequestProcessorThread();
+        assert rp.isRequestProcessorThread();
         LOG.finer("findDefaultRepository()");                           //NOI18N
         updateProgress(Progress.WILL_DETERMINE_DEFAULT_REPO);
 
@@ -666,6 +682,7 @@ public final class RepositoryComboSupport implements ItemListener, Runnable {
             assert !EventQueue.isDispatchThread();
 
             Runnable doneNotifier = new Runnable() {
+                @Override
                 public void run() {
                     updateProgress(Progress.THREAD_PROGRESS_DONE);
                 }
