@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2008-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -34,7 +37,7 @@
  *
  * Contributor(s):
  *
- * Portions Copyrighted 2008 Sun Microsystems, Inc.
+ * Portions Copyrighted 2008-2010 Sun Microsystems, Inc.
  */
 
 package org.netbeans.modules.bugtracking.util;
@@ -67,7 +70,7 @@ import javax.swing.text.StyleContext;
 import javax.swing.text.StyledDocument;
 import org.netbeans.api.java.classpath.GlobalPathRegistry;
 import org.netbeans.modules.bugtracking.BugtrackingManager;
-import org.netbeans.modules.bugtracking.spi.VCSSupport;
+import org.netbeans.modules.bugtracking.spi.VCSAccessor;
 import org.openide.cookies.EditorCookie;
 import org.openide.cookies.LineCookie;
 import org.openide.cookies.OpenCookie;
@@ -101,7 +104,7 @@ public class StackTraceSupport {
         for (StackTracePosition stp : st) {
             StackTraceElement ste = stp.getStackTraceElements()[0];
             String path = getPath(ste);
-            open(path, ste.getLineNumber());
+            open(path, ste.getLineNumber() - 1);
             break;
         }
     }
@@ -319,11 +322,11 @@ public class StackTraceSupport {
                 // XXX any chance to disable the action if it's not a real io.File - e.g. a jdk class?
                 return;
             }
-            Collection<? extends VCSSupport> supports = Lookup.getDefault().lookupAll(VCSSupport.class);
+            Collection<? extends VCSAccessor> supports = Lookup.getDefault().lookupAll(VCSAccessor.class);
             if(supports == null) {
                 return;
             }
-            for (final VCSSupport s : supports) {
+            for (final VCSAccessor s : supports) {
                 // XXX this is messy - we implicitly expect that unrelevant VCS modules
                 // will skip the action
                 BugtrackingManager.getInstance().getRequestProcessor().post(new Runnable() {
@@ -468,9 +471,9 @@ public class StackTraceSupport {
             } catch (BadLocationException ex) {
                 BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
             }
+            textPane.addMouseListener(getHyperlinkListener());
+            textPane.addMouseMotionListener(getHyperlinkListener());
         }
-        textPane.addMouseListener(getHyperlinkListener());
-        textPane.addMouseMotionListener(getHyperlinkListener());
     }
 
     private static MouseInputAdapter hyperlinkListener;
@@ -525,11 +528,13 @@ public class StackTraceSupport {
                     if (e.isPopupTrigger()) {
                         try {
                             Element elem = element(e);
-                            String stackFrame = elem.getDocument().getText(elem.getStartOffset(), elem.getEndOffset() - elem.getStartOffset());
-                            JPopupMenu menu = new JPopupMenu();
-                            menu.add(new StackTraceAction(stackFrame, false));
-                            menu.add(new StackTraceAction(stackFrame, true));
-                            menu.show((JTextPane)e.getSource(), e.getX(), e.getY());
+                            if (elem.getAttributes().getAttribute(STACKTRACE_ATTRIBUTE) != null) {
+                                String stackFrame = elem.getDocument().getText(elem.getStartOffset(), elem.getEndOffset() - elem.getStartOffset());
+                                JPopupMenu menu = new JPopupMenu();
+                                menu.add(new StackTraceAction(stackFrame, false));
+                                menu.add(new StackTraceAction(stackFrame, true));
+                                menu.show((JTextPane)e.getSource(), e.getX(), e.getY());
+                            }
                         } catch(Exception ex) {
                             BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
                         }
