@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -67,7 +70,7 @@ public class GetMultiTaskDataCommand extends BugzillaCommand {
     @Override
     public void execute() throws CoreException {
         if(Bugzilla.LOG.isLoggable(Level.FINER)) {
-            Bugzilla.LOG.finer("will retrieve data for issues: " + print(ids));    // NOI18N
+            Bugzilla.LOG.log(Level.FINER, "will retrieve data for issues: {0}", print(ids));    // NOI18N
         }
         Bugzilla.getInstance().getRepositoryConnector().getTaskDataHandler().getMultiTaskData(
                 repository.getTaskRepository(),
@@ -77,15 +80,24 @@ public class GetMultiTaskDataCommand extends BugzillaCommand {
     }
 
     private String print(Set<String> ids) {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         int i = 0;
         for (String string : ids) {
             sb.append(string);
             if(++i < ids.size()) {
-                sb.append(", ");                                                // NOI18N
+                sb.append(",");                                                 // NOI18N
             }
         }
         return sb.toString();
     }
 
+    @Override
+    public String toString() {
+        StringBuilder sb = new StringBuilder();
+        sb.append("GetMultiTaskDataCommand [repository=");                      // NOI18N
+        sb.append(repository.getUrl());
+        sb.append(",...]");                                                     // NOI18N
+        return sb.toString();
+    }
+
 }
