@@ -172,6 +172,8 @@ public class BugzillaIssue extends Issue implements IssueTable.NodeProvider {
     private Map<String, String> attributes;
     private Map<String, TaskOperation> availableOperations;
 
+    private static final RequestProcessor parallelRP = new RequestProcessor("BugzillaIssue", 5); //NOI18N
+
     public BugzillaIssue(TaskData data, BugzillaRepository repo) {
         super(repo);
         this.data = data;
@@ -827,28 +829,30 @@ public class BugzillaIssue extends Issue implements IssueTable.NodeProvider {
             Bugzilla.LOG.log(Level.FINER, "resolving issue #{0} as fixed", new Object[]{getID()});
             resolve(RESOLVE_FIXED); // XXX constant?
 
-            // check for other preselections
-            Properties p = System.getProperties();
-            Enumeration<Object> keys = p.keys();
-            List<String> keyList = new LinkedList<String>();
-            while(keys.hasMoreElements()) {
-                Object key = keys.nextElement();
-                if(key.toString().startsWith(VCSHOOK_BUGZILLA_FIELD)) {
-                    keyList.add(key.toString());
+            if(BugzillaUtil.isNbRepository(repository)) {
+                // check for other preselections
+                Properties p = System.getProperties();
+                Enumeration<Object> keys = p.keys();
+                List<String> keyList = new LinkedList<String>();
+                while(keys.hasMoreElements()) {
+                    Object key = keys.nextElement();
+                    if(key.toString().startsWith(VCSHOOK_BUGZILLA_FIELD)) {
+                        keyList.add(key.toString());
+                    }
                 }
-            }
-            for (String key : keyList) {
-                String fieldName = key.substring(VCSHOOK_BUGZILLA_FIELD.length());
-                String value = p.getProperty(key);
-                IssueField issueField = repository.getConfiguration().getField(fieldName);
-                if(issueField != null) {
-                    if(issueField.isReadOnly()) {
-                        Bugzilla.LOG.log(Level.WARNING, "field [{0}] is read-only.", new Object[]{repository.getUrl(), fieldName});
+                for (String key : keyList) {
+                    String fieldName = key.substring(VCSHOOK_BUGZILLA_FIELD.length());
+                    String value = p.getProperty(key);
+                    IssueField issueField = repository.getConfiguration().getField(fieldName);
+                    if(issueField != null) {
+                        if(issueField.isReadOnly()) {
+                            Bugzilla.LOG.log(Level.WARNING, "field [{0}] is read-only.", new Object[]{repository.getUrl(), fieldName});
+                        } else {
+                            setFieldValue(issueField, value);
+                        }
                     } else {
-                        setFieldValue(issueField, value);
+                        Bugzilla.LOG.log(Level.WARNING, "Repsitory [{0}] has no field [{1}]", new Object[]{repository.getUrl(), fieldName});
                     }
-                } else {
-                    Bugzilla.LOG.log(Level.WARNING, "Repsitory [{0}] has no field [{1}]", new Object[]{repository.getUrl(), fieldName});
                 }
             }
 
@@ -958,6 +962,7 @@ public class BugzillaIssue extends Issue implements IssueTable.NodeProvider {
                 return false;
             }
             getBugzillaRepository().getIssueCache().setIssueData(this, td); // XXX
+            getBugzillaRepository().ensureConfigurationUptodate(this);
             refreshViewData(afterSubmitRefresh);
         } catch (IOException ex) {
             Bugzilla.LOG.log(Level.SEVERE, null, ex);
@@ -1174,7 +1179,7 @@ public class BugzillaIssue extends Issue implements IssueTable.NodeProvider {
             final ProgressHandle handle = ProgressHandleFactory.createHandle(progressMessage);
             handle.start();
             handle.switchToIndeterminate();
-            RequestProcessor.getDefault().post(new Runnable() {
+            parallelRP.post(new Runnable() {
                 @Override
                 public void run() {
                     try {
@@ -1217,7 +1222,7 @@ public class BugzillaIssue extends Issue implements IssueTable.NodeProvider {
                 final ProgressHandle handle = ProgressHandleFactory.createHandle(progressMessage);
                 handle.start();
                 handle.switchToIndeterminate();
-                RequestProcessor.getDefault().post(new Runnable() {
+                parallelRP.post(new Runnable() {
                     @Override
                     public void run() {
                         try {
@@ -1242,7 +1247,7 @@ public class BugzillaIssue extends Issue implements IssueTable.NodeProvider {
                 final ProgressHandle handle = ProgressHandleFactory.createHandle(progressMessage);
                 handle.start();
                 handle.switchToIndeterminate();
-                RequestProcessor.getDefault().post(new Runnable() {
+                parallelRP.post(new Runnable() {
                     @Override
                     public void run() {
                         try {
