@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,6 +47,7 @@ import java.awt.EventQueue;
 import java.awt.event.ActionEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
+import java.io.IOException;
 import java.lang.ref.WeakReference;
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -59,18 +63,17 @@ import javax.swing.AbstractAction;
 import javax.swing.Action;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
+import org.netbeans.modules.bugtracking.kenai.spi.KenaiAccessor;
 import org.netbeans.modules.bugtracking.spi.Issue;
 import org.netbeans.modules.bugtracking.spi.Repository;
 import org.netbeans.modules.bugtracking.spi.IssueProvider;
 import org.netbeans.modules.bugtracking.ui.issue.cache.IssueCache;
-import org.netbeans.modules.bugtracking.util.KenaiUtil;
+import org.netbeans.modules.bugtracking.kenai.spi.KenaiUtil;
 import org.netbeans.modules.bugzilla.Bugzilla;
 import org.netbeans.modules.bugzilla.BugzillaConfig;
 import org.netbeans.modules.bugzilla.kenai.KenaiRepository;
 import org.netbeans.modules.bugzilla.repository.BugzillaRepository;
 import org.netbeans.modules.bugzilla.util.BugzillaUtil;
-import org.netbeans.modules.kenai.api.Kenai;
-import org.netbeans.modules.kenai.api.KenaiException;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.Lookup;
@@ -193,6 +196,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
         support.removePropertyChangeListener(listener);
     }
 
+    @Override
     public void propertyChange(PropertyChangeEvent evt) {
         if (Repository.EVENT_ATTRIBUTES_CHANGED.equals(evt.getPropertyName())) {
             if (evt.getOldValue() != null && evt.getOldValue() instanceof Map) {
@@ -226,16 +230,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
                     }
                 }
             }
-        } else if (Kenai.PROP_LOGIN.equals(evt.getPropertyName())) {
-            // kenai issues need instantiated repository so they can be shown in tasklist
-            // but some (e.g. private kenai projects) cannot be instantiated without being logged in. So kenai issues need to be notified
-            // when user loggs in so the repository can be created.
-            rp.post(new Runnable() { // do not block here
-                public void run() {
-                    notifyKenaiLogin();
-                }
-            });
-        }
+        } 
     }
 
     /**
@@ -311,6 +306,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
 
     private void reloadAsync() {
         rp.post(new Runnable () {
+            @Override
             public void run() {
                 initializeIssues();
             }
@@ -324,6 +320,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
         }
         final BugzillaLazyIssue[] lazyIssuesToSave = lazyIssues;
         rp.post(new Runnable () {
+            @Override
             public void run() {
                 initializeIssues();
                 LOG.log(Level.FINE, "saveIntern: saving issues");       //NOI18N
@@ -377,7 +374,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
             LOG.finer("initializeIssues: reloading saved issues");      //NOI18N
             // load from storage
             Map<String, List<String>> repositoryIssues = BugzillaConfig.getInstance().getTaskListIssues();
-            if (repositoryIssues.size() == 0) {
+            if (repositoryIssues.isEmpty()) {
                 LOG.fine("initializeIssues: no saved issues");          //NOI18N
                 return;
             }
@@ -423,7 +420,6 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
 
     private void addKenaiIssues (Map<String, List<String>> repositoryIssues) {
         // now what remains are kenai issues and non-existant repositories
-        boolean kenaiIssueAdded = false;
         for (Map.Entry<String, List<String>> e : repositoryIssues.entrySet()) {
             String projectName = e.getKey();
             if (projectName.startsWith(KENAI_REPOSITORY_IDENT_PREFIX)) { // is kenai
@@ -451,17 +447,55 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
                             continue;
                         }
                         add(issueName, issueUrl, issueId, projectName);
-                        kenaiIssueAdded = true;
+                        KenaiAccessor ka = KenaiUtil.getKenaiAccessor();
+                        if(ka != null) {
+                            String host = issueUrl.getHost();
+                            Map<String, PropertyChangeListener> kl = getKenaiListeners();
+                            PropertyChangeListener l = kl.get(host);
+                            if (l == null) {
+                                // kenai host not registered yet
+                                l = new KenaiListener(host);
+                                ka.addPropertyChangeListener(l, host);
+                                kl.put(host, l);
+                            }
+                        }
                     }
                 }
             }
         }
-        if (kenaiIssueAdded) {
-            Kenai.getDefault().removePropertyChangeListener(this);
-            Kenai.getDefault().addPropertyChangeListener(this);
+    }
+
+    private class KenaiListener implements PropertyChangeListener {
+        private final String kenaiHost;
+
+        public KenaiListener(String kenaiHost) {
+            this.kenaiHost = kenaiHost;
+        }
+
+        @Override
+        public void propertyChange(PropertyChangeEvent evt) {
+            if (KenaiAccessor.PROP_LOGIN.equals(evt.getPropertyName())) {
+                // kenai issues need instantiated repository so they can be shown in tasklist
+                // but some (e.g. private kenai projects) cannot be instantiated without being logged in. So kenai issues need to be notified
+                // when user loggs in so the repository can be created.
+                rp.post(new Runnable() { // do not block here
+                    @Override
+                    public void run() {
+                        notifyKenaiLogin(kenaiHost);
+                    }
+                });
+            }
         }
     }
 
+    private Map<String, PropertyChangeListener> kenaiListeners;
+    private Map<String, PropertyChangeListener> getKenaiListeners() {
+        if (kenaiListeners == null) {
+            kenaiListeners = new HashMap<String, PropertyChangeListener>();
+        }
+        return kenaiListeners;
+    }
+    
     private void remove (URL url, boolean savePermanently) {
         BugzillaLazyIssue lazyIssue;
         synchronized (LOCK) {
@@ -517,6 +551,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
         final BugzillaIssue[] issue = new BugzillaIssue[1];
         if (status == IssueCache.ISSUE_STATUS_UNKNOWN) { // not yet cached
             Runnable runnable = new Runnable() {
+                @Override
                 public void run() {
                     LOG.log(Level.FINE, "getIssue: creating issue {0}", repository.getUrl() + "#" + issueId); //NOI18N
                     issue[0] = (BugzillaIssue) repository.getIssue(issueId);
@@ -541,11 +576,14 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
      * Notifies all kenai issues that user has logged on. Private kenai projects cannot be instantiated without being logged in
      * and issue tracking repository cannot be created.
      */
-    private void notifyKenaiLogin () {
+    private void notifyKenaiLogin (String notifiedKenaiHost) {
+        assert notifiedKenaiHost != null;
         synchronized (LOCK) {
             for (BugzillaLazyIssue issue : watchedIssues.values()) {
                 if (issue instanceof KenaiBugzillaLazyIssue) {
-                    ((KenaiBugzillaLazyIssue) issue).notifyKenaiLogin();
+                    if(notifiedKenaiHost.equals(issue.getUrl().getHost())) {
+                        ((KenaiBugzillaLazyIssue) issue).notifyKenaiLogin();
+                    }
                 }
             }
         }
@@ -620,6 +658,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
         private void attachIssueListener (BugzillaIssue issue) {
             if (issueListener == null) {
                 issueListener = new PropertyChangeListener() {
+                    @Override
                     public void propertyChange(PropertyChangeEvent evt) {
                         BugzillaIssue issue = issueRef.get();
                         if (Issue.EVENT_ISSUE_DATA_CHANGED.equals(evt.getPropertyName()) && issue != null) {
@@ -658,8 +697,10 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
         public List<? extends Action> getActions() {
             List<AbstractAction> actions = new LinkedList<AbstractAction>();
             actions.add(new AbstractAction(NbBundle.getMessage(BugzillaIssueProvider.class, "BugzillaIssueProvider.resolveAction")) { //NOI18N
+                @Override
                 public void actionPerformed(ActionEvent e) {
                     RequestProcessor.getDefault().post(new Runnable() {
+                        @Override
                         public void run() {
                             final BugzillaIssue issue = getIssue();
                             if (issue == null) {
@@ -679,6 +720,7 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
                                     final String duplicateId = panel.getDuplicateId();
                                     final String comment = panel.getComment();
                                     runCancellableCommand(new Runnable () {
+                                        @Override
                                         public void run() {
                                             if (BugzillaIssue.RESOLVE_DUPLICATE.equals(resolution)) {
                                                 issue.duplicate(duplicateId);
@@ -760,8 +802,9 @@ public final class BugzillaIssueProvider extends IssueProvider implements Proper
             if (loginStatusChanged) {
                 try {
                     LOG.log(Level.FINE, "KenaiBugzillaLazyIssue.lookupRepository: getting repository for: " + projectName);
-                    repo = KenaiUtil.getKenaiBugtrackingRepository(projectName);
-                } catch (KenaiException ex) {
+                    String url = getUrl().toString();
+                    repo = KenaiUtil.getRepository(url, projectName);
+                } catch (IOException ex) {
                     LOG.log(Level.FINE, "KenaiBugzillaLazyIssue.lookupRepository: getting repository for " + projectName, ex);
                 }
                 loginStatusChanged = false;
