@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -138,9 +141,8 @@ public class BugzillaQuery extends Query {
         return columnDescriptors;
     }
 
-    @Override
-    public boolean refresh() { // XXX what if already running! - cancel task
-        return refreshIntern(false);
+    public void refresh() { // XXX what if already running! - cancel task
+        refreshIntern(false);
     }
 
     boolean refreshIntern(final boolean autoRefresh) { // XXX what if already running! - cancel task
@@ -199,6 +201,8 @@ public class BugzillaQuery extends Query {
                     // - and issues which were returned by some previous run and are archived now
                     queryIssues.addAll(issues);
 
+                    getController().switchToDeterminateProgress(queryIssues.size());
+
                     GetMultiTaskDataCommand dataCmd = new GetMultiTaskDataCommand(repository, queryIssues, new IssuesCollector());
                     repository.getExecutor().execute(dataCmd, !autoRefresh);
                     ret[0] = dataCmd.hasFailed();
@@ -277,10 +281,6 @@ public class BugzillaQuery extends Query {
         super.setSaved(saved);
     }
 
-    public void setFilter(Filter filter) {
-        getController().selectFilter(filter);
-    }
-
     @Override
     public void fireQuerySaved() {
         super.fireQuerySaved();
@@ -329,6 +329,7 @@ public class BugzillaQuery extends Query {
         public IssuesCollector() {}
         public void accept(TaskData taskData) {
             String id = BugzillaIssue.getID(taskData);
+            getController().addProgressUnit(BugzillaIssue.getDisplayName(taskData));
             BugzillaIssue issue;
             try {
                 IssueCache<TaskData> cache = repository.getIssueCache();
