@@ -77,7 +77,7 @@ import org.netbeans.modules.bugtracking.spi.RepositoryUser;
 import org.netbeans.modules.bugtracking.util.BugtrackingUtil;
 import org.netbeans.modules.bugtracking.ui.issue.cache.IssueCache;
 import org.netbeans.modules.bugtracking.kenai.spi.KenaiUtil;
-import org.netbeans.modules.bugtracking.util.MylynUtils;
+import org.netbeans.libs.bugtracking.MylynUtils;
 import org.netbeans.modules.bugzilla.commands.BugzillaExecutor;
 import org.netbeans.modules.bugzilla.commands.GetMultiTaskDataCommand;
 import org.netbeans.modules.bugzilla.commands.PerformQueryCommand;
@@ -294,7 +294,9 @@ public class BugzillaRepository extends Repository {
             return null;
         }
         try {
-            return getIssueCache().setIssueData(id, taskData);
+            BugzillaIssue issue = (BugzillaIssue) getIssueCache().setIssueData(id, taskData);
+            ensureConfigurationUptodate(issue);
+            return issue;
         } catch (IOException ex) {
             Bugzilla.LOG.log(Level.SEVERE, null, ex);
             return null;
@@ -581,9 +583,16 @@ public class BugzillaRepository extends Repository {
     }
 
     private void scheduleQueryRefresh() {
+        String schedule = System.getProperty("netbeans.t9y.bugzilla.force.refresh.schedule", "");
+        if(!schedule.isEmpty()) {
+            int delay = Integer.parseInt(schedule);
+            refreshQueryTask.schedule(delay); 
+            return;
+        }
+        
         int delay = BugzillaConfig.getInstance().getQueryRefreshInterval();
         Bugzilla.LOG.log(Level.FINE, "scheduling query refresh for repository {0} in {1} minute(s)", new Object[] {name, delay}); // NOI18N
-        if(delay < 5 && System.getProperty("netbeans.t9y.bugzilla.force.refresh.delay") == null) {
+        if(delay < 5) {
             Bugzilla.LOG.log(Level.WARNING, " wrong query refresh delay {0}. Falling back to default {0}", new Object[] {delay, BugzillaConfig.DEFAULT_QUERY_REFRESH}); // NOI18N
             delay = BugzillaConfig.DEFAULT_QUERY_REFRESH;
         }
@@ -641,6 +650,35 @@ public class BugzillaRepository extends Repository {
         });
     }
 
+    public void ensureConfigurationUptodate(BugzillaIssue issue) {
+        BugzillaConfiguration conf = getConfiguration();
+
+        String product = issue.getFieldValue(IssueField.PRODUCT);
+        String resolution = issue.getFieldValue(IssueField.RESOLUTION);
+        String severity = issue.getFieldValue(IssueField.SEVERITY);
+        String milestone = issue.getFieldValue(IssueField.MILESTONE);
+        String version = issue.getFieldValue(IssueField.VERSION);
+        String priority = issue.getFieldValue(IssueField.PRIORITY);
+        String platform = issue.getFieldValue(IssueField.PLATFORM);
+        String status = issue.getFieldValue(IssueField.STATUS);
+        String os = issue.getFieldValue(IssueField.OS);
+        String component = issue.getFieldValue(IssueField.COMPONENT);
+
+        if(!component.isEmpty() && !conf.getComponents(product).contains(component) ||
+           !os.isEmpty() && !conf.getOSs().contains(os) ||
+           !status.isEmpty() && !conf.getStatusValues().contains(status) ||
+           !platform.isEmpty() && !conf.getPlatforms().contains(platform) ||
+           !priority.isEmpty() && !conf.getPriorities().contains(priority) ||
+           !product.isEmpty() && !conf.getProducts().contains(product) ||
+           !resolution.isEmpty() && !conf.getResolutions().contains(resolution) ||
+           !severity.isEmpty() && !conf.getSeverities().contains(severity) ||
+           !milestone.isEmpty() && !conf.getTargetMilestones(product).contains(milestone) ||
+           !version.isEmpty() && !conf.getVersions(product).contains(version))
+        {
+            refreshConfiguration();
+        }
+    }
+
     private class IssuesCollector extends TaskDataCollector {
         public void accept(TaskData taskData) {
             String id = BugzillaIssue.getID(taskData);
