@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -42,17 +45,11 @@ package org.netbeans.modules.bugzilla.repository;
 import java.awt.BorderLayout;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.io.UnsupportedEncodingException;
-import java.net.MalformedURLException;
 import java.net.URI;
-import java.net.URISyntaxException;
 import java.net.URL;
-import java.net.URLEncoder;
 import java.util.logging.Level;
 import javax.swing.JComponent;
 import javax.swing.SwingUtilities;
-import javax.swing.event.AncestorEvent;
-import javax.swing.event.AncestorListener;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
@@ -61,11 +58,11 @@ import org.eclipse.mylyn.tasks.core.TaskRepository;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.modules.bugtracking.spi.BugtrackingController;
+import org.netbeans.modules.bugtracking.util.BugtrackingUtil;
 import org.netbeans.modules.bugzilla.Bugzilla;
 import org.netbeans.modules.bugzilla.BugzillaConfig;
 import org.netbeans.modules.bugzilla.commands.ValidateCommand;
 import org.openide.util.Cancellable;
-import org.openide.util.Exceptions;
 import org.openide.util.HelpCtx;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -80,7 +77,9 @@ public class RepositoryController extends BugtrackingController implements Docum
     private RepositoryPanel panel;
     private String errorMessage;
     private boolean validateError;
-    private boolean populating;
+    private boolean populated = false;
+    private TaskRunner taskRunner;
+    private RequestProcessor rp;
 
     RepositoryController(BugzillaRepository repository) {
         this.repository = repository;
@@ -91,16 +90,9 @@ public class RepositoryController extends BugtrackingController implements Docum
         panel.psswdField.getDocument().addDocumentListener(this);
 
         panel.validateButton.addActionListener(this);
-        panel.addAncestorListener(new AncestorListener() {
-            public void ancestorAdded(AncestorEvent event) {
-                populate();
-            }
-            public void ancestorRemoved(AncestorEvent event) { }
-            public void ancestorMoved(AncestorEvent event)   { }
-        });
-
     }
 
+    @Override
     public JComponent getComponent() {
         return panel;
     }
@@ -109,6 +101,7 @@ public class RepositoryController extends BugtrackingController implements Docum
         return new HelpCtx(org.netbeans.modules.bugzilla.repository.BugzillaRepository.class);
     }
 
+    @Override
     public boolean isValid() {
         return validate();
     }
@@ -144,12 +137,16 @@ public class RepositoryController extends BugtrackingController implements Docum
 
     private boolean validate() {
         if(validateError) {
+            panel.validateButton.setEnabled(true);
+            return false;
+        }
+        panel.validateButton.setEnabled(false);
+
+        if(!populated) {
             return false;
         }
         errorMessage = null;
 
-        panel.validateButton.setEnabled(false);
-
         // check name
         String name = panel.nameField.getText().trim();
         if(name.equals("")) { // NOI18N
@@ -161,8 +158,8 @@ public class RepositoryController extends BugtrackingController implements Docum
         String[] repositories = null;
         if(repository.getTaskRepository() == null) {
             repositories = BugzillaConfig.getInstance().getRepositories();
-            for (String repositoryName : repositories) {
-                if(name.equals(repositoryName)) {
+            for (String repoID : repositories) {
+                if(name.equals(BugzillaConfig.getInstance().getRepositoryName(repoID))) {
                     errorMessage = NbBundle.getMessage(RepositoryController.class, "MSG_NAME_ALREADY_EXISTS");  // NOI18N
                     return false;
                 }
@@ -181,7 +178,7 @@ public class RepositoryController extends BugtrackingController implements Docum
             new URI(url);
         } catch (Exception ex) {
             errorMessage = NbBundle.getMessage(RepositoryController.class, "MSG_WRONG_URL_FORMAT");  // NOI18N
-            Bugzilla.LOG.log(Level.FINEST, errorMessage, ex);
+            Bugzilla.LOG.log(Level.FINE, errorMessage, ex);
             return false;
         }
 
@@ -229,53 +226,77 @@ public class RepositoryController extends BugtrackingController implements Docum
     }
 
     void populate() {
-        if(repository.getTaskRepository() != null) {
-            SwingUtilities.invokeLater(new Runnable() {
-                public void run() {
-                    populating = true;
-                    AuthenticationCredentials c = repository.getTaskRepository().getCredentials(AuthenticationType.REPOSITORY);
-                    panel.userField.setText(c.getUserName());
-                    panel.psswdField.setText(c.getPassword());
-                    c = repository.getTaskRepository().getCredentials(AuthenticationType.HTTP);
-                    if(c != null) {
-                        String httpUser = c.getUserName();
-                        String httpPsswd = c.getPassword();
-                        if(httpUser != null && !httpUser.equals("") &&          // NOI18N
-                           httpPsswd != null && !httpPsswd.equals(""))          // NOI18N
-                        {
-                            panel.httpCheckBox.setSelected(true);
-                            panel.httpUserField.setText(httpUser);
-                            panel.httpPsswdField.setText(httpPsswd);
+        taskRunner = new TaskRunner(NbBundle.getMessage(RepositoryPanel.class, "LBL_ReadingRepoData")) {  // NOI18N
+            @Override
+            protected void preRun() {
+                panel.validateButton.setVisible(false);
+                super.preRun();
+            }
+            @Override
+            protected void postRun() {
+                panel.validateButton.setVisible(true);
+                super.postRun();
+            }
+            @Override
+            void execute() {
+                BugzillaConfig.getInstance().setupCredentials(repository);
+                SwingUtilities.invokeLater(new Runnable() {
+                    @Override
+                    public void run() {
+                        TaskRepository taskRepository = repository.getTaskRepository();
+                        if(taskRepository != null) {
+                            AuthenticationCredentials c = taskRepository.getCredentials(AuthenticationType.REPOSITORY);
+                            if(c != null) {
+                                panel.userField.setText(c.getUserName());
+                                panel.psswdField.setText(c.getPassword());
+                            }
+                            c = taskRepository != null ? taskRepository.getCredentials(AuthenticationType.HTTP) : null;
+                            if(c != null) {
+                                String httpUser = c.getUserName();
+                                String httpPsswd = c.getPassword();
+                                if(httpUser != null && !httpUser.equals("") &&          // NOI18N
+                                   httpPsswd != null && !httpPsswd.equals(""))          // NOI18N
+                                {
+                                    panel.httpCheckBox.setSelected(true);
+                                    panel.httpUserField.setText(httpUser);
+                                    panel.httpPsswdField.setText(httpPsswd);
+                                }
+                            }
+                            panel.urlField.setText(taskRepository.getUrl());
+                            panel.nameField.setText(repository.getDisplayName());
+                            panel.cbEnableLocalUsers.setSelected(repository.isShortUsernamesEnabled());
                         }
+                        populated = true;
+                        fireDataChanged();
                     }
-                    panel.urlField.setText(repository.getTaskRepository().getUrl());
-                    panel.nameField.setText(repository.getDisplayName());
-                    panel.cbEnableLocalUsers.setSelected(repository.isShortUsernamesEnabled());
-                    populating = false;
-                    fireDataChanged();
-                }
-            });
-        }
+                });
+            }
+        };
+        taskRunner.startTask();
     }
 
+    @Override
     public void insertUpdate(DocumentEvent e) {
-        if(populating) return;
+        if(!populated) return;
         validateErrorOff(e);
         fireDataChanged();
     }
 
+    @Override
     public void removeUpdate(DocumentEvent e) {
-        if(populating) return;
+        if(!populated) return;
         validateErrorOff(e);
         fireDataChanged();
     }
 
+    @Override
     public void changedUpdate(DocumentEvent e) {
-        if(populating) return;
+        if(!populated) return;
         validateErrorOff(e);
         fireDataChanged();
     }
 
+    @Override
     public void actionPerformed(ActionEvent e) {
         if(e.getSource() == panel.validateButton) {
             onValidate();
@@ -283,80 +304,51 @@ public class RepositoryController extends BugtrackingController implements Docum
     }
 
     private void onValidate() {
-        RequestProcessor rp = Bugzilla.getInstance().getRequestProcessor();
+        taskRunner = new TaskRunner(NbBundle.getMessage(RepositoryPanel.class, "LBL_Validating")) {  // NOI18N
+            @Override
+            void execute() {
+                validateError = false;
+                repository.resetRepository(true); // reset mylyns caching
 
-        final Task[] task = new Task[1];
-        Cancellable c = new Cancellable() {
-            public boolean cancel() {
-                panel.progressPanel.setVisible(false);
-                panel.validateLabel.setVisible(false);
-                if(task[0] != null) {
-                    task[0].cancel();
+                String name = getName();
+                String url = getUrl();
+                String user = getUser();
+                String httpUser = getHttpUser();
+                TaskRepository taskRepo = BugzillaRepository.createTaskRepository(
+                        name,
+                        url,
+                        user,
+                        getPassword(),
+                        httpUser,
+                        getHttpPassword(),
+                        isLocalUserEnabled());
+
+                ValidateCommand cmd = new ValidateCommand(taskRepo);
+                repository.getExecutor().execute(cmd, false, false, false);
+                if(cmd.hasFailed()) {
+                    if(cmd.getErrorMessage() == null) {
+                        logValidateMessage("validate for [{0},{1},{2},{3},{4},{5}] has failed, yet the returned error message is null.", // NOI18N
+                                           Level.WARNING, name, url, user, getPassword(), httpUser, getHttpPassword());
+                        errorMessage = NbBundle.getMessage(RepositoryController.class, "MSG_VALIDATION_FAILED"); // NOI18N
+                    } else {
+                        errorMessage = cmd.getErrorMessage();
+                        logValidateMessage("validate for [{0},{1},{2},{3},{4},{5}] has failed: " + errorMessage, // NOI18N
+                                           Level.WARNING, name, url, user, getPassword(), httpUser, getHttpPassword());
+                    }
+                    validateError = true;
+                } else {
+                    panel.connectionLabel.setVisible(true);
+                    logValidateMessage("validate for [{0},{1},{2},{3},{4},{5}] ok.", // NOI18N
+                                       Level.INFO, name, url, user, getPassword(), httpUser, getHttpPassword());
                 }
-                return true;
+                fireDataChanged();
+            }
+
+            private void logValidateMessage(String msg, Level level, String name, String url, String user, String psswd, String httpUser, String httpPsswd) {
+                Bugzilla.LOG.log(level, msg, new Object[] {name, url, user, BugtrackingUtil.getPasswordLog(psswd), httpUser, BugtrackingUtil.getPasswordLog(httpPsswd)});
             }
         };
-        final ProgressHandle handle = ProgressHandleFactory.createHandle(NbBundle.getMessage(RepositoryPanel.class, "LBL_Validating"), c); // NOI18N
-        JComponent comp = ProgressHandleFactory.createProgressComponent(handle);
-        panel.progressPanel.removeAll();
-        panel.progressPanel.add(comp, BorderLayout.CENTER);
-
-        task[0] = rp.create(new Runnable() {
-            public void run() {
-                panel.connectionLabel.setVisible(false);
-                handle.start();
-                panel.progressPanel.setVisible(true);
-                panel.validateLabel.setVisible(true);
-                panel.enableFields(false);
-                panel.validateLabel.setText(NbBundle.getMessage(RepositoryPanel.class, "LBL_Validating")); // NOI18N
-                try {
-                    repository.resetRepository(); // reset mylyns caching
-
-                    String name = getName();
-                    String url = getUrl();
-                    String user = getUser();
-                    String httpUser = getHttpUser();
-                    TaskRepository taskRepo = BugzillaRepository.createTaskRepository(
-                            name,
-                            url,
-                            user,
-                            getPassword(),
-                            httpUser,
-                            getHttpPassword(),
-                            isLocalUserEnabled());
-
-                    ValidateCommand cmd = new ValidateCommand(taskRepo);
-                    repository.getExecutor().execute(cmd, false, false);
-                    if(cmd.hasFailed()) {
-                        if(cmd.getErrorMessage() == null) {
-                            logValidateMessage("validate for [{0},{1},{2},****{3},****] has failed, yet the returned error message is null.", // NOI18N
-                                               Level.WARNING, name, url, user, httpUser);
-                            errorMessage = NbBundle.getMessage(RepositoryController.class, "MSG_VALIDATION_FAILED"); // NOI18N
-                        } else {
-                            errorMessage = cmd.getErrorMessage();
-                            logValidateMessage("validate for [{0},{1},{2},****{3},****] has failed: " + errorMessage, // NOI18N
-                                               Level.WARNING, name, url, user, httpUser);
-                        }
-                        validateError = true;
-                        fireDataChanged();
-                    } else {
-                        panel.connectionLabel.setVisible(true);
-                        logValidateMessage("validate for [{0},{1},{2},****{3},****] worked.", // NOI18N
-                                           Level.INFO, name, url, user, httpUser);
-                    }
-                } finally {
-                    panel.enableFields(true);
-                    panel.progressPanel.setVisible(false);
-                    panel.validateLabel.setVisible(false);
-                    handle.finish();
-                }
-            }
-
-            private void logValidateMessage(String msg, Level level, String name, String url, String user, String httpUser) {
-                Bugzilla.LOG.log(level, msg, new Object[] {name, url, user, httpUser});
-            }
-        });
-        task[0].schedule(0);
+        taskRunner.startTask();
     }
 
     private void validateErrorOff(DocumentEvent e) {
@@ -364,4 +356,93 @@ public class RepositoryController extends BugtrackingController implements Docum
             validateError = false;
         }
     }
+
+    void cancel() {
+        if(taskRunner != null) {
+            taskRunner.cancel();
+        }
+    }
+
+    private abstract class TaskRunner implements Runnable, Cancellable, ActionListener {
+        private Task task;
+        private ProgressHandle handle;
+        private String labelText;
+
+        public TaskRunner(String labelText) {
+            this.labelText = labelText;            
+        }
+
+        final void startTask() {
+            cancel();
+            task = getRequestProcessor().create(this);
+            task.schedule(0);
+        }
+
+        @Override
+        final public void run() {
+            preRun();
+            try {
+                execute();
+            } finally {
+                postRun();
+            }
+        }
+
+        abstract void execute();
+
+        protected void preRun() {
+            handle = ProgressHandleFactory.createHandle(labelText, this);
+            JComponent comp = ProgressHandleFactory.createProgressComponent(handle);
+            panel.progressPanel.removeAll();
+            panel.progressPanel.add(comp, BorderLayout.CENTER);
+            panel.cancelButton.addActionListener(this);
+            panel.connectionLabel.setVisible(false);
+            handle.start();
+            panel.progressPanel.setVisible(true);
+            panel.cancelButton.setVisible(true);
+            panel.validateButton.setVisible(false);
+            panel.validateLabel.setVisible(true);
+            panel.enableFields(false);
+            panel.validateLabel.setText(labelText); // NOI18N
+        }
+
+        protected void postRun() {
+            if(handle != null) {
+                handle.finish();
+            }
+            panel.cancelButton.removeActionListener(this);
+            panel.progressPanel.setVisible(false);
+            panel.validateLabel.setVisible(false);
+            panel.validateButton.setVisible(true);
+            panel.cancelButton.setVisible(false);
+            panel.enableFields(true);
+        }
+
+        @Override
+        public boolean cancel() {
+            boolean ret = true;
+            postRun();
+            if(task != null) {
+                ret = task.cancel();
+            }
+            errorMessage = null;
+            return ret;
+        }
+
+        @Override
+        public void actionPerformed(ActionEvent e) {
+            if(e.getSource() == panel.cancelButton) {
+                cancel();
+            }
+        }
+
+    }
+
+    private RequestProcessor getRequestProcessor() {
+        if(rp == null) {
+            rp = new RequestProcessor("Bugzilla Repository tasks", 1, true); // NOI18N
+        }
+        return rp;
+    }
+
 }
