@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -48,6 +51,7 @@ import org.eclipse.mylyn.internal.bugzilla.core.IBugzillaConstants;
 public interface BugzillaConstants {
     public static final String URL_ADVANCED_BUG_LIST = IBugzillaConstants.URL_BUGLIST + "?query_format=advanced"; //NOI18N
     public static final String URL_BUG_IDS = IBugzillaConstants.URL_BUGLIST + "?bug_id="; //NOI18N
+    public static final String URL_SHOW_BUG = IBugzillaConstants.URL_GET_SHOW_BUG;
     public static final String QUERY_COLUMN_LIST = "&columnlist=bug_severity%2Cpriority%2Cbug_status%2Cresolution%2Cshort_desc%2Cchangeddate"; //NOI18N
 
     public static final String MY_ISSUES_PARAMETERS_FORMAT =
@@ -61,6 +65,16 @@ public interface BugzillaConstants {
             "&emailtype1=exact" +                                               // NOI18N
             "&email1={1}";                                                      // NOI18N
 
+    public static final String NB_MY_ISSUES_PARAMETERS_FORMAT =
+            "&product={0}" +                                                    // NOI18N
+            "&bug_status=NEW" +                                                 // NOI18N
+            "&bug_status=STARTED" +                                             // NOI18N
+            "&bug_status=REOPENED" +                                            // NOI18N
+            "&emailassigned_to1=1" +                                            // NOI18N
+            "&emailreporter1=1" +                                               // NOI18N
+            "&emailtype1=exact" +                                               // NOI18N
+            "&email1={1}";                                                      // NOI18N
+
     public static final String ALL_ISSUES_PARAMETERS =
             "&product={0}" +                                                    // NOI18N
             "&bug_status=UNCONFIRMED" +                                         // NOI18N
