@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -285,6 +288,18 @@ public class BugzillaIssueFinderTest extends NbTestCase {
         checkIssueSpans("See issue 1446.", "issue 1446");
     }
 
+    @Test
+    public void testBug177290() {
+        issueFinder = BugzillaIssueFinder.getTestInstance();
+
+        checkIssueSpans(
+                "Seems like duplicate of 149393, thank you for report anyway.\n"
+                + '\n'
+                + "*** This issue has been marked as a duplicate of 149393 ***",
+                "149393",
+                "149393");
+    }
+
     private void checkIssueSpans(String str, String... substr) {
         checkTestValidity(str != null);
         checkTestValidity(substr != null);
