@@ -148,9 +148,9 @@ public final class IOWindow implements IOContainer.Provider {
         return true;
     }
 
-    static final class IOWindowImpl extends TopComponent implements ChangeListener, PropertyChangeListener {
+    public static final class IOWindowImpl extends TopComponent implements ChangeListener, PropertyChangeListener {
 
-        static IOWindowImpl DEFAULT;
+        public static IOWindowImpl DEFAULT;
 
         static synchronized IOWindowImpl findDefault() {
             if (DEFAULT == null) {
@@ -194,7 +194,7 @@ public final class IOWindow implements IOContainer.Provider {
         private static final String ICON_PROP = "tabIcon"; //NOI18N
         private static final String TOOLBAR_ACTIONS_PROP = "toolbarActions"; //NOI18N
         private static final String TOOLBAR_BUTTONS_PROP = "toolbarButtons"; //NOI18N
-        private static final String ICON_RESOURCE = "org/netbeans/core/resources/frames/output.png"; // NOI18N
+        private static final String ICON_RESOURCE = "org/netbeans/core/io/ui/output.png"; // NOI18N
         private static final boolean AQUA = "Aqua".equals(UIManager.getLookAndFeel().getID()); // NOI18N
         private JTabbedPane pane;
         private JComponent singleTab;
@@ -291,9 +291,6 @@ public final class IOWindow implements IOContainer.Provider {
         public void requestVisible() {
             if (!isShowing()) {
 		super.requestVisible();
-		if (Boolean.TRUE.equals(getClientProperty("isSliding"))) { //NOI18N
-		    requestActive();
-		}
 	    }
         }
 
@@ -532,6 +529,13 @@ public final class IOWindow implements IOContainer.Provider {
                     throw new IllegalStateException ("No icon provided for " + actions[i]); //NOI18N
                 }
                 buttons[i].setDisabledIcon(ImageUtilities.createDisabledIcon((Icon) icon));
+                String name = (String) actions[i].getValue(Action.NAME);
+                String shortDescription = (String) actions[i].getValue(Action.SHORT_DESCRIPTION);
+                String longDescription = (String) actions[i].getValue(Action.LONG_DESCRIPTION);
+                if (name == null) name = shortDescription;
+                if (longDescription == null) longDescription = shortDescription;
+                buttons[i].getAccessibleContext().setAccessibleName(name);
+                buttons[i].getAccessibleContext().setAccessibleDescription(longDescription);
             }
             return buttons;
         }
