@@ -44,25 +44,9 @@
 
 package org.openide.explorer;
 
-import java.awt.BorderLayout;
-import java.awt.Component;
-import java.awt.DefaultKeyboardFocusManager;
-import java.awt.KeyboardFocusManager;
-import java.awt.event.ActionEvent;
-import java.beans.FeatureDescriptor;
-import java.util.*;
-import javax.swing.AbstractAction;
-import javax.swing.ActionMap;
-import javax.swing.JTextField;
 
-import junit.framework.*;
 
-import org.netbeans.junit.*;
-import org.openide.cookies.*;
 import org.openide.nodes.*;
-import org.openide.util.*;
-import org.openide.util.lookup.AbstractLookup;
-import org.openide.util.lookup.InstanceContent;
 
 /**
  * Check the behaviour of ExplorerManager's lookup by doing the same 
@@ -71,20 +55,11 @@ import org.openide.util.lookup.InstanceContent;
  *
  * @author Jaroslav Tulach
  */
-public class ExplorerUtilCreateLookupTest extends org.openide.windows.TopComponentGetLookupTest {
+public class ExplorerUtilCreateLookupTest extends org.openide.explorer.windows.TopComponentGetLookupTest {
     public ExplorerUtilCreateLookupTest(String testName) {
         super(testName);
     }
     
-    public static void main(String[] args) {
-        junit.textui.TestRunner.run(suite());
-    }
-    
-    public static Test suite() {
-        return new NbTestSuite(ExplorerUtilCreateLookupTest.class);
-    }
-    
-    
     protected boolean runInEQ () {
         return true;
     }
@@ -121,6 +96,7 @@ public class ExplorerUtilCreateLookupTest extends org.openide.windows.TopCompone
         ExTC e = new ExTC ();
         
         top = e;
+        get = e;
         lookup = ExplorerUtils.createLookup (e.em, e.getActionMap ());
     }
     
