@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -95,9 +98,13 @@ final class MultiViewActionMap extends ActionMap {
                     preventRecursive = false;
                     return null;
                 }
+                Action a;
                 preventRecursive = true;
-                Action a = m.get (key);
-                preventRecursive = false;
+                try {
+                    a = m.get (key);
+                } finally {
+                    preventRecursive = false;
+                }
                 if (a != null) {
                     return a;
                 }
@@ -110,6 +117,9 @@ final class MultiViewActionMap extends ActionMap {
             if (found == null && (owner instanceof JComponent)) {
                 m = ((JComponent)owner).getActionMap ();
                 if (m != null) {
+                    if( m instanceof MultiViewActionMap && ((MultiViewActionMap)m).preventRecursive ) {
+                        break;
+                    }
                     found = m.get (key);
                 }
             }
@@ -132,13 +142,15 @@ final class MultiViewActionMap extends ActionMap {
         java.util.Set keys = new java.util.HashSet();
 
         if (delegate != null) {
-            java.util.List l;
+            Object[] delegateKeys;
             if (all) {
-                l = Arrays.asList(delegate.allKeys());
+                delegateKeys = delegate.allKeys();
             } else {
-                l = Arrays.asList(delegate.keys());
+                delegateKeys = delegate.keys();
+            }
+            if( null != delegateKeys ) {
+                keys.addAll(Arrays.asList(delegateKeys));
             }
-            keys.addAll(l);
         }
         
         if (topComponentMap != null) {
