@@ -98,6 +98,14 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
     Framework getFramework() {
         return framework;
     }
+    @Override
+    protected ClassLoader findFrameworkClassLoader() {
+        Framework f = framework;
+        if (f != null) {
+            return f.getClass().getClassLoader();
+        }
+        return getClass().getClassLoader();
+    }
 
     @Override
     protected void prepare(Lookup lkp, Collection<? extends Module> preregister) {
@@ -138,15 +146,16 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
 
     @Override
     protected Set<String> start(Collection<? extends Module> allModules) {
-        if (framework.getState() == Bundle.ACTIVE) {
-            return toActivate(framework, allModules);
-        }
+        return toActivate(framework, allModules);
+    }
+
+    @Override
+    protected void start() {
         try {
             framework.start();
         } catch (BundleException ex) {
             LOG.log(Level.WARNING, "Cannot start Container" + framework, ex);
         }
-        return toActivate(framework, allModules);
     }
 
     private static Set<String> toActivate(Framework f, Collection<? extends Module> allModules) {
@@ -158,6 +167,11 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
         if (pkgAdm == null) {
             return null;
         }
+        Set<String> allCnbs = new HashSet<String>(allModules.size() * 2);
+        for (ModuleInfo m : allModules) {
+            allCnbs.add(m.getCodeNameBase());
+        }
+        
         Set<String> needEnablement = new HashSet<String>();
         for (Bundle b : f.getBundleContext().getBundles()) {
             String loc = b.getLocation();
@@ -169,7 +183,7 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
             RequiredBundle[] arr = pkgAdm.getRequiredBundles(loc);
             for (RequiredBundle rb : arr) {
                 for (Bundle n : rb.getRequiringBundles()) {
-                    if (n.getState() == Bundle.ACTIVE) {
+                    if (allCnbs.contains(n.getSymbolicName().replace('-', '_'))) {
                         needEnablement.add(loc);
                     }
                 }
@@ -197,6 +211,9 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
             assert registered.containsKey(m.getCodeNameBase()) : m.getCodeNameBase();
             Bundle b = findBundle(m.getCodeNameBase());
             if (b == null) {
+                for (Bundle bb : framework.getBundleContext().getBundles()) {
+                    LOG.log(Level.FINE, "Bundle {0}: {1}", new Object[] { bb.getBundleId(), bb.getSymbolicName() });
+                }
                 throw new IOException("Not found bundle:" + m.getCodeNameBase());
             }
             ClassLoader l = new NetigsoLoader(b, m, jar);
@@ -205,13 +222,27 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
             if (knownPkgs == EMPTY) {
                 try {
                     SELF_QUERY.set(true);
-                    Enumeration en = b.findEntries("", "", true);
-                    while (en.hasMoreElements()) {
-                        URL url = (URL) en.nextElement();
-                        if (url.getFile().startsWith("/META-INF")) {
-                            continue;
+                    Enumeration en = b.findEntries("", null, true);
+                    if (en == null) {
+                        LOG.log(Level.INFO, "Bundle {0}: {1} is empty", new Object[] { b.getBundleId(), b.getSymbolicName() });
+                    } else {
+                        while (en.hasMoreElements()) {
+                            URL url = (URL) en.nextElement();
+                            if (url.getFile().startsWith("/META-INF")) {
+                                continue;
+                            }
+                            pkgs.add(url.getFile().substring(1).replaceFirst("/[^/]*$", "").replace('/', '.'));
+                        }
+                    }
+                    Object exported = b.getHeaders("").get("Export-Package");
+                    if (exported instanceof String) {
+                        for (String p : exported.toString().split(",")) { // NOI18N
+                            int semic = p.indexOf(';');
+                            if (semic >= 0) {
+                                p = p.substring(0, semic);
+                            }
+                            pkgs.add(p);
                         }
-                        pkgs.add(url.getFile().substring(1).replaceFirst("/[^/]*$", "").replace('/', '.'));
                     }
                 } finally {
                     SELF_QUERY.set(false);
@@ -222,23 +253,40 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
                 pkgs.addAll(Arrays.asList(knownPkgs));
             }
             pcl.append(new ClassLoader[]{ l });
-            LOG.log(Level.FINE, "Starting bundle {0}", m.getCodeNameBase());
-            b.start();
+            try {
+                LOG.log(Level.FINE, "Starting bundle {0}", m.getCodeNameBase());
+                b.start();
+            } catch (BundleException possible) {
+                if (isRealBundle(b)) {
+                    throw possible;
+                }
+                LOG.log(Level.FINE, "Not starting fragment {0}", m.getCodeNameBase());
+            }
             return pkgs;
         } catch (BundleException ex) {
             throw new IOException("Cannot start " + jar, ex);
         }
     }
 
+    private static boolean isRealBundle(Bundle b) {
+        return b.getHeaders("").get("Fragment-Host") == null; // NOI18N
+    }
+
     @Override
     protected void stopLoader(ModuleInfo m, ClassLoader loader) {
         NetigsoLoader nl = (NetigsoLoader)loader;
         Bundle b = nl.bundle;
         try {
             assert b != null;
-            assert b.getState() == Bundle.ACTIVE : "Wrong state: " + b.getState() + " for " + m.getCodeNameBase();
-            LOG.log(Level.FINE, "Stopping bundle {0}", m.getCodeNameBase());
-            b.stop();
+            try {
+                LOG.log(Level.FINE, "Stopping bundle {0}", m.getCodeNameBase());
+                b.stop();
+            } catch (BundleException possible) {
+                if (isRealBundle(b)) {
+                    throw possible;
+                }
+                LOG.log(Level.FINE, "Not stopping fragment {0}", m.getCodeNameBase());
+            }
         } catch (BundleException ex) {
             throw new IllegalStateException(ex);
         }
@@ -391,6 +439,7 @@ public final class Netigso extends NetigsoFramework implements Stamps.Updater {
                 String k = (String)entry.getKey();
                 String v = (String)entry.getValue();
                 registered.put(k, v.split(","));
+                LOG.log(Level.FINE, "readBundle: {0}", k);
             }
         } catch (IOException ex) {
             LOG.log(Level.WARNING, "Cannot read cache", ex);
