@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -59,6 +62,7 @@ import java.util.regex.Pattern;
 import javax.swing.UIManager;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.openide.filesystems.FileUtil;
 import org.openide.util.Exceptions;
 import org.openide.util.Mutex;
 import org.openide.windows.IOColors;
@@ -70,6 +74,7 @@ import org.openide.windows.OutputListener;
 abstract class AbstractLines implements Lines, Runnable, ActionListener {
     /** A collections-like lineStartList that maps file positions to getLine numbers */
     IntList lineStartList;
+    IntListSimple lineCharLengthListWithTabs;
     /** Maps output listeners to the lines they are associated with */
     IntMap lineWithListenerToInfo;
 
@@ -85,6 +90,11 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
      * line index to physical (real) line index */
     private SparseIntList knownLogicalLineCounts = null;
 
+    /** Offset positions of tabs */
+    private IntList tabCharOffsets = new IntList(100);
+    /** Sums of length of all preceding tabs (length of extra spaces) */
+    private IntListSimple tabLengthSums = new IntListSimple(100);
+
     /** last storage size (after dispose), in bytes */
     private int lastStorageSize = -1;
 
@@ -277,6 +287,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         knownLogicalLineCounts = null;
         lineStartList = new IntList(100);
         lineStartList.add(0);
+        lineCharLengthListWithTabs = new IntListSimple(100);
         linesToInfos = new IntMap();
         lineWithListenerToInfo = new IntMap();
         longestLineLen = 0;
@@ -342,6 +353,19 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         return toCharIndex(getByteLineLength(idx));
     }
 
+    /**
+     * Returns the length of the specified lin characters.
+     *
+     * @param idx A getLine number
+     * @return The number of characters
+     */
+    public int lengthWithTabs (int idx) {
+        if (idx == lineCharLengthListWithTabs.size()) {
+            return Math.max(0, lastCharLengthWithTabs);
+        }
+        return lineCharLengthListWithTabs.get(idx);
+    }
+
     /**
      * Get the <strong>character</strong> index of a getLine as a position in
      * the output file.
@@ -452,7 +476,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
             //First getLine never has lines above it
             info[0] = 0;
             info[1] = 0;
-            info[2] = lengthToLineCount(length(0), charsPerLine);
+            info[2] = lengthToLineCount(lengthWithTabs(0), charsPerLine);
             return;
         }
 
@@ -469,7 +493,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         // compute how many logical lines is above our physical line
         int linesAbove = getLogicalLineCountAbove(physLineIdx, charsPerLine);
 
-        int len = length(physLineIdx);
+        int len = lengthWithTabs(physLineIdx);
         int wrapCount = lengthToLineCount(len, charsPerLine);
 
         info[0] = physLineIdx;
@@ -523,6 +547,92 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         }
     }
 
+    /**
+     * Get number of physical characters for the given logical (expanded TABs) length.
+     * @param offset
+     * @param logicalLength
+     * @param tabShiftPtr
+     * @return number of physical characters
+     */
+    public int getNumPhysicalChars(int offset, int logicalLength, int[] tabShiftPtr) {
+        synchronized (readLock()) {
+            int tabIndex1 = tabCharOffsets.findNearest(offset);
+            int tabSum1;
+            if (tabIndex1 > 0) {
+                if (tabCharOffsets.get(tabIndex1) < offset) {
+                    tabSum1 = tabLengthSums.get(tabIndex1);
+                } else {
+                    tabSum1 = tabLengthSums.get(tabIndex1 - 1);
+                }
+            } else {
+                tabSum1 = 0;
+            }
+            int tabIndex2 = tabCharOffsets.findNearest(offset + logicalLength);
+            if (tabIndex2 < 0) {
+                return logicalLength;
+            }
+            int tabSum2 = (tabIndex2 >= 0) ? tabLengthSums.get(tabIndex2) : 0;
+            if (tabSum1 == tabSum2) {
+                return logicalLength;
+            }
+            int realLength = logicalLength + tabSum1 - tabSum2; // rough guess, might be too small
+            if (realLength < 0) realLength = 0;
+            int i = offset + realLength;
+            tabIndex2 = tabCharOffsets.findNearest(i);
+            if (tabIndex2 < 0) {
+                tabIndex2 = - 1;
+                tabSum2 = 0;
+            } else {
+                tabSum2 = tabLengthSums.get(tabIndex2);
+            }
+            int n = tabCharOffsets.size();
+            for (tabIndex2++; tabIndex2 < n; tabIndex2++) {
+                if (realLength + tabSum2 - tabSum1 < logicalLength) {
+                    int nextTabOffset = tabCharOffsets.get(tabIndex2);
+                    tabSum2 = tabLengthSums.get(tabIndex2);
+                    if (nextTabOffset - offset + tabSum2 - tabSum1 > logicalLength) {
+                        tabSum2 = (tabIndex2 > 0) ? tabLengthSums.get(tabIndex2 - 1) : 0;
+                        realLength = logicalLength + tabSum1 - tabSum2;
+                        if (realLength > (nextTabOffset - offset)) {
+                            realLength = nextTabOffset - offset;
+                        }
+                        break;
+                    } else {
+                        realLength = nextTabOffset - offset;
+                    }
+                } else {
+                    if (tabShiftPtr != null) {
+                        tabShiftPtr[0] = realLength + tabSum2 - tabSum1 - logicalLength;
+                    }
+                    break;
+                }
+            }
+            if (realLength < 0) realLength = 0;
+            return realLength;
+        }
+    }
+
+    public int getNumLogicalChars(int offset, int physicalLength) {
+        synchronized (readLock()) {
+            int tabIndex1 = tabCharOffsets.findNearest(offset);
+            int tabSum1;
+            if (tabIndex1 >= 0 && tabCharOffsets.get(tabIndex1) < offset) {
+                tabSum1 = tabLengthSums.get(tabIndex1);
+            } else if (tabIndex1 > 0) {
+                tabSum1 = tabLengthSums.get(tabIndex1 - 1);
+            } else {
+                tabSum1 = 0;
+            }
+
+            int tabIndex2 = tabCharOffsets.findNearest(offset + physicalLength - 1);
+            if (tabIndex2 < 0) {
+                return physicalLength;
+            }
+            int tabSum2 = tabLengthSums.get(tabIndex2);
+            return physicalLength + tabSum2 - tabSum1;
+        }
+    }
+
     private void registerLineWithListener(int line, LineInfo info, boolean important) {
         lineWithListenerToInfo.put(line, info);
         if (important) {
@@ -553,7 +663,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
 
             int val = 0;
             for (int i = 0; i < lineCount; i++) {
-                int len = length(i);
+                int len = lengthWithTabs(i);
 
                 if (len > width) {
                     val += lengthToLineCount(len, width);
@@ -580,7 +690,9 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
 
     private boolean lastLineFinished = true;
     private int lastLineLength = -1;
+    private int lastCharLengthWithTabs = -1;
 
+    // lineLength with tabs
     private void updateLastLine(int lineIdx, int lineLength) {
         synchronized (readLock()) {
             longestLineLen = Math.max(longestLineLen, lineLength);
@@ -596,7 +708,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
                     knownLogicalLineCounts.removeLast();
                 } else {
                     aboveLineCount = knownLogicalLineCounts.lastAdded()
-                            - lengthToLineCount(lastLineLength, knownCharsPerLine)
+                            - lengthToLineCount(lastCharLengthWithTabs, knownCharsPerLine)
                             + lengthToLineCount(lineLength, knownCharsPerLine);
                     knownLogicalLineCounts.updateLast(lineIdx, aboveLineCount);
                 }
@@ -621,18 +733,20 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         }
     }
 
-    public void lineUpdated(int lineStart, int lineLength, boolean isFinished) {
+    public void lineUpdated(int lineStart, int lineLength, int charLengthWithTabs, boolean isFinished) {
         synchronized (readLock()) {
             int charLineLength = toCharIndex(lineLength);
             if (isFinished) {
                 charLineLength -= 1;
             }
-            updateLastLine(lineStartList.size() - 1, charLineLength);
+            updateLastLine(lineStartList.size() - 1, charLengthWithTabs);
             if (isFinished) {
                 lineStartList.add(lineStart + lineLength);
+                lineCharLengthListWithTabs.add(charLengthWithTabs);
             }
             lastLineFinished = isFinished;
             lastLineLength = isFinished ? -1 : charLineLength;
+            lastCharLengthWithTabs = isFinished ? -1 : charLengthWithTabs;
         }
         markDirty();
     }
@@ -680,6 +794,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
             ch.close();
         } finally {
             fos.close();
+            FileUtil.refreshFor(new java.io.File(path));
         }
     }
 
@@ -858,7 +973,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         return lineStartList.toString();
     }
 
-    int addSegment(CharSequence s, int offset, int lineIdx, int pos, OutputListener l, boolean important, boolean err, Color c) {
+    private int addSegment(CharSequence s, int offset, int lineIdx, int pos, OutputListener l, boolean important, boolean err, Color c) {
         int len = length(lineIdx);
         if (len > 0) {
             LineInfo info = (LineInfo) linesToInfos.get(lineIdx);
@@ -900,6 +1015,9 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
                 registerLineWithListener(lineIdx, info, important);
             } else {
                 info.addSegment(len, err, l, c, important);
+                if (important) {
+                    importantLines.add(lineIdx);
+                }
             }
         }
         return len;
@@ -907,6 +1025,8 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
 
     void updateLinesInfo(CharSequence s, int startLine, int startPos, OutputListener l, boolean important, boolean err, Color c) {
         int offset = 0;
+        /* If it's necessary to translate tabs to spaces, use this.
+         * But it seems that it works fine without the translation. Translation breaks character indexes.
         CharSequence noTabsStr = s;
         if (l != null) {
             for (int i = 0; i < s.length(); i++) {
@@ -916,7 +1036,14 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
                     for (int k = i; k < s.length(); k++) {
                         if (s.charAt(k) == '\t') {
                             str.append(s, start, k);
-                            str.append(OutWriter.TAB_REPLACEMENT);
+                            int tabLength;
+                            synchronized (readLock()) {
+                                int tabIndex = tabCharOffsets.findNearest(startPos + k);
+                                tabLength = getTabLength(tabIndex);
+                            }
+                            while (tabLength-- > 0) {
+                                str.append(' ');
+                            }
                             start = k + 1;
                         }
                     }
@@ -926,9 +1053,10 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
                 }
             }
         }
+         */
         int startLinePos = startPos - getLineStart(startLine);
         for (int i = startLine; i < getLineCount(); i++) {
-            offset += addSegment(noTabsStr, offset, i, startLinePos, l, important, err, c) + 1;
+            offset += addSegment(s, offset, i, startLinePos, l, important, err, c) + 1;
             startLinePos = 0;
         }
     }
@@ -939,4 +1067,24 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
             registerLineWithListener(idx, info, important);
         }
     }
+
+    private int getTabLength(int i) {
+        if (i == 0) {
+            return tabLengthSums.get(0);
+        } else {
+            return tabLengthSums.get(i) - tabLengthSums.get(i-1) + 1;
+        }
+    }
+
+    void addTabAt(int i, int tabLength) {
+        tabLength--;    // substract the tab character as such, to have the extra length
+        synchronized (readLock()) {
+            tabCharOffsets.add(i);
+            int n = tabLengthSums.size();
+            if (n > 0) {
+                tabLength += tabLengthSums.get(n - 1);
+            }
+            tabLengthSums.add(tabLength);
+        }
+    }
 }
