@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.core.output2;
 
+import java.util.Set;
 import org.openide.windows.InputOutput;
 import org.openide.windows.OutputListener;
 import org.openide.windows.OutputWriter;
@@ -57,6 +61,7 @@ import org.openide.windows.IOColorPrint;
 import org.openide.windows.IOColors;
 import org.openide.windows.IOContainer;
 import org.openide.windows.IOPosition;
+import org.openide.windows.IOSelect;
 import org.openide.windows.IOTab;
 
 /** Implementation of InputOutput.  Implements calls as a set of
@@ -272,7 +277,7 @@ class NbIO implements InputOutput, Lookup.Provider {
         if (lookup == null) {
             ioTab = new IOTabImpl();
             ioColors = new IOColorsImpl();
-            lookup = Lookups.fixed(ioTab, ioColors, new IOPositionImpl(), new IOColorLinesImpl(), new IOColorPrintImpl());
+            lookup = Lookups.fixed(ioTab, ioColors, new IOPositionImpl(), new IOColorLinesImpl(), new IOColorPrintImpl(), new IOSelectImpl());
         }
         return lookup;
     }
@@ -502,6 +507,15 @@ class NbIO implements InputOutput, Lookup.Provider {
         }
     }
 
+    private class IOSelectImpl extends IOSelect {
+
+	@Override
+	protected void select(Set<AdditionalOperation> extraOps) {
+	    if (Controller.LOG) Controller.log (this + ": IOSelect.select");
+	    NbIO.post (NbIO.this, IOEvent.CMD_FINE_SELECT, extraOps);
+	}
+    }
+
     private class IOColorsImpl extends IOColors {
         Color[] clrs = new Color[4];
 
