@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -38,21 +41,19 @@
  * Version 2 license, then the option applies only if the new code is
  * made subject to such option by the copyright holder.
  */
-/*
- * OutWriter.java
- *
- * Created on February 27, 2004, 7:24 PM
- */
 
 package org.netbeans.core.output2;
 
 import java.awt.Color;
-import java.util.logging.Logger;
 import org.openide.util.NbBundle;
 import org.openide.windows.OutputListener;
 import java.io.*;
 import java.nio.ByteBuffer;
 import java.nio.CharBuffer;
+import java.nio.channels.ClosedByInterruptException;
+import java.util.Collection;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.openide.util.Exceptions;
 import org.openide.util.Utilities;
 
@@ -62,7 +63,7 @@ import org.openide.util.Utilities;
  * @author  Tim Boudreau
  */
 class OutWriter extends PrintWriter {
-    /** A flag indicating an io exception occured */
+    /** A flag indicating an io exception occurred */
     private boolean trouble = false;
 
     private NbIO owner;
@@ -78,7 +79,7 @@ class OutWriter extends PrintWriter {
     /**
      * Byte array used to write the line separator after line writes.
      */
-    static String lineSeparator = System.getProperty ("line.separator" );
+    static final String LINE_SEPARATOR = "\n";
 
     /** The read-write backing storage.  May be heap or */
     private Storage storage;
@@ -98,6 +99,7 @@ class OutWriter extends PrintWriter {
      */
     private int lineStart;
     private int lineLength;
+    private int lineCharLengthWithTabs;
 
     /** Creates a new instance of OutWriter */
     OutWriter(NbIO owner) {
@@ -112,6 +114,7 @@ class OutWriter extends PrintWriter {
         super (new DummyWriter());
         lineStart = -1;
         lineLength = 0;
+        lineCharLengthWithTabs = 0;
     }
 
     Storage getStorage() {
@@ -120,7 +123,7 @@ class OutWriter extends PrintWriter {
         }
         if (storage == null) {
             storage = USE_HEAP_STORAGE || lowDiskSpace ? 
-                (Storage)new HeapStorage() : (Storage)new FileMapStorage();
+                new HeapStorage() : new FileMapStorage();
         }
         return storage;
     }
@@ -166,7 +169,7 @@ class OutWriter extends PrintWriter {
      * @param bb
      * @throws IOException
      */
-    public synchronized void write(ByteBuffer bb, boolean completeLine) {
+    private synchronized void write(ByteBuffer bb, int lineCharLengthWithTabs, boolean completeLine) {
         if (checkError()) {
             return;
         }
@@ -174,9 +177,12 @@ class OutWriter extends PrintWriter {
         int start = -1;
         try {
             start = getStorage().write(bb);
+        } catch (ClosedByInterruptException cbiex) {
+            onWriteException();
         } catch (java.nio.channels.AsynchronousCloseException ace) {
             //Execution termination has sent ThreadDeath to the process in the
             //middle of a write
+            Exceptions.printStackTrace(ace);
             onWriteException();
         } catch (IOException ioe) {
             //Out of disk space
@@ -201,13 +207,15 @@ class OutWriter extends PrintWriter {
         }
         int length = bb.limit();
         lineLength = lineLength + length;
+        this.lineCharLengthWithTabs += lineCharLengthWithTabs;
         if (start >= 0 && lineStart == -1) {
             lineStart = start;
         }
-        lines.lineUpdated(lineStart, lineLength, completeLine);
+        lines.lineUpdated(lineStart, lineLength, this.lineCharLengthWithTabs, completeLine);
         if (completeLine) {
             lineStart = -1;
             lineLength = 0;
+            this.lineCharLengthWithTabs = 0;
         }
         if (owner != null && owner.isStreamClosed()) {
             owner.setStreamClosed(false);
@@ -262,20 +270,14 @@ class OutWriter extends PrintWriter {
             return;
         }
         synchronized (this) {
-            if (lines.hasHyperlinks()) {
-                int[] listenerLines = lines.allListenerLines();
+            if (lines.hasListeners()) {
+                int[] listenerLines = lines.getLinesWithListeners();
                 Controller.ControllerOutputEvent e = new Controller.ControllerOutputEvent(owner, 0);
                 for (int i=0; i < listenerLines.length; i++) {
-                    OutputListener ol = lines.getListenerForLine(listenerLines[i]);
-                    if (Controller.LOG) {
-                        Controller.log("Clearing listener " + ol);
-                    }
+                    Collection<OutputListener> ols = lines.getListenersForLine(listenerLines[i]);
                     e.setLine(listenerLines[i]);
-                    if (ol != null) {
+                    for (OutputListener ol : ols) {
                         ol.outputLineCleared(e);
-                    } else {
-                        //#56826 - debug messaging
-                        Logger.getAnonymousLogger().warning("issue #56826 - There was a null OutputListener on line:" + listenerLines[i]);
                     }
                 }
             } else {
@@ -336,7 +338,7 @@ class OutWriter extends PrintWriter {
         return disposed || trouble;
     }
 
-    class CharArrayWrapper implements CharSequence {
+    static class CharArrayWrapper implements CharSequence {
 
         private char[] arr;
         private int off;
@@ -381,48 +383,65 @@ class OutWriter extends PrintWriter {
     }
     
     /** write buffer size in chars */
-    static private final int writeBuffSize = 16*1024;
-    private final String tabReplacement = "        ";
-    public synchronized int doWrite(CharSequence s, int off, int len) {
+    private static final int WRITE_BUFF_SIZE = 16*1024;
+    private synchronized void doWrite(CharSequence s, int off, int len) {
         if (checkError() || len == 0) {
-            return 0;
+            return;
         }
+        
+        // XXX will not pick up ANSI sequences broken across write blocks, but this is likely rare
+        if (printANSI(s.subSequence(off, off + len), false, false, false)) {
+            return;
+        }
+        /* XXX causes stack overflow
+        if (ansiColor != null) {
+            print(s, null, false, null, false, false);
+            return;
+        }
+         */
 
-        int lineCount = 0;
+        int lineCLVT = 0;
         try {
             boolean written = false;
-            ByteBuffer byteBuff = getStorage().getWriteBuffer(writeBuffSize * 2);
+            ByteBuffer byteBuff = getStorage().getWriteBuffer(WRITE_BUFF_SIZE * 2);
             CharBuffer charBuff = byteBuff.asCharBuffer();
+            int charOffset = AbstractLines.toCharIndex(getStorage().size());
             for (int i = off; i < off + len; i++) {
-                if (charBuff.position() + tabReplacement.length() >= writeBuffSize) {
-                    write((ByteBuffer) byteBuff.position(charBuff.position() * 2), false);
+                if (charBuff.position() + 1 >= WRITE_BUFF_SIZE) {
+                    write((ByteBuffer) byteBuff.position(charBuff.position() * 2), lineCLVT, false);
                     written = true;
                 }
                 if (written) {
-                    byteBuff = getStorage().getWriteBuffer(writeBuffSize * 2);
+                    byteBuff = getStorage().getWriteBuffer(WRITE_BUFF_SIZE * 2);
                     charBuff = byteBuff.asCharBuffer();
+                    lineCLVT = 0;
                     written = false;
                 }
                 char c = s.charAt(i);
                 if (c == '\t') {
-                    charBuff.put(tabReplacement);
+                    charBuff.put(c);
+                    int tabLength = WrappedTextView.TAB_SIZE - ((this.lineCharLengthWithTabs + lineCLVT) % WrappedTextView.TAB_SIZE);
+                    lines.addTabAt(charOffset + (i - off), tabLength);
+                    lineCLVT += tabLength;
+                } else if (c == '\r') {
+                    // skip
                 } else if (c == '\n') {
                     charBuff.put(c);
-                    write((ByteBuffer) byteBuff.position(charBuff.position() * 2), true);
+                    write((ByteBuffer) byteBuff.position(charBuff.position() * 2), lineCLVT, true);
                     written = true;
-                    lineCount++;
                 } else {
                     charBuff.put(c);
+                    lineCLVT++;
                 }
             }
             if (!written) {
-                write((ByteBuffer) byteBuff.position(charBuff.position() * 2), false);
+                write((ByteBuffer) byteBuff.position(charBuff.position() * 2), lineCLVT, false);
             }
         } catch (IOException ioe) {
             onWriteException();
         }
         lines.delayedFire();
-        return lineCount;
+        return;
     }
 
     @Override
@@ -432,7 +451,7 @@ class OutWriter extends PrintWriter {
 
     @Override
     public synchronized void println() {
-        doWrite(lineSeparator, 0, lineSeparator.length());
+        doWrite("\n", 0, 1);
     }
 
     /**
@@ -456,26 +475,125 @@ class OutWriter extends PrintWriter {
     }
 
     public synchronized void println(String s, OutputListener l, boolean important) {
-        print(s, l, important, null, true);
+        print(s, l, important, null, false, true);
     }
 
-    synchronized void print(CharSequence s, OutputListener l, boolean important, Color c, boolean addLS) {
-        int addedCount = doWrite(s, 0, s.length());
+    synchronized void print(CharSequence s, OutputListener l, boolean important, Color c, boolean err, boolean addLS) {
+        if (c == null) {
+            if (l == null && printANSI(s, important, err, addLS)) {
+                return;
+            }
+            c = ansiColor; // carry over from previous line
+        }
+        int lastLine = lines.getLineCount() - 1;
+        int lastPos = lines.getCharCount();
+        doWrite(s, 0, s.length());
         if (addLS) {
             println();
-            addedCount++;
         }
-        if (checkError()) {
-            return;
+        lines.updateLinesInfo(s, lastLine, lastPos, l, important, err, c);
+    }
+    private Color ansiColor;
+    private int ansiColorCode;
+    private boolean ansiBright;
+    private boolean ansiFaint;
+    private static final Pattern ANSI_CSI_SGR = Pattern.compile("\u001B\\[(\\d+(;\\d+)*)?m"); // XXX or x9B for single-char CSI?
+    private static final Color[] COLORS = { // xterm from http://en.wikipedia.org/wiki/ANSI_escape_code#Colors
+        null, // default color (black for stdout)
+        new Color(205, 0, 0),
+        new Color(0, 205, 0),
+        new Color(205, 205, 0),
+        new Color(0, 0, 238),
+        new Color(205, 0, 205),
+        new Color(0, 205, 205),
+        new Color(229, 229, 229),
+        // bright variants:
+        new Color(127, 127, 127),
+        new Color(255, 0, 0),
+        new Color(0, 255, 0),
+        new Color(255, 255, 0),
+        new Color(92, 92, 255),
+        new Color(255, 0, 255),
+        new Color(0, 255, 255),
+        new Color(255, 255, 255),
+    };
+    private boolean printANSI(CharSequence s, boolean important, boolean err, boolean addLS) { // #192779
+        int len = s.length();
+        boolean hasEscape = false; // fast initial check
+        for (int i = 0; i < len - 1; i++) {
+            if (s.charAt(i) == '\u001B' && s.charAt(i + 1) == '[') { // XXX or x9B for single-char CSI?
+                hasEscape = true;
+                break;
+            }
         }
-        int newCount = lines.getLineCount()-1;
-        for (int i = newCount - addedCount; i < newCount; i++) {
-            if (l != null) {
-                lines.addListener(i, l, important);
+        if (!hasEscape) {
+            return false;
+        }
+        Matcher m = ANSI_CSI_SGR.matcher(s);
+        int text = 0;
+        while (m.find()) {
+            int esc = m.start();
+            if (esc > text) {
+                print(s.subSequence(text, esc), null, important, ansiColor, err, false);
             }
-            if (c != null) {
-                lines.setColor(i, c);
+            text = m.end();
+            String paramsS = m.group(1);
+            if (Controller.VERBOSE) {
+                Controller.log("ANSI CSI+SGR: " + paramsS);
             }
+            if (paramsS == null) { // like ["0"]
+                ansiColorCode = 0;
+                ansiBright = false;
+                ansiFaint = false;
+            } else {
+                for (String param : paramsS.split(";")) {
+                    int code = Integer.parseInt(param);
+                    if (code == 0) { // Reset / Normal
+                        ansiColorCode = 0;
+                        ansiBright = false;
+                        ansiFaint = false;
+                    } else if (code == 1) { // Bright (increased intensity) or Bold
+                        ansiBright = true;
+                        ansiFaint = false;
+                    } else if (code == 2) { // Faint (decreased intensity)
+                        ansiBright = false;
+                        ansiFaint = true;
+                    } else if (code == 21) { // Bright/Bold: off or Underline: Double
+                        ansiBright = false;
+                    } else if (code == 22) { // Normal color or intensity
+                        ansiBright = false;
+                        ansiFaint = false;
+                    } else if (code >= 30 && code <= 37) { // Set text color
+                        ansiColorCode = code - 30;
+                    } else if (code == 39) { // Default text color
+                        ansiColorCode = 0;
+                    }
+                }
+            }
+            assert ansiColorCode >= 0 && ansiColorCode <= 7;
+            assert !(ansiBright && ansiFaint);
+            ansiColor = COLORS[ansiColorCode + (ansiBright ? 8 : 0)];
+            if (ansiFaint && ansiColor != null) {
+                ansiColor = ansiColor.darker();
+            }
+        }
+        if (text == 0) {
+            // That was an unknown sequence
+            return false;
+        }
+        if (text < len) { // final segment
+            print(s.subSequence(text, len), null, important, ansiColor, err, addLS);
+        } else if (addLS) { // line ended w/ control seq
+            println();
+        }
+        return true;
+    }
+
+    synchronized void print(CharSequence s, LineInfo info, boolean important) {
+        int line = lines.getLineCount() - 1;
+        doWrite(s, 0, s.length());
+        if (info != null) {
+            lines.addLineInfo(line, info, important);
         }
     }
 
