@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -198,6 +201,13 @@ public class OutputDocument implements Document, Element, ChangeListener {
         try {
             synchronized (getLines().readLock()) {
                 int charCount = getLines().getCharCount();
+                // #180404
+                if (charCount < 0) {
+                    txt.array = new char[0];
+                    txt.offset=0;
+                    txt.count = 0;
+                    return;
+                }
                 int linesOffset = Math.min(charCount, offset);
                 int linesEnd = Math.min(charCount, offset + length);
                 char[] chars = getLines().getText(linesOffset, linesEnd, reusableSubrange);
@@ -253,7 +263,7 @@ public class OutputDocument implements Document, Element, ChangeListener {
             AbstractLines lines = (AbstractLines) getLines();
             int start = lines.getLineStart(lines.getLineCount() - 1);
             int length = getLength() - start;
-            lines.lineUpdated(2*start, 2*length, false);
+            lines.lineUpdated(2*start, 2*length, length, false);
         }
         fireDocumentEvent(ev);
     }
@@ -287,7 +297,7 @@ public class OutputDocument implements Document, Element, ChangeListener {
         if (getLines() instanceof AbstractLines) {
             AbstractLines lines = (AbstractLines) getLines();
             int start = lines.getLineStart(lines.getLineCount() - 1);
-            lines.lineUpdated(2*start, 0, false);
+            lines.lineUpdated(2*start, 0, 0, false);
         }        
         fireDocumentEvent(ev);
         return toReturn;
@@ -328,7 +338,7 @@ public class OutputDocument implements Document, Element, ChangeListener {
                 AbstractLines lines = (AbstractLines) getLines();
                 int start = lines.getLineStart(lines.getLineCount() - 1);
                 int l = getLength() - start;
-                lines.lineUpdated(2*start, 2*l, false);
+                lines.lineUpdated(2*start, 2*l, l, false);
             }            
             fireDocumentEvent(ev);
         }
