@@ -61,9 +61,12 @@ import org.openide.util.Exceptions;
  * All position/line calculations this view does are based on the integer array
  * of line offsets kept by the writer's Lines object.
  *
- * @author Tim Boudreau
+ * @author Tim Boudreau, Martin Entlicher
  */
-public class WrappedTextView extends View {
+public class WrappedTextView extends View implements TabExpander {
+
+    static final int TAB_SIZE = 8;  // The default tab size
+
     /**
      * The component we will paint
      */
@@ -116,6 +119,10 @@ public class WrappedTextView extends View {
 
     private static Map hintsMap = null;
     
+    int tabSize;
+    int tabBase;
+    private int tabOffsetX = 0;
+    
     @SuppressWarnings("unchecked")
     static final Map getHints() {
         if (hintsMap == null) {
@@ -177,6 +184,22 @@ public class WrappedTextView extends View {
         }
     }
 
+    private int getTabSize() {
+        //Integer i = (Integer) getDocument().getProperty(PlainDocument.tabSizeAttribute);
+        //int size = (i != null) ? i.intValue() : TAB_SIZE;
+        //return size;
+        return TAB_SIZE;
+    }
+
+    @Override
+    public float nextTabStop(float x, int tabOffset) {
+        if (tabSize == 0) {
+            return x;
+        }
+        int ntabs = (((int) x) - margin() + tabOffsetX) / tabSize;
+        return margin() + ((ntabs + 1) * tabSize) - tabOffsetX;
+    }
+
     void updateMetrics() {
         Font font = comp.getFont();
         FontMetrics fm = comp.getFontMetrics(font);
@@ -189,6 +212,7 @@ public class WrappedTextView extends View {
             aa = g2d.getRenderingHint(RenderingHints.KEY_ANTIALIASING) ==
                     RenderingHints.VALUE_ANTIALIAS_ON;
         }
+        tabSize = getTabSize() * charWidth;
         updateWidth();
     }
 
@@ -234,7 +258,9 @@ public class WrappedTextView extends View {
         ((Graphics2D)g).addRenderingHints(getHints());
         
         comp.getHighlighter().paint(g);
-        
+
+        tabBase = ((Rectangle) allocation).x + margin();
+
         OutputDocument doc = odoc();
         if (doc != null) {
             Rectangle clip = g.getClipBounds();
@@ -271,6 +297,7 @@ public class WrappedTextView extends View {
                         y += charHeight;
                         continue;
                     }
+                    length = lines.lengthWithTabs(i);
                     LineInfo info = lines.getLineInfo(i);
 
                     // get number of logical lines
@@ -279,56 +306,97 @@ public class WrappedTextView extends View {
                     
                     // get current (first which we will draw) logical line
                     int currLogicalLine = (i == firstline && logicalLines > 0 && ln[1] > 0 ) ? ln[1] : 0;
-                    
-                    // shift lineStart to position of first logical line that will be drawn
-                    int logLineOffset = currLogicalLine * charsPerLine;
-                    lineStart += logLineOffset;
-                    
-                    // limit number of chars needed by estimation of maximum number of chars we need to repaint
-                    length = Math.min(maxVisibleChars, lineEnd - lineStart);
-                    
-                    // get just small part of document we need (no need to get e.g. whole 10 MB line)
-                    doc.getText(lineStart, length, seg);
 
                     int charpos = 0;
+                    //int tabOverLine = 0;    // 0 or 1
+                    int charsWithTabs = 0;
                     int arrowDrawn = currLogicalLine - 1;
                     int x = 0;
                     int remainCharsOnLogicalLine = charsPerLine;
+                    
+                    int logLineOffset;
+                    if (currLogicalLine > 0) {
+                        // shift lineStart to position of first logical line that will be drawn
+                        // we have lineStart - offset of the beginning of the physical line
+                        // we have to add (currLogicalLine * charsPerLine) characters with expanded TABs
+                        // this corresponds to a different real number of characters
+                        logLineOffset = currLogicalLine * charsPerLine;
+                        int[] tabShiftPtr = new int[] { 0 };
+                        logLineOffset = lines.getNumPhysicalChars(lineStart, logLineOffset, tabShiftPtr);
+                        lineStart += logLineOffset;
+                        if (tabShiftPtr[0] > 0) {
+                            //tabOverLine = 1;
+                            remainCharsOnLogicalLine -= tabShiftPtr[0];
+                            x = tabShiftPtr[0] * charWidth;
+                            charsWithTabs += tabShiftPtr[0];
+                        }
+                    } else {
+                        logLineOffset = 0;
+                    }
+                    
+                    // limit number of chars needed by estimation of maximum number of chars we need to repaint
+                    length = Math.min(maxVisibleChars, length - logLineOffset);
+                    int sourceLength = Math.min(maxVisibleChars, lineEnd - lineStart);
+
+                    // get just small part of document we need (no need to get e.g. whole 10 MB line)
+                    doc.getText(lineStart, sourceLength, seg);
+
+                    tabOffsetX = charWidth * currLogicalLine * charsPerLine; //logLineOffset;
                     for (LineInfo.Segment ls : info.getLineSegments()) {
                         if (ls.getEnd() < logLineOffset) {
                             continue;
                         }
                         g.setColor(ls.getColor());
+                        int shift = 0;
                         while (charpos < ls.getEnd() - logLineOffset && currLogicalLine < logicalLines) {
                             int lenToDraw = Math.min(remainCharsOnLogicalLine, ls.getEnd() - logLineOffset - charpos);
+                            int charsToDraw = lenToDraw;
                             if (lenToDraw > 0) {
+                                charsToDraw = getCharsForLengthWithTabs(seg.array, charpos, currLogicalLine * charsPerLine + shift, lenToDraw, remainCharsOnLogicalLine);// - tabOverLine;
                                 if (currLogicalLine != logicalLines - 1 && arrowDrawn != currLogicalLine) {
                                     arrowDrawn = currLogicalLine;
                                     drawArrow(g, y, currLogicalLine == logicalLines - 2);
                                 }
-                                drawText(seg, g, x, y, lineStart, charpos, selStart, lenToDraw, selEnd);
+                                drawText(seg, g, x, y, lineStart, charpos, selStart, charsToDraw, selEnd);
                                 if (ls.getListener() != null) {
-                                    underline(g, seg, charpos, lenToDraw, x, y);
+                                    underline(g, seg, charpos, charsToDraw, x, y);
                                 }
                             }
-                            charpos += lenToDraw;
+                            lenToDraw = getCharLengthWithTabs(seg.array, charpos, currLogicalLine * charsPerLine + shift, charsToDraw);
+                            charpos += charsToDraw;
+                            charsWithTabs += lenToDraw;
                             remainCharsOnLogicalLine -= lenToDraw;
                             x += lenToDraw * charWidth;
-                            if (remainCharsOnLogicalLine == 0) {
-                                remainCharsOnLogicalLine = charsPerLine;
+                            shift += lenToDraw;
+                            //tabOverLine = (remainCharsOnLogicalLine < 0) ? 1 : 0;
+                            while(remainCharsOnLogicalLine <= 0) {
+                                shift = -remainCharsOnLogicalLine;
+                                remainCharsOnLogicalLine += charsPerLine;
                                 currLogicalLine++;
-                                x = 0;
+                                x = shift * charWidth;
+                                tabOffsetX += charWidth * (charsPerLine);// + shift);
                                 y += charHeight;
                                 if (y > clip.y + clip.height) {
                                     return;
                                 }
+                                if (shift > 0) {
+                                    if (selStart != selEnd) {
+                                        int realPos = lineStart + charpos;
+                                        int a = Math.max(selStart, realPos);
+                                        int b = Math.min(selEnd, realPos + charsToDraw);
+                                        if (a < b) {
+                                            drawSelection(g, 0, x, y);
+                                        }
+                                    }
+                                }
                             }
                         }
                     }
-                    if (charpos % charsPerLine != 0) {
+                    if (charsPerLine == 0 || charsWithTabs % charsPerLine != 0) {
                         y += charHeight;
                     }
                 }
+                tabOffsetX = 0;
             } catch (BadLocationException e) {
                 Exceptions.printStackTrace(e);
             }
@@ -353,15 +421,36 @@ public class WrappedTextView extends View {
             int a = Math.max(selStart, realPos);
             int b = Math.min(selEnd, realPos + lenToDraw);
             if (a < b) {
+                realPos = odoc().getLines().getNumLogicalChars(lineStart, realPos - lineStart) + lineStart;
+                a = odoc().getLines().getNumLogicalChars(lineStart, a - lineStart) + lineStart;
+                b = odoc().getLines().getNumLogicalChars(lineStart, b - lineStart) + lineStart;
                 int start = x + margin() + (a - realPos) * charWidth;
                 int len = (b - a) * charWidth;
+                int w = charsPerLine * charWidth;
+                if (start - margin() + len > w) {
+                    len = w - start + margin();
+                }
                 Color c = g.getColor();
                 g.setColor (comp.getSelectionColor());
                 g.fillRect (start, y + fontDescent - charHeight, len, charHeight);
                 g.setColor (c);
             }
         }
-        g.drawChars(seg.array, charpos, lenToDraw, margin() + x, y);
+        //g.drawChars(seg.array, charpos, lenToDraw, margin() + x, y);
+        int count = seg.count;
+        int offset = seg.offset;
+        seg.count = lenToDraw;
+        seg.offset = charpos;
+        Utilities.drawTabbedText(seg, margin() + x, y, g, this, charpos);
+        seg.count = count;
+        seg.offset = offset;
+    }
+
+    private void drawSelection(Graphics g, int x1, int x2, int y) {
+        Color c = g.getColor();
+        g.setColor (comp.getSelectionColor());
+        g.fillRect (x1 + margin(), y + fontDescent - charHeight, x2 - x1, charHeight);
+        g.setColor (c);
     }
 
     private void underline(Graphics g, Segment seg, int charpos, int lenToDraw, int x, int y) {
@@ -436,6 +525,8 @@ public class WrappedTextView extends View {
 
             int column = pos - start;
 
+            column = od.getLines().getNumLogicalChars(start, column);
+
             int row = od.getLines().getLogicalLineCountAbove(line, charsPerLine);
             //#104307
             if (column > charsPerLine && charsPerLine != 0) {
@@ -470,16 +561,19 @@ public class WrappedTextView extends View {
             }
 
             int lineStart = od.getLineStart(logicalLine);
-            int lineEnd = od.getLineEnd(logicalLine);
+            int lineLength = od.getLines().lengthWithTabs(logicalLine);
+            int lineEnd = lineStart + lineLength;//od.getLineEnd(logicalLine);
 
             int column = ix / charWidth;
-            if (column > lineEnd) {
-                column = lineEnd;
+            if (column > lineLength) {
+                column = lineLength;
             }
 
             int result = wraps > 0 ?
                 Math.min(lineEnd, lineStart + (ln[1] * charsPerLine) + column)
                 : Math.min(lineStart + column, lineEnd);
+            Lines lines = od.getLines();
+            result = lines.getNumPhysicalChars(lineStart, result - lineStart, null) + lineStart;
             result = Math.min (od.getLength(), result);
             return result;
 /*            System.err.println ("ViewToModel " + ix + "," + iy + " = " + result + " physical ln " + physicalLine +
@@ -491,4 +585,37 @@ public class WrappedTextView extends View {
             return 0;
         }
     }
+
+    private int getCharLengthWithTabs(char[] array, int charpos, int tabLineOffset, int lenToDraw) {
+        int n = Math.min(array.length, charpos + lenToDraw);
+        int tabExpand = 0;
+        for (int i = charpos; i < n; i++) {
+            if ('\t' == array[i]) {
+                int numSpaces = TAB_SIZE - (((i - charpos + tabLineOffset) + tabExpand) % TAB_SIZE);
+                tabExpand += numSpaces - 1;
+                lenToDraw += numSpaces - 1;
+            }
+        }
+        return lenToDraw;
+    }
+
+    private int getCharsForLengthWithTabs(char[] array, int charpos, int tabLineOffset, int lenToDraw, int length) {
+        int n = Math.min(array.length, charpos + lenToDraw);
+        int lengthWithTab = 0;
+        int tabExpand = 0;
+        int i;
+        for (i = charpos; i < n && lengthWithTab < length; i++) {
+            if ('\t' == array[i]) {
+                int numSpaces = TAB_SIZE - (((i - charpos + tabLineOffset) + tabExpand) % TAB_SIZE);
+                tabExpand += numSpaces - 1;
+                lengthWithTab += numSpaces;
+            } else {
+                lengthWithTab++;
+            }
+        }
+        if (lengthWithTab > length && i > (charpos + 1) && array[i-1] != '\t') {
+            i--;
+        }
+        return i - charpos;
+    }
 }
