@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -258,6 +261,9 @@ public abstract class AbstractOutputPane extends JScrollPane implements Document
         }
     }
 
+    /**
+     * Accessed reflectively from org.netbeans.jellytools.OutputTabOperator.
+     */
     public final Document getDocument() {
         return textView.getDocument();
     }
@@ -347,19 +353,26 @@ public abstract class AbstractOutputPane extends JScrollPane implements Document
 
     public final void sendCaretToPos(int startPos, int endPos, boolean select) {
         inSendCaretToLine = true;
-        getCaret().setVisible(true);
-        getCaret().setSelectionVisible(true);
-        if (select) {
-            scrollTo(endPos);
-            getCaret().setDot(endPos);
-            getCaret().moveDot(startPos);
-            textView.repaint();
-        } else {
-            getCaret().setDot(startPos);
+        try {
+            getCaret().setVisible(true);
+            getCaret().setSelectionVisible(true);
+            if (select) {
+                scrollTo(endPos);
+                getCaret().setDot(endPos);
+                getCaret().moveDot(startPos);
+                textView.repaint();
+            } else {
+                getCaret().setDot(startPos);
+            }
+        } catch (Error sie) {
+            if (sie.getClass().getName().equals("javax.swing.text.StateInvariantError")) {
+                Exceptions.attachMessage(sie, "sendCaretToPos("+startPos+", "+endPos+", "+select+"), caret = "+getCaret()+", highlighter = "+textView.getHighlighter()+", document length = "+textView.getDocument().getLength());
+            }
+            Exceptions.printStackTrace(sie);
+        } finally {
+            locked = false;
+            inSendCaretToLine = false;
         }
-
-        locked = false;
-        inSendCaretToLine = false;
     }
 
     private boolean inSendCaretToLine = false;
@@ -370,23 +383,31 @@ public abstract class AbstractOutputPane extends JScrollPane implements Document
             idx = lastLine;
         }
         inSendCaretToLine = true;
-        getCaret().setVisible(true);
-        getCaret().setSelectionVisible(true);
-        Element el = textView.getDocument().getDefaultRootElement().getElement(idx);
-        int position = el.getStartOffset();
-        if (select) {
-            getCaret().setDot(el.getEndOffset() - 1);
-            getCaret().moveDot(position);
-            textView.repaint();
-        } else {
-            getCaret().setDot(position);
-        }
+        try {
+            getCaret().setVisible(true);
+            getCaret().setSelectionVisible(true);
+            Element el = textView.getDocument().getDefaultRootElement().getElement(idx);
+            int position = el.getStartOffset();
+            if (select) {
+                getCaret().setDot(el.getEndOffset() - 1);
+                getCaret().moveDot(position);
+                textView.repaint();
+            } else {
+                getCaret().setDot(position);
+            }
 
-        if (!scrollToLine(idx + 3) && isScrollLocked()) {
-            lineToScroll = idx + 3;
+            if (!scrollToLine(idx + 3) && isScrollLocked()) {
+                lineToScroll = idx + 3;
+            }
+        } catch (Error sie) {
+            if (sie.getClass().getName().equals("javax.swing.text.StateInvariantError")) {
+                Exceptions.attachMessage(sie, "sendCaretToLine("+idx+", "+select+"), caret = "+getCaret()+", highlighter = "+textView.getHighlighter()+", document length = "+textView.getDocument().getLength());
+            }
+            Exceptions.printStackTrace(sie);
+        } finally {
+            locked = false;
+            inSendCaretToLine = false;
         }
-        locked = false;
-        inSendCaretToLine = false;
         return true;
     }
 
