@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -43,16 +46,19 @@ package org.netbeans.core.output2;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
+import java.lang.reflect.InvocationTargetException;
 import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
-import junit.framework.TestCase;
+import org.netbeans.junit.NbTestCase;
+import org.netbeans.junit.RandomlyFails;
+import org.openide.util.Exceptions;
 
 /** Tests the OutWriter class
  *
  * @author Tim Boudreau
  */
-public class OutWriterTest extends TestCase {
+public class OutWriterTest extends NbTestCase {
 
     public OutWriterTest(String testName) {
         super(testName);
@@ -77,17 +83,17 @@ public class OutWriterTest extends TestCase {
         
         assertTrue ("First line position should be 0 but is " + pos, pos == 0);
         
-        int expectedPosition = first.length() + OutWriter.lineSeparator.length();
+        int expectedPosition = first.length() + OutWriter.LINE_SEPARATOR.length();
         pos = ow.getLines().getLineStart(1);
         
         assertTrue ("Second line position should be length of first (" + first.length() + ") + line " +
-            "separator length (" + OutWriter.lineSeparator.length() + "), which should be " + 
+            "separator length (" + OutWriter.LINE_SEPARATOR.length() + "), which should be " +
             expectedPosition + " but is " + pos, 
             pos == expectedPosition);
          
         
         pos = ow.getLines().getLineStart (2);
-        int targetPos = first.length() + second.length() + 2 * OutWriter.lineSeparator.length();
+        int targetPos = first.length() + second.length() + 2 * OutWriter.LINE_SEPARATOR.length();
         
         assertTrue ("Third line position should be " + targetPos + " but is " + pos, pos == targetPos);
     }
@@ -113,7 +119,7 @@ public class OutWriterTest extends TestCase {
         
         assertTrue (ow.getLines().getLineCount() == 3);
 
-        int targetLength = first.length() + second.length() + 2 * OutWriter.lineSeparator.length();
+        int targetLength = first.length() + second.length() + 2 * OutWriter.LINE_SEPARATOR.length();
 
         assertTrue ( 
             "After printing strings with length " + first.length() + " and " + 
@@ -124,7 +130,7 @@ public class OutWriterTest extends TestCase {
         ow.println (third);
         
         targetLength = first.length() + second.length() + third.length() + 
-            (3 *  OutWriter.lineSeparator.length());
+            (3 *  OutWriter.LINE_SEPARATOR.length());
         
         assertTrue ("Length should be " + targetLength + " but position is "
             + ow.getLines().getCharCount(), targetLength == ow.getLines().getCharCount());
@@ -160,9 +166,9 @@ public class OutWriterTest extends TestCase {
             ioe.printStackTrace();
             fail (ioe.getMessage());
         }
-        String firstExpected = first + OutWriter.lineSeparator;
-        String secondExpected = second + OutWriter.lineSeparator;
-        String thirdExpected = third + OutWriter.lineSeparator;
+        String firstExpected = first + OutWriter.LINE_SEPARATOR;
+        String secondExpected = second + OutWriter.LINE_SEPARATOR;
+        String thirdExpected = third + OutWriter.LINE_SEPARATOR;
         
         assertEquals("First string should be \"" + firstExpected + "\" but was \"" + firstBack + "\"",
             firstBack, firstExpected);
@@ -197,7 +203,7 @@ public class OutWriterTest extends TestCase {
             " not " + line,
             line == 0);
         
-        line = ow.getLines().getLineAt (first.length() + OutWriter.lineSeparator.length() +
+        line = ow.getLines().getLineAt (first.length() + OutWriter.LINE_SEPARATOR.length() +
             (second.length() / 2));
         
         assertTrue ("Position halfway through line 1 should map to line 1, not " +
@@ -226,14 +232,8 @@ public class OutWriterTest extends TestCase {
         ow.println (third);
         
         ow.flush();
-        try {
-        SwingUtilities.invokeAndWait (new Runnable() {
-            public void run() {
-                System.currentTimeMillis();
-             }
-        });
-        } catch (Exception e) {}
-        Thread.currentThread().yield();
+        processEQ();
+        Thread.yield();
         
         assertTrue ("Linecount should be 4 after printing 3 lines, not " +
             ow.getLines().getLineCount(), ow.getLines().getLineCount() == 4);
@@ -246,37 +246,31 @@ public class OutWriterTest extends TestCase {
                 ow.getLines().getLineCount(), ow.getLines().getLineCount() == 4);
 
     }
-
-    // mkleint TODO temporary disable. 
-//    public void testAddChangeListener() {
-//        System.out.println("testAddChangeListener");
-//        OutWriter ow = new OutWriter ();
-//        
-//        CL cl = new CL();
-//        try {
-//            ow.getLines().addChangeListener(cl);
-//        } catch (Exception e) {
-//            e.printStackTrace();
-//            fail ("Caught exception " + e);
-//        }
-//        
-//        
-//        String first = "This is the first string";
-//        String second = "This is the second string, ain't it?";
-//        String third = "This is the third string";
-//        
-//        ow.println(first);
-//        
-//        ow.println (second);
-//        
-//        ow.println (third);
-//        
-//        ow.flush();        
-//        
-//        cl.assertChanged();
-//        
-//    }
     
+    public void testAddChangeListener() {
+        System.out.println("testAddChangeListener");
+        OutWriter ow = new OutWriter ();
+
+        CL cl = new CL();
+        try {
+            ow.getLines().addChangeListener(cl);
+        } catch (Exception e) {
+            e.printStackTrace();
+            fail ("Caught exception " + e);
+        }
+
+        String first = "This is the first string";
+        String second = "This is the second string, ain't it?";
+        String third = "This is the third string";
+        
+        ow.println(first);
+        ow.println (second);
+        ow.println (third);
+        ow.flush();
+        processEQ();
+        cl.assertChanged();
+    }
+
     public void testMultilineText() {
         System.out.println("testMultilineText");
         OutWriter ow = new OutWriter ();
@@ -288,7 +282,8 @@ public class OutWriterTest extends TestCase {
         ow.println(threeLines);
         assertTrue ("Line count should be 7, not " + ow.getLines().getLineCount(), ow.getLines().getLineCount() == 7);
     }
-    
+
+    @RandomlyFails // NB-Core-Build #1887
     public void testRemoveChangeListener() {
         System.out.println("testRemoveChangeListener");
         
@@ -374,7 +369,7 @@ public class OutWriterTest extends TestCase {
             ow.println(first);
             ow.flush();
             
-            String firstExpected = first + OutWriter.lineSeparator;
+            String firstExpected = first + OutWriter.LINE_SEPARATOR;
             String firstReceived = ow.getLines().getLine(0);
             
             assertEquals ("First line should be \"" + firstExpected + "\" but was \"" + firstReceived + "\"", firstExpected, firstReceived);
@@ -423,7 +418,7 @@ public class OutWriterTest extends TestCase {
             ow.flush();
             assertEquals(2, ow.getLines().getLineCount());
             String firstReceived = ow.getLines().getLine(0);
-            assertEquals ("xyz" + OutWriter.lineSeparator, firstReceived);
+            assertEquals ("xyz" + OutWriter.LINE_SEPARATOR, firstReceived);
         
             ow = new OutWriter();
             ow.println("firstline");
@@ -432,7 +427,7 @@ public class OutWriterTest extends TestCase {
             ow.flush();
             assertEquals(3, ow.getLines().getLineCount());
             firstReceived = ow.getLines().getLine(1);
-            assertEquals ("xyz" + OutWriter.lineSeparator, firstReceived);
+            assertEquals ("xyz" + OutWriter.LINE_SEPARATOR, firstReceived);
             
             ow = new OutWriter();
             ow.println("firstline");
@@ -442,31 +437,31 @@ public class OutWriterTest extends TestCase {
             ow.flush();
             assertEquals(3, ow.getLines().getLineCount());
             firstReceived = ow.getLines().getLine(1);
-            assertEquals ("xyzxyz-end" + OutWriter.lineSeparator, firstReceived);
+            assertEquals ("xyzxyz-end" + OutWriter.LINE_SEPARATOR, firstReceived);
             
             ow = new OutWriter();
             ow.write(new char[] {'x', 'y', '\n', 'z', 'z', 'z', '\n', 'A'});
             ow.flush();
             assertEquals(3, ow.getLines().getLineCount());
-            assertEquals("xy" + '\n', ow.getLines().getLine(0));
-            assertEquals("zzz" + '\n', ow.getLines().getLine(1));
+            assertEquals("xy" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(0));
+            assertEquals("zzz" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(1));
             assertEquals("A", ow.getLines().getLine(2));
             
             ow = new OutWriter();
             ow.write(new char[] {'x', 'y', '\n', 'z', 'z', 'z', '\n'});
             ow.flush();
             assertEquals(3, ow.getLines().getLineCount());
-            assertEquals("xy" + '\n', ow.getLines().getLine(0));
-            assertEquals("zzz" + '\n', ow.getLines().getLine(1));
+            assertEquals("xy" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(0));
+            assertEquals("zzz" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(1));
             
             ow = new OutWriter();
             ow.write(new char[] {'\n', '\n', '\n', 'z', 'z', 'z', '\n'});
             ow.flush();
             assertEquals(5, ow.getLines().getLineCount());
-            assertEquals("\n", ow.getLines().getLine(0));
-            assertEquals("\n", ow.getLines().getLine(1));
-            assertEquals("\n", ow.getLines().getLine(2));
-            assertEquals("zzz" + "\n", ow.getLines().getLine(3));
+            assertEquals(OutWriter.LINE_SEPARATOR, ow.getLines().getLine(0));
+            assertEquals(OutWriter.LINE_SEPARATOR, ow.getLines().getLine(1));
+            assertEquals(OutWriter.LINE_SEPARATOR, ow.getLines().getLine(2));
+            assertEquals("zzz" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(3));
             
             
         } catch (Exception e) {
@@ -488,7 +483,7 @@ public class OutWriterTest extends TestCase {
             ow.write('z');
             assertEquals ("xyz", ow.getLines().getLine(0));
             ow.println();
-            assertEquals ("xyz" + OutWriter.lineSeparator, ow.getLines().getLine(0));
+            assertEquals ("xyz" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(0));
             ow.write('a');
             assertEquals(2, ow.getLines().getLineCount());
             assertEquals ("a", ow.getLines().getLine(1));
@@ -497,14 +492,14 @@ public class OutWriterTest extends TestCase {
             ow = new OutWriter();
             ow.write(new char[] { 'x', 'y', 'z', '\n', 'A'});
             assertEquals(2, ow.getLines().getLineCount());
-            assertEquals ("xyz" + '\n', ow.getLines().getLine(0));
+            assertEquals ("xyz" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(0));
             assertEquals ("A", ow.getLines().getLine(1));
             ow.write('B');
             assertEquals(2, ow.getLines().getLineCount());
             assertEquals ("AB", ow.getLines().getLine(1));
             ow.println("CD");
             assertEquals(3, ow.getLines().getLineCount());
-            assertEquals ("ABCD" + OutWriter.lineSeparator, ow.getLines().getLine(1));
+            assertEquals ("ABCD" + OutWriter.LINE_SEPARATOR, ow.getLines().getLine(1));
             
         } catch (Exception e) {
             e.printStackTrace();
@@ -513,15 +508,21 @@ public class OutWriterTest extends TestCase {
         
     }
     
+    void processEQ() {
+        try {
+            SwingUtilities.invokeAndWait(new Runnable() {
 
+                public void run() {
+                    System.currentTimeMillis();
+                }
+            });
+        } catch (InterruptedException ex) {
+            Exceptions.printStackTrace(ex);
+        } catch (InvocationTargetException ex) {
+            Exceptions.printStackTrace(ex);
+        }
+    }
 
-   
-    
-    // TODO add test methods here, they have to start with 'test' name.
-    // for example:
-    // public void testHello() {}
-    
-    
     private class CL implements ChangeListener {
         
         public void assertChanged () {
@@ -545,6 +546,4 @@ public class OutWriterTest extends TestCase {
             ce = null;
         }
     }
-     
-    
 }
