@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -305,7 +308,7 @@ public class OutputDocumentTest extends NbTestCase {
         ow.println (third);
         ow.flush();
         
-        int expectedLength = first.length() + second.length() + third.length() + (3 * OutWriter.lineSeparator.length()) ;
+        int expectedLength = first.length() + second.length() + third.length() + (3 * OutWriter.LINE_SEPARATOR.length()) ;
         int receivedLength = doc.getLength();
         
         assertTrue ("Number of characters counting carriage returns should be " 
@@ -387,7 +390,7 @@ public class OutputDocumentTest extends NbTestCase {
             ble.printStackTrace();
             fail ("Unexpected BadLocationException: " + ble.getMessage());
         }
-        expected = first + OutWriter.lineSeparator + second + OutWriter.lineSeparator;
+        expected = first + OutWriter.LINE_SEPARATOR + second + OutWriter.LINE_SEPARATOR;
         
         assertEquals ("getText for first two strings should be \"" + expected + "\" but was \"" + received + "\"", expected, received);
     }
@@ -449,8 +452,8 @@ public class OutputDocumentTest extends NbTestCase {
         Element el = doc.getElement(0);
         assertTrue (el.getStartOffset() == 0);
         assertTrue ("End offset should be length of string + separator length (" 
-            + (first.length() + OutWriter.lineSeparator.length()) + " but was " + el.getEndOffset(), 
-            el.getEndOffset() == first.length() + OutWriter.lineSeparator.length());
+            + (first.length() + OutWriter.LINE_SEPARATOR.length()) + " but was " + el.getEndOffset(),
+            el.getEndOffset() == first.length() + OutWriter.LINE_SEPARATOR.length());
         
         el = doc.getElement(1);
     }
@@ -567,13 +570,13 @@ public class OutputDocumentTest extends NbTestCase {
         
         String s = "This is a string I will append";
         
-        styled.insertString(styled.getLength(), s + OutWriter.lineSeparator, SimpleAttributeSet.EMPTY);
+        styled.insertString(styled.getLength(), s + OutWriter.LINE_SEPARATOR, SimpleAttributeSet.EMPTY);
         ow.println (s);
         ow.flush();
         docListener.assertChanged();
         styListener.assertChanged();
         
-        styled.insertString(styled.getLength(), s + OutWriter.lineSeparator, SimpleAttributeSet.EMPTY);
+        styled.insertString(styled.getLength(), s + OutWriter.LINE_SEPARATOR, SimpleAttributeSet.EMPTY);
         ow.println (s);
         ow.flush();
         
@@ -603,7 +606,7 @@ public class OutputDocumentTest extends NbTestCase {
         //Stress test it to ensure no off-by-ones that show up only when the file is large
         for (int i = 0; i < 10; i++) {
             for (int j=0; j < STRINGS.length; j++) {
-                styled.insertString(styled.getLength(), s + OutWriter.lineSeparator, SimpleAttributeSet.EMPTY);
+                styled.insertString(styled.getLength(), s + OutWriter.LINE_SEPARATOR, SimpleAttributeSet.EMPTY);
                 ow.println (s);
                 ow.flush();
 
