@@ -44,8 +44,11 @@
 
 package org.netbeans.core.startup;
 
+import org.netbeans.Module;
 import org.openide.modules.ModuleInfo;
+import org.openide.modules.Modules;
 import org.openide.util.Lookup;
+import org.openide.util.Task;
 import org.openide.util.lookup.AbstractLookup;
 import org.openide.util.lookup.InstanceContent;
 import org.openide.util.lookup.Lookups;
@@ -72,6 +75,15 @@ public final class MainLookup extends ProxyLookup {
         started = true;
     }
     
+    /** Schedule all {@link Runnable} in WarmUp folder for invocation.
+     * @since 1.30
+     * @param delay time in ms to wait with warmup
+     * @return task one can wait for
+     */
+    public static Task warmUp(long delay) {
+        return WarmUpSupport.warmUp(delay);
+    }
+    
     /** Checks whether everything is started.
      */
     static boolean isStarted() {
@@ -202,9 +214,9 @@ public final class MainLookup extends ProxyLookup {
     protected void beforeLookup(Lookup.Template templ) {
         Class type = templ.getType();
 
-        // Force module system to be initialize by looking up ModuleInfo.
+        // Force module system to be initialize by looking up ModuleInfo or Modules.
         // Good for unit tests, etc.
-        if (!started && (type == ModuleInfo.class || type == org.netbeans.Module.class)) {
+        if (!started && (type == ModuleInfo.class || type == Module.class || type == Modules.class)) {
             Main.getModuleSystem ();
         }
 
