@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -60,6 +63,7 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.netbeans.DuplicateException;
 import org.netbeans.Events;
+import org.netbeans.JaveleonModule;
 import org.netbeans.Module;
 import org.netbeans.ModuleManager;
 import org.netbeans.Stamps;
@@ -72,7 +76,7 @@ import org.openide.util.Exceptions;
  * Contains higher-level convenience methods to
  * access the basic functionality and procedural
  * stages of the module system.
- * The NbTopManager should hold a reference to one instance.
+ * Main should hold a reference to one instance.
  * Methods are thread-safe.
  * @author Jesse Glick
  */
@@ -80,7 +84,7 @@ public final class ModuleSystem {
     private static final Logger LOG = Logger.getLogger(ModuleSystem.class.getName());
     private final ModuleManager mgr;
     private final NbInstaller installer;
-    private final ModuleList list;
+    private ModuleList list;
     private final Events ev;
     
     /** Initialize module system.
@@ -89,10 +93,17 @@ public final class ModuleSystem {
      * so it is forbidden to call readList, scanForNewAndRestore, or installNew.
      */
     public ModuleSystem(FileSystem systemFileSystem) throws IOException {
-        if (Boolean.getBoolean("org.netbeans.core.startup.ModuleSystem.CULPRIT")) Thread.dumpStack(); // NOI18N
-        ev = Boolean.getBoolean("netbeans.modules.quiet") ? (Events)new QuietEvents() : new NbEvents();
+        this();
+        init(systemFileSystem);
+    }
+    ModuleSystem() {
+        ev = Boolean.getBoolean("netbeans.modules.quiet") ? (Events) new QuietEvents() : new NbEvents();
         installer = new NbInstaller(ev);
         mgr = new ModuleManager(installer, ev);
+    }
+
+    final void init(FileSystem systemFileSystem) throws IOException {
+        if (Boolean.getBoolean("org.netbeans.core.startup.ModuleSystem.CULPRIT")) Thread.dumpStack(); // NOI18N
         PropertyChangeListener l = new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent ev) {
                 if (ModuleManager.PROP_CLASS_LOADER.equals(ev.getPropertyName())) {
@@ -253,6 +264,13 @@ public final class ModuleSystem {
         }
     }
     
+    /** Refreshes the list of modules. Used from autoupdate.services.
+     * @since 1.28
+     */
+    public final void refresh() {
+        list.moduleListChanged();
+    }
+    
     /** Read disk settings and determine what the known modules are.
      */
     public void readList() {
@@ -284,15 +302,21 @@ public final class ModuleSystem {
     /** Shut down the system: ask modules to shut down.
      * Some of them may refuse.
      */
-    public boolean shutDown(Runnable midHook) {
+    public boolean shutDown(final Runnable midHook) {
         mgr.mutexPrivileged().enterWriteAccess();
         boolean res;
+        Runnable both = new Runnable() {
+            @Override
+            public void run() {
+                midHook.run();
+                Stamps.getModulesJARs().shutdown();
+            }
+        };
         try {
-            res = mgr.shutDown(midHook);
+            res = mgr.shutDown(both);
         } finally {
             mgr.mutexPrivileged().exitWriteAccess();
         }
-        Stamps.getModulesJARs().shutdown();
         return res;
     }
     
@@ -306,6 +330,13 @@ public final class ModuleSystem {
      */
     final void deployTestModule(File jar) throws IOException {
         if (! jar.isAbsolute()) throw new IOException("Absolute paths only please"); // NOI18N
+
+        // Check to see if Javeleon is enabled. If so,
+        // let Javeleon handle the module reloading.
+        if (JaveleonModule.isJaveleonPresent && JaveleonModuleReloader.getDefault().reloadJaveleonModule(jar, mgr, installer, ev)) {
+            return;
+        }
+        
         mgr.mutexPrivileged().enterWriteAccess();
         ev.log(Events.START_DEPLOY_TEST_MODULE, jar);
         // For now, just print to stderr directly; could also go thru Events.
