@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,26 +44,37 @@
 
 package org.netbeans.core.startup;
 
+import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
+import java.io.FileReader;
 import java.io.IOException;
 import java.io.PrintStream;
 import java.io.PrintWriter;
+import java.io.Reader;
 import java.io.StringWriter;
 import java.io.UnsupportedEncodingException;
+import java.net.URL;
+import java.net.URLClassLoader;
 import java.text.DateFormat;
+import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.MissingResourceException;
 import java.util.Set;
 import java.util.StringTokenizer;
+import java.util.WeakHashMap;
+import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.Callable;
+import java.util.concurrent.LinkedBlockingQueue;
 import java.util.logging.Formatter;
 import java.util.logging.Handler;
 import java.util.logging.Level;
@@ -68,6 +82,7 @@ import java.util.logging.LogManager;
 import java.util.logging.LogRecord;
 import java.util.logging.Logger;
 import java.util.logging.StreamHandler;
+import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 import org.netbeans.TopSecurityManager;
@@ -208,17 +223,18 @@ public final class TopLogging {
                 assert false;
             }
         }
-
-        if (!(System.err instanceof LgStream)) {
-            System.setErr(new LgStream(Logger.getLogger("stderr"))); // NOI18N
-            if (DEBUG != null) DEBUG.println("initializing stderr"); // NOI18N
-        }
-        if (!(System.out instanceof LgStream)) {
-            System.setOut(new LgStream(Logger.getLogger("stderr"))); // NOI18N
-            if (DEBUG != null) DEBUG.println("initializing stdout"); // NOI18N
+        if (!Boolean.getBoolean("netbeans.logger.noSystem")) {
+            if (!(System.err instanceof LgStream)) {
+                System.setErr(new LgStream(Logger.getLogger("stderr"))); // NOI18N
+                if (DEBUG != null) DEBUG.println("initializing stderr"); // NOI18N
+            }
+            if (!(System.out instanceof LgStream)) {
+                System.setOut(new LgStream(Logger.getLogger("stderr"))); // NOI18N
+                if (DEBUG != null) DEBUG.println("initializing stdout"); // NOI18N
+            }
         }
     }
-    
+
 
     private static void printSystemInfo(PrintStream ps) {
         DateFormat df = DateFormat.getDateTimeInstance(DateFormat.FULL, DateFormat.FULL, Locale.US);
@@ -227,10 +243,48 @@ public final class TopLogging {
         ps.println("-------------------------------------------------------------------------------"); // NOI18N
         ps.println(">Log Session: "+df.format (date)); // NOI18N
         ps.println(">System Info: "); // NOI18N
-        
+
+        List<File> clusters = new ArrayList<File>();
+        String nbdirs = System.getProperty("netbeans.dirs");
+        if (nbdirs != null) { // noted in #67862: should show all clusters here.
+            StringTokenizer tok = new StringTokenizer(nbdirs, File.pathSeparator);
+            while (tok.hasMoreTokens()) {
+                File dir = FileUtil.normalizeFile(new File(tok.nextToken()));
+                if (dir.isDirectory()) {
+                    clusters.add(dir);
+                }
+            }
+        }
+
         String buildNumber = System.getProperty ("netbeans.buildnumber"); // NOI18N
         String currentVersion = NbBundle.getMessage(TopLogging.class, "currentVersion", buildNumber );
-        ps.println("  Product Version         = " + currentVersion); // NOI18N
+        ps.print("  Product Version         = " + currentVersion); // NOI18N
+        for (File cluster : clusters) { // also print Hg ID if available; more precise
+            File buildInfo = new File(cluster, "build_info"); // NOI18N
+            if (buildInfo.isFile()) {
+                try {
+                    Reader r = new FileReader(buildInfo);
+                    try {
+                        BufferedReader b = new BufferedReader(r);
+                        String line;
+                        Pattern p = Pattern.compile("Hg ID:    ([0-9a-f]{12})"); // NOI18N
+                        while ((line = b.readLine()) != null) {
+                            Matcher m = p.matcher(line);
+                            if (m.matches()) {
+                                ps.print(" (#" + m.group(1) + ")"); // NOI18N
+                                break;
+                            }
+                        }
+                    } finally {
+                        r.close();
+                    }
+                } catch (IOException x) {
+                    x.printStackTrace(ps);
+                }
+                break;
+            }
+        }
+        ps.println();
         ps.println("  Operating System        = " + System.getProperty("os.name", "unknown")
                    + " version " + System.getProperty("os.version", "unknown")
                    + " running on " +  System.getProperty("os.arch", "unknown"));
@@ -254,17 +308,28 @@ public final class TopLogging {
         ps.print(  "  User Directory          = "); // NOI18N
         ps.println(CLIOptions.getUserDir()); // NOI18N
         ps.print(  "  Installation            = "); // NOI18N
-        String nbdirs = System.getProperty("netbeans.dirs");
-        if (nbdirs != null) { // noted in #67862: should show all clusters here.
-            StringTokenizer tok = new StringTokenizer(nbdirs, File.pathSeparator);
-            while (tok.hasMoreTokens()) {
-                ps.print(FileUtil.normalizeFile(new File(tok.nextToken())));
-                ps.print("\n                            "); //NOI18N
-            }
+        for (File cluster : clusters) {
+            ps.print(cluster + "\n                            "); // NOI18N
         }
-        ps.println(CLIOptions.getHomeDir());
+        ps.println(CLIOptions.getHomeDir()); // platform cluster is separate
         ps.println("  Boot & Ext. Classpath   = " + createBootClassPath()); // NOI18N
-        ps.println("  Application Classpath   = " + System.getProperty("java.class.path", "unknown")); // NOI18N
+        String cp;
+        ClassLoader l = Lookup.class.getClassLoader();
+        if (l == ClassLoader.getSystemClassLoader()) {
+            cp = System.getProperty("java.class.path", "unknown"); // NOI18N
+        } else {
+            StringBuilder sb = new StringBuilder("loaded by "); // NOI18N
+            if (l instanceof URLClassLoader) {
+                sb.append("URLClassLoader"); // NOI18N
+                for (URL u : ((URLClassLoader)l).getURLs()) {
+                    sb.append(' ').append(u);
+                }
+            } else {
+                sb.append(l);
+            }
+            cp = sb.toString();
+        }
+        ps.println("  Application Classpath   = " + cp); // NOI18N
         ps.println("  Startup Classpath       = " + System.getProperty("netbeans.dynamic.classpath", "unknown")); // NOI18N
         ps.println("-------------------------------------------------------------------------------"); // NOI18N
     }
@@ -274,7 +339,7 @@ public final class TopLogging {
         // boot
         String boot = System.getProperty("sun.boot.class.path"); // NOI18N
         StringBuffer sb = (boot != null ? new StringBuffer(boot) : new StringBuffer());
-        
+
         // std extensions
         findBootJars(System.getProperty("java.ext.dirs"), sb);
         findBootJars(System.getProperty("java.endorsed.dirs"), sb);
@@ -311,11 +376,11 @@ public final class TopLogging {
         StreamHandler s = new StreamHandler (
             pw, NbFormatter.FORMATTER
         );
-        return s;
+        return new NonClose(s, 50);
     }
-    
-    private static java.util.logging.Handler streamHandler;
-    private static synchronized java.util.logging.Handler streamHandler () {
+
+    private static NonClose streamHandler;
+    private static synchronized NonClose streamHandler() {
         if (streamHandler == null) {
             StreamHandler sth = new StreamHandler (OLD_ERR, NbFormatter.FORMATTER);
             sth.setLevel(Level.ALL);
@@ -323,9 +388,9 @@ public final class TopLogging {
         }
         return streamHandler;
     }
-    
-    private static java.util.logging.Handler defaultHandler;
-    private static synchronized java.util.logging.Handler defaultHandler () {
+
+    private static NonClose defaultHandler;
+    private static synchronized NonClose defaultHandler() {
         if (defaultHandler != null) return defaultHandler;
 
         String home = System.getProperty("netbeans.user");
@@ -346,7 +411,7 @@ public final class TopLogging {
                 if (f.exists()) {
                     f.renameTo(f1);
                 }
-                
+
                 FileOutputStream fout = new FileOutputStream(f, false);
                 Handler h = new StreamHandler(fout, NbFormatter.FORMATTER);
                 h.setLevel(Level.ALL);
@@ -356,7 +421,7 @@ public final class TopLogging {
                 ex.printStackTrace();
             }
         }
-        
+
         if (defaultHandler == null) {
             defaultHandler = streamHandler();
             disabledConsole = true;
@@ -367,8 +432,8 @@ public final class TopLogging {
     /** Allows tests to flush all standard handlers */
     static void flush(boolean clear) {
         System.err.flush();
-        
-        
+
+
         Handler s = streamHandler;
         if (s != null) {
             s.flush();
@@ -385,16 +450,14 @@ public final class TopLogging {
         }
     }
     static void close() {
-        Handler s = streamHandler;
-        if (s instanceof NonClose) {
-            NonClose ns = (NonClose)s;
-            ns.doClose();
+        NonClose s = streamHandler;
+        if (s != null) {
+            s.doClose();
         }
 
-        Handler d = defaultHandler;
+        NonClose d = defaultHandler;
         if (d != null) {
-            NonClose nd = (NonClose)d;
-            nd.doClose();
+            d.doClose();
         }
     }
     static void exit(int exit) {
@@ -402,14 +465,17 @@ public final class TopLogging {
         TopSecurityManager.exit(exit);
     }
 
+    private static final Map<Throwable,Integer> catchIndex = Collections.synchronizedMap(new WeakHashMap<Throwable,Integer>()); // #190623
+
     /** Non closing handler.
      */
     private static final class NonClose extends Handler
     implements Runnable {
-        private static RequestProcessor RP = new RequestProcessor("Logging Flush"); // NOI18N
+        private static RequestProcessor RP = new RequestProcessor("Logging Flush", 1, false, false); // NOI18N
         private static ThreadLocal<Boolean> FLUSHING = new ThreadLocal<Boolean>();
 
         private final Handler delegate;
+        private final BlockingQueue<LogRecord> queue = new LinkedBlockingQueue<LogRecord>(1000);
         private RequestProcessor.Task flush;
         private int delay;
 
@@ -421,21 +487,56 @@ public final class TopLogging {
         }
 
         public void publish(LogRecord record) {
-            delegate.publish(record);
+            if (RP.isRequestProcessorThread()) {
+                return;
+            }
+            if (!queue.offer(record)) {
+                for (;;) {
+                    try {
+                        // queue is full, schedule its clearing
+                        if (!schedule(0)) {
+                            return;
+                        }
+                        queue.put(record);
+                        Thread.yield();
+                        break;
+                    } catch (InterruptedException ex) {
+                        // OK, ignore and try again
+                    }
+                }
+            }
+            Throwable t = record.getThrown();
+            if (t != null) {
+                StackTraceElement[] tStack = t.getStackTrace();
+                StackTraceElement[] hereStack = new Throwable().getStackTrace();
+                for (int i = 1; i <= Math.min(tStack.length, hereStack.length); i++) {
+                    if (!tStack[tStack.length - i].equals(hereStack[hereStack.length - i])) {
+                        catchIndex.put(t, tStack.length - i);
+                        break;
+                    }
+                }
+            }
+            schedule(delay);
+        }
+
+        private boolean schedule(int d) {
             if (!Boolean.TRUE.equals(FLUSHING.get())) {
                 try {
                     FLUSHING.set(true);
-                    flush.schedule(delay);
+                    flush.schedule(d);
                 } finally {
                     FLUSHING.set(false);
                 }
+                return true;
+            } else {
+                return false;
             }
         }
 
         public void flush() {
             flush.cancel();
             flush.waitFinished();
-            delegate.flush();
+            run();
         }
 
         public void close() throws SecurityException {
@@ -448,7 +549,7 @@ public final class TopLogging {
             delegate.close();
         }
 
-        public Formatter getFormatter() {
+        public @Override Formatter getFormatter() {
             return delegate.getFormatter();
         }
 
@@ -460,6 +561,13 @@ public final class TopLogging {
         }
 
         public void run() {
+            for (;;) {
+                LogRecord r = queue.poll();
+                if (r == null) {
+                    break;
+                }
+                delegate.publish(r);
+            }
             delegate.flush();
         }
     }
@@ -470,23 +578,13 @@ public final class TopLogging {
      * @param pw the destination
      */
     public static void printStackTrace(Throwable t, PrintWriter pw) {
-        // First try to find where the throwable was caught.
-        StackTraceElement[] tStack = t.getStackTrace();
-        StackTraceElement[] hereStack = new Throwable().getStackTrace();
-        int idx = -1;
-        for (int i = 1; i <= Math.min(tStack.length, hereStack.length); i++) {
-            if (!tStack[tStack.length - i].equals(hereStack[hereStack.length - i])) {
-                idx = tStack.length - i;
-                break;
-            }
-        }
-        doPrintStackTrace(pw, t, null, idx);
+        doPrintStackTrace(pw, t, null);
     }
 
     /**
      * #91541: show stack traces in a more natural order.
      */
-    private static void doPrintStackTrace(PrintWriter pw, Throwable t, Throwable higher, int caughtIndex) {
+    private static void doPrintStackTrace(PrintWriter pw, Throwable t, Throwable higher) {
         //if (t != null) {t.printStackTrace(pw);return;}//XxX
         try {
             if (t.getClass().getMethod("printStackTrace", PrintWriter.class).getDeclaringClass() != Throwable.class) { // NOI18N
@@ -501,7 +599,7 @@ public final class TopLogging {
         }
         Throwable lower = t.getCause();
         if (lower != null) {
-            doPrintStackTrace(pw, lower, t, -1);
+            doPrintStackTrace(pw, lower, t);
             pw.print("Caused: "); // NOI18N
         }
         String summary = t.toString();
@@ -524,8 +622,9 @@ public final class TopLogging {
                 end--;
             }
         }
+        Integer caughtIndex = catchIndex.get(t);
         for (int i = 0; i < end; i++) {
-            if (i == caughtIndex) {
+            if (caughtIndex != null && i == caughtIndex) {
                 // Translate following tab -> space since formatting is bad in
                 // Output Window (#8104) and some mail agents screw it up etc.
                 pw.print("[catch] at "); // NOI18N
@@ -535,7 +634,7 @@ public final class TopLogging {
             pw.println(trace[i]);
         }
     }
-    
+
     /** Modified formater for use in NetBeans.
      */
     private static final class NbFormatter extends java.util.logging.Formatter {
@@ -559,6 +658,9 @@ public final class TopLogging {
             if (message != null && message.indexOf('\n') != -1 && record.getThrown() == null) {
                 // multi line messages print witout any wrappings
                 sb.append(message);
+                if (message.charAt(message.length() - 1) != '\n') {
+                    sb.append(lineSeparator);
+                }
                 return;
             }
             if ("stderr".equals(record.getLoggerName()) && record.getLevel() == Level.INFO) { // NOI18N
@@ -567,7 +669,7 @@ public final class TopLogging {
                 return;
             }
 
-            sb.append(record.getLevel().getLocalizedName());
+            sb.append(record.getLevel().getName());
             addLoggerName (sb, record);
             if (message != null) {
                 sb.append(": ");
@@ -595,7 +697,7 @@ public final class TopLogging {
                 specialProcessing(sb, record.getThrown(), beenThere);
             }
         }
-        
+
         private static void addLoggerName (StringBuilder sb, java.util.logging.LogRecord record) {
             String name = record.getLoggerName ();
             if (!"".equals (name)) {
@@ -662,7 +764,7 @@ public final class TopLogging {
                     Object[] param;
                     if (col != -1 || line != -1) {
                         msg = "EXC_sax_parse_col_line"; // NOI18N
-                        param = new Object[] {String.valueOf(pubid), String.valueOf(sysid), new Integer(col), new Integer(line)};
+                        param = new Object[] {String.valueOf(pubid), String.valueOf(sysid), col, line};
                     } else {
                         msg = "EXC_sax_parse"; // NOI18N
                         param = new Object[] { String.valueOf(pubid), String.valueOf(sysid) };
@@ -681,7 +783,7 @@ public final class TopLogging {
      */
     private static final class LgStream extends PrintStream implements Runnable {
         private Logger log;
-        private StringBuffer sb = new StringBuffer();
+        private final StringBuilder sb = new StringBuilder();
         private static RequestProcessor RP = new RequestProcessor("StdErr Flush");
         private RequestProcessor.Task flush = RP.create(this, true);
 
@@ -690,33 +792,54 @@ public final class TopLogging {
             this.log = log;
         }
 
-        public void write(byte[] buf, int off, int len) {
+        public @Override void write(byte[] buf, int off, int len) {
             if (RP.isRequestProcessorThread()) {
                 return;
             }
             String s = new String(buf, off, len);
-            if (unwantedMessages != null && unwantedMessages.matcher(s).find()) {
-                new Exception().printStackTrace(DEBUG);
-            }
-            sb.append(s);
-            checkFlush();
+            print(s);
         }
 
-        public void write(byte[] b) throws IOException {
+        public @Override void write(byte[] b) throws IOException {
             write(b, 0, b.length);
         }
 
-        public void write(int b) {
+        public @Override void write(int b) {
             if (RP.isRequestProcessorThread()) {
                 return;
             }
-            sb.append((char)b);
+            synchronized (sb) {
+                sb.append((char)b);
+            }
             checkFlush();
         }
 
+        @Override
+        public void print(String s) {
+            if (unwantedMessages != null && unwantedMessages.matcher(s).find()) {
+                new Exception().printStackTrace(DEBUG);
+            }
+            synchronized (sb) {
+                sb.append(s);
+            }
+            checkFlush();
+        }
+        
+        @Override
+        public void println(String x) {
+            print(x);
+            print(System.getProperty("line.separator"));
+        }
+        @Override
+        public void println(Object x) {
+            String s = String.valueOf(x);
+            println(s);
+        }
+        
         @Override
         public void flush() {
             try {
+                flush.schedule(0);
                 flush.waitFinished(500);
             } catch (InterruptedException ex) {
                 // ok, flush failed, do not even print
@@ -725,8 +848,8 @@ public final class TopLogging {
             super.flush();
         }
 
-        
-        
+
+
         private void checkFlush() {
             //if (DEBUG != null) DEBUG.println("checking flush; buffer: " + sb); // NOI18N
             try {
@@ -753,46 +876,54 @@ public final class TopLogging {
                             at org.netbeans.insane.impl.LiveEngine.trace(LiveEngine.java:180)
                             at org.netbeans.insane.live.LiveReferences.fromRoots(LiveReferences.java:110)
 
-                 * just ignore it, we cannot print it at this situation anyway...                
+                 * just ignore it, we cannot print it at this situation anyway...
                  */
             }
         }
-        
+
         public void run() {
             for (;;) {
                 String toLog;
                 synchronized (sb) {
-                    int first = sb.indexOf("\n"); // NOI18N
-                    if (first < 0) {
+                    if (sb.length() == 0) {
                         break;
                     }
-                    if (first == 0) {
-                        sb.delete(0, 1);
-                        toLog = "\n";
-                    } else {
-                        toLog = sb.substring(0, first + 1);
-                        sb.delete(0, first + 1);
+                    int last = -1;
+                    for (int i = sb.length() - 1; i >=0; i--) {
+                        if (sb.charAt(i) == '\n') {
+                            last = i;
+                            break;
+                        }
                     }
+                    if (last == -1) {
+                        break;
+                    }
+                    toLog = sb.substring(0, last + 1);
+                    sb.delete(0, last + 1);
+                }
+                int begLine = 0;
+                while (begLine < toLog.length()) {
+                    int endLine = toLog.indexOf('\n', begLine);
+                    log.log(Level.INFO, toLog.substring(begLine, endLine + 1));
+                    begLine = endLine + 1;
                 }
-                //if (DEBUG != null) DEBUG.println("delegating: " + toLog); // NOI18N
-                log.log(Level.INFO, toLog);
             }
         }
     } // end of LgStream
 
-    private static final class LookupDel extends Handler 
+    private static final class LookupDel extends Handler
     implements LookupListener {
         private Lookup.Result<Handler> handlers;
         private Collection<? extends Handler> instances;
-        
-        
+
+
         public LookupDel() {
             handlers = Lookup.getDefault().lookupResult(Handler.class);
             instances = handlers.allInstances();
             handlers.addLookupListener(this);
         }
-        
-        
+
+
         public void publish(LogRecord record) {
             for (Handler h : instances) {
                 h.publish(record);
@@ -818,7 +949,7 @@ public final class TopLogging {
 
     /** Instances are created in awt.EventDispatchThread */
     public static final class AWTHandler {
-        /** The name MUST be handle and MUST be public 
+        /** The name MUST be handle and MUST be public
          * @param t the throwable to print
          */
         public static void handle(Throwable t) {
