@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,6 +44,7 @@
 
 package org.netbeans.core.startup;
 
+import java.lang.Thread.UncaughtExceptionHandler;
 import org.netbeans.TopSecurityManager;
 import org.openide.util.Exceptions;
 
@@ -83,8 +87,15 @@ final class TopThreadGroup extends ThreadGroup implements Runnable {
         super(parent, name);
     }
 
+    @Override
     public void uncaughtException(Thread t, Throwable e) {
         if (!(e instanceof ThreadDeath)) {
+            UncaughtExceptionHandler h = Thread.getDefaultUncaughtExceptionHandler();
+            if (h != null) {
+                h.uncaughtException(t, e);
+                return;
+            }
+            
             if (e instanceof VirtualMachineError) {
                 // Try as hard as possible to get a stack trace from e.g. StackOverflowError
                 e.printStackTrace();
@@ -106,6 +117,7 @@ final class TopThreadGroup extends ThreadGroup implements Runnable {
         }
     }
 
+    @Override
     public void run() {
         try {
             Main.start (args);
