@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -48,6 +51,7 @@ import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.net.MalformedURLException;
@@ -65,6 +69,7 @@ import java.util.Enumeration;
 import java.util.List;
 import java.util.Set;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Map;
 import java.util.StringTokenizer;
 import java.util.logging.Level;
@@ -150,11 +155,12 @@ final class BinaryFS extends FileSystem {
         // fill the modifications array
         int stop = buff.getInt() + 8 + MAGIC.length;
         urls = new ArrayList<String>();
-        modifications = new ArrayList<Long>();
+        List<Long> _modifications = new ArrayList<Long>();
         while (buff.position() < stop) {
             urls.add(getString(buff));
-            modifications.add(null);
+            _modifications.add(null);
         }
+        modifications = Collections.synchronizedList(_modifications);
 
 
         // prepare the content buffer and root
@@ -368,6 +374,7 @@ final class BinaryFS extends FileSystem {
         // Attributes implementation:
 
         /** Get the file attribute with the specified name. */
+        @Override
         public Object getAttribute(String attrName) {
             initialize();
             AttrImpl attr = attrs.get(attrName);
@@ -375,6 +382,19 @@ final class BinaryFS extends FileSystem {
                 attr = attrs.get(attrName.substring(6));
                 return attr == null ? null : attr.getType(this);
             }
+            if (attr == null && attrName.startsWith("raw:")) { // NOI18N
+                attr = attrs.get(attrName.substring(4));
+                try {
+                    if (attr != null && attr.index == 10) {
+                        return attr.methodValue(attr.value, this, attrName).getMethod();
+                    }
+                    if (attr != null && attr.index == 11) {
+                        return attr.getType(this);
+                    }
+                } catch (Exception ex) {
+                }
+                return null;
+            }
             if (attr == null && attrName.equals("layers")) { // NOI18N
                 return getLayersAttr();
             }
@@ -540,7 +560,9 @@ final class BinaryFS extends FileSystem {
                         if (SharedClassObject.class.isAssignableFrom(cls)) {
                             return SharedClassObject.findObject(cls.asSubclass(SharedClassObject.class), true);
                         } else {
-                            return cls.newInstance();
+                            Constructor<?> init = cls.getDeclaredConstructor();
+                            init.setAccessible(true);
+                            return init.newInstance((Object[]) null);
                         }
 
                     case 12: // serialvalue
@@ -552,10 +574,11 @@ final class BinaryFS extends FileSystem {
                         throw new IllegalStateException("Bad index: " + index); // NOI18N
                 }
             } catch (Exception exc) {
-                LOG.log(Level.WARNING, "value = " + value + " from " + foProvider.getPath(), exc); // NOI18N
+                LOG.log(notified.add(foProvider.getPath()) ? Level.INFO : Level.FINE, "value = " + value + " from " + foProvider.getPath(), exc); // NOI18N
             }
             return null; // problem getting the value...
         }
+        private static final Set<String> notified = Collections.synchronizedSet(new HashSet<String>());
 
         public Class<?> getType( BFSBase foProvider) {
             try {
@@ -583,7 +606,7 @@ final class BinaryFS extends FileSystem {
                 }
             } catch (Exception exc) {
                 Exceptions.attachMessage(exc, "value = " + value + " from " + foProvider.getPath()); //NOI18N
-                LOG.log(Level.WARNING, null, exc);
+                LOG.log(notified.add(foProvider.getPath()) ? Level.INFO : Level.FINE, null, exc);
             }
             return null; // problem getting the value...
         }
@@ -677,7 +700,7 @@ final class BinaryFS extends FileSystem {
                 } else {
                     return Class.forName (tname, true, c);
                 }
-            } catch (NoClassDefFoundError err) {
+            } catch (LinkageError err) {
                 throw new ClassNotFoundException ("Cannot read " + name, err);
             }
         }
@@ -806,7 +829,6 @@ final class BinaryFS extends FileSystem {
         @Override
         public Date lastModified() {
             initialize();
-            synchronized (modifications) {
                 if (lastModified >= 0) {
                     return new Date(lastModified);
                 }
@@ -848,7 +870,6 @@ final class BinaryFS extends FileSystem {
                 } catch (Exception e) {
                     LOG.log(Level.WARNING, null, e);
                 }
-            }
             return super.lastModified ();
         }
     }
@@ -884,16 +905,15 @@ final class BinaryFS extends FileSystem {
         /** Get all children of this folder (files and subfolders). */
         public FileObject[] getChildren() {
             initialize();
-            // 145775 - workaround of JDK 1.5 bug 6377302 (toArray is not thread safe)
-            // When JDK 1.6 is only supported, use just "return childrenMap.values().toArray(NO_CHILDREN);" instead
-            // and remove synchronized in doInitialize.
-            synchronized (this) {
                 return childrenMap.values().toArray(NO_CHILDREN);
-            }
         }
 
         /** Retrieve file or folder contained in this folder by name. */
+        @Override
         public FileObject getFileObject(String name, String ext) {
+            if ("..".equals(name) && ext == null) { // NOI18N
+                return getParent();
+            }
             initialize();
             String fullName = ext == null ? name : name + "." + ext; // XXX - ??
             return childrenMap.get(fullName);
@@ -910,17 +930,16 @@ final class BinaryFS extends FileSystem {
         protected void doInitialize(ByteBuffer sub) throws Exception {
             int files = sub.getInt();
             if (files > 0) {
-                synchronized (this) {  // 145775
-                    childrenMap = new HashMap<String,BFSBase>(files*4/3+1);
-                    for (int i=0; i<files; i++) { //read file desc:
-                        String nm = getString(sub);   // String name
-                        byte isFolder = sub.get();      // boolean isFolder
-                        int off = sub.getInt();          // int contentRef
-                        childrenMap.put(nm, isFolder == 0 ?
-                            new BFSFile(nm, this, off) :
-                            new BFSFolder(nm, this, off));
-                    }
-                }  // 145775
+                HashMap<String, BFSBase> map = new HashMap<String, BFSBase>(files * 4 / 3 + 1);
+                for (int i=0; i<files; i++) { //read file desc:
+                    String nm = getString(sub);   // String name
+                    byte isFolder = sub.get();      // boolean isFolder
+                    int off = sub.getInt();          // int contentRef
+                    map.put(nm, isFolder == 0 ?
+                        new BFSFile(nm, this, off) :
+                        new BFSFolder(nm, this, off));
+                }
+                childrenMap = map;
                 if (LayerCacheManager.err.isLoggable(Level.FINEST)) {
                     LayerCacheManager.err.log(Level.FINEST, "  children for " + getPath() + " are: " + childrenMap.keySet());
                 }
@@ -956,6 +975,9 @@ final class BinaryFS extends FileSystem {
 
         @Override
         public Object get(Object key) {
+            if (key == FileObject.class) {
+                return fo;
+            }
             return key instanceof String ? fo.getAttribute((String)key) : null;
         }
 
@@ -973,8 +995,9 @@ final class BinaryFS extends FileSystem {
             if (!(obj instanceof Map)) {
                 return false;
             }
-            if (obj instanceof FileMap) {
-                return fo.equals(((FileMap)obj).fo);
+            Object o = ((Map)obj).get(FileObject.class);
+            if (o != null) {
+                return fo.equals(o);
             }
             return obj.equals(this);
         }
