@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,14 +44,9 @@
 
 package org.netbeans.core.startup.layers;
 
-import java.beans.PropertyVetoException;
-import java.io.ByteArrayOutputStream;
-import java.io.DataOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
-import java.nio.ByteBuffer;
-import java.nio.ByteOrder;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -56,19 +54,15 @@ import java.util.List;
 import java.util.jar.Manifest;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.netbeans.Stamps;
 import org.netbeans.core.startup.StartLog;
 import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileSystem;
-import org.openide.filesystems.FileSystem.AtomicAction;
 import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.MultiFileSystem;
 import org.openide.filesystems.XMLFileSystem;
-import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
 import org.openide.util.LookupEvent;
 import org.openide.util.LookupListener;
-import org.openide.util.NbBundle;
 import org.openide.util.NbCollections;
 
 /** Layered file system serving itself as either the user or installation layer.
@@ -81,8 +75,6 @@ implements LookupListener {
     /** serial version UID */
     private static final long serialVersionUID = 782910986724201983L;
     
-    private static final String LAYER_STAMP = "layer-stamp.txt";
-    
     static final Logger err = Logger.getLogger("org.netbeans.core.projects"); // NOI18N
 
     /** lookup result we listen on */
@@ -99,7 +91,7 @@ implements LookupListener {
     /** other layers */
     private final FileSystem[] otherLayers;
     /** addLookup */
-    private final boolean addLookup;
+    private final boolean addLookupBefore;
 
     /** Create layered filesystem based on a supplied writable layer.
      * @param userDir is this layer for modules from userdir or not?
@@ -127,7 +119,7 @@ implements LookupListener {
         this.writableLayer = writableLayer;
         this.otherLayers = otherLayers;
         this.cacheLayer = cacheLayer;
-        this.addLookup = addLookup;
+        this.addLookupBefore = addLookup;
         
         // Wish to permit e.g. a user-installed module to mask files from a
         // root-installed module, so propagate masks up this high.
@@ -137,19 +129,20 @@ implements LookupListener {
         
         urls = null;
 
-        if (addLookup) {
-            result.addLookupListener(this);
-            result.allItems();
-        }
-        
+        result.addLookupListener(this);
+        result.allItems();
     }
     
-    private static FileSystem[] appendLayers(FileSystem fs1, boolean addLookup, FileSystem[] fs2s, FileSystem fs3, boolean addClasspathLayers) {
+    private static FileSystem[] appendLayers(FileSystem fs1, boolean addLookupBefore, FileSystem[] fs2s, FileSystem fs3, boolean addClasspathLayers) {
         List<FileSystem> l = new ArrayList<FileSystem>(fs2s.length + 2);
         l.add(fs1);
-        if (addLookup) {
-            Collection<? extends FileSystem> fromLookup = result.allInstances();
-            l.addAll(fromLookup);
+        if (addLookupBefore) {
+            for (FileSystem f : result.allInstances()) {
+                if (Boolean.TRUE.equals(f.getRoot().getAttribute("fallback"))) { // NOI18N
+                    continue;
+                }
+                l.add(f);
+            }
         }
         l.addAll(Arrays.asList(fs2s));
         l.add(fs3);
@@ -186,6 +179,13 @@ implements LookupListener {
                 err.log(Level.WARNING, "Setting layer URLs: " + layerUrls, x);
             }
         }
+        if (!addLookupBefore) {
+            for (FileSystem f : result.allInstances()) {
+                if (Boolean.TRUE.equals(f.getRoot().getAttribute("fallback"))) { // NOI18N
+                    l.add(f);
+                }
+            }
+        }
         return l.toArray(new FileSystem[l.size()]);
     }
 
@@ -208,11 +208,11 @@ implements LookupListener {
      * if working within the core.
      */
     public static ModuleLayeredFileSystem getInstallationModuleLayer () {
-        SystemFileSystem sfs = null;
+        SystemFileSystem sfs;
         try {
             sfs = (SystemFileSystem) FileUtil.getConfigRoot().getFileSystem();
         } catch (FileStateInvalidException ex) {
-            Exceptions.printStackTrace(ex);
+            throw new AssertionError(ex);
         }
         ModuleLayeredFileSystem home = sfs.getInstallationLayer ();
         if (home != null)
@@ -226,11 +226,11 @@ implements LookupListener {
      * if working within the core.
      */
     public static ModuleLayeredFileSystem getUserModuleLayer () {
-        SystemFileSystem sfs = null;
+        SystemFileSystem sfs;
         try {
             sfs = (SystemFileSystem) FileUtil.getConfigRoot().getFileSystem();
         } catch (FileStateInvalidException ex) {
-            Exceptions.printStackTrace(ex);
+            throw new AssertionError(ex);
         }
         return sfs.getUserLayer ();
     }
@@ -257,7 +257,7 @@ implements LookupListener {
             }
             cacheLayer = manager.store(cacheLayer, urls);
             err.log(Level.FINEST, "changing delegates");
-            setDelegates(appendLayers(writableLayer, addLookup, otherLayers, cacheLayer, false));
+            setDelegates(appendLayers(writableLayer, addLookupBefore, otherLayers, cacheLayer, false));
             err.log(Level.FINEST, "delegates changed");
         }
         
@@ -289,7 +289,7 @@ implements LookupListener {
     
     /** Refresh layers */
     public void resultChanged(LookupEvent ev) {
-        setDelegates(appendLayers(writableLayer, addLookup, otherLayers, cacheLayer, false));
+        setDelegates(appendLayers(writableLayer, addLookupBefore, otherLayers, cacheLayer, false));
     }
     
     private static void setStatusText (String msg) {
