@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -104,7 +107,9 @@ abstract class ParsingLayerCacheManager extends LayerCacheManager implements Con
     private MemFolder root;
     private Stack<Object> curr; // Stack<MemFileOrFolder | MemAttr>
     private URL base;
-    private StringBuffer buf = new StringBuffer();
+    private final StringBuilder buf = new StringBuilder();
+    private URL ref;
+    private int weight;
     private int fileCount, folderCount, attrCount;
     // Folders, files, and attrs already encountered in this layer.
     // By path; attrs as folder/file path plus "//" plus attr name.
@@ -216,18 +221,21 @@ abstract class ParsingLayerCacheManager extends LayerCacheManager implements Con
         } else if (qname.equals("folder")) {
             fileOrFolder(qname, attrs);
         } else if (qname.equals("file")) {
-            MemFile file = (MemFile)fileOrFolder(qname, attrs);
-            file.contents = null;
+            MemFileOrFolder mfof = fileOrFolder(qname, attrs);
+            if (!(mfof instanceof MemFile)) { // a collision between modules
+                throw new ClassCastException("Stack: " + curr); // NOI18N
+            }
+            buf.setLength(0);
+            ref = null;
             String u = attrs.getValue("url");
             if (u != null) {
                 try {
-                    file.ref = new URL(base, u);
+                    ref = new URL(base, u);
                 } catch (MalformedURLException mfue) {
                     throw (SAXException) new SAXException(mfue.toString()).initCause(mfue);
                 }
-            } else {
-                file.ref = null;
             }
+            weight = 0;
         } else if (qname.equals("attr")) {
             attrCount++;
             MemAttr attr = new MemAttr();
@@ -248,6 +256,17 @@ abstract class ParsingLayerCacheManager extends LayerCacheManager implements Con
                     break;
                 }
             }
+            if (/*MultiFileObject.WEIGHT_ATTRIBUTE*/"weight".equals(attr.name)) {
+                if ("intvalue".equals(attr.type)) {
+                    try {
+                        weight = Integer.parseInt(attr.data);
+                    } catch (NumberFormatException x) {
+                        // ignore here (other places should report it)
+                    }
+                } else {
+                    LayerCacheManager.err.log(Level.WARNING, "currently unsupported value type for weight attribute in {0}: {1}", new Object[] {base, attr.type});
+                }
+            }
 //            System.out.println("found attr "+attr);
             /*
             attr.name = attrs.getValue("name");
@@ -322,42 +341,51 @@ abstract class ParsingLayerCacheManager extends LayerCacheManager implements Con
     }
     
     public void endElement(String ns, String lname, String qname) throws SAXException {
-        if (qname.equals("file") && buf.length() > 0) {
-            String text = buf.toString().trim();
-            if (text.length() > 0) {
-                MemFile file = (MemFile)curr.peek();
-                if (file.ref != null) throw new SAXParseException("CDATA plus url= in <file>", locator);
-                LayerCacheManager.err.warning("use of inline CDATA text contents in <file name=\"" + file.name + "\"> deprecated for performance and charset safety at " + locator.getSystemId() + ":" + locator.getLineNumber() + ". Please use the 'url' attribute instead, or the file attribute 'originalFile' on *.shadow files.");
-                // Note: platform default encoding used. If you care about the encoding,
-                // you had better be using url= instead.
-                file.contents = text.getBytes();
-            }
-            buf.setLength(0);
-        }
-        if (qname.equals("file") && openURLs()) {
-            MemFile file = (MemFile)curr.peek();
-            // Only open simple URLs. Assume that JARs are the same JARs with the layers.
-            if (file.ref != null && file.ref.toExternalForm().startsWith("jar:file:")) { // NOI18N
-                try {
-                    URLConnection conn = file.ref.openConnection();
-                    conn.connect();
-                    byte[] readBuf = new byte[conn.getContentLength()];
-                    InputStream is = conn.getInputStream();
-                    try {
-                        int pos = 0;
-                        while (pos < readBuf.length) {
-                            int read = is.read(readBuf, pos, readBuf.length - pos);
-                            if (read < 1) throw new IOException("Premature EOF on " + file.ref.toExternalForm()); // NOI18N
-                            pos += read;
+        if (qname.equals("file")) {
+            MemFile file = (MemFile) curr.peek();
+            if (weight /* #23609: reversed, so not > */>= file.weight) {
+                file.weight = weight;
+                file.contents = null;
+                if (buf.length() > 0) {
+                    String text = buf.toString().trim();
+                    if (text.length() > 0) {
+                        if (ref != null) {
+                            throw new SAXParseException("CDATA plus url= in <file>", locator);
+                        }
+                        /* May be used legitimately by e.g. @HelpSetRegistration:
+                        LayerCacheManager.err.warning("use of inline CDATA text contents in <file name=\"" + file.name + "\"> deprecated for performance and charset safety at " + locator.getSystemId() + ":" + locator.getLineNumber() + ". Please use the 'url' attribute instead, or the file attribute 'originalFile' on *.shadow files.");
+                         */
+                        // Note: platform default encoding used. If you care about the encoding,
+                        // you had better be using url= instead.
+                        file.contents = text.getBytes();
+                    }
+                }
+                file.ref = ref;
+                if (openURLs()) {
+                    // Only open simple URLs. Assume that JARs are the same JARs with the layers.
+                    if (file.ref != null && file.contents == null && file.ref.toExternalForm().startsWith("jar:file:")) { // NOI18N
+                        try {
+                            URLConnection conn = file.ref.openConnection();
+                            conn.connect();
+                            byte[] readBuf = new byte[conn.getContentLength()];
+                            InputStream is = conn.getInputStream();
+                            try {
+                                int pos = 0;
+                                while (pos < readBuf.length) {
+                                    int read = is.read(readBuf, pos, readBuf.length - pos);
+                                    if (read < 1) throw new IOException("Premature EOF on " + file.ref.toExternalForm()); // NOI18N
+                                    pos += read;
+                                }
+                                if (is.read() != -1) throw new IOException("Delayed EOF on " + file.ref.toExternalForm()); // NOI18N
+                            } finally {
+                                is.close();
+                            }
+                            file.contents = readBuf;
+                            file.ref = null;
+                        } catch (IOException ioe) {
+                            throw new SAXException(ioe);
                         }
-                        if (is.read() != -1) throw new IOException("Delayed EOF on " + file.ref.toExternalForm()); // NOI18N
-                    } finally {
-                        is.close();
                     }
-                    file.contents = readBuf;
-                    file.ref = null;
-                } catch (IOException ioe) {
-                    throw new SAXException(ioe);
                 }
             }
         }
@@ -377,10 +405,6 @@ abstract class ParsingLayerCacheManager extends LayerCacheManager implements Con
         if (!(currF instanceof MemFile)) {
             return;
         }
-        // Usually this will just be whitespace which we will ignore anyway.
-        // Do it anyway, so that people who accidentally write:
-        // <file name="x" url="y"><![CDATA[z]]></file>
-        // will at least get an error.
         buf.append(ch, start, len);
     }
     
@@ -490,6 +514,8 @@ abstract class ParsingLayerCacheManager extends LayerCacheManager implements Con
     protected static final class MemFile extends MemFileOrFolder {
         public byte[] contents = null; // {null | byte[]}
         public URL ref = null; // {null | URL}
+
+        private int weight = Integer.MIN_VALUE;
         
         public MemFile (URL base) {
             super (base);
