@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -357,6 +360,43 @@ public class TopLoggingTest extends NbTestCase {
             fail("Expecting exception: " + disk);
         }
     }
+
+    @RandomlyFails // NB-Core-Build #5167: m.find()
+    public void testSystemErrIsSentToLogWithoutFlush() throws Exception {
+        System.err.println("Ahoj");
+        System.err.println("Jardo");
+        new IllegalStateException("Hi").printStackTrace();
+        
+        String disk = "";
+        for (int i = 0; i < 100; i++) {
+            new IOException("More output").printStackTrace();
+            System.err.println("Line " + i);
+
+            Thread.sleep(100);
+            
+            disk = readLog(false);
+
+            Matcher m = Pattern.compile("^Ahoj(.*)Jardo", Pattern.MULTILINE | Pattern.DOTALL).matcher(disk);
+            
+            if (m.find()) {
+                break;
+            }
+        }
+        Matcher m = Pattern.compile("^Ahoj(.*)Jardo", Pattern.MULTILINE | Pattern.DOTALL).matcher(disk);
+        assertTrue(disk, m.find());
+        assertEquals("One group found", 1, m.groupCount());
+        assertTrue("Non empty group: " + m.group(1) + "\n" + disk, m.group(1).length() > 0);
+        char next = m.group(1).charAt(0);
+        if (next != 10 && next != 13) {
+            fail("Expecting 'Ahoj': index: " + 0 + " next char: " + (int)next + "text:\n" + disk);
+        }
+        
+        Pattern p = Pattern.compile("IllegalStateException.*Hi");
+        Matcher d = p.matcher(disk);
+        if (!d.find()) {
+            fail("Expecting exception: " + disk);
+        }
+    }
     
     public void testSystemErrPrintLnIsSentToLog() throws Exception {
         System.err.println("BEGIN");
