@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,6 +47,7 @@ package org.netbeans.core.startup.layers;
 import java.awt.Image;
 import java.awt.image.ImageObserver;
 import java.beans.BeanInfo;
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
@@ -56,11 +60,12 @@ import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.FileUtil;
 import org.openide.filesystems.MultiFileSystem;
+import org.openide.util.test.TestFileUtils;
 /** Test layer cache managers generally.
  * @author Jesse Glick
  */
 public abstract class CacheManagerTestBaseHid extends NbTestCase implements ImageObserver {
-    private long initTime = System.currentTimeMillis ();
+    private static Long initTime;
     
     /**
      * Called from layer, do not rename!
@@ -91,6 +96,17 @@ public abstract class CacheManagerTestBaseHid extends NbTestCase implements Imag
         LayerCacheManager createManager() throws Exception;
         boolean supportsTimestamps ();
     }
+
+    @Override
+    protected void setUp() throws Exception {
+        if (initTime == null) {
+            File f = new File(getWorkDir(), "test");
+            f.createNewFile();
+            TestFileUtils.touch(f, null);
+            initTime = f.lastModified();
+        }
+        clearWorkDir();
+    }
     
     public void testCacheManager() throws Exception {
         ManagerFactory mf = (ManagerFactory)this;
