@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -39,14 +42,6 @@
 
 package org.netbeans.core.ui.notifications;
 
-import java.awt.Color;
-import java.awt.Component;
-import java.awt.Container;
-import java.awt.Cursor;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
-import java.awt.Insets;
-import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
@@ -55,17 +50,13 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
-import javax.swing.AbstractButton;
-import javax.swing.BorderFactory;
 import javax.swing.Icon;
-import javax.swing.JButton;
 import javax.swing.JComponent;
-import javax.swing.JLabel;
-import javax.swing.JPanel;
 import javax.swing.SwingUtilities;
 import org.openide.awt.Notification;
 import org.openide.awt.NotificationDisplayer;
 import org.openide.util.Lookup;
+import org.openide.util.Parameters;
 import org.openide.util.lookup.ServiceProvider;
 import org.openide.xml.XMLUtil;
 
@@ -86,52 +77,29 @@ public final class NotificationDisplayerImpl extends NotificationDisplayer {
     private final PropertyChangeSupport propSupport = new PropertyChangeSupport(this);
 
     static NotificationDisplayerImpl getInstance() {
-        return (NotificationDisplayerImpl) Lookup.getDefault().lookup(NotificationDisplayer.class);
+        NotificationDisplayer nd = Lookup.getDefault().lookup(NotificationDisplayer.class);
+        if( nd instanceof NotificationDisplayerImpl )
+            return (NotificationDisplayerImpl) nd;
+        return null;
     }
 
     @Override
     public Notification notify(String title, Icon icon, String detailsText, ActionListener detailsAction, Priority priority) {
-        if( null == detailsText )
-            throw new NullPointerException("detailsText cannot be null."); //NOI18N
+        Parameters.notNull("detailsText", detailsText); //NOI18N
 
-        JComponent detailsComp1 = createDetails( detailsText, detailsAction );
-        JComponent detailsComp2 = createDetails( detailsText, detailsAction );
-
-        return notify(title, icon, detailsComp1, detailsComp2, priority);
+        NotificationImpl n = createNotification( title, icon, priority );
+        n.setDetails( detailsText, detailsAction );
+        add( n );
+        return n;
     }
 
     @Override
     public Notification notify(String title, Icon icon, JComponent balloonDetails, JComponent popupDetails, Priority priority) {
-        NotificationImpl n = new NotificationImpl();
+        Parameters.notNull("balloonDetails", balloonDetails); //NOI18N
+        Parameters.notNull("popupDetails", popupDetails); //NOI18N
 
-        return notify( n, title, icon, balloonDetails, popupDetails, priority );
-    }
-
-    private Notification notify( NotificationImpl n, String title, Icon icon, JComponent balloonDetails, JComponent popupDetails, Priority priority) {
-        if( null == title )
-            throw new NullPointerException("title cannot be null."); //NOI18N
-        if( null == icon )
-            throw new NullPointerException("icon cannot be null."); //NOI18N
-        if( null == balloonDetails )
-            throw new NullPointerException("balloonDetails cannot be null."); //NOI18N
-        if( null == popupDetails )
-            throw new NullPointerException("popupDetails cannot be null."); //NOI18N
-        if( null == priority )
-            throw new NullPointerException("priority cannot be null."); //NOI18N
-
-        try {
-            title = XMLUtil.toElementContent(title);
-        } catch( CharConversionException ex ) {
-            throw new IllegalArgumentException(ex);
-        }
-        JComponent titleComp = createTitle(title);
-        JComponent balloon = createContent( icon, titleComp, balloonDetails, n );
-        balloon.setBorder(BorderFactory.createEmptyBorder(8, 5, 0, 0));
-        
-        titleComp = createTitle(title);
-        JComponent popup = createContent( icon, titleComp, popupDetails, n );
-        
-        n.init(title, icon, priority, balloon, popup);
+        NotificationImpl n = createNotification(title, icon, priority);
+        n.setDetails( balloonDetails, popupDetails );
         add( n );
         return n;
     }
@@ -201,64 +169,13 @@ public final class NotificationDisplayerImpl extends NotificationDisplayer {
         propSupport.removePropertyChangeListener(l);
     }
 
-    private JComponent createContent(Icon icon, JComponent titleComp, JComponent popupDetails, final Notification n) {
-        JPanel panel = new JPanel( new GridBagLayout() );
-        panel.setOpaque(false);
-        panel.add( new JLabel(icon), new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(3,3,3,3), 0, 0));
-        panel.add( titleComp, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(3,3,3,3), 0, 0));
-        panel.add( popupDetails, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(3,3,3,3), 0, 0));
-        panel.add( new JLabel(), new GridBagConstraints(2, 2, 1, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0,0,0,0), 0, 0));
-
-        ActionListener al = new ActionListener() {
-            public void actionPerformed(ActionEvent e) {
-                n.clear();
-                PopupList.dismiss();
-            }
-        };
-        addActionListener( popupDetails, al );
-        return panel;
-    }
-
-    private void addActionListener(Container c, ActionListener al) {
-        if( c instanceof AbstractButton ) {
-            ((AbstractButton)c).addActionListener(al);
-        }
-        for( Component child : c.getComponents() ) {
-            if( child instanceof Container ) {
-                addActionListener((Container)child, al);
-            }
-        }
-    }
-
-    private JComponent createTitle( String title ) {
-        return new JLabel("<html>" + title); // NOI18N
-    }
-
-    private JComponent createDetails( String text, ActionListener action ) {
-        if( null == action ) {
-            return new JLabel(text);
-        }
-        try {
-            text = "<html><u>" + XMLUtil.toElementContent(text); //NOI18N
-        } catch( CharConversionException ex ) {
-            throw new IllegalArgumentException(ex);
-        }
-        JButton btn = new JButton(text);
-        btn.setFocusable(false);
-        btn.setBorder(BorderFactory.createEmptyBorder());
-        btn.setBorderPainted(false);
-        btn.setFocusPainted(false);
-        btn.setOpaque(false);
-        btn.setContentAreaFilled(false);
-        btn.addActionListener(action);
-        btn.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
-        btn.setForeground(Color.blue);
-        return btn;
-    }
-
     private void firePropertyChange(final String propName, final NotificationImpl notification) {
         Runnable r = new Runnable() {
+            @Override
             public void run() {
+                if( PROP_NOTIFICATION_ADDED.equals(propName) ) {
+                    notification.initDecorations();
+                }
                 propSupport.firePropertyChange(propName, null, notification);
             }
         };
@@ -268,4 +185,18 @@ public final class NotificationDisplayerImpl extends NotificationDisplayer {
             SwingUtilities.invokeLater(r);
         }
     }
+
+    private NotificationImpl createNotification(String title, Icon icon, Priority priority) {
+        Parameters.notNull("title", title); //NOI18N
+        Parameters.notNull("icon", icon); //NOI18N
+        Parameters.notNull("priority", priority); //NOI18N
+
+        try {
+            title = XMLUtil.toElementContent(title);
+        } catch( CharConversionException ex ) {
+            throw new IllegalArgumentException(ex);
+        }
+
+        return new NotificationImpl(title, icon, priority);
+    }
 }
