@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -64,6 +67,7 @@ import org.openide.windows.*;
  *
  * @author Peter Zavadsky
  */
+@org.openide.util.lookup.ServiceProvider(service=org.openide.windows.WindowManager.class)
 public final class WindowManagerImpl extends WindowManager implements Workspace {
 // XXX Implements Workspace for backward compatibility of old API only,
 // there are no workspaces any more.
@@ -106,6 +110,8 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
 
     /** flag that prevents calling Exclusive.run on each main window repaint */
     private boolean exclusivesCompleted = false;
+    /** possibly stacktrace of creator */
+    private Throwable createdBy;
 
     /** Default constructor. Don't use directly, use getDefault()
      * instead.
@@ -114,7 +120,16 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
         synchronized(LOCK_INIT) {
             // a static object to synchronize on
             if(defaultInstance != null) {
-                throw new IllegalStateException("Instance already exists"); // NOI18N
+                IllegalStateException ex = new IllegalStateException("Instance already exists"); // NOI18N
+                if (createdBy != null) {
+                    ex.initCause(createdBy);
+                }
+                throw ex;
+            }
+            boolean on = false;
+            assert on = true;
+            if (on) {
+                createdBy = new Exception("createdBy");
             }
             defaultInstance = this;
         }
@@ -542,6 +557,16 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
         }
     }
     
+    /** Gets default mode for opening new component. */
+    /*private*/ ModeImpl getDefaultEditorModeForOpen() {
+        ModeImpl mode = central.getLastActiveEditorMode();
+        if (mode == null) {
+            return getDefaultEditorMode();
+        } else {
+            return mode;
+        }
+    }
+    
     // XXX
     /** Gets default view mode. */
     ModeImpl getDefaultViewMode() {
@@ -768,9 +793,7 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
 
     /** Sets visible or invisible window system GUI. */
     public void setVisible(boolean visible) {
-        if( visible ) {
-            FloatingWindowTransparencyManager.getDefault().start();
-        } else {
+        if( !visible ) {
             FloatingWindowTransparencyManager.getDefault().stop();
         }
         central.setVisible(visible);
@@ -780,6 +803,8 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
         if (visible) {
             if (!exclusivesCompleted) {
                 paintedTimer.restart();
+            } else {
+                FloatingWindowTransparencyManager.getDefault().start();
             }
         } else {
             paintedTimer.stop();
@@ -840,8 +865,6 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
         return null;
     }
     
-    private static final boolean NAME_HACK = Boolean.getBoolean("nb.tabnames.html"); //NOI18N
-    
     /** Helper method to retrieve some form of display name of TopComponent.
      * First tries TopComponent's getHtmlDisplayName, if is it null then continues
      * with getDisplayName and getName in this order.
@@ -861,39 +884,6 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
         if (displayName == null) {
             displayName = tc.getName();
         }
-        if (NAME_HACK && displayName != null) {
-            //THIS IS FOR DEMO PURPOSES ONLY!  A PROPER API IS NEEDED
-            //(TopComponent.getHtmlDisplayName()), OR
-            //HTML SHOULD BE PRE-SUPPLIED
-            if (displayName.endsWith("*")) { 
-                
-                if (displayName.startsWith("<html>")) {
-                    displayName = displayName.substring(6);
-                }
-                
-                displayName = "<html><b>" + 
-                    displayName.substring(0, displayName.length()-2);
-                
-            } else {
-                
-                int i = displayName.indexOf ("[r/o]"); 
-                if (i > 0) {
-                    
-                    if (displayName.startsWith("<html>")) {
-                        displayName = displayName.substring(6);
-                        i -= 6;
-                    }
-
-                    int roLength = "[r/o]".length();
-                    String nuName = "<html><font color='#555555'><i>" + //NOI18N
-                        displayName.substring (0, i-1);
-                    if (i + roLength < displayName.length()) {
-                        nuName += displayName.substring(i + roLength);
-                    }
-                    displayName = nuName;
-                }
-            }
-        }
         return displayName;
     }
     
@@ -1080,11 +1070,11 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
                 "TopComponent"); //NOI18N
         }
         
-        
         ModeImpl mode = getMode(tc);
         
-        if(mode == null) {
-            mode = getDefaultEditorMode();
+        if (mode == null) {
+            mode = getDefaultEditorModeForOpen();
+            assert getModes().contains(mode) : "Mode " + mode.getName() + " is not in model."; //NOI18N
             if (tc.getClientProperty (Constants.TOPCOMPONENT_ALLOW_DOCK_ANYWHERE) == null) {
                 tc.putClientProperty (Constants.TOPCOMPONENT_ALLOW_DOCK_ANYWHERE, Boolean.TRUE);
             }
@@ -1155,7 +1145,7 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
                     recentTc = central.getRecentTopComponent( mode, tc );
                 }
                 mode.close(tc);
-                if( null != recentTc )
+                if( !tc.isOpened() && null != recentTc )
                     mode.setSelectedTopComponent(recentTc);
             }
         }
@@ -1176,6 +1166,9 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
         ModeImpl mode = getModeForOpenedTopComponent(tc);
         if(mode != null) {
             central.setModeSelectedTopComponent(mode, tc);
+            if( mode.getState() == Constants.MODE_STATE_SEPARATED ) {
+                tc.toFront();
+            }
         }
     }
 
@@ -1290,10 +1283,16 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
     }
 
     public final void mainWindowPainted () {
-        if (!exclusivesCompleted) {
+        if (!exclusivesCompleted && WindowManagerImpl.getInstance().isVisible()) {
             exclusivesCompleted = true;
             paintedTimer.stop();
 
+            exclusive.register(new Runnable() {
+                public void run() {
+                    FloatingWindowTransparencyManager.getDefault().start();
+                }
+            });
+
             SwingUtilities.invokeLater(exclusive);
         }
     }
@@ -1318,26 +1317,26 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
                 return;
             }
             
-            ArrayList<Runnable> arrCopy = null;
             synchronized (this) {
                 if (arr.isEmpty()) {
                     return;
                 }
                 
-                arrCopy = arr;
-                arr = new ArrayList<Runnable>();
-            }
-
-            Logger perf = Logger.getLogger("org.netbeans.log.startup"); // NOI18N
-            for (Runnable r : arrCopy) {
-                try {
-                    perf.log(Level.FINE, "start", "invokeWhenUIReady: " + r.getClass().getName()); // NOI18N
-                    r.run();
-                    perf.log(Level.FINE, "end", "invokeWhenUIReady: " + r.getClass().getName()); // NOI18N
-                } catch (RuntimeException ex) {
-                    Logger.getLogger(WindowManagerImpl.class.getName()).log(
-                            Level.WARNING, null, ex);
-                }
+                final Runnable toRun = arr.remove(0);
+                SwingUtilities.invokeLater(new Runnable() {
+                    public void run() {
+                        Logger perf = Logger.getLogger("org.netbeans.log.startup"); // NOI18N
+                        try {
+                            perf.log(Level.FINE, "start", "invokeWhenUIReady: " + toRun.getClass().getName()); // NOI18N
+                            toRun.run();
+                            perf.log(Level.FINE, "end", "invokeWhenUIReady: " + toRun.getClass().getName()); // NOI18N
+                        } catch (RuntimeException ex) {
+                            Logger.getLogger(WindowManagerImpl.class.getName()).log(
+                                    Level.WARNING, null, ex);
+                        }
+                        SwingUtilities.invokeLater(Exclusive.this);
+                    }
+                });
             }
         }
 
@@ -1606,6 +1605,39 @@ public final class WindowManagerImpl extends WindowManager implements Workspace
             }
         }
     }
+
+    @Override
+    public TopComponent[] getOpenedTopComponents(Mode mode) {
+        if( mode instanceof ModeImpl ) {
+            java.util.List<TopComponent> openedTcs = ((ModeImpl)mode).getOpenedTopComponents();
+            return openedTcs.toArray(new TopComponent[openedTcs.size()]);
+        }
+        return super.getOpenedTopComponents(mode);
+    }
+
+    public boolean isHeavyWeightShowing() {
+        TopComponent.Registry registry = TopComponent.getRegistry();
+        Set<TopComponent> opened = new HashSet<TopComponent>(registry.getOpened());
+        for( TopComponent tc : opened ) {
+            if( !tc.isShowing() )
+                continue;
+            if( isHeavyWeight( tc ) )
+                return true;
+        }
+        return false;
+    }
+
+    private boolean isHeavyWeight( java.awt.Component c ) {
+        if( null != c && !c.isLightweight() )
+            return true;
+        if( c instanceof Container ) {
+            for( java.awt.Component child : ((Container)c).getComponents() ) {
+                if( isHeavyWeight(child) )
+                    return true;
+            }
+        }
+        return false;
+    }
     
     /**
      * An empty TopComponent needed for deselectEditorTopComponents()
