@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -51,6 +54,8 @@ import java.util.*;
 import javax.swing.*;
 import org.netbeans.core.windows.*;
 import org.netbeans.core.windows.view.ui.slides.SlideController;
+import org.openide.DialogDisplayer;
+import org.openide.NotifyDescriptor;
 import org.openide.actions.SaveAction;
 import org.openide.cookies.SaveCookie;
 import org.openide.util.*;
@@ -194,53 +199,21 @@ public abstract class ActionUtils {
     /**
      * Toggle transparency of slided-in window
      */
-    public static final class ToggleWindowTransparencyAction extends AbstractAction implements Presenter.Popup {
-        
-        private final SlideController slideController;
-        
-        private final int tabIndex;
-        
-        private boolean state;
-        
-        private JCheckBoxMenuItem menuItem;
+    public static final class ToggleWindowTransparencyAction extends AbstractAction {
         
         public ToggleWindowTransparencyAction(SlideController slideController, int tabIndex, boolean initialState) {
             super();
-            this.slideController = slideController;
-            this.tabIndex = tabIndex;
-            this.state = initialState;
-            putValue(Action.NAME, NbBundle.getMessage(ActionUtils.class, "LBL_ToggleWindowTransparencyAction"));
+            putValue(Action.NAME, NbBundle.getMessage(ActionUtils.class, "LBL_ToggleWindowTransparencyAction")); //NOI18N
         }
         
         public HelpCtx getHelpCtx() {
             return null;
         }
         
-        /** Chnage boolean state and delegate event to winsys through
-         * SlideController (implemented by SlideBar component)
-         */
         public void actionPerformed(ActionEvent e) {
-            // update state and menu item
-            state = !state;
-            getMenuItem().setSelected(state);
-            // send event to winsys
-            slideController.userToggledTransparency(tabIndex);
+            DialogDisplayer.getDefault().notifyLater(new NotifyDescriptor.Message(
+                    NbBundle.getMessage(ActionUtils.class, "LBL_WindowTransparencyHint"), NotifyDescriptor.INFORMATION_MESSAGE)); //NOI18N
         }
-
-        public JMenuItem getPopupPresenter() {
-            return getMenuItem();
-        }
-        
-        private JCheckBoxMenuItem getMenuItem() {
-            if (menuItem == null) {
-                menuItem = new JCheckBoxMenuItem((String)getValue(Action.NAME), state);
-                //TODO make shortcut configurable
-                menuItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_NUMPAD0, InputEvent.CTRL_DOWN_MASK));
-                menuItem.addActionListener(this);
-            }
-            return menuItem;
-        }
-        
     } // End of class ToggleWindowTransparencyAction
 
     private static class SaveDocumentAction extends AbstractAction implements PropertyChangeListener {
