@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,6 +47,7 @@ package org.netbeans.core.windows.actions;
 
 
 import java.awt.EventQueue;
+import java.awt.Frame;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import javax.swing.Action;
@@ -70,22 +74,27 @@ public class ToggleFullScreenAction extends SystemAction implements DynamicMenuC
     public ToggleFullScreenAction() {
         addPropertyChangeListener( new PropertyChangeListener() {
 
+            @Override
             public void propertyChange(PropertyChangeEvent evt) {
                 if( Action.ACCELERATOR_KEY.equals(evt.getPropertyName()) ) {
-                    //119127 - make sure shortcut gets updated in the menu
-                    menuItems = null;
-                    createItems();
+                    synchronized( ToggleFullScreenAction.this ) {
+                        //119127 - make sure shortcut gets updated in the menu
+                        menuItems = null;
+                        createItems();
+                    }
                 }
             }
         });
     }
     
+    @Override
     public JComponent[] getMenuPresenters() {
         createItems();
         updateState();
         return menuItems;
     }
 
+    @Override
     public JComponent[] synchMenuPresenters(JComponent[] items) {
         updateState();
         return menuItems;
@@ -100,38 +109,47 @@ public class ToggleFullScreenAction extends SystemAction implements DynamicMenuC
     }
     
     /** Updates state of action. Uses Runnable interface impl to save one class */ 
+    @Override
     public void run () {
-        createItems();
-        MainWindow frame = (MainWindow)WindowManager.getDefault().getMainWindow();
-        menuItems[0].setSelected(null != frame && frame.isFullScreenMode());
+        Frame frame = WindowManager.getDefault().getMainWindow();
+        synchronized( this ) {
+            createItems();
+            menuItems[0].setSelected(null != frame 
+                    && MainWindow.getInstance().isFullScreenMode());
+        }
     }
     
     private void createItems() {
-        if (menuItems == null) {
-            menuItems = new JCheckBoxMenuItem[1];
-            menuItems[0] = new JCheckBoxMenuItem(this);
-            menuItems[0].setIcon(null);
-            Mnemonics.setLocalizedText(menuItems[0], NbBundle.getMessage(ToggleFullScreenAction.class, "CTL_ToggleFullScreenAction"));
+        synchronized( this ) {
+            if (menuItems == null) {
+                menuItems = new JCheckBoxMenuItem[1];
+                menuItems[0] = new JCheckBoxMenuItem(this);
+                menuItems[0].setIcon(null);
+                Mnemonics.setLocalizedText(menuItems[0], NbBundle.getMessage(ToggleFullScreenAction.class, "CTL_ToggleFullScreenAction"));
+            }
         }
     }
 
     /** Perform the action. Sets/unsets maximzed mode. */
+    @Override
     public void actionPerformed(java.awt.event.ActionEvent ev) {
-        MainWindow frame = (MainWindow)WindowManager.getDefault().getMainWindow();
-        frame.setFullScreenMode( !frame.isFullScreenMode() );
+        MainWindow mainWindow = MainWindow.getInstance();
+        mainWindow.setFullScreenMode( !mainWindow.isFullScreenMode() );
     }
 
+    @Override
     public String getName() {
         return NbBundle.getMessage(ToggleFullScreenAction.class, "CTL_ToggleFullScreenAction");
     }
 
+    @Override
     public HelpCtx getHelpCtx() {
         return new HelpCtx(ToggleFullScreenAction.class);
     }
 
     @Override
     public boolean isEnabled() {
-        return WindowManager.getDefault().getMainWindow() instanceof MainWindow;
+        return WindowManager.getDefault().getMainWindow() == MainWindow.getInstance().getFrame();
     }
 }
 
