@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -65,6 +68,7 @@ import org.netbeans.core.windows.SplitConstraint;
 import org.netbeans.core.windows.TopComponentGroupImpl;
 import org.netbeans.core.windows.WindowManagerImpl;
 import org.netbeans.core.windows.WindowSystemSnapshot;
+import org.openide.windows.RetainLocation;
 import org.openide.windows.TopComponent;
 
 
@@ -249,9 +253,9 @@ final class DefaultModel implements Model {
             modesSubModel.addMode(mode, constraints);
         }
     }
-    
 
-    
+
+
     // XXX
     public void addModeToSide(ModeImpl mode, ModeImpl attachMode, String side) {
         synchronized(LOCK_MODES) {
@@ -784,7 +788,17 @@ final class DefaultModel implements Model {
     public boolean isModePermanent(ModeImpl mode) {
         ModeModel modeModel = getModelForMode(mode);
         if(modeModel != null) {
-            return modeModel.isPermanent();
+            boolean result = modeModel.isPermanent();
+            if (!result) {
+                for (TopComponent tc : mode.getTopComponents()) {
+                    result |= tc.getClass().getAnnotation(RetainLocation.class)
+                            != null;
+                    if (result) {
+                        break;
+                    }
+                }
+            }
+            return result;
         } else {
             return false;
         }
