@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -97,7 +100,7 @@ class DefaultView implements View, Controller, WindowDnDManager.ViewAccessor {
     
     // XXX
     public Frame getMainWindow() {
-        return hierarchy.getMainWindow();
+        return hierarchy.getMainWindow().getFrame();
     }
     
     public Component getEditorAreaComponent() {
@@ -183,7 +186,7 @@ class DefaultView implements View, Controller, WindowDnDManager.ViewAccessor {
                 return;
             }
         }
-        
+
         // Process all event types.
         for(int i = 0; i < viewEvents.length; i++) {
             ViewEvent viewEvent = viewEvents[i];
@@ -517,6 +520,8 @@ class DefaultView implements View, Controller, WindowDnDManager.ViewAccessor {
 //        }, AWTEvent.FOCUS_EVENT_MASK);
         
         hierarchy.getMainWindow().initializeComponents();
+
+        JFrame frame = hierarchy.getMainWindow().getFrame();
         // Init toolbar.
         ToolbarPool.getDefault().setConfiguration(wsa.getToolbarConfigurationName());
         
@@ -566,7 +571,7 @@ class DefaultView implements View, Controller, WindowDnDManager.ViewAccessor {
         // XXX PENDING
         if(wsa.getEditorAreaState() == Constants.EDITOR_AREA_JOINED) {
             // Ignore when main window is maximized.
-            if(hierarchy.getMainWindow().getExtendedState() != Frame.MAXIMIZED_BOTH) {
+            if(frame.getExtendedState() != Frame.MAXIMIZED_BOTH) {
                 if (DEBUG) {
                     debugLog("do updateMainWindowBoundsSeparatedHelp");
                 }
