@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -50,6 +53,8 @@ import java.awt.dnd.DragSourceDragEvent;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.geom.Area;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import java.util.prefs.Preferences;
 import javax.swing.SwingUtilities;
 import org.netbeans.core.windows.nativeaccess.NativeWindowSystem;
@@ -138,10 +143,16 @@ public class DragAndDropFeedbackVisualizer {
             SwingUtilities.convertPointToScreen(loc, source.getComponent());
             tmp.setLocation( loc.x-dragOffset.x, loc.y-dragOffset.y );
             //let the JNA transparency stuff to kick in
-            tmp.setVisible( true );
-            //make drag window visible, i.e. move to proper location, 
-            //dragImage.setLocation( startingPoint );
-            dragWindow = tmp;
+            try {
+                tmp.setVisible( true );
+                //make drag window visible, i.e. move to proper location,
+                //dragImage.setLocation( startingPoint );
+                dragWindow = tmp;
+            } catch( UnsatisfiedLinkError ulE ) {
+                Logger.getLogger(DragAndDropFeedbackVisualizer.class.getName()).log(Level.INFO, null, ulE);
+            } catch( Throwable ex ) {
+                Logger.getLogger(DragAndDropFeedbackVisualizer.class.getName()).log(Level.FINE, null, ex);
+            }
         }
     }
 
