@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -149,6 +152,7 @@ public abstract class AbstractModeContainer implements ModeContainer {
         tabbedHandler.setActive(active);
     }
     
+    @Override
     public void focusSelectedTopComponent() {
         // PENDING focus gets main window sometimes, investgate and refine (jdk1.4.1?).
         final TopComponent selectedTopComponent = tabbedHandler.getSelectedTopComponent();
@@ -159,46 +163,19 @@ public abstract class AbstractModeContainer implements ModeContainer {
 
         Window oldFocusedW = FocusManager.getCurrentManager().getFocusedWindow();
         Window newFocusedW = SwingUtilities.getWindowAncestor(selectedTopComponent);
-        
-        if ((newFocusedW != null && newFocusedW.equals(oldFocusedW))) {
-            // focus transfer inside one window or system is not active in OS at all
-            // so requestFocusInWindow call is right and enough
-            if (!Utilities.isMac()) {
+        //#177550: Call requestFocus on selected TC only if TC is in AWT hierarchy
+        if (newFocusedW != null) {
+            if (newFocusedW.equals(oldFocusedW)) {
+                // focus transfer inside one window or system is not active in OS at all
+                // so requestFocusInWindow call is right and enough
                 selectedTopComponent.requestFocusInWindow();
             } else {
-                //#60235 - on macosx 1.5 there seems to be a bug with requesting focus.
-                // this piece of code seems to workaround most of the usecases in 60235
-                SwingUtilities.invokeLater(new Runnable() {
-                    public void run() {
-                        //#62947 another workaround for macosx 1.5 focus behaviour.
-                        // when maximizing the mode, the old and new focused component is the same, but removed from
-                        // awt hierarchy and added elsewhere.
-                        // the DefautlkeyboardFocusmanager doen't do it's job then and locks the keyboard.
-                        // hack it by make it believe the focus changed.
-                        try {
-                            Field fld = KeyboardFocusManager.class.getDeclaredField("focusOwner");//NOI18N
-                            fld.setAccessible(true);
-                            fld.set(KeyboardFocusManager.getCurrentKeyboardFocusManager(), null);
-                        } catch (IllegalArgumentException ex) {
-                            ex.printStackTrace();
-                        } catch (SecurityException ex) {
-                            ex.printStackTrace();
-                        } catch (NoSuchFieldException ex) {
-                            ex.printStackTrace();
-                        } catch (IllegalAccessException ex) {
-                            ex.printStackTrace();
-                        }
-                        //#62947 hack finished.
-                        selectedTopComponent.requestFocusInWindow();
-                    }
-                });
+                // focus transfer between different windows
+                newFocusedW.toFront();
+                selectedTopComponent.requestFocus();
             }
-        } else {
-            // focus transfer between different windows
-            selectedTopComponent.requestFocus();
         }
     }
-
     
     public TopComponent[] getTopComponents() {
         return tabbedHandler.getTopComponents();
