@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -98,7 +101,14 @@ public final class DesktopImpl {
         layeredPane = new JLayeredPane();
         layeredPane.setLayout(new LayeredLayout());
         // desktop represents regular layer of layeredPane
-        desktop = new JPanel();
+        desktop = new JPanel() {
+            @Override
+            public boolean isOpaque() {
+                if( UIManager.getBoolean( "NbMainWindow.showCustomBackground" ) ) //NOI18N
+                    return false;
+                return super.isOpaque();
+            }
+        };
         desktop.setLayout(new GridBagLayout());
         Color bkColor = UIManager.getColor("NbSplitPane.background"); //NOI18N
         if( null != bkColor ) {
