@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -49,7 +52,6 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
-import java.util.Map;
 import javax.swing.*;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
@@ -173,10 +175,7 @@ final class CommandManager implements ActionListener {
     }
     
     public void toggleTransparency( int tabIndex ) {
-        if( isCompSlided() ) {
-            TabbedContainer container = (TabbedContainer)getSlidedComp();
-            container.setTransparent( !container.isTransparent() );
-        }
+        //do nothing, the TabbedContainer will take care of the transparency
     }
     
     public void showPopup(MouseEvent mouseEvent, int tabIndex) {
@@ -218,6 +217,8 @@ final class CommandManager implements ActionListener {
                 if (actions == null) {
                     actions = tc.getActions();
                 }
+                if (actions == null || actions.length == 0 )
+                    return;
                 
                 showPopupMenu(
                     Utilities.actionsToPopup(actions, tc.getLookup()), tae.getMouseEvent().getPoint(), tae.getMouseEvent().getComponent());
@@ -281,9 +282,13 @@ final class CommandManager implements ActionListener {
     private TabbedContainer getSlidedTabContainer () {
         if (slidedTabContainer == null) {
             TabDataModel slidedCompModel = new DefaultTabDataModel();
-            slidedTabContainer = new TabbedContainer(slidedCompModel, TabbedContainer.TYPE_VIEW, slideBar);
+            slidedTabContainer = new TabbedContainer(slidedCompModel, TabbedContainer.TYPE_VIEW, slideBar.createWinsysInfo());
             slidedTabContainer.addActionListener(this);
-            Border b = (Border) UIManager.get ("floatingBorder"); //NOI18N
+            Border b = null;
+            String side = orientation2Side( slideBar.getModel().getOrientation() );
+            b = UIManager.getBorder("floatingBorder-"+side); //NOI18N
+            if( b == null )
+                b = UIManager.getBorder("floatingBorder"); //NOI18N
             if (b != null) {
                 slidedTabContainer.setBorder (b);
             }
@@ -400,6 +405,8 @@ final class CommandManager implements ActionListener {
                     slidedModel.setText(0, freshText);
                     slideBar.repaint();
                 }
+                curSlideButton = slideBar.getButton(curSlidedIndex);
+                curSlideButton.setSelected(true);
             }
         }
     }
@@ -415,7 +422,7 @@ final class CommandManager implements ActionListener {
     
     private final class EscapeAction extends javax.swing.AbstractAction {
         public void actionPerformed(ActionEvent e) {
-            slideOut(true, true);
+            slideBar.getSelectionModel().setSelectedIndex(-1);
         }
     } // end of EscapeAction
    
