@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -251,22 +254,24 @@ final class DnDSupport implements DragSourceListener, DragGestureListener, DropT
             } else if( Boolean.TRUE.equals( ((JComponent) c).getClientProperty(ToolbarContainer.PROP_DRAGGER) ) ) {
                 //dragging the whole toolbar
                 final ToolbarContainer container = (ToolbarContainer) c.getParent().getParent();
-                sourceContainer = container;
-                sourceRow = (ToolbarRow) container.getParent();
-                t = new ExTransferable.Single(toolbarDataFlavor) {
+                if( container.isShowing() ) {
+                    sourceContainer = container;
+                    sourceRow = (ToolbarRow) container.getParent();
+                    t = new ExTransferable.Single(toolbarDataFlavor) {
 
-                    public Object getData() {
-                        return container;
-                    }
-                };
-                isToolbarDrag = true;
-                isButtonDrag = false;
-                startingPoint = new Point(e.getDragOrigin());
-                Rectangle bounds = new Rectangle(sourceContainer.getPreferredSize());
-                bounds.setLocation(sourceContainer.getLocationOnScreen());
-                dragImage = createContentImage(sourceContainer, bounds.getSize());
-                sourceRow.dragStarted( sourceContainer );
-                dragWindow = createDragWindow( dragImage, bounds );
+                        public Object getData() {
+                            return container;
+                        }
+                    };
+                    isToolbarDrag = true;
+                    isButtonDrag = false;
+                    startingPoint = new Point(e.getDragOrigin());
+                    Rectangle bounds = new Rectangle(sourceContainer.getPreferredSize());
+                    bounds.setLocation(sourceContainer.getLocationOnScreen());
+                    dragImage = createContentImage(sourceContainer, bounds.getSize());
+                    sourceRow.dragStarted( sourceContainer );
+                    dragWindow = createDragWindow( dragImage, bounds );
+                }
             }
             if( c instanceof JButton ) {
                 ((JButton) c).getModel().setArmed(false);
@@ -461,7 +466,7 @@ final class DnDSupport implements DragSourceListener, DragGestureListener, DropT
             }
         }
 
-        DataObject objUnderCursor = getDataObjectUnderDropCursor( dropIndex, dropBefore );
+        DataObject objUnderCursor = getDataObjectUnderDropCursor( dropIndex-1, dropBefore );
 
         DataShadow shadow = DataShadow.create( backingFolder, dobj );
 
@@ -486,7 +491,7 @@ final class DnDSupport implements DragSourceListener, DragGestureListener, DropT
      */
     private boolean moveButton( DataObject ob, int dropIndex, boolean dropBefore ) throws IOException {
         //find out which button is currently under the drag cursor
-        DataObject objUnderCursor = getDataObjectUnderDropCursor( dropIndex, dropBefore );
+        DataObject objUnderCursor = getDataObjectUnderDropCursor( dropIndex-1, dropBefore );
 
         if( sourceToolbar != currentToolbar ) {
             //move button to the new toolbar
