@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -59,6 +62,7 @@ import org.netbeans.modules.csl.api.GsfLanguage;
 import org.netbeans.modules.csl.api.SemanticAnalyzer;
 import org.netbeans.modules.csl.api.KeystrokeHandler;
 import org.netbeans.modules.csl.api.Formatter;
+import org.netbeans.modules.csl.api.OverridingMethods;
 import org.netbeans.modules.csl.api.StructureScanner;
 import org.netbeans.modules.csl.spi.DefaultLanguageConfig;
 import org.netbeans.modules.csl.editor.semantic.ColoringManager;
@@ -99,6 +103,7 @@ public final class Language {
     private KeystrokeHandler keystrokeHandler;
     private EmbeddingIndexerFactory indexerFactory;
     private StructureScanner structure;
+    private OverridingMethods overridingMethods;
     private HintsProvider hintsProvider;
     private GsfHintsManager hintsManager;
     private IndexSearcher indexSearcher;
@@ -114,6 +119,7 @@ public final class Language {
     private FileObject keystrokeHandlerFile;
     private FileObject indexerFile;
     private FileObject structureFile;
+    private FileObject overridingMethodsFile;
     private FileObject hintsProviderFile;
     //private FileObject paletteFile;
     private FileObject semanticFile;
@@ -738,4 +744,31 @@ public final class Language {
         }
         return binaryLibraryPathIds;
     }
+
+    /**
+     * Return the overriding methods computer for this language
+     */
+    @NonNull
+    public OverridingMethods getOverridingMethods() {
+        if (overridingMethods == null) {
+            if (overridingMethodsFile != null) {
+                overridingMethods = (OverridingMethods)createInstance(overridingMethodsFile);
+                if (overridingMethods == null) {
+                    // Don't keep trying
+                    overridingMethodsFile = null;
+                }
+            } else {
+                getGsfLanguage(); // Also initializes languageConfig
+                if (languageConfig != null) {
+                    overridingMethods = languageConfig.getOverridingMethods();
+                }
+            }
+        }
+        return overridingMethods;
+    }
+
+    void setOverridingMethodsFile(FileObject fo) {
+        this.overridingMethodsFile = fo;
+    }
+
 }
