@@ -1,8 +1,11 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
- * 
- * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
- * 
+ *
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
+ *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
  * Development and Distribution License("CDDL") (collectively, the
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -39,14 +42,16 @@
 package org.netbeans.modules.css.editor;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.Stack;
 import java.util.logging.Logger;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.netbeans.modules.css.editor.CssPropertyValue.ResolveContext.ResolveType;
 import org.netbeans.modules.css.editor.PropertyModel.Element;
 import org.netbeans.modules.css.editor.PropertyModel.GroupElement;
@@ -70,10 +75,27 @@ public class CssPropertyValue {
     private final String propertyDefinition;
     Stack<String> originalStack;
     final StringBuffer log = new StringBuffer();
+    private static final Pattern FILTER_COMMENTS_PATTERN = Pattern.compile("/\\*.*?\\*/");//NOI18N
+
+    private static String filterComments(String text) {
+        Matcher m = FILTER_COMMENTS_PATTERN.matcher(text);
+        StringBuilder b = new StringBuilder(text);
+        while (m.find()) {
+            int from = m.start();
+            int to = m.end();
+            if (from != to) {
+                char[] spaces = new char[to-from];
+                Arrays.fill(spaces, ' ');
+                String replacement = new String(spaces);
+                b.replace(from, to, replacement);
+            }
+        }
+        return b.toString();
+    }
 
     public CssPropertyValue(Property property, String textOfTheValue) {
         this.groupElement = property.values();
-        this.text = textOfTheValue;
+        this.text = filterComments(textOfTheValue);
         this.propertyDefinition = null;
         consume();
     }
