@@ -1,8 +1,11 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
- * 
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
- * 
+ *
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
+ *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
  * Development and Distribution License("CDDL") (collectively, the
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -43,6 +46,7 @@ import javax.swing.text.Document;
 import org.netbeans.api.lexer.TokenHierarchy;
 import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.modules.css.lexer.api.CssTokenId;
+import org.netbeans.modules.parsing.api.Snapshot;
 
 /**
  *
@@ -131,4 +135,27 @@ public class LexerUtils {
         return null;
 
     }
+
+    public static int findNearestMappableSourcePosition(Snapshot snapshot, int position, boolean forward, int limit) {
+        if(forward) {
+            int boundary = Math.max(snapshot.getText().length(), position + limit);
+            for (int i = position; i < boundary; i++) {
+                int original = snapshot.getOriginalOffset(i);
+                if(original != -1) {
+                    return original;
+                }
+            }
+        } else {
+            //backward
+            int boundary = Math.min(0, position - limit);
+            for (int i = position; i >= boundary; i--) {
+                int original = snapshot.getOriginalOffset(i);
+                if(original != -1) {
+                    return original;
+                }
+            }
+        }
+        return -1;
+    }
+
 }
