@@ -214,16 +214,16 @@ public class LexUtilities {
         ts.moveEnd();
         ts.movePrevious();
         int offset = ts.offset() + ts.token().length();
-        ts.move(currentIndex);
+        ts.moveIndex(currentIndex);
         return offset;
     }
 
     public static int getTokenSequenceEndOffset(JoinedTokenSequence<? extends TokenId> ts) {
-        int currentIndex = ts.index();
+        int[] currentIndex = ts.index();
         ts.moveEnd();
         ts.movePrevious();
         int offset = ts.offset() + ts.token().length();
-        ts.move(currentIndex);
+        ts.moveIndex(currentIndex);
         return offset;
     }
 
@@ -232,21 +232,21 @@ public class LexUtilities {
         ts.moveStart();
         ts.moveNext();
         int offset = ts.offset();
-        ts.move(currentIndex);
+        ts.moveIndex(currentIndex);
         return offset;
     }
 
     public static int getTokenSequenceStartOffset(JoinedTokenSequence<? extends TokenId> ts) {
-        int currentIndex = ts.index();
+        int[] currentIndex = ts.index();
         ts.moveStart();
         ts.moveNext();
         int offset = ts.offset();
-        ts.move(currentIndex);
+        ts.moveIndex(currentIndex);
         return offset;
     }
 
     public static <T1 extends TokenId> Token<T1> getTokenAtOffset(JoinedTokenSequence<T1> ts, int offset) {
-        int currentIndex = ts.index();
+        int[] currentIndex = ts.index();
         ts.move(offset);
         ts.moveNext();
         Token<T1> t = ts.token();
@@ -266,10 +266,12 @@ public class LexUtilities {
         List<TokenSequence<T1>> tss = new ArrayList<TokenSequence<T1>>();
         for (LanguagePath lp : lps) {
             List<TokenSequence<?>> tss2 = th.tokenSequenceList(lp, start, end);
-            for (TokenSequence<?> ts2 : tss2) {
-                ts2.moveStart();
-                if (ts2.moveNext()) {
-                    tss.add((TokenSequence<T1>)ts2);
+            if (tss2 != null) {
+                for (TokenSequence<?> ts2 : tss2) {
+                    ts2.moveStart();
+                    if (ts2.moveNext()) {
+                        tss.add((TokenSequence<T1>)ts2);
+                    }
                 }
             }
         }
