@@ -1,8 +1,11 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
- * 
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
- * 
+ *
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
+ *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
  * Development and Distribution License("CDDL") (collectively, the
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -97,6 +100,14 @@ public class CssSemanticAnalyzer extends  SemanticAnalyzer {
             public void visit(SimpleNode node) {
                 if (node.kind() == CssParserTreeConstants.JJTELEMENTNAME || node.kind() == CssParserTreeConstants.JJT_CLASS || node.kind() == CssParserTreeConstants.JJTPSEUDO || node.kind() == CssParserTreeConstants.JJTHASH || node.kind() == CssParserTreeConstants.JJTATTRIB) {
                     int dso = snapshot.getOriginalOffset(node.startOffset());
+                    if(dso == -1) {
+                        //try next offset - for virtually created class and id
+                        //selectors the . an # prefix are virtual code and is not
+                        //a part of the source document, try to highlight just
+                        //the class or id name
+                        dso = snapshot.getOriginalOffset(node.startOffset() + 1);
+                    }
+
                     int deo =snapshot.getOriginalOffset(node.endOffset());
                     //filter out generated and inlined style definitions - they have just virtual selector which
                     //is mapped to empty string
