@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,7 +44,6 @@
 package org.netbeans.modules.css.lexer.api;
 
 import java.util.Collection;
-import java.util.Collections;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.Map;
@@ -50,7 +52,7 @@ import org.netbeans.api.lexer.Language;
 import org.netbeans.api.lexer.LanguagePath;
 import org.netbeans.api.lexer.Token;
 import org.netbeans.api.lexer.TokenId;
-import org.netbeans.modules.css.editor.Css;
+import org.netbeans.modules.css.gsf.CssLanguage;
 import org.netbeans.modules.css.lexer.CssLexer;
 import org.netbeans.spi.lexer.LanguageEmbedding;
 import org.netbeans.spi.lexer.LanguageHierarchy;
@@ -109,6 +111,9 @@ public enum CssTokenId implements TokenId {
     CDO("whitespace"),
     CDC("whitespace"),
     INCLUDES("operator"),
+    CSS3_BEGINS("operator"),
+    CSS3_ENDS("operator"),
+    CSS3_CONTAINS("operator"),
     DASHMATCH("operator"),
     IMPORT_SYM("keyword"),
     PAGE_SYM("keyword"),
@@ -139,7 +144,7 @@ public enum CssTokenId implements TokenId {
     RGB("others"),
     FUNCTION("function"),
     IDENT("identifier"),
-    NAME("others"),
+    NAME("mod-custom1"),
     NUM("number"),
     UNICODERANGE("others"),
     RANGE("others"),
@@ -151,7 +156,7 @@ public enum CssTokenId implements TokenId {
     Q11("others"),
     NMSTART("others"),
     NMCHAR("others"),
-    SELECTOR_NMSTART("others"),
+    SELECTOR_NMSTART("mod-method"),
     SELECTOR_NMCHAR("others"),
     STRING1("string"),
     STRING2("string"),
@@ -217,7 +222,7 @@ public enum CssTokenId implements TokenId {
 
         @Override
         protected String mimeType() {
-            return Css.CSS_MIME_TYPE;
+            return CssLanguage.CSS_MIME_TYPE;
         }
     }.language();
 
