@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -719,4 +722,34 @@ public class PropertyModelTest extends TestBase {
         assertTrue(csspv.success());
 
     }
+
+    public void testCommnetsInValue() {
+        Property p = PropertyModel.instance().getProperty("border-color");
+        String text = "red /* comment */ yellow black yellow";
+
+        CssPropertyValue csspv = new CssPropertyValue(p, text);
+
+        dumpResult(csspv);
+
+        assertTrue(csspv.success());
+    }
+
+    public void testBorder_Top_Style() {
+        Property p = PropertyModel.instance().getProperty("border-top-style");
+
+        CssPropertyValue csspv = new CssPropertyValue(p, "dotted dotted dashed dashed");
+        assertFalse(csspv.success());
+
+        csspv = new CssPropertyValue(p, "dotted");
+        assertTrue(csspv.success());
+
+    }
+
+    public void testIssue185995() {
+        Property p = PropertyModel.instance().getProperty("border-color");
+
+        CssPropertyValue csspv = new CssPropertyValue(p, "transparent transparent");
+        assertTrue(csspv.success());
+
+    }
 }
