@@ -74,7 +74,7 @@ import org.openide.util.NbBundle;
  */
 public class BorderStyleEditor extends StyleEditor {
 
-    BorderDataTable borderDataTable = new BorderDataTable();
+    BorderDataTable borderDataTable;
 
     /** Creates new form FontStyleEditor */
     public BorderStyleEditor() {
@@ -83,6 +83,7 @@ public class BorderStyleEditor extends StyleEditor {
 
     @Override
     protected void lazyInitializePanel() {
+        borderDataTable = new BorderDataTable();
         initComponents();
         borderPanel.add(borderDataTable, BorderLayout.CENTER);
     }
@@ -250,13 +251,13 @@ public class BorderStyleEditor extends StyleEditor {
             allStyleCombo.addItemListener(new ItemListener() {
 
                 public void itemStateChanged(ItemEvent evt) {
-                    CssEditorSupport.getDefault().firstAggregatedEventWillFire();
+                    startAggregatedEventsSession();
                     //cssPropertyChangeSupport().firePropertyChange(CssStyleData.BORDER_STYLE, null, allStyleCombo.getSelectedItem().toString());
                     topStyleCombo.setSelectedIndex(allStyleCombo.getSelectedIndex());
                     bottomStyleCombo.setSelectedIndex(allStyleCombo.getSelectedIndex());
                     leftStyleCombo.setSelectedIndex(allStyleCombo.getSelectedIndex());
                     rightStyleCombo.setSelectedIndex(allStyleCombo.getSelectedIndex());
-                    CssEditorSupport.getDefault().lastAggregatedEventFired();
+                    closeAggregatedEventsSession();
                 }
             });
 
@@ -269,13 +270,13 @@ public class BorderStyleEditor extends StyleEditor {
 
                 //NOI18N
                 public void propertyChange(PropertyChangeEvent evt) {
-                    CssEditorSupport.getDefault().firstAggregatedEventWillFire();
+                    startAggregatedEventsSession();
                     //cssPropertyChangeSupport().firePropertyChange(CssStyleData.BORDER_WIDTH, null, evt.getNewValue().toString());
                     topWidthField.setWidthString(evt.getNewValue().toString());
                     bottomWidthField.setWidthString(evt.getNewValue().toString());
                     leftWidthField.setWidthString(evt.getNewValue().toString());
                     rightWidthField.setWidthString(evt.getNewValue().toString());
-                    CssEditorSupport.getDefault().lastAggregatedEventFired();
+                    closeAggregatedEventsSession();
                 }
             });
 
@@ -286,13 +287,13 @@ public class BorderStyleEditor extends StyleEditor {
 
                 //NOI18N
                 public void propertyChange(PropertyChangeEvent evt) {
-                    CssEditorSupport.getDefault().firstAggregatedEventWillFire();
+                    startAggregatedEventsSession();
                     //cssPropertyChangeSupport().firePropertyChange(CssStyleData.BORDER_COLOR, null, allColorField.getColorString());
                     topColorField.setColorString(allColorField.getColorString());
                     bottomColorField.setColorString(allColorField.getColorString());
                     leftColorField.setColorString(allColorField.getColorString());
                     rightColorField.setColorString(allColorField.getColorString());
-                    CssEditorSupport.getDefault().lastAggregatedEventFired();
+                    closeAggregatedEventsSession();
                 }
             });
 
