@@ -92,6 +92,8 @@ import org.openide.loaders.MultiDataObject;
 import org.openide.text.CloneableEditor;
 import org.openide.util.Exceptions;
 import org.openide.util.Mutex;
+import org.openide.util.Task;
+import org.openide.util.TaskListener;
 import org.openide.windows.CloneableOpenSupport;
 
 /** 
@@ -136,6 +138,7 @@ public class SQLEditorSupport extends DataEditorSupport
      * data object's cookie set depending on if modification flag was set/unset. 
      */
     private final SaveCookie saveCookie = new SaveCookie() {
+        @Override
         public void save() throws IOException {
             saveDocument();
         }
@@ -164,6 +167,11 @@ public class SQLEditorSupport extends DataEditorSupport
         return true;
     }
 
+    @Override
+    protected boolean asynchronousOpen() {
+        return false;
+    }
+
     @Override
     protected void notifyUnmodified () {
         super.notifyUnmodified();
@@ -286,15 +294,18 @@ public class SQLEditorSupport extends DataEditorSupport
         return dbconn;
     }
     
+    @Override
     public synchronized void setDatabaseConnection(DatabaseConnection dbconn) {
         this.dbconn = dbconn;
         sqlPropChangeSupport.firePropertyChange(SQLExecution.PROP_DATABASE_CONNECTION, null, null);
     }
     
+    @Override
     public DatabaseConnection getDatabaseConnection() {
         return dbconn;
     }
 
+    @Override
     public void execute() {
         Document doc = getDocument();
         if (doc == null) {
@@ -350,9 +361,19 @@ public class SQLEditorSupport extends DataEditorSupport
             return;
         }
         SQLExecutor executor = new SQLExecutor(this, conn, sql, startOffset, endOffset);
-        RequestProcessor.Task task = rp.create(executor);
+        final RequestProcessor.Task task = rp.create(executor);
         executor.setTask(task);
         task.schedule(0);
+        if ((sql.toUpperCase().indexOf("CREATE") != -1) || (sql.toUpperCase().indexOf("DROP") != -1)) { // NOI18N
+            task.addTaskListener(new TaskListener() {
+                @Override
+                public void taskFinished(Task task) {
+                    task.removeTaskListener(this);
+                    refresh();
+                }
+
+            });
+        }
     }
     
     synchronized boolean isExecuting() {
@@ -366,6 +387,7 @@ public class SQLEditorSupport extends DataEditorSupport
     
     private void setResultsToEditors(final SQLExecutionResults results) {
        Mutex.EVENT.writeAccess(new Runnable() {
+            @Override
             public void run() {
                 List<Component> components = null;
                 
@@ -397,6 +419,7 @@ public class SQLEditorSupport extends DataEditorSupport
         setResultsToEditors(null);
         
         Runnable run = new Runnable() {
+            @Override
             public void run() {
                 if (executionResults != null) {
                     executionResults = null;
@@ -417,6 +440,13 @@ public class SQLEditorSupport extends DataEditorSupport
         }
     }
     
+    private void refresh() {
+        if (dbconn == null) {
+            return ;
+        }
+        ConnectionManager.getDefault().refreshConnectionInExplorer(dbconn);
+    }
+    
     private SQLExecutionLoggerImpl createLogger() {
         closeLogger();
         
@@ -470,6 +500,7 @@ public class SQLEditorSupport extends DataEditorSupport
             this.task = task;
         }
         
+        @Override
         public void run() {
             assert task != null : "Should have called setTask()"; // NOI18N
             
@@ -481,6 +512,7 @@ public class SQLEditorSupport extends DataEditorSupport
                 }
 
                 Mutex.EVENT.readAccess(new Mutex.Action<Void>() {
+                    @Override
                     public Void run() {
                         ConnectionManager.getDefault().showConnectionDialog(dbconn);
                         return null;
@@ -498,6 +530,7 @@ public class SQLEditorSupport extends DataEditorSupport
                 // need to save the document, otherwise the Line.Set.getOriginal mechanism does not work
                 try {
                     Mutex.EVENT.readAccess(new Mutex.ExceptionAction<Void>() {
+                        @Override
                         public Void run() throws Exception {
                             parent.saveDocument();
                             return null;
@@ -570,6 +603,7 @@ public class SQLEditorSupport extends DataEditorSupport
             StatusDisplayer.getDefault().setStatusText(statusText);
         }
         
+        @Override
         public boolean cancel() {
             return task.cancel();
         }
@@ -591,10 +625,12 @@ public class SQLEditorSupport extends DataEditorSupport
             super(obj);
         }
 
+        @Override
         protected FileObject getFile() {
             return getDataObject().getPrimaryFile();
         }
 
+        @Override
         protected FileLock takeLock() throws IOException {
             MultiDataObject obj = (MultiDataObject)getDataObject();
             fileLock = obj.getPrimaryEntry().takeLock();
