@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -24,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -41,6 +44,7 @@
 package org.netbeans.modules.db.dataview.util;
 
 import org.netbeans.modules.db.dataview.meta.DBException;
+import org.openide.util.NbBundle;
 
 public class BinaryToStringConverter {
 
@@ -149,7 +153,7 @@ public class BinaryToStringConverter {
 
     public static byte[] convertBitStringToBytes(String s) throws DBException {
         int shtBits = s.length() % 8;
-        s = (shtBits > 0 ? "00000000".substring(0, 8 - shtBits) + s : s);
+        s = (shtBits > 0 ? "00000000".substring(0, 8 - shtBits) + s : s); // NOI18N
 
         byte[] buf = new byte[s.length() / 8];
 
@@ -159,7 +163,7 @@ public class BinaryToStringConverter {
                 int b = 1 << (7 - bit);
                 buf[index] |= b;
             } else if ('0' != s.charAt(i)) { // NOI18N
-                throw new DBException(s.charAt(i) + "found at character " + i + "; 0 or 1 expected. ");
+                throw new DBException(NbBundle.getMessage(BinaryToStringConverter.class, "BinaryToStringConverter_InvalidBitFormat", s.charAt(i), i)); // NOI18N
             }
             bit++;
             if (bit > 7) {
