@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2008 - 2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2008 - 2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -37,23 +37,25 @@
  *
  * Contributor(s):
  *
- * Portions Copyrighted 2009 Sun Microsystems, Inc.
+ * Portions Copyrighted 2009-2010 Sun Microsystems, Inc.
  */
-
 package org.netbeans.modules.db.metadata.model.jdbc.oracle;
 
 import java.sql.DatabaseMetaData;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.netbeans.modules.db.metadata.model.api.MetadataException;
+import org.netbeans.modules.db.metadata.model.api.Procedure;
 import org.netbeans.modules.db.metadata.model.api.Table;
 import org.netbeans.modules.db.metadata.model.jdbc.JDBCCatalog;
 import org.netbeans.modules.db.metadata.model.jdbc.JDBCSchema;
@@ -81,8 +83,8 @@ public class OracleSchema extends JDBCSchema {
         Map<String, Table> newTables = new LinkedHashMap<String, Table>();
         try {
             DatabaseMetaData dmd = jdbcCatalog.getJDBCMetadata().getDmd();
-            Set<String> recycleBinTables = getRecycleBinTables(dmd);
-            ResultSet rs = dmd.getTables(jdbcCatalog.getName(), name, "%", new String[] { "TABLE" }); // NOI18N
+            Set<String> recycleBinTables = getRecycleBinObjects(dmd, "TABLE"); // NOI18N
+            ResultSet rs = dmd.getTables(jdbcCatalog.getName(), name, "%", new String[]{"TABLE"}); // NOI18N
             try {
                 while (rs.next()) {
                     String tableName = rs.getString("TABLE_NAME"); // NOI18N
@@ -103,35 +105,80 @@ public class OracleSchema extends JDBCSchema {
         tables = Collections.unmodifiableMap(newTables);
     }
 
-    private Set<String> getRecycleBinTables(DatabaseMetaData dmd) {
+    private Set<String> getRecycleBinObjects(DatabaseMetaData dmd, String... types) {
         String driverName = null;
         String driverVer = null;
+        List<String> emptyList = Collections.emptyList();
+        Set<String> result = new HashSet<String>();
         try {
             driverName = dmd.getDriverName();
             driverVer = dmd.getDriverVersion();
-            if (dmd.getDatabaseMajorVersion() < 10) {
+            int databaseMajorVersion = 0;
+            try {
+                databaseMajorVersion = dmd.getDatabaseMajorVersion();
+            } catch (UnsupportedOperationException use) {
+                LOGGER.log(Level.FINEST, "getDatabaseMajorVersion() on " + dmd, use);
+            }
+            if (databaseMajorVersion < 10 || types == null) {
                 return Collections.emptySet();
             }
-            Set<String> result = new HashSet<String>();
             Statement stmt = dmd.getConnection().createStatement();
+            ResultSet rs = null;
             try {
-                ResultSet rs = stmt.executeQuery("SELECT OBJECT_NAME FROM RECYCLEBIN WHERE TYPE = 'TABLE'"); // NOI18N
+                rs = stmt.executeQuery("SELECT OBJECT_NAME, TYPE FROM SYS.DBA_RECYCLEBIN"); // NOI18N
+            } catch (SQLException ex) {
+                LOGGER.log(Level.FINE, ex.getMessage(), ex); 
+                // try both
+                rs = stmt.executeQuery("SELECT OBJECT_NAME, TYPE FROM RECYCLEBIN"); // NOI18N
+            }
+            if (rs != null) {
+                List<String> typesL = types == null ? emptyList : Arrays.asList(types);
                 try {
                     while (rs.next()) {
-                        result.add(rs.getString("OBJECT_NAME")); // NOI18N
+                        String type = rs.getString("TYPE"); // NOI18N
+                        if (typesL.isEmpty() || typesL.contains(type)) {
+                            result.add(rs.getString("OBJECT_NAME")); // NOI18N
+                        }
                     }
                 } finally {
                     rs.close();
                 }
-            } finally {
-                stmt.close();
             }
-            return result;
-        } catch (AbstractMethodError ame) {
-            LOGGER.log(Level.INFO, "Error while analyzing the recycle bin. JDBC Driver: " + driverName + "(" + driverVer + ")", ame);
-        } catch (SQLException e) {
+        } catch (Exception e) {
             LOGGER.log(Level.INFO, "Error while analyzing the recycle bin. JDBC Driver: " + driverName + "(" + driverVer + ")", e);
         }
-        return Collections.emptySet();
+        return result;
+    }
+
+    @Override
+    protected void createProcedures() {
+        LOGGER.log(Level.FINE, "Initializing Oracle procedures in {0}", this);
+        Map<String, Procedure> newProcedures = new LinkedHashMap<String, Procedure>();
+        try {
+            DatabaseMetaData dmd = jdbcCatalog.getJDBCMetadata().getDmd();
+            Statement stmt = dmd.getConnection().createStatement();
+            Set<String> recycleBinObjects = getRecycleBinObjects(dmd, "TRIGGER", "FUNCTION", "PROCEDURE"); // NOI18N
+            ResultSet rs = stmt.executeQuery("SELECT OBJECT_NAME, OBJECT_TYPE, STATUS FROM SYS.ALL_OBJECTS WHERE OWNER='" + name + "'" // NOI18N
+                    + " AND ( OBJECT_TYPE = 'PROCEDURE' OR OBJECT_TYPE = 'TRIGGER' OR OBJECT_TYPE = 'FUNCTION' )"); // NOI18N
+            try {
+                while (rs.next()) {
+                    String procedureName = rs.getString("OBJECT_NAME"); // NOI18N
+                    Procedure procedure = createJDBCProcedure(procedureName).getProcedure();
+                    if (!recycleBinObjects.contains(procedureName)) {
+                        newProcedures.put(procedureName, procedure);
+                        LOGGER.log(Level.FINE, "Created Oracle procedure: {0}, type: {1}, status: {2}", new Object[]{procedure, rs.getString("OBJECT_TYPE"), rs.getString("STATUS")});
+                    } else {
+                        LOGGER.log(Level.FINEST, "Oracle procedure found id RECYCLEBIN: {0}, type: {1}, status: {2}", new Object[]{procedure, rs.getString("OBJECT_TYPE"), rs.getString("STATUS")});
+                    }
+                }
+            } finally {
+                if (rs != null) {
+                    rs.close();
+                }
+            }
+        } catch (SQLException e) {
+            throw new MetadataException(e);
+        }
+        procedures = Collections.unmodifiableMap(newProcedures);
     }
 }
