@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2010-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -42,7 +42,6 @@
 
 package org.netbeans.modules.db.mysql.ui;
 
-import java.awt.Color;
 import java.awt.Dialog;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -57,7 +56,6 @@ import java.util.logging.Logger;
 import javax.swing.ComboBoxModel;
 import javax.swing.JButton;
 import javax.swing.SwingUtilities;
-import javax.swing.UIManager;
 import javax.swing.event.ListDataListener;
 import org.netbeans.api.db.explorer.ConnectionManager;
 import org.netbeans.api.db.explorer.DatabaseConnection;
@@ -90,7 +88,6 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
     private final DatabaseServer server;
     private final DatabaseComboModel databaseComboModel;
     private DatabaseConnection dbconn;
-    private Color nbErrorForeground;
     private JButton okButton;
     private JButton cancelButton;
     
@@ -102,7 +99,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
         String error = null;
 
         comboUsers.setEnabled(this.isGrantAccess());
-                
+        
         if ( Utils.isEmpty(databaseName) ) {
             error = NbBundle.getMessage(CreateDatabasePanel.class,
                         "CreateNewDatabasePanel.MSG_SpecifyDatabase");
@@ -145,6 +142,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
     private void setProgress(final boolean start) {
         SwingUtilities.invokeLater(new Runnable() {
 
+            @Override
             public void run() {
                 comboDatabaseName.setEnabled(!start);
                 okButton.setEnabled(okButton.isEnabled() && !start);
@@ -172,6 +170,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
         ActionListener listener = new ActionListener() {
             Task task;
 
+            @Override
             public void actionPerformed(ActionEvent e) {
                 if (e.getSource().equals(okButton)) {
                     if (task != null && !task.isFinished()) {
@@ -182,6 +181,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
                     startProgress();
 
                     task = RequestProcessor.getDefault().create(new Runnable() {
+                        @Override
                         public void run() {
                             createDatabase();
                             if (isGrantAccess()) {
@@ -191,6 +191,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
                     });
 
                     task.addTaskListener(new TaskListener() {
+                        @Override
                         public void taskFinished(org.openide.util.Task task) {
                             stopProgress();
                             dialog.dispose();
@@ -241,6 +242,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
      * Create a database based on settings of the dialog.  Set the member
      * variable dbconn to the resulting Database Connection.
      */
+    @SuppressWarnings("SleepWhileInLoop")
     private void createDatabase() {
 
         dbconn = null;
@@ -252,15 +254,27 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
                 return;
             }
 
-            if ( ! checkExistingDatabase(server, getDatabaseName()) ) {
+            if ( ! checkExistingDatabase(server, dbname) ) {
                 return;
             }
 
             server.createDatabase(dbname);
             
-            dbCreated = true;
+            int timeout = 30;
+            
+            while (timeout-- > 0 && ! server.databaseExists(dbname)) {
+                try {
+                    Thread.sleep(300);
+                } catch (InterruptedException ex) {
+                    LOGGER.log(Level.FINEST, ex.getMessage(), ex);
+                }
+            }
+            
+            dbCreated = server.databaseExists(dbname);
                            
-            dbconn = createConnection(server, dbname);
+            if (dbCreated) {
+                dbconn = createConnection(server, dbname);
+            }
 
             if (dbconn == null) {
                 return;
@@ -382,12 +396,6 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
     /** Creates new form CreateDatabasePanel */
     public CreateDatabasePanel(DatabaseServer server) throws DatabaseException {
         this.server = server;
-        nbErrorForeground = UIManager.getColor("nb.errorForeground"); //NOI18N
-        if (nbErrorForeground == null) {
-            //nbErrorForeground = new Color(89, 79, 191); // RGB suggested by Bruce in #28466
-            nbErrorForeground = new Color(255, 0, 0); // RGB suggested by jdinga in #65358
-        }
-
         initComponents();
 
         databaseComboModel = new DatabaseComboModel();
@@ -396,6 +404,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
         comboDatabaseName.getEditor().getEditorComponent().addKeyListener(
             new KeyListener() {
 
+            @Override
             public void keyTyped(KeyEvent event) {
                 // Get the actual key.  apparently getItem() doesn't return the current
                 // string typed until *after* this event finishes :(
@@ -411,9 +420,11 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
                 validatePanel(dbname);
             }
 
+            @Override
             public void keyPressed(KeyEvent event) {
             }
 
+            @Override
             public void keyReleased(KeyEvent event) {
                 // Get the actual key.  apparently getItem() doesn't return the current
                 // string typed until *after* this event finishes :(
@@ -583,6 +594,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
         
         private String selected = null;
 
+        @Override
         public void setSelectedItem(Object item) {
             selected = (String)item;
         }
@@ -591,6 +603,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
             return selected != null && selected.startsWith(SAMPLE_PREFIX);
         }
 
+        @Override
         public Object getSelectedItem() {
             if (isSelectedSample()) {
                 // trim off the "Sample database: " string
@@ -602,10 +615,12 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
             }
         }
 
+        @Override
         public int getSize() {
             return sampleNames.size();
         }
 
+        @Override
         public Object getElementAt(int index) {
             if (index < 0) {
                 return null;
@@ -613,23 +628,22 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
             return SAMPLE_PREFIX + sampleNames.get(index).toString();
         }
 
+        @Override
         public void addListDataListener(ListDataListener listener) {
         }
 
+        @Override
         public void removeListDataListener(ListDataListener listener) {
         }
                 
     }
     
     private static class UsersComboModel implements ComboBoxModel {
-        private final DatabaseServer server;
 
         private List<DatabaseUser> users= new ArrayList<DatabaseUser>();
         private DatabaseUser selected;
 
         public UsersComboModel(DatabaseServer server) throws DatabaseException {
-            this.server = server;
-                        
             try {
                 users.addAll(server.getUsers());
                 
@@ -662,6 +676,7 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
             }
         }
 
+        @Override
         public void setSelectedItem(Object item) {
             if (item == null || item.toString().trim().length() == 0) {
                 return;
@@ -672,21 +687,26 @@ public class CreateDatabasePanel extends javax.swing.JPanel {
             }
         }
 
+        @Override
         public Object getSelectedItem() {
             return selected;
         }
 
+        @Override
         public int getSize() {
             return users.size();
         }
 
+        @Override
         public Object getElementAt(int index) {
             return users.get(index);
         }
 
+        @Override
         public void addListDataListener(ListDataListener arg0) {
         }
 
+        @Override
         public void removeListDataListener(ListDataListener arg0) {
         }
 
