@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -79,8 +79,6 @@ public class SQLSyntax extends Syntax {
     private static final int ISA_HASH = 39; // '#' char
 
     private int startQuoteChar = -1;
-    /** MySQL data type (#152751). */
-    private static final String MEDIUMINT = "MEDIUMINT";  //NOI18N
 
     /** 
      * Creates a new instance of SQLSyntax 
@@ -112,7 +110,7 @@ public class SQLSyntax extends Syntax {
                             state = ISA_SLASH;
                             break;
                         case '#':
-                            state = ISA_HASH;
+                                state = ISA_HASH;
                             break;
                         case '=':
                         case '>':
@@ -208,7 +206,7 @@ public class SQLSyntax extends Syntax {
                             offset++;
                         }
                     } else {
-                        if (Character.isLetterOrDigit(actChar) || actChar == '_') {
+                        if (Character.isLetterOrDigit(actChar) || actChar == '_' || actChar == '#') {
                             break;
                         }
                     }
@@ -250,9 +248,16 @@ public class SQLSyntax extends Syntax {
                     if (Character.isWhitespace(actChar)) {
                         // only in MySQL # starts line comment
                         state = ISI_LINE_COMMENT;
+                        if (actChar == '\n') {
+                            return SQLTokenContext.LINE_COMMENT;
+                        }
                     } else {
                         // otherwise it can be identifier (issue 172904)
-                        state = ISI_IDENTIFIER;
+                        if (offset > 1) {
+                            state = ISI_IDENTIFIER;
+                        } else {
+                            state = ISI_LINE_COMMENT;
+                        }
                     }
                     break;
 
@@ -493,7 +498,7 @@ public class SQLSyntax extends Syntax {
     public TokenID matchKeyword(char[] buffer, int offset, int len) {
         String keywordCandidate = new String(buffer, offset, len);
         
-        if (SQLKeywords.isSQL99Keyword(keywordCandidate) || MEDIUMINT.equalsIgnoreCase(keywordCandidate)) {
+        if (SQLKeywords.isSQL99Keyword(keywordCandidate.toUpperCase(), true)) {
             return SQLTokenContext.KEYWORD;
         }
         
