@@ -54,6 +54,11 @@ import org.netbeans.spi.db.explorer.DatabaseRuntime;
 import org.openide.modules.ModuleInstall;
 
 public class DatabaseModule extends ModuleInstall {
+
+    public static final String IDENTIFIER_MYSQL = "MySQL"; // NOI18N
+    public static final String IDENTIFIER_ORACLE = "Oracle"; // NOI18N
+    //public static final String IDENTIFIER_ORACLE_THIN_DRIVER = "Thin"; // NOI18N
+    public static final String IDENTIFIER_ORACLE_OCI_DRIVER = "OCI"; // NOI18N
     
     @Override
     public void close () {
