@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2009 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -44,6 +44,8 @@
 
 package org.netbeans.modules.db.explorer;
 
+import java.awt.Dialog;
+import java.awt.Dimension;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 import java.beans.PropertyVetoException;
@@ -62,6 +64,10 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import javax.swing.JComponent;
+import javax.swing.JDialog;
+import javax.swing.SwingUtilities;
+import org.netbeans.lib.ddl.CommandNotSupportedException;
 import org.openide.util.Lookup;
 import org.openide.util.LookupEvent;
 import org.openide.util.LookupListener;
@@ -73,13 +79,21 @@ import org.netbeans.lib.ddl.DDLException;
 import org.netbeans.api.db.explorer.DatabaseException;
 import org.netbeans.api.db.explorer.JDBCDriver;
 import org.netbeans.api.db.explorer.JDBCDriverManager;
+import org.netbeans.api.keyring.Keyring;
+import org.netbeans.api.progress.ProgressHandle;
+import org.netbeans.api.progress.ProgressHandleFactory;
+import org.netbeans.lib.ddl.impl.Specification;
 
 import org.netbeans.modules.db.ExceptionListener;
 import org.netbeans.modules.db.explorer.action.ConnectAction;
+import org.netbeans.modules.db.explorer.dlg.ConnectProgressDialog;
 import org.netbeans.modules.db.explorer.node.ConnectionNode;
 import org.netbeans.modules.db.explorer.node.DDLHelper;
 import org.netbeans.modules.db.explorer.node.RootNode;
+import org.netbeans.modules.db.metadata.model.api.Action;
+import org.netbeans.modules.db.metadata.model.api.Metadata;
 import org.netbeans.modules.db.metadata.model.api.MetadataModel;
+import org.netbeans.modules.db.metadata.model.api.MetadataModelException;
 import org.netbeans.modules.db.runtime.DatabaseRuntimeManager;
 import org.netbeans.spi.db.explorer.DatabaseRuntime;
 import org.openide.DialogDisplayer;
@@ -88,9 +102,11 @@ import org.openide.explorer.ExplorerManager;
 import org.openide.nodes.Node;
 import org.openide.util.Exceptions;
 import org.openide.util.Mutex;
+import org.openide.util.Parameters;
 import org.openide.util.RequestProcessor;
 import org.openide.util.RequestProcessor.Task;
 import org.openide.windows.TopComponent;
+import org.openide.windows.WindowManager;
 
 
 
@@ -102,7 +118,7 @@ import org.openide.windows.TopComponent;
  * Instances of this class uses explorer option to store information about
  * open connection.
  */
-public class DatabaseConnection implements DBConnection {
+public final class DatabaseConnection implements DBConnection {
 
     private static final Logger LOGGER = Logger.getLogger(DatabaseConnection.class.getName());
     private static final boolean LOG = LOGGER.isLoggable(Level.FINE);
@@ -136,6 +152,8 @@ public class DatabaseConnection implements DBConnection {
     /** Remembers password */
     private Boolean rpwd = Boolean.FALSE;
 
+    private String connectionFileName;
+
     /** The support for firing property changes */
     private PropertyChangeSupport propertySupport;
 
@@ -184,6 +202,7 @@ public class DatabaseConnection implements DBConnection {
     static {
         openConnectionLookupResult = Lookup.getDefault().lookup(new Lookup.Template<OpenConnectionInterface>(OpenConnectionInterface.class));
         openConnectionLookupResult.addLookupListener(new LookupListener() {
+            @Override
             public void resultChanged(LookupEvent ev) {
                 synchronized (DatabaseConnection.class) {
                     openConnectionServices = null;
@@ -191,8 +210,10 @@ public class DatabaseConnection implements DBConnection {
             }
         });
     }
+    private static final RequestProcessor RP = new RequestProcessor(DatabaseConnection.class.getName(), 1);
 
     /** Default constructor */
+    @SuppressWarnings("LeakingThisInConstructor")
     public DatabaseConnection() {
         dbconn = DatabaseConnectionAccessor.DEFAULT.createDatabaseConnection(this);
         propertySupport = new PropertyChangeSupport(this);
@@ -206,26 +227,31 @@ public class DatabaseConnection implements DBConnection {
      * @param password User password
      */
     public DatabaseConnection(String driver, String database, String user, String password) {
-        this(driver, null, database, null, user, password, false);
+        this(driver, null, database, null, user, password, null);
     }
 
     public DatabaseConnection(String driver, String driverName, String database,
             String theschema, String user, String password) {
-        this(driver, driverName, database, theschema, user, password, false);
+        this(driver, driverName, database, theschema, user, password, null);
+    }
+
+    public DatabaseConnection(String driver, String driverName, String database, 
+            String theschema, String user) {
+        this(driver, driverName, database, theschema, user, null, null);
     }
 
     public DatabaseConnection(String driver, String driverName, String database,
             String theschema, String user, String password,
-            boolean rememberPassword) {
+            Boolean rememberPassword) {
         this();
         drv = driver;
         drvname = driverName;
         db = database;
         usr = user;
-        schema = theschema;
         pwd = password;
+        rpwd = rememberPassword == null ? null : Boolean.valueOf(rememberPassword);
+        schema = theschema;
         name = getName();
-        rpwd = Boolean.valueOf(rememberPassword);
     }
 
     public JDBCDriver findJDBCDriver() {
@@ -285,7 +311,7 @@ public class DatabaseConnection implements DBConnection {
                 LOGGER.log(Level.FINE, "Warnings while trying vitality of connection: " + warnings);
             }
             return ! conn.isClosed();
-        } catch (SQLException ex) {
+        } catch (Exception ex) {
             if (dbconn != null) {
                 try {
                     dbconn.disconnect();
@@ -343,12 +369,13 @@ public class DatabaseConnection implements DBConnection {
                  }
              }
          } catch(Exception ex) {
-             Logger.getLogger("global").log(Level.INFO, null, ex);
+             LOGGER.log(Level.INFO, null, ex);
          }
          return openConnection;
      }
 
     /** Returns driver class */
+    @Override
     public String getDriver() {
         return drv;
     }
@@ -357,6 +384,7 @@ public class DatabaseConnection implements DBConnection {
      * Fires propertychange event.
      * @param driver DNew driver URL
      */
+    @Override
     public void setDriver(String driver) {
         if (driver == null || driver.equals(drv)) {
             return;
@@ -368,10 +396,12 @@ public class DatabaseConnection implements DBConnection {
         openConnection = null;
     }
 
+    @Override
     public String getDriverName() {
         return drvname;
     }
 
+    @Override
     public void setDriverName(String name) {
         if (name == null || name.equals(drvname)) {
             return;
@@ -385,6 +415,7 @@ public class DatabaseConnection implements DBConnection {
     }
 
     /** Returns database URL */
+    @Override
     public String getDatabase() {
         if (db == null) {
             db = "";
@@ -397,6 +428,7 @@ public class DatabaseConnection implements DBConnection {
      * Fires propertychange event.
      * @param database New database URL
      */
+    @Override
     public void setDatabase(String database) {
         if (database == null || database.equals(db)) {
             return;
@@ -412,6 +444,7 @@ public class DatabaseConnection implements DBConnection {
     }
 
     /** Returns user login name */
+    @Override
     public String getUser() {
         if (usr == null) {
             usr = "";
@@ -424,6 +457,7 @@ public class DatabaseConnection implements DBConnection {
      * Fires propertychange event.
      * @param user New login name
      */
+    @Override
     public void setUser(String user) {
         if (user == null || user.equals(usr)) {
             return;
@@ -439,6 +473,7 @@ public class DatabaseConnection implements DBConnection {
     }
 
     /** Returns name of the connection */
+    @Override
     public String getName() {
         if(name == null) {
             if((getSchema()==null)||(getSchema().length()==0)) {
@@ -455,6 +490,7 @@ public class DatabaseConnection implements DBConnection {
      * Fires propertychange event.
      * @param value New connection name
      */
+    @Override
     public void setName(String value) {
         if (name == null || name.equals(value)) {
             return;
@@ -467,10 +503,12 @@ public class DatabaseConnection implements DBConnection {
         }
     }
 
+    @Override
     public String getDisplayName() {
         return (displayName != null && displayName.length() > 0) ? displayName : getName();
     }
 
+    @Override
     public void setDisplayName(String value) {
         if ((displayName == null && value == null) || (displayName != null && displayName.equals(value))) {
             return;
@@ -484,11 +522,16 @@ public class DatabaseConnection implements DBConnection {
     }
 
     /** Returns user schema name */
+    @Override
     public String getSchema() {
         if (schema == null) {
             schema = "";
         }
 
+        if (schema.length() == 0) {
+            return defaultSchema == null ? "" : defaultSchema;
+        }
+
         return schema;
     }
 
@@ -496,21 +539,24 @@ public class DatabaseConnection implements DBConnection {
      * Fires propertychange event.
      * @param schema_name New login name
      */
+    @Override
     public void setSchema(String schema_name) {
         if (schema_name == null || schema_name.equals(schema)) {
             return;
         }
 
+        String oldName = getName();
+        name = null;
         String oldschema = schema;
         schema = schema_name;
-        name = null;
         name = getName();
         if (propertySupport != null) {
             propertySupport.firePropertyChange(PROP_SCHEMA, oldschema, schema);
+            propertySupport.firePropertyChange(PROP_NAME, oldName, name);
         }
     }
 
-    public void setDefaultCatalog(String val) throws Exception {
+    public void setDefaultCatalog(String val) throws CommandNotSupportedException, DDLException {
         DDLHelper.setDefaultDatabase(getConnector().getDatabaseSpecification(), val);
         String oldVal = defaultCatalog;
         defaultCatalog = val;
@@ -524,13 +570,21 @@ public class DatabaseConnection implements DBConnection {
         return defaultCatalog;
     }
 
-    public void setDefaultSchema(String val) throws Exception {
-        DDLHelper.setDefaultSchema(getConnector().getDatabaseSpecification(), val);
-        String oldVal = defaultSchema;
-        defaultSchema = val;
+    public void setDefaultSchema(String newDefaultSchema) throws Exception {
+        DDLHelper.setDefaultSchema(getConnector().getDatabaseSpecification(), newDefaultSchema);
+
+        String oldName = name;
+        name = null;
+
+        String oldDefaultSchema = defaultSchema;
+        defaultSchema = newDefaultSchema;
+        
+        name = getName();
 
         if (propertySupport != null) {
-            propertySupport.firePropertyChange(PROP_DEFSCHEMA, oldVal, defaultSchema);
+            propertySupport.firePropertyChange(PROP_DEFSCHEMA, oldDefaultSchema, defaultSchema);
+            propertySupport.firePropertyChange(PROP_SCHEMA, schema, getSchema());
+            propertySupport.firePropertyChange(PROP_NAME, oldName, name);
         }
     }
 
@@ -538,14 +592,147 @@ public class DatabaseConnection implements DBConnection {
         return defaultSchema;
     }
 
+    public void setConnectionFileName(String connectionFileName) {
+        this.connectionFileName = connectionFileName;
+    }
+    
+    private void restorePassword() {
+        if (this.connectionFileName == null) {
+            LOGGER.log(Level.FINE, "No connectionFileName for " + this);
+            pwd = "";
+            rpwd = false;
+            return ;
+        }
+        final String key = this.connectionFileName;
+        waitForReading(new Runnable() {
+            @Override
+            public void run() {
+                // If the password was saved, then it means the user checked
+                // the box to say the password should be remembered.
+                char[] chars = Keyring.read(key);
+                if (chars != null) {
+                    LOGGER.log(Level.FINE, "A password read for " + key);
+                    pwd = String.valueOf(chars);
+                    rpwd = true;
+                } else {
+                    LOGGER.log(Level.FINE, "No password read for " + key);
+                    pwd = "";
+                    rpwd = false;
+                }
+            }
+            
+        });
+    }
+
+    public static void storePassword(final String key, final char[] pwd) {
+        Parameters.notNull("key", key);
+        Parameters.notNull("pwd", pwd);
+        RP.post(new Runnable() {
+
+            @Override
+            public void run() {
+                LOGGER.log(Level.FINE, "Storing password for " + key);
+                Keyring.save(key,
+                        pwd,
+                        NbBundle.getMessage(DatabaseConnectionConvertor.class,
+                            "DatabaseConnectionConvertor.password_description", key)); //NOI18N
+            }
+        });
+    }
+    
+    private void waitForReading(final Runnable toRun) {
+        if (SwingUtilities.isEventDispatchThread()) {
+            showWaitingDialog(toRun);
+        } else {
+            if (keyringTask != null && ! keyringTask.isFinished()) {
+                keyringTask.waitFinished();
+                toRun.run();
+                return ;
+            }            
+            final Object lock = new Object();
+            SwingUtilities.invokeLater(new Runnable() {
+
+                @Override
+                public void run() {
+                    showWaitingDialog(toRun);
+                    synchronized (lock) {
+                        lock.notifyAll();
+                    }
+                }
+            });
+            try {
+                synchronized (lock) {
+                    lock.wait();
+                }
+            } catch (InterruptedException ex) {
+                LOGGER.log(Level.INFO, ex.getMessage(), ex);
+            }
+        }
+    }
+    
+    private RequestProcessor.Task keyringTask = null;
+    
+    private void showWaitingDialog(final Runnable toRun) {
+        assert SwingUtilities.isEventDispatchThread();
+
+        ProgressHandle progress = ProgressHandleFactory.createHandle("keyring");
+        JComponent progressComponent = ProgressHandleFactory.createProgressComponent(progress);
+        progressComponent.setPreferredSize(new Dimension(350, 20));
+        ConnectProgressDialog panel = new ConnectProgressDialog(progressComponent,
+                NbBundle.getMessage(DatabaseConnection.class, "DatabaseConnection_PleaseWaitMessage")); // NOI18N);
+        panel.getAccessibleContext().setAccessibleDescription(NbBundle.getMessage (ConnectAction.class, "ACS_ConnectingDialogTextA11yDesc")); // NOI18N
+        final Dialog d = new JDialog(WindowManager.getDefault().getMainWindow(),
+                                NbBundle.getMessage(DatabaseConnection.class, "DatabaseConnection_PleaseWaitTitle"), // NOI18N
+                                true);
+        d.add(panel);
+        keyringTask = RP.post(new Runnable() {
+
+            @Override
+            public void run() {
+                try {
+                    toRun.run();
+                } finally {
+                    SwingUtilities.invokeLater(new Runnable() {
+
+                        @Override
+                        public void run() {
+                            if (d != null) {
+                                d.setVisible(false);
+                                d.dispose();
+                            }
+                        }
+                    });
+                }
+            }
+        });
+        d.setVisible(true);
+    }
+    
+    public static void deletePassword(final String key) {
+        Parameters.notNull("key", key);
+        RP.post(new Runnable() {
+
+            @Override
+            public void run() {
+                LOGGER.log(Level.FINE, "Deleting password for " + key);
+                Keyring.delete(key);
+            }
+        });
+    }
+    
     /** Returns if password should be remembered */
+    @Override
     public boolean rememberPassword() {
+        if (rpwd == null) {
+            restorePassword();
+        }
         return rpwd.booleanValue();
     }
 
     /** Sets password should be remembered
      * @param flag New flag
      */
+    @Override
     public void setRememberPassword(boolean flag) {
         Boolean oldrpwd = rpwd;
         rpwd = Boolean.valueOf(flag);
@@ -555,14 +742,19 @@ public class DatabaseConnection implements DBConnection {
     }
 
     /** Returns password */
+    @Override
     public String getPassword() {
+        if (pwd == null) {
+            restorePassword();
+        }
         return pwd;
     }
-
+    
     /** Sets password
      * Fires propertychange event.
      * @param password New password
      */
+    @Override
     public void setPassword(String password) {
         if (password == null || password.equals(pwd)) {
             return;
@@ -582,6 +774,7 @@ public class DatabaseConnection implements DBConnection {
      * DDLException if none of driver/database/user/password is set or if
      * driver or database does not exist or is inaccessible.
      */
+    @Override
     public Connection createJDBCConnection() throws DDLException {
         if (LOG) {
             LOGGER.log(Level.FINE, "createJDBCConnection()");
@@ -633,9 +826,7 @@ public class DatabaseConnection implements DBConnection {
             getOpenConnection().disable();
 
             initSQLException(e);
-            DDLException ddle = new DDLException(message);
-            ddle.initCause(e);
-            throw ddle;
+            throw new DDLException(message, e);
         } catch (Exception exc) {
             String message = NbBundle.getMessage (DatabaseConnection.class, "EXC_CannotEstablishConnection", db, drv, exc.getMessage()); // NOI18N
 
@@ -643,10 +834,7 @@ public class DatabaseConnection implements DBConnection {
 
             // For Java Studio Enterprise.
             getOpenConnection().disable();
-
-            DDLException ddle = new DDLException(message);
-            ddle.initCause(exc);
-            throw ddle;
+            throw new DDLException(message, exc);
         }
     }
 
@@ -670,6 +858,7 @@ public class DatabaseConnection implements DBConnection {
             return errorCode;
         }
 
+    @SuppressWarnings("deprecation")
     private void doConnect() throws DDLException {
         if (drv == null || db == null || usr == null ) {
             sendException(new DDLException(NbBundle.getMessage(DatabaseConnection.class, "EXC_InsufficientConnInfo")));
@@ -707,6 +896,15 @@ public class DatabaseConnection implements DBConnection {
             DatabaseUILogger.logConnection(drv);
 
             propertySupport.firePropertyChange("connected", null, null);
+            if (getConnector().getDatabaseSpecification() != null && getConnector().supportsCommand(Specification.DEFAULT_SCHEMA)) {
+                try {
+                    setDefaultSchema(getSchema());
+                } catch (DDLException x) {
+                    LOGGER.log(Level.INFO, x.getLocalizedMessage(), x);
+                } catch (CommandNotSupportedException x) {
+                    LOGGER.log(Level.INFO, x.getLocalizedMessage(), x);
+                }
+            }
         } catch (Exception e) {
             String message = NbBundle.getMessage (DatabaseConnection.class, "EXC_CannotEstablishConnection", // NOI18N
                         db, drv, e.getMessage());
@@ -734,7 +932,7 @@ public class DatabaseConnection implements DBConnection {
                 try {
                     conn.close();
                 } catch (SQLException sqle) {
-                    Logger.getLogger("global").log(Level.WARNING, null, sqle); // NOI18N
+                    LOGGER.log(Level.WARNING, null, sqle); // NOI18N
                 }
             }
 
@@ -755,6 +953,7 @@ public class DatabaseConnection implements DBConnection {
         }
 
         Runnable runnable = new Runnable() {
+            @Override
             public void run() {
                 try {
                     doConnect();
@@ -765,7 +964,7 @@ public class DatabaseConnection implements DBConnection {
             }
         };
 
-        Task task = RequestProcessor.getDefault().post(runnable, 0);
+        Task task = RP.post(runnable, 0);
         return task;
     }
 
@@ -966,12 +1165,43 @@ public class DatabaseConnection implements DBConnection {
             return;
         }
     }
+    
+    public void refreshInExplorer() throws DatabaseException {
+        final ConnectionNode connectionNode = findConnectionNode(getName());
+        if (connectionNode != null) {
+            RP.post(
+                new Runnable() {
+                    @Override
+                    public void run() {
+                        MetadataModel model = getMetadataModel();
+                        if (model != null) {
+                            try {
+                                model.runReadAction(
+                                    new Action<Metadata>() {
+                                        @Override
+                                        public void run(Metadata metaData) {
+                                            metaData.refresh();
+                                        }
+                                    }
+                                );
+                            } catch (MetadataModelException e) {
+                                Exceptions.printStackTrace(e);
+                            }
+                        }
+                        connectionNode.refresh();
+                    }
+                }
+            );
+        }
+    }
 
     public void showConnectionDialog() {
         try {
-            final ConnectionNode cni = findConnectionNode(getName());
+            final ConnectionNode cni = findConnectionNode(getDisplayName());
+            assert cni != null : "DatabaseConnection node found for " + this;
             if (cni != null && cni.getDatabaseConnection().getConnector().isDisconnected()) {
                 Mutex.EVENT.readAccess(new Runnable() {
+                    @Override
                     public void run() {
                         new ConnectAction.ConnectionDialogDisplayer().showDialog(DatabaseConnection.this, false);
                     }
@@ -1028,4 +1258,5 @@ public class DatabaseConnection implements DBConnection {
         }
         return this;
     }
+
 }
