@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -64,7 +64,6 @@ import java.util.WeakHashMap;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.netbeans.api.keyring.Keyring;
 import org.openide.cookies.InstanceCookie;
 import org.openide.filesystems.FileLock;
 import org.openide.filesystems.FileObject;
@@ -82,7 +81,6 @@ import org.openide.util.lookup.AbstractLookup;
 import org.openide.util.lookup.InstanceContent;
 import org.openide.xml.EntityCatalog;
 import org.openide.xml.XMLUtil;
-import org.openide.util.NbBundle;
 import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
@@ -131,6 +129,7 @@ public class DatabaseConnectionConvertor implements Environment.Provider, Instan
     
     private PCL listener;
 
+    // a essential method for testing DB Explorer, don't remove it.
     private static DatabaseConnectionConvertor createProvider() {
         return new DatabaseConnectionConvertor();
     }
@@ -208,6 +207,7 @@ public class DatabaseConnectionConvertor implements Environment.Provider, Instan
                 reader.parse(is);
             } catch (SAXException ex) {
                 Exception x = ex.getException();
+                LOGGER.log(Level.FINE, "Cannot read " + obj + ". Cause: " + ex.getLocalizedMessage(), ex);
                 if (x instanceof java.io.IOException)
                     throw (IOException)x;
                 else
@@ -232,30 +232,17 @@ public class DatabaseConnectionConvertor implements Environment.Provider, Instan
     }
 
     private static DatabaseConnection createDatabaseConnection(Handler handler) {
-        // If the password was saved, then it means the user checked
-        // the box to say the password should be remembered.
-        boolean rememberPassword = false;
-        String password = null;
-        char[] chars = Keyring.read(handler.connectionFileName);
-        if (chars != null) {
-            LOGGER.log(Level.FINE, "A password read for " + handler.connectionFileName);
-            password = String.valueOf(chars);
-            rememberPassword = true;
-        } else {
-            LOGGER.log(Level.FINE, "No password read for " + handler.connectionFileName);
-        }
-
         DatabaseConnection dbconn = new DatabaseConnection(
                 handler.driverClass, 
                 handler.driverName,
                 handler.connectionUrl,
                 handler.schema,
-                handler.user,
-                password,
-                rememberPassword);
+                handler.user);
+        dbconn.setConnectionFileName(handler.connectionFileName);
         if (handler.displayName != null) {
             dbconn.setDisplayName(handler.displayName);
         }
+        LOGGER.fine("Created DatabaseConnection[" + dbconn.toString() + "] from file: " + handler.connectionFileName);
 
         return dbconn;
     }
@@ -410,14 +397,10 @@ public class DatabaseConnectionConvertor implements Environment.Provider, Instan
             }
             if (instance.rememberPassword() ) {
                 char[] password = instance.getPassword() == null ? new char[0] : instance.getPassword().toCharArray();
-
-                // use Keyring API instead Base64.byteArrayToBase64
-                assert name != null : "The parameter name cannot be null.";
-                LOGGER.log(Level.FINE, "Storing password for " + name);
-                Keyring.save(name, password, NbBundle.getMessage(DatabaseConnectionConvertor.class, "DatabaseConnectionConvertor.password_description", name)); //NOI18N
+                
+                DatabaseConnection.storePassword(name, password);
             } else {
-                LOGGER.log(Level.FINE, "Deleting password for " + name);
-                Keyring.delete(name);
+                DatabaseConnection.deletePassword(name);
             }
             pw.println("</connection>"); //NOI18N
         }        
@@ -437,7 +420,7 @@ public class DatabaseConnectionConvertor implements Environment.Provider, Instan
         private static final String ELEMENT_DISPLAY_NAME = "display-name"; // NOI18N
         private static final String ATTR_PROPERTY_VALUE = "value"; // NOI18N
         
-        private final String connectionFileName;
+        final String connectionFileName;
         
         String driverClass;
         String driverName;
@@ -488,11 +471,8 @@ public class DatabaseConnectionConvertor implements Environment.Provider, Instan
                 }
                 if (bytes != null) {
                     try {
-                        // use Keyring API instead Base64.byteArrayToBase64
                         LOGGER.log(Level.FINE, "Reading old settings from " + connectionFileName);
-                        Keyring.save(connectionFileName,
-                                decodePassword(bytes).toCharArray(),
-                                NbBundle.getMessage(DatabaseConnectionConvertor.class, "DatabaseConnectionConvertor.password_description", connectionFileName)); //NOI18N
+                        DatabaseConnection.storePassword(connectionFileName, decodePassword(bytes).toCharArray());
                     } catch (CharacterCodingException e) {
                         LOGGER.log(Level.WARNING,
                                 "Illegal UTF-8 bytes in password for connection " 
