@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,7 +47,6 @@ import java.util.logging.Logger;
 import org.netbeans.modules.db.explorer.DatabaseConnection;
 import org.netbeans.modules.db.explorer.DbUtilities;
 import org.netbeans.modules.db.explorer.dlg.AddTableColumnDialog;
-import org.netbeans.modules.db.explorer.dlg.ColumnItem;
 import org.netbeans.modules.db.explorer.node.TableNode;
 import org.openide.nodes.Node;
 import org.openide.util.HelpCtx;
@@ -76,6 +78,7 @@ public class AddColumnAction extends BaseAction {
     protected void performAction(final Node[] activatedNodes) {
         RequestProcessor.getDefault().post(
             new Runnable() {
+            @Override
                 public void run() {
                     final TableNode node = activatedNodes[0].getLookup().lookup(TableNode.class);
                     final DatabaseConnection connection = node.getLookup().lookup(DatabaseConnection.class);
@@ -86,7 +89,7 @@ public class AddColumnAction extends BaseAction {
                             SystemAction.get(RefreshAction.class).performAction(new Node[]{node});
                         }
                     } catch(Exception exc) {
-                        LOGGER.log(Level.WARNING, null, exc);
+                        LOGGER.log(Level.WARNING, exc.getLocalizedMessage(), exc);
                         DbUtilities.reportError(NbBundle.getMessage (AddColumnAction.class, "ERR_UnableToAddColumn"), exc.getMessage()); // NOI18N
                     }
                 }
