@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2009 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -45,6 +45,7 @@
 package org.netbeans.modules.db.explorer.dlg;
 
 import java.awt.BorderLayout;
+import java.util.Collections;
 import java.util.List;
 import javax.swing.JComponent;
 import javax.swing.SwingUtilities;
@@ -57,8 +58,6 @@ import org.netbeans.modules.db.explorer.DatabaseConnection;
 
 public class SchemaPanel extends javax.swing.JPanel {
 
-    private ConnectionDialogMediator mediator;
-    private DatabaseConnection dbcon;
     private ProgressHandle progressHandle;
     private JComponent progressComponent;
 
@@ -68,8 +67,6 @@ public class SchemaPanel extends javax.swing.JPanel {
      * @param dbcon instance of DatabaseConnection object
      */
     public SchemaPanel(ConnectionDialogMediator mediator, DatabaseConnection dbcon) {
-        this.mediator = mediator;
-        this.dbcon = dbcon;
         initComponents();
         initAccessibility();
 
@@ -216,6 +213,9 @@ public class SchemaPanel extends javax.swing.JPanel {
     }
     
     public boolean setSchemas(List<String> items, String schema) {
+        if (items == null) {
+            items = Collections.emptyList();
+        }
         schemaComboBox.removeAllItems();
         for (int i = 0; i < items.size(); i++)
             schemaComboBox.addItem(items.get(i));
