@@ -37,7 +37,7 @@
  *  
  * Contributor(s):
  * 
- * Portions Copyrighted 2009 Sun Microsystems, Inc.
+ * Portions Copyrighted 2009-2010 Sun Microsystems, Inc.
  */
 
 package org.netbeans.modules.db.explorer.node;
@@ -114,6 +114,8 @@ public class ConnectionNode extends BaseNode {
                     if (evt.getPropertyName().equals("connectionComplete") || // NOI18N
                             evt.getPropertyName().equals("disconnected")) { // NOI18N
                         updateModel();
+                    } else if (evt.getPropertyName().equals(DatabaseConnection.PROP_NAME)) {
+                        updateModel();
                     }
                 }
             }
@@ -348,14 +350,30 @@ public class ConnectionNode extends BaseNode {
     
     @Override
     public String getName() {
-        return connection.getName();
+        return connection.getDisplayName();
+    }
+
+    @Override
+    public void setName(String name) {
+        connection.setDisplayName(name);
+        fireNameChange(null, null);
     }
 
     @Override
     public String getDisplayName() {
         return connection.getDisplayName();
     }
- 
+
+    @Override
+    public void setDisplayName(String name) {
+        connection.setDisplayName(name);
+    }
+
+    @Override
+    public boolean canRename() {
+        return true;
+    }
+
     @Override
     public String getIconBase() {
         boolean disconnected = ! DatabaseConnection.isVitalConnection(connection.getConnection(), null);
@@ -397,7 +415,7 @@ public class ConnectionNode extends BaseNode {
 
     @Override
     public HelpCtx getHelpCtx() {
-        return new HelpCtx(ConnectionNode.class);
+        return null;
     }
 
 }
