@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -53,7 +53,7 @@ import org.netbeans.modules.dbschema.*;
 import org.netbeans.modules.dbschema.util.*;
 
 public class TableElementImpl extends DBElementImpl implements TableElement.Impl {
-    private static Logger LOGGER = Logger.getLogger(TableElementImpl.class.getName());
+    private static final Logger LOGGER = Logger.getLogger(TableElementImpl.class.getName());
 
     private DBElementsCollection columns;
     private DBElementsCollection indexes;
@@ -117,6 +117,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
     /** Get the name of this element.
     * @return the name
     */
+    @Override
     public DBIdentifier getName() {
         if (_name.getFullName() == null)
             _name.setFullName(((TableElement) element).getDeclaringSchema().getName().getFullName() + "." + _name.getName());
@@ -128,6 +129,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param isTable one of {@link #TABLE} or {@link #VIEW}
      * @throws DBException if impossible
      */
+    @Override
     public void setTableOrView(boolean isTable) throws DBException {
         this.isTable = isTable;
     }
@@ -135,6 +137,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
     /** Test whether this is really a class, or an interface.
      * @return one of {@link #TABLE} or {@link #VIEW}
      */
+    @Override
     public boolean isTableOrView() {
         return isTable;
     }
@@ -144,6 +147,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param action one of {@link #ADD}, {@link #REMOVE}, or {@link #SET}
      * @exception DBException if the action cannot be handled
      */
+    @Override
     public void changeColumns(ColumnElement[] elems,int action) throws DBException {
         columns.changeElements(elems, action);
     }
@@ -151,6 +155,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
     /** Get all columns.
      * @return the columns
      */
+    @Override
     public ColumnElement[] getColumns() {
         DBElement[] dbe = columns.getElements();
         return (ColumnElement[]) Arrays.asList(dbe).toArray(new ColumnElement[dbe.length]);
@@ -160,6 +165,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param name the name for which to look
      * @return the column, or <code>null</code> if it does not exist
     */
+    @Override
     public ColumnElement getColumn(DBIdentifier name) {
 		return (ColumnElement) columns.find(name);
     }
@@ -187,15 +193,22 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                 String colName, colNull, colSize, colDec;
                 String strAutoIncrement = null;
                 if (rs != null) {
-                    HashMap rset = new HashMap();
+                    Map rset = new HashMap();
                     while (rs.next()) {
                         if (bridge != null) {
                             rset = bridge.getDriverSpecification().getRow();
                             Object type = rset.get(new Integer(5));
-                            if (type != null)
+                            if (type != null) {
                                 sqlType = (new Integer((String) rset.get(new Integer(5)))).intValue();
-                            else
+                            } else {
                                 sqlType = 0; //java.sql.Types.NULL
+                            }
+                            // #192609: IllegalArgumentException: aType == null
+                            if ("PostgreSQL".equalsIgnoreCase(dmd.getDatabaseProductName())) { // NOI18N
+                                if (Types.DISTINCT == sqlType) {
+                                    sqlType = (new Integer((String) rset.get(new Integer(22)))).intValue();
+                                }
+                            }
                             sqlTypeName = (String) rset.get(new Integer(6));
                             colName = (String) rset.get(new Integer(4));
                             colNull = (String) rset.get(new Integer(11));
@@ -236,16 +249,15 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                             if ((sqlType == 1111) && sqlTypeName.equals("NVARCHAR2")) //NOI18N
                                 sqlType = Types.CHAR;
                         }
-                       //MySQL driver hacks
+                        //MySQL driver hacks
                         if (dbProductName.indexOf("MySQL") != -1) { //NOI18N
                             if ((sqlType == 1111) && sqlTypeName.equalsIgnoreCase("BIT")) //NOI18N
                                 sqlType = Types.BIT;
                         }
-
                         //workaround for i-net Oranxo driver
                         //value in int range is expected by JDBC API but 4294967296 is returned
                         try {
-                            new Integer(colSize);
+                            colSize = new Integer(colSize).toString();
                         } catch (NumberFormatException exc) {
                             colSize = Integer.toString(Integer.MAX_VALUE);
                         }
@@ -259,8 +271,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                     rs.close();
                 }
             } catch (Exception exc) {
-                if (Boolean.getBoolean("netbeans.debug.exceptions")) // NOI18N
-                    exc.printStackTrace();
+                LOGGER.log(Level.INFO, exc.getLocalizedMessage(), exc);
             }
     }
   
@@ -269,6 +280,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param action one of {@link #ADD}, {@link #REMOVE}, or {@link #SET}
      * @exception DBException if the action cannot be handled
      */
+    @Override
     public void changeIndexes(IndexElement[] elems,int action) throws DBException {
         indexes.changeElements(elems, action);
     }
@@ -276,6 +288,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
     /** Get all indexes.
      * @return the indexes
      */
+    @Override
     public IndexElement[] getIndexes() {
         DBElement[] dbe = indexes.getElements();        
         return (IndexElement[]) Arrays.asList(dbe).toArray(new IndexElement[dbe.length]);
@@ -285,6 +298,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param name the name for which to look
      * @return the index, or <code>null</code> if it does not exist
      */
+    @Override
     public IndexElement getIndex(DBIdentifier name) {
 		return (IndexElement) indexes.find(name);
     }
@@ -320,10 +334,18 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                 boolean unq;
                 LinkedList idxs = new LinkedList();
                 if (rs != null) {
-                    HashMap rset = new HashMap();
+                    Map rset = new HashMap();
                     String uniqueStr;
                     while (rs.next()) {
                         if (bridge != null) {
+                            // Ignore Indices marked statistic
+                            // explizit: TYPE == DatabaseMetaData or
+                            // implizit: ORDINAL_POSITION == 0
+                            // @see java.sql.DatabaseMetaData#getIndexInfo
+                            if (rs.getShort("TYPE") == DatabaseMetaData.tableIndexStatistic // NOI18N
+                                    || rs.getInt("ORDINAL_POSITION") == 0) { // NOI18N
+                                continue;
+                            }
                             rset = bridge.getDriverSpecification().getRow();
                             name = (String) rset.get(new Integer(6));
                             columnName = (String) rset.get(new Integer(9));
@@ -379,8 +401,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                     changeIndexes(ie, DBElement.Impl.ADD);
                 }
             } catch (Exception exc) {
-                if (Boolean.getBoolean("netbeans.debug.exceptions")) // NOI18N
-                    exc.printStackTrace();
+                LOGGER.log(Level.INFO, exc.getLocalizedMessage(), exc);
             }
     }
       
@@ -389,6 +410,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param action one of {@link #ADD}, {@link #REMOVE}, or {@link #SET}
      * @exception DBException if the action cannot be handled
      */
+    @Override
     public void changeKeys(KeyElement[] elems,int action) throws DBException {
         keys.changeElements(elems, action);
     }
@@ -396,6 +418,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
     /** Get all keys.
      * @return the keys
      */
+    @Override
     public KeyElement[] getKeys() {
         DBElement[] dbe = keys.getElements();
         return (KeyElement[]) Arrays.asList(dbe).toArray(new KeyElement[dbe.length]);
@@ -405,6 +428,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
      * @param name the name for which to look
      * @return the key, or <code>null</code> if it does not exist
      */
+    @Override
     public KeyElement getKey(DBIdentifier name) {
 		return (KeyElement) keys.find(name);
     }
@@ -444,8 +468,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                 if (id != 2)
                     initPK(cp, bridge, shortTableName);
             } catch (Exception exc) {
-                if (Boolean.getBoolean("netbeans.debug.exceptions")) // NOI18N
-                    exc.printStackTrace();
+                LOGGER.log(Level.INFO, exc.getLocalizedMessage(), exc);
             }
     }
     
@@ -463,7 +486,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
 
         String name, fkColName, pkTableName, pkColName, c1, c2, s1, s2;
         if (rs != null) {
-            HashMap rset = new HashMap();
+            Map rset = new HashMap();
             while (rs.next()) {
                 if (bridge != null) {
                     rset = bridge.getDriverSpecification().getRow();
@@ -559,7 +582,7 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
             Object keySeq;
             String colName;
             if (rs != null) {
-                HashMap rset = new HashMap();
+                Map rset = new HashMap();
                 while (rs.next()) {
                     if (bridge != null) {
                         rset = bridge.getDriverSpecification().getRow();
@@ -635,11 +658,13 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
         }
     }
 
+    @Override
     public ColumnPairElement[] getColumnPairs() {
         DBElement[] dbe = columnPairs.getElements();
         return (ColumnPairElement[]) Arrays.asList(dbe).toArray(new ColumnPairElement[dbe.length]);
     }
     
+    @Override
     public ColumnPairElement getColumnPair(DBIdentifier name) {
         ColumnPairElement cpe = (ColumnPairElement) columnPairs.find(name);
         if (cpe == null)
@@ -669,13 +694,14 @@ public class TableElementImpl extends DBElementImpl implements TableElement.Impl
                 cpe = new ColumnPairElement(cpei, lce, fce, (TableElement) element);
                 changeColumnPairs(new ColumnPairElement[] {cpe}, DBElement.Impl.ADD);
             } catch (DBException exc) {
-                exc.printStackTrace();
+                LOGGER.log(Level.INFO, exc.getLocalizedMessage(), exc);
                 return null;
             }
         
 		return cpe;
     }
     
+    @Override
     public void changeColumnPairs(ColumnPairElement[] pairs,int action) throws DBException {
         columnPairs.changeElements(pairs, action);
     }
