@@ -50,7 +50,6 @@ import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -60,6 +59,7 @@ import com.sun.jdi.Bootstrap;
 import com.sun.jdi.connect.ListeningConnector;
 import com.sun.jdi.connect.Transport;
 import com.sun.jdi.connect.Connector;
+import java.beans.PropertyChangeListener;
 
 import java.lang.ref.WeakReference;
 import java.net.InetAddress;
@@ -107,6 +107,7 @@ import org.netbeans.api.java.source.BuildArtifactMapper;
 import org.netbeans.api.java.source.BuildArtifactMapper.ArtifactsUpdated;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
+import org.openide.util.WeakListeners;
 
 
 /**
@@ -126,6 +127,7 @@ public class JPDAStart extends Task implements Runnable {
     private static final Pattern[] BOOT_CLASSPATH_WARNING_FILTER = new Pattern[] {
         Pattern.compile(".*jre.lib.sunrsasign\\.jar$"),
         Pattern.compile(".*jre.classes$"),
+        Pattern.compile(".*jdk\\.boot\\.jar$"),
     };
 
     /** Name of the property to which the JPDA address will be set.
@@ -152,6 +154,7 @@ public class JPDAStart extends Task implements Runnable {
     /** The class debugger should stop in, or null. */
     private String                  stopClassName = null;
     private String                  listeningCP = null;
+    private RequestProcessor        rp = new RequestProcessor("JPDAStart", 1);
 
     
     // properties ..............................................................
@@ -275,7 +278,7 @@ public class JPDAStart extends Task implements Runnable {
             lock[0] = lock[1] = null;
             synchronized (lock) {
                 debug ("Entered synch lock"); // NOI18N
-                RequestProcessor.getDefault ().post (this);
+                rp.post (this);
                 try {
                     debug ("Entering wait"); // NOI18N
                     lock.wait ();
@@ -494,12 +497,12 @@ public class JPDAStart extends Task implements Runnable {
 
                 DebuggerManager.getDebuggerManager().addDebuggerListener(
                         DebuggerManager.PROP_DEBUGGER_ENGINES,
-                        new Listener(first, artificialBreakpoints, listeners, startedSessionRef));
+                        new Listener(first, artificialBreakpoints, listeners, startedSessionRef, rp));
 
                 // Let it start asynchronously so that the script can go on and start the debuggee
                 final Thread[] listeningThreadPtr = new Thread[] { null };
                 final boolean[] listeningStarted = new boolean[] { false };
-                RequestProcessor.getDefault().post(new Runnable() {
+                rp.post(new Runnable() {
                     public void run() {
                         synchronized (listeningStarted) {
                             listeningThreadPtr[0] = Thread.currentThread();
@@ -693,7 +696,7 @@ public class JPDAStart extends Task implements Runnable {
             String pathName = project.replaceProperties(paths[i]);
             File f = FileUtil.normalizeFile (project.resolveFile (pathName));
             if (!isValid (f, project)) continue;
-            URL url = fileToURL (f, project, null);
+            URL url = fileToURL (f, project, null, false);
             if (url == null) continue;
             l.add (url);
         }
@@ -717,7 +720,7 @@ public class JPDAStart extends Task implements Runnable {
             File file = FileUtil.normalizeFile
                 (project.resolveFile (pathName));
             if (!isValid (file, project)) continue;
-            URL url = fileToURL (file, project, warningFilters);
+            URL url = fileToURL (file, project, warningFilters, true);
             if (url == null) continue;
             logger.fine("convertToSourcePath - class: " + url); // NOI18N
             try {
@@ -759,7 +762,7 @@ public class JPDAStart extends Task implements Runnable {
     }
 
 
-    private static URL fileToURL (File file, Project project, Pattern[] warningFilters) {
+    private static URL fileToURL (File file, Project project, Pattern[] warningFilters, boolean withSlash) {
         try {
             FileObject fileObject = FileUtil.toFileObject (file);
             if (fileObject == null) {
@@ -790,7 +793,11 @@ public class JPDAStart extends Task implements Runnable {
                     return null;
                 }
             }
-            return fileObject.getURL ();
+            if (withSlash) {
+                return FileUtil.urlForArchiveOrDir(file);
+            } else {
+                return fileObject.getURL ();
+            }
         } catch (FileStateInvalidException e) {
             ErrorManager.getDefault ().notify (ErrorManager.EXCEPTION, e);
             return null;
@@ -862,6 +869,8 @@ public class JPDAStart extends Task implements Runnable {
 
     private static class Listener extends DebuggerManagerAdapter {
 
+        private final PropertyChangeListener pcl = WeakListeners.propertyChange(this, null);
+
         private Set<DebuggerEngine> engines = new HashSet<DebuggerEngine>();
 
         private Breakpoint first;
@@ -869,15 +878,18 @@ public class JPDAStart extends Task implements Runnable {
         private final Map<URL, ArtifactsUpdated> listeners;
         private final WeakReference<Session> startedSessionRef[];
         private boolean enginesCheckDone = false;
+        private final RequestProcessor rp;
 
         private Listener(Breakpoint first,
                          List<Breakpoint> artificalBreakpoints,
                          Map<URL, ArtifactsUpdated> listeners,
-                         WeakReference<Session> startedSessionRef[]) {
+                         WeakReference<Session> startedSessionRef[],
+                         RequestProcessor rp) {
             this.first = first;
             this.artificalBreakpoints = artificalBreakpoints;
             this.listeners = listeners;
             this.startedSessionRef = startedSessionRef;
+            this.rp = rp;
         }
 
         @Override
@@ -885,12 +897,12 @@ public class JPDAStart extends Task implements Runnable {
             if (JPDADebugger.PROP_STATE.equals(e.getPropertyName ())) {
                 int state = ((Integer) e.getNewValue ()).intValue ();
                 if (state == JPDADebugger.STATE_STOPPED || state == JPDADebugger.STATE_DISCONNECTED) {
-                    RequestProcessor.getDefault().post(new Runnable() {
+                    rp.post(new Runnable() {
                         public void run() {
                             if (first != null) {
                                 DebuggerManager.getDebuggerManager().removeBreakpoint(first);
                                 first = null;
-                                ((JPDADebugger) e.getSource()).removePropertyChangeListener(Listener.this);
+                                ((JPDADebugger) e.getSource()).removePropertyChangeListener(JPDADebugger.PROP_STATE, pcl);
                             }
                         }
                     });
@@ -904,7 +916,7 @@ public class JPDAStart extends Task implements Runnable {
                 DebuggerManager.PROP_DEBUGGER_ENGINES,
                 this
             );
-            RequestProcessor.getDefault().post (new Runnable () {
+            rp.post (new Runnable () {
                 public void run () {
                     if (artificalBreakpoints != null) {
                         for (Breakpoint b : artificalBreakpoints) {
@@ -947,7 +959,7 @@ public class JPDAStart extends Task implements Runnable {
             if (debugger == null) return;
             debugger.addPropertyChangeListener (
                 JPDADebugger.PROP_STATE,
-                this
+                pcl
             );
             engines.add(engine);
         }
@@ -980,7 +992,7 @@ public class JPDAStart extends Task implements Runnable {
             if (engines.remove(engine)) {
                 debugger.removePropertyChangeListener (
                     JPDADebugger.PROP_STATE,
-                    this
+                    pcl
                 );
             }
             if (engines.isEmpty()) {
