@@ -44,34 +44,20 @@
 
 package org.netbeans.modules.debugger.jpda.projects;
 
-import com.sun.corba.se.impl.protocol.InfoOnlyServantCacheLocalCRDImpl;
-import com.sun.source.tree.ArrayAccessTree;
-import com.sun.source.tree.AssignmentTree;
-import com.sun.source.tree.BinaryTree;
 import com.sun.source.tree.CompilationUnitTree;
-import com.sun.source.tree.CompoundAssignmentTree;
-import com.sun.source.tree.ConditionalExpressionTree;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.IdentifierTree;
-import com.sun.source.tree.InstanceOfTree;
 import com.sun.source.tree.LineMap;
-import com.sun.source.tree.LiteralTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodInvocationTree;
-import com.sun.source.tree.NewArrayTree;
 import com.sun.source.tree.NewClassTree;
-import com.sun.source.tree.ParenthesizedTree;
 import com.sun.source.tree.Tree;
-import com.sun.source.tree.TypeCastTree;
-import com.sun.source.tree.UnaryTree;
 import com.sun.source.util.SourcePositions;
 import com.sun.source.util.TreePath;
 import com.sun.source.util.Trees;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.TypeParameterElement;
 import javax.lang.model.type.ArrayType;
@@ -82,7 +68,6 @@ import javax.lang.model.util.Types;
 import javax.tools.Diagnostic;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.ElementUtilities;
-import org.netbeans.api.java.source.TreeUtilities;
 
 import org.netbeans.spi.debugger.jpda.EditorContext;
 import org.openide.ErrorManager;
@@ -161,10 +146,12 @@ class AST2Bytecode {
                     TreePath nodePath = trees.getPath(cu, node);
                     if (nodePath != null && !ci.getTreeUtilities().isSynthetic(nodePath)) {
                         String methodNameInBytecode = null;
+                        String methodDescriptorInBytecode = null;
                         if (constantPool != null) {
                             int constantPoolIndex = ((bytecodes[from+1] & 0xFF) << 8) + (bytecodes[from+2] & 0xFF);
                             try {
                                 methodNameInBytecode = constantPool.getMethodName(constantPoolIndex);
+                                methodDescriptorInBytecode = constantPool.getMethodDescriptor(constantPoolIndex);
                             } catch (IndexOutOfBoundsException ioobex) {
                                 ioobex = Exceptions.attachMessage(ioobex, "While matching "+java.util.Arrays.asList(treeNodes)+". Please attach the code where this happens to http://www.netbeans.org/issues/show_bug.cgi?id=161839");
                                 Exceptions.printStackTrace(ioobex);
@@ -283,6 +270,7 @@ class AST2Bytecode {
                                         int constantPoolIndex = ((bytecodes[next+1] & 0xFF) << 8) + (bytecodes[next+2] & 0xFF);
                                         try {
                                             methodNameInBytecode = constantPool.getMethodName(constantPoolIndex);
+                                            methodDescriptorInBytecode = constantPool.getMethodDescriptor(constantPoolIndex);
                                         } catch (IndexOutOfBoundsException ioobex) {
                                             ioobex = Exceptions.attachMessage(ioobex, "While matching "+java.util.Arrays.asList(treeNodes)+". Please attach the code where this happens to http://www.netbeans.org/issues/show_bug.cgi?id=161839");
                                             Exceptions.printStackTrace(ioobex);
@@ -292,6 +280,7 @@ class AST2Bytecode {
                                             break;
                                         } else {
                                             //System.err.println("AST2Bytecode: skipped method in bytecode '"+methodNameInBytecode+"'");
+                                            methodDescriptorInBytecode = null;
                                         }
                                     }
                                     next += getInstrSize(opcode, bytecodes, next);
@@ -346,6 +335,13 @@ class AST2Bytecode {
                                         methodClassType,
                                         from
                                 );
+                        try {
+                            java.lang.reflect.Field methodDescriptorField = EditorContext.Operation.class.getDeclaredField("methodDescriptor");
+                            methodDescriptorField.setAccessible(true);
+                            methodDescriptorField.set(op, methodDescriptorInBytecode);
+                        } catch (Exception ex) {
+                            Exceptions.printStackTrace(ex);
+                        }
                         //treeNodes.get(treeIndex).setCodeIndex(from);
                         operations.add(op);
                     }
