@@ -53,12 +53,11 @@ import java.net.URL;
 import java.util.HashSet;
 import java.util.Set;
 import javax.swing.Action;
-
 import javax.swing.SwingUtilities;
+import org.netbeans.api.annotations.common.SuppressWarnings;
 import org.netbeans.api.java.project.JavaProjectConstants;
 import org.netbeans.api.java.source.SourceUtils;
 import org.netbeans.api.project.Project;
-import org.netbeans.api.project.ProjectManager;
 import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.Sources;
@@ -67,10 +66,9 @@ import org.netbeans.spi.project.ui.support.ProjectActionPerformer;
 import org.netbeans.spi.project.ui.support.ProjectSensitiveActions;
 import org.openide.filesystems.FileStateInvalidException;
 import org.openide.util.Exceptions;
-import org.openide.windows.WindowManager;
 
 /**
- * Provies access to the main or currently selected project.
+ * Provides access to the main or currently selected project.
  *
  * @author   Jan Jancura, Martin Entlicher
  */
@@ -88,57 +86,65 @@ public class MainProjectManager implements ProjectActionPerformer, PropertyChang
     
     
     private Action a;
-    private Project currentProject; // The current/main project
-    private Reference<Project> lastSelectedProjectRef = new WeakReference(null);
+    private Reference<Project> currentProject = new WeakReference<Project>(null); // The current/main project
+    private Reference<Project> lastSelectedProjectRef = new WeakReference<Project>(null);
     private boolean isMainProject;  // true iff currentProject is the main project.
     private PropertyChangeSupport pcs;
 
-
+    @java.lang.SuppressWarnings("LeakingThisInConstructor")
     private MainProjectManager () {
         pcs = new PropertyChangeSupport (this);
         a = ProjectSensitiveActions.projectSensitiveAction (
             this, "x", null
         );
         OpenProjects.getDefault().addPropertyChangeListener(this);
-        currentProject = OpenProjects.getDefault().getMainProject();
-        isMainProject = currentProject != null;
+        currentProject = new WeakReference<Project>(OpenProjects.getDefault().getMainProject());
+        isMainProject = currentProject.get() != null;
         a.addPropertyChangeListener(this); // I'm listening on it so that I get enable() called.
         SwingUtilities.invokeLater(new Runnable() {
-            public void run() {
+            public @Override void run() {
                 a.isEnabled();
             }
         });
     }
 
     public synchronized Project getMainProject () {
-        Project lastSelectedProject = lastSelectedProjectRef.get();
-        if (isMainProject && lastSelectedProject != null &&
-            !isDependent(lastSelectedProject, currentProject)) {
+        final Project lastSelectedProject;
+        final Project current;
+        final boolean isMain;
+        synchronized (this) {
+            lastSelectedProject = lastSelectedProjectRef.get();
+            current = currentProject.get();
+            isMain = isMainProject;
+        }
+        if (isMain && lastSelectedProject != null &&
+            !isDependent(lastSelectedProject, current)) {
             // If there's a main project set, but the current project has no
             // dependency on it, return the current project.
             //System.err.println("getMainProject() = (LS) "+lastSelectedProject);
             return lastSelectedProject;
+        } else {
+            return current;
         }
         //System.err.println("getMainProject() = "+currentProject);
-        return currentProject;
     }
 
-    public void perform (Project p) {
+    public @Override void perform(Project p) {
         assert false : "Fake action should never really be called";
     }
 
-    public boolean enable (Project p) {
+    public @Override boolean enable(Project p) {
         Project old = p;
         Project oldSelected = p;
         synchronized (this) {
             if (isMainProject) {
                 oldSelected = lastSelectedProjectRef.get();
             }
-            lastSelectedProjectRef = new WeakReference(p);
+            lastSelectedProjectRef = new WeakReference<Project>(p);
             if (!isMainProject) {
-                if (currentProject != p) {
-                    old = currentProject;
-                    currentProject = p;
+                if (currentProject.get() != p) {
+                    old = currentProject.get();
+                    currentProject = new WeakReference<Project>(p);
                 }
             }
         }
@@ -158,6 +164,7 @@ public class MainProjectManager implements ProjectActionPerformer, PropertyChang
      * @param p2 main project
      * @return <code>true</code> if project <code>p1</code> depends on project <code>p2</code>
      */
+    @SuppressWarnings("DMI_COLLECTION_OF_URLS")
     private static boolean isDependent(Project p1, Project p2) {
         Set<URL> p1Roots = getProjectRoots(p1);
         Set<URL> p2Roots = getProjectRoots(p2);
@@ -173,6 +180,7 @@ public class MainProjectManager implements ProjectActionPerformer, PropertyChang
         return false;
     }
 
+    @SuppressWarnings("DMI_COLLECTION_OF_URLS")
     private static Set<URL> getProjectRoots(Project p) {
         Set<URL> projectRoots = new HashSet<URL>(); // roots
         Sources sources = ProjectUtils.getSources(p);
@@ -205,18 +213,18 @@ public class MainProjectManager implements ProjectActionPerformer, PropertyChang
         pcs.removePropertyChangeListener (l);
     }
 
-    public void propertyChange(PropertyChangeEvent evt) {
+    public @Override void propertyChange(PropertyChangeEvent evt) {
         //System.err.println("MainProjectManager.propertyChange("+evt+") name = "+evt.getPropertyName());
         if (OpenProjects.PROPERTY_MAIN_PROJECT.equals(evt.getPropertyName())) {
             Project theMainProject = OpenProjects.getDefault().getMainProject();
             Project old = theMainProject;
             synchronized (this) {
                 isMainProject = theMainProject != null;
-                old = currentProject;
+                old = currentProject.get();
                 if (isMainProject) {
-                    currentProject = theMainProject;
+                    currentProject = new WeakReference<Project>(theMainProject);
                 } else {
-                    currentProject = lastSelectedProjectRef.get();
+                    currentProject = lastSelectedProjectRef;
                 }
             }
             //System.err.println(" main project = "+theMainProject+", old = "+old);
@@ -234,12 +242,12 @@ public class MainProjectManager implements ProjectActionPerformer, PropertyChang
             Project currentNew = null;
             Project lastGone = null;
             synchronized (this) {
-                boolean isCurrent = OpenProjects.getDefault().isProjectOpen(currentProject);
+                boolean isCurrent = OpenProjects.getDefault().isProjectOpen(currentProject.get());
                 Project last = lastSelectedProjectRef.get();
                 boolean isLast = OpenProjects.getDefault().isProjectOpen(last);
-                if (!isCurrent && currentProject != null) {
-                    currentGone = currentProject;
-                    currentProject = null;
+                if (!isCurrent && currentProject.get() != null) {
+                    currentGone = currentProject.get();
+                    currentProject = new WeakReference<Project>(null);
                 }
                 if (!isLast && last != null) {
                     if (isMainProject) {
@@ -248,9 +256,9 @@ public class MainProjectManager implements ProjectActionPerformer, PropertyChang
                     lastSelectedProjectRef = new WeakReference<Project>(null);
                 }
                 isMainProject = theMainProject != null;
-                if (isMainProject && currentProject == null) {
-                    currentProject = theMainProject;
-                    currentNew = currentProject;
+                if (isMainProject && currentProject.get() == null) {
+                    currentProject = new WeakReference<Project>(theMainProject);
+                    currentNew = currentProject.get();
                 }
             }
             if (currentGone != currentNew) {
