@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -42,8 +45,6 @@
 package org.netbeans.modules.debugger.jpda.projects;
 
 import java.beans.PropertyChangeEvent;
-import java.lang.ref.WeakReference;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.Set;
 import javax.swing.SwingUtilities;
@@ -56,17 +57,14 @@ import org.netbeans.api.debugger.DebuggerManagerAdapter;
 
 import org.netbeans.api.debugger.jpda.JPDADebugger;
 import org.netbeans.api.debugger.jpda.LineBreakpoint;
-import org.netbeans.api.java.source.SourceUtils;
-import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
+import org.netbeans.spi.debugger.ActionsProvider.Registration;
 import org.netbeans.spi.debugger.ActionsProviderSupport;
 import org.netbeans.spi.debugger.ui.EditorContextDispatcher;
 import org.netbeans.spi.project.ActionProvider;
 import org.openide.ErrorManager;
 import org.openide.filesystems.FileObject;
-import org.openide.util.Lookup;
 import org.openide.util.RequestProcessor;
-import org.openide.util.Utilities;
 import org.openide.util.WeakListeners;
 
 
@@ -74,6 +72,7 @@ import org.openide.util.WeakListeners;
 *
 * @author   Jan Jancura
 */
+@Registration(actions={"runToCursor"}, activateForMIMETypes={"text/x-java"})
 public class RunToCursorActionProvider extends ActionsProviderSupport {
     
     private EditorContextDispatcher editorContext;
@@ -149,16 +148,6 @@ public class RunToCursorActionProvider extends ActionsProviderSupport {
     }
     
     private void invokeAction() {
-        FileObject fo = Utilities.actionsGlobalContext().lookup(FileObject.class);
-        if (fo != null) {
-            //JavaSource source = JavaSource.forFileObject(fo);
-            Collection mainClasses = SourceUtils.getMainClasses(fo);
-            if (!mainClasses.isEmpty()) {
-                if (debugFile(fo)) {
-                    return ;
-                }
-            }
-        }
         debugProject(MainProjectManager.getDefault ().getMainProject ());
     }
 
@@ -169,20 +158,6 @@ public class RunToCursorActionProvider extends ActionsProviderSupport {
             );
     }
 
-    private static boolean debugFile(FileObject fo) {
-        Project p = FileOwnerQuery.getOwner(fo);
-        if (p == null) {
-            return false;
-        }
-        ActionProvider ap = p.getLookup().lookup(ActionProvider.class);
-        if (ap.isActionEnabled(ActionProvider.COMMAND_DEBUG_SINGLE, Utilities.actionsGlobalContext())) {
-            ap.invokeAction(ActionProvider.COMMAND_DEBUG_SINGLE, Utilities.actionsGlobalContext());
-            return true;
-        } else {
-            return false;
-        }
-    }
-    
     private boolean shouldBeEnabled () {
         if (editorContext.getCurrentLineNumber () < 0) return false;
         FileObject fo = editorContext.getCurrentFile();
