@@ -59,6 +59,7 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
@@ -89,6 +90,7 @@ import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.ui.OpenProjects;
+import org.netbeans.spi.java.classpath.PathResourceImplementation;
 import org.netbeans.spi.java.classpath.support.ClassPathSupport;
 
 import org.openide.filesystems.FileObject;
@@ -106,9 +108,10 @@ import org.openide.util.WeakListeners;
  *
  * @author Jan Jancura
  */
+@SourcePathProvider.Registration(path="netbeans-JPDASession")
 public class SourcePathProviderImpl extends SourcePathProvider {
     
-    private static boolean          verbose = 
+    private static final boolean    verbose =
         System.getProperty ("netbeans.debugger.sourcepathproviderimpl") != null;
     
     private static Logger logger = Logger.getLogger("org.netbeans.modules.debugger.jpda.projects");
@@ -120,6 +123,8 @@ public class SourcePathProviderImpl extends SourcePathProvider {
     private ClassPath               originalSourcePath;
     /** Contains the additional source roots, added at a later time to the original roots. */
     private Set<String>             additionalSourceRoots;
+    /** Contains platform (JDK) source roots. */
+    private Set<String>             platformSourceRoots;
     /** Contains just the source paths from {@link #originalSourcePath} which are selected for debugging. */
     private ClassPath               smartSteppingSourcePath;
     /** Roots of {@link #originalSourcePath} */
@@ -131,6 +136,9 @@ public class SourcePathProviderImpl extends SourcePathProvider {
     private PropertyChangeSupport   pcs;
     private PathRegistryListener    pathRegistryListener;
     private File                    baseDir;
+
+    private final Map<String, String> urlCache = new URLCacheMap();
+    private final Map<String, String> urlCacheGlobal = new URLCacheMap();
     
     public SourcePathProviderImpl () {
         pcs = new PropertyChangeSupport (this);
@@ -153,6 +161,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             ClassPath jdkCP = (ClassPath) properties.get ("jdksources");
             if ( (jdkCP == null) && (JavaPlatform.getDefault () != null) )
                 jdkCP = JavaPlatform.getDefault ().getSourceFolders ();
+            platformSourceRoots = getSourceRootsSet(jdkCP);
             ClassPath additionalClassPath;
             if (baseDir != null) {
                 additionalClassPath = getAdditionalClassPath(baseDir);
@@ -201,7 +210,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                         enabledSourcePath.remove(fo);
                     }
                 }
-                smartSteppingSourcePath = ClassPathSupport.createClassPath(
+                smartSteppingSourcePath = createClassPath(
                         enabledSourcePath.toArray(new FileObject[0]));
             }
 
@@ -212,7 +221,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             Set<FileObject> globalRoots = new TreeSet<FileObject>(new FileObjectComparator());
             globalRoots.addAll(GlobalPathRegistry.getDefault().getSourceRoots());
             globalRoots.removeAll(preferredRoots);
-            ClassPath globalCP = ClassPathSupport.createClassPath(globalRoots.toArray(new FileObject[0]));
+            ClassPath globalCP = createClassPath(globalRoots.toArray(new FileObject[0]));
             originalSourcePath = ClassPathSupport.createProxyClassPath(
                     originalSourcePath,
                     globalCP
@@ -249,6 +258,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             Set<FileObject> preferredRoots = new HashSet<FileObject>();
             Set<FileObject> addedBinaryRoots = new HashSet<FileObject>();
             Project mainProject = OpenProjects.getDefault().getMainProject();
+            platformSourceRoots = new HashSet<String>();
             if (mainProject != null) {
                 SourceGroup[] sgs = ProjectUtils.getSources(mainProject).getSourceGroups(JavaProjectConstants.SOURCES_TYPE_JAVA);
                 for (SourceGroup sg : sgs) {
@@ -276,6 +286,10 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                             }
                         }
                     }
+                    ecp = ClassPath.getClassPath(sg.getRootFolder(), ClassPath.BOOT);
+                    if (ecp != null) {
+                        platformSourceRoots.addAll(getSourceRootsSet(ecp));
+                    }
                 }
             }
             if (logger.isLoggable(Level.FINE)) {
@@ -298,6 +312,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                         allSourceRoots.add(roots [j]);
                     }
                 }
+                platformSourceRoots.addAll(getSourceRootsSet(platforms[i].getSourceFolders()));
             }
             List<FileObject> additional = getAdditionalRemoteClassPath();
             if (additional != null) {
@@ -315,7 +330,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             Set<String> disabledRoots = getRemoteDisabledSourceRoots();
             
             synchronized (this) {
-                unorderedOriginalSourcePath = ClassPathSupport.createClassPath (
+                unorderedOriginalSourcePath = createClassPath (
                     allSourceRoots.toArray
                         (new FileObject [allSourceRoots.size()])
                 );
@@ -342,7 +357,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                             enabledSourcePath.remove(fo);
                         }
                     }
-                    smartSteppingSourcePath = ClassPathSupport.createClassPath(
+                    smartSteppingSourcePath = createClassPath(
                             enabledSourcePath.toArray(new FileObject[0]));
                 }
             }
@@ -402,7 +417,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                 }
             }
             this.additionalSourceRoots = new LinkedHashSet<String>(additionalSourceRoots);
-            return ClassPathSupport.createClassPath(
+            return createClassPath(
                     additionalSourcePath.toArray(new FileObject[0]));
         } catch (MalformedURLException ex) {
             Exceptions.printStackTrace(ex);
@@ -578,8 +593,23 @@ public class SourcePathProviderImpl extends SourcePathProvider {
      * @return url or <code>null</code>
      */
     public String getURL (String relativePath, boolean global) {    if (verbose) System.out.println ("SPPI: getURL " + relativePath + " global " + global);
-        FileObject fo;
         relativePath = normalize(relativePath);
+        if (global) {
+            synchronized (urlCacheGlobal) {
+                if (urlCacheGlobal.containsKey(relativePath)) {
+                    if (verbose) System.out.println("Have cached global path for '"+relativePath+"' url = "+urlCacheGlobal.get(relativePath));
+                    return urlCacheGlobal.get(relativePath);    // URL or null
+                }
+            }
+        } else {
+            synchronized (urlCache) {
+                if (urlCache.containsKey(relativePath)) {
+                    if (verbose) System.out.println("Have cached path for '"+relativePath+"' url = "+urlCache.get(relativePath));
+                    return urlCache.get(relativePath);  // URL or null
+                }
+            }
+        }
+        FileObject fo;
         ClassPath ss = null;
         ClassPath os = null;
         synchronized (this) {
@@ -602,12 +632,30 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         
         if (verbose) System.out.println ("SPPI:   fo " + fo);
 
-        if (fo == null) return null;
-        try {
-            return fo.getURL ().toString ();
-        } catch (FileStateInvalidException e) {                     if (verbose) System.out.println ("SPPI:   FileStateInvalidException");
-            return null;
+        String url;
+        if (fo == null) {
+            url = null;
+        } else {
+            try {
+                url = fo.getURL ().toString ();
+            } catch (FileStateInvalidException e) {         if (verbose) System.out.println ("SPPI:   FileStateInvalidException");
+                url = null;
+            }
         }
+        if (global) {
+            synchronized (urlCacheGlobal) {
+                if (verbose) System.out.println("Storing path into global cache for '"+relativePath+"' url = "+url);
+                urlCacheGlobal.put(relativePath, url);
+                if (verbose) System.out.println("  Global cache ("+urlCacheGlobal.size()+") = "+urlCacheGlobal);
+            }
+        } else {
+            synchronized (urlCache) {
+                if (verbose) System.out.println("Storing path into cache for '"+relativePath+"' url = "+url);
+                urlCache.put(relativePath, url);
+                if (verbose) System.out.println("  Cache = ("+urlCache.size()+") "+urlCache);
+            }
+        }
+        return url;
     }
     
     /**
@@ -744,6 +792,22 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         return roots.toArray(new String[0]);
     }
     
+    private static Set<String> getSourceRootsSet(ClassPath classPath) {
+        FileObject[] sourceRoots = classPath.getRoots();
+        Set<String> roots = new HashSet<String>(sourceRoots.length);
+        for (FileObject fo : sourceRoots) {
+            String root = getRoot(fo);
+            if (root != null) {
+                roots.add(root);
+            }
+        }
+        return roots;
+    }
+
+    public synchronized Set<String> getPlatformSourceRoots() {
+        return Collections.unmodifiableSet(platformSourceRoots);
+    }
+
     /**
      * Returns allSourceRoots of original source roots.
      *
@@ -779,7 +843,8 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         return (additionalSourceRoots == null) ? new String[] {} : additionalSourceRoots.toArray(new String[]{});
     }
 
-    public synchronized void reorderOriginalSourceRoots(int[] permutation) {
+    public void reorderOriginalSourceRoots(int[] permutation) {
+        synchronized (this) {
         String[] srcRoots = getOriginalSourceRoots();
         if (permutation == null) {
             // Restting the order to the original
@@ -817,6 +882,14 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         }
         smartSteppingSourcePath = createClassPath(orderedSmartSteppingRoots);
         storeSourceRootsOrder(baseDir, srcRoots, sourcePathPermutation);
+        }
+        // Clear caches so that the new order is taken into account
+        synchronized (urlCache) {
+            urlCache.clear();
+        }
+        synchronized (urlCacheGlobal) {
+            urlCacheGlobal.clear();
+        }
     }
     
     /**
@@ -849,6 +922,14 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             }
         }
         
+        // Clear caches so that the new source roots are taken into account
+        synchronized (urlCache) {
+            urlCache.clear();
+        }
+        synchronized (urlCacheGlobal) {
+            urlCacheGlobal.clear();
+        }
+
         if (oldCP_ptr[0] != null) {
             pcs.firePropertyChange (PROP_SOURCE_ROOTS, oldCP_ptr[0], newCP_ptr[0]);
         }
@@ -877,6 +958,14 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             }
         }
         
+        // Clear caches so that the new source roots are taken into account
+        synchronized (urlCache) {
+            urlCache.clear();
+        }
+        synchronized (urlCacheGlobal) {
+            urlCacheGlobal.clear();
+        }
+
         if (oldCP_ptr[0] != null) {
             pcs.firePropertyChange (PROP_SOURCE_ROOTS, oldCP_ptr[0], newCP_ptr[0]);
         }
@@ -902,17 +991,22 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             // There are new additional source roots added. We need to update
             // unorderedOriginalSourcePath, originalSourcePath, projectSourceRoots,
             // smartSteppingSourcePath, sourcePathPermutation and additionalSourceRoots
+            Set<String> addedOriginalRoots = new LinkedHashSet<String>(newOriginalRoots.size());
             for (String root : newOriginalRoots) {
                 FileObject fo = getFileObject(root);
                 if (fo != null && fo.canRead()) {
                     sourcePathOriginal.add(fo);
                     unorderedSourcePathOriginal.add(fo);
+                    addedOriginalRoots.add(root);
                 }
             }
-            if (additionalSourceRoots == null) {
-                additionalSourceRoots = new LinkedHashSet<String>();
+            newOriginalRoots = addedOriginalRoots;
+            if (!newOriginalRoots.isEmpty()) {
+                if (additionalSourceRoots == null) {
+                    additionalSourceRoots = new LinkedHashSet<String>();
+                }
+                additionalSourceRoots.addAll(newOriginalRoots);
             }
-            additionalSourceRoots.addAll(newOriginalRoots);
         }
 
         // Then correct the smart-stepping path
@@ -962,10 +1056,10 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             }
             sourcePathPermutation = newSourcePathPermutation;
             originalSourcePath =
-                    ClassPathSupport.createClassPath(
+                    createClassPath(
                         sourcePathOriginal.toArray(new FileObject[0]));
             unorderedOriginalSourcePath =
-                    ClassPathSupport.createClassPath(
+                    createClassPath(
                         unorderedSourcePathOriginal.toArray(new FileObject[0]));
             projectSourceRoots = getSourceRoots(originalSourcePath);
         }
@@ -979,7 +1073,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             sourcePath.removeAll(removedSteppingRoots);
             oldCP_ptr[0] = smartSteppingSourcePath;
             smartSteppingSourcePath =
-                    ClassPathSupport.createClassPath(
+                    createClassPath(
                         sourcePath.toArray(new FileObject[0]));
             newCP_ptr[0] = smartSteppingSourcePath;
         }
@@ -1037,13 +1131,13 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         index = unorderedSourcePathOriginal.indexOf(renamedFO);
         unorderedSourcePathOriginal.set(index, newFO);
         smartSteppingSourcePath =
-                ClassPathSupport.createClassPath(
+                createClassPath(
                     sourcePath.toArray(new FileObject[0]));
         originalSourcePath =
-                ClassPathSupport.createClassPath(
+                createClassPath(
                     sourcePathOriginal.toArray(new FileObject[0]));
         unorderedOriginalSourcePath =
-                ClassPathSupport.createClassPath(
+                createClassPath(
                     unorderedSourcePathOriginal.toArray(new FileObject[0]));
         projectSourceRoots = getSourceRoots(originalSourcePath);
         Set<String> disabledRoots;
@@ -1137,9 +1231,9 @@ public class SourcePathProviderImpl extends SourcePathProvider {
     /**
      * Returns FileObject for given String.
      */
-    private FileObject getFileObject (String file) {
+    private static FileObject getFileObject (String file) {
         File f = new File (file);
-        FileObject fo = FileUtil.toFileObject (f);
+        FileObject fo = FileUtil.toFileObject (FileUtil.normalizeFile(f));
         String path = null;
         if (fo == null && file.contains("!/")) {
             int index = file.indexOf("!/");
@@ -1212,25 +1306,36 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         }
         Cmp cmp = new Cmp();
         Arrays.sort(roots, cmp);
-        List<FileObject> froots = new ArrayList<FileObject>(roots.length);
-        for (String r : roots) {
-            FileObject fo = getFileObject(r);
-            if (fo != null && fo.canRead()) {
-                froots.add(fo);
-            }
-        }
-        return ClassPathSupport.createClassPath(froots.toArray(new FileObject[]{}));
+        return createClassPath(roots);
     }
 
-    private ClassPath createClassPath(String[] roots) {
-        List<FileObject> froots = new ArrayList<FileObject>(roots.length);
-        for (String r : roots) {
-            FileObject fo = getFileObject(r);
+    private static ClassPath createClassPath(String[] roots) {
+        int n = roots.length;
+        FileObject[] froots = new FileObject[n];
+        for (int i = 0; i < n; i++) {
+            froots[i] = getFileObject(roots[i]);
+        }
+        return createClassPath(froots);
+    }
+
+    private static ClassPath createClassPath(FileObject[] froots) {
+        List<PathResourceImplementation> pris = new ArrayList<PathResourceImplementation> ();
+        for (FileObject fo : froots) {
             if (fo != null && fo.canRead()) {
-                froots.add(fo);
+                try {
+                    URL url = fo.getURL();
+                    pris.add(ClassPathSupport.createResource(url));
+                } catch (FileStateInvalidException e) {
+                    Exceptions.printStackTrace (e);
+                } catch (IllegalArgumentException iaex) {
+                    // Can be thrown from ClassPathSupport.createResource()
+                    // Ignore - bad source root
+                    //logger.log(Level.INFO, "Invalid source root = "+fo, iaex);
+                    logger.warning(iaex.getLocalizedMessage());
+                }
             }
         }
-        return ClassPathSupport.createClassPath(froots.toArray(new FileObject[]{}));
+        return ClassPathSupport.createClassPath(pris);
     }
     
     private ArtifactsUpdatedImpl addArtifactsUpdateListenerFor(JPDADebugger debugger, FileObject src) throws FileStateInvalidException {
@@ -1343,16 +1448,23 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                             Arrays.asList(originalSourcePath.getRoots()));
                     sourcePaths.addAll(addedRoots);
                     originalSourcePath =
-                            ClassPathSupport.createClassPath(
+                            SourcePathProviderImpl.createClassPath(
                                 sourcePaths.toArray(new FileObject[0]));
 
                     sourcePaths = new ArrayList<FileObject>(
                             Arrays.asList(smartSteppingSourcePath.getRoots()));
                     sourcePaths.addAll(addedRoots);
                     smartSteppingSourcePath =
-                            ClassPathSupport.createClassPath(
+                            SourcePathProviderImpl.createClassPath(
                                 sourcePaths.toArray(new FileObject[0]));
                 }
+                // Clear caches so that the new source roots are taken into account
+                synchronized (urlCache) {
+                    urlCache.clear();
+                }
+                synchronized (urlCacheGlobal) {
+                    urlCacheGlobal.clear();
+                }
                 pcs.firePropertyChange (PROP_SOURCE_ROOTS, null, null);
             }
         }
@@ -1380,16 +1492,23 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                             Arrays.asList(originalSourcePath.getRoots()));
                     sourcePaths.removeAll(removedRoots);
                     originalSourcePath =
-                            ClassPathSupport.createClassPath(
+                            SourcePathProviderImpl.createClassPath(
                                 sourcePaths.toArray(new FileObject[0]));
 
                     sourcePaths = new ArrayList<FileObject>(
                             Arrays.asList(smartSteppingSourcePath.getRoots()));
                     sourcePaths.removeAll(removedRoots);
                     smartSteppingSourcePath =
-                            ClassPathSupport.createClassPath(
+                            SourcePathProviderImpl.createClassPath(
                                 sourcePaths.toArray(new FileObject[0]));
                 }
+                // Clear caches so that the new source roots are taken into account
+                synchronized (urlCache) {
+                    urlCache.clear();
+                }
+                synchronized (urlCacheGlobal) {
+                    urlCacheGlobal.clear();
+                }
                 pcs.firePropertyChange (PROP_SOURCE_ROOTS, null, null);
             }
         }
@@ -1410,6 +1529,7 @@ public class SourcePathProviderImpl extends SourcePathProvider {
             boolean changed = false;
             synchronized (SourcePathProviderImpl.this) {
                 if (originalSourcePath == null) return ;
+                platformSourceRoots.clear();
                 List<FileObject> sourcePaths = new ArrayList<FileObject>(
                         Arrays.asList(originalSourcePath.getRoots()));
                 for(JavaPlatform jp : platforms) {
@@ -1420,14 +1540,22 @@ public class SourcePathProviderImpl extends SourcePathProvider {
                             changed = true;
                         }
                     }
+                    platformSourceRoots.addAll(getSourceRootsSet(jp.getSourceFolders()));
                 }
                 if (changed) {
                     originalSourcePath =
-                            ClassPathSupport.createClassPath(
+                            SourcePathProviderImpl.createClassPath(
                                 sourcePaths.toArray(new FileObject[0]));
                 }
             }
             if (changed) {
+                // Clear caches so that the new source roots are taken into account
+                synchronized (urlCache) {
+                    urlCache.clear();
+                }
+                synchronized (urlCacheGlobal) {
+                    urlCacheGlobal.clear();
+                }
                 pcs.firePropertyChange (PROP_SOURCE_ROOTS, null, null);
             }
         }
@@ -1448,4 +1576,19 @@ public class SourcePathProviderImpl extends SourcePathProvider {
         }
         
     }
+
+    private static final class URLCacheMap extends LinkedHashMap<String, String> {
+
+        private static final int URL_CACHE_SIZE = 500;
+
+        public URLCacheMap() {
+            super(URL_CACHE_SIZE, .1f, true);
+        }
+
+        @Override
+        protected boolean removeEldestEntry(Map.Entry<String, String> eldest) {
+            return size() >= URL_CACHE_SIZE;
+        }
+
+    }
 }
