@@ -70,7 +70,9 @@ import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.Sources;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.netbeans.spi.debugger.jpda.SourcePathProvider;
+import org.netbeans.spi.debugger.ui.EditorContextDispatcher;
 import org.netbeans.spi.viewmodel.CheckNodeModel;
 import org.netbeans.spi.viewmodel.CheckNodeModelFilter;
 import org.netbeans.spi.viewmodel.ModelEvent;
@@ -95,6 +97,10 @@ import org.openide.util.WeakListeners;
 /**
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistration(path="SourcesView/netbeans-JPDASession/Current",
+                             types={ TreeModel.class,
+                                     CheckNodeModelFilter.class,
+                                     NodeActionsProvider.class })
 public class SourcesCurrentModel implements TreeModel, CheckNodeModelFilter,
 NodeActionsProvider {
 
@@ -606,6 +612,22 @@ NodeActionsProvider {
 
     private JFileChooser newSourceFileChooser;
 
+    static File getCurrentSourceRoot() {
+        FileObject fo = EditorContextDispatcher.getDefault().getMostRecentFile();
+        if (fo == null) {
+            return null;
+        }
+        ClassPath cp = ClassPath.getClassPath(fo, ClassPath.SOURCE);
+        if (cp == null) {
+            return null;
+        }
+        fo = cp.findOwnerRoot(fo);
+        if (fo == null) {
+            return null;
+        }
+        return FileUtil.toFile(fo);
+    }
+
     private final Action NEW_SOURCE_ROOT_ACTION = new AbstractAction(
             NbBundle.getMessage(SourcesCurrentModel.class, "CTL_SourcesModel_Action_AddSrc")) {
         public void actionPerformed (ActionEvent e) {
@@ -632,6 +654,10 @@ NodeActionsProvider {
 
                 });
             }
+            File currentSourceRoot = getCurrentSourceRoot();
+            if (currentSourceRoot != null) {
+                newSourceFileChooser.setSelectedFile(currentSourceRoot);
+            }
             int state = newSourceFileChooser.showDialog(org.openide.windows.WindowManager.getDefault().getMainWindow(),
                                       NbBundle.getMessage(SourcesCurrentModel.class, "CTL_SourcesModel_AddSrc_Btn"));
             if (state == JFileChooser.APPROVE_OPTION) {
