@@ -88,9 +88,11 @@ import org.netbeans.api.debugger.jpda.This;
 import org.netbeans.api.debugger.jpda.Variable;
 import org.netbeans.api.java.source.Comment;
 import org.netbeans.api.java.source.CompilationController;
+import org.netbeans.api.java.source.ElementUtilities;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.editor.BaseDocument;
+import org.netbeans.editor.EditorUI;
 import org.netbeans.editor.PopupManager;
 import org.netbeans.editor.Utilities;
 import org.netbeans.editor.ext.ToolTipSupport;
@@ -153,7 +155,7 @@ public class ToolTipAnnotation extends Annotation implements Runnable {
             rp = RequestProcessor.getDefault();
         }
         rp.post (this);
-        return "";
+        return null;
     }
 
     public void run () {
@@ -165,8 +167,8 @@ public class ToolTipAnnotation extends Annotation implements Runnable {
         } catch (IOException ex) {
             return ;
         }
-        final JEditorPane ep = EditorContextDispatcher.getDefault().getCurrentEditor ();
-        if (ep == null) return ;
+        final JEditorPane ep = EditorContextDispatcher.getDefault().getMostRecentEditor ();
+        if (ep == null || ep.getDocument() != doc) return ;
         DebuggerEngine currentEngine = DebuggerManager.getDebuggerManager ().
             getCurrentEngine ();
         if (currentEngine == null) return;
@@ -257,25 +259,42 @@ public class ToolTipAnnotation extends Annotation implements Runnable {
         }
 
         if (tooltipVariable != null) {
-            final ToolTipView.ExpandableTooltip et = ToolTipView.createExpandableTooltip(toolTipText);
             final ObjectVariable var = tooltipVariable;
-            et.addExpansionListener(new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    et.setBorder(BorderFactory.createLineBorder(et.getForeground()));
-                    et.removeAll();
-                    et.setWidthCheck(false);
-                    et.add(ToolTipView.getToolTipView(expression, var));
-                    et.revalidate();
-                    et.repaint();
-                    SwingUtilities.invokeLater(new Runnable() {
-                        public @Override void run() {
-                            Utilities.getEditorUI(ep).getToolTipSupport().setToolTip(et, PopupManager.ViewPortBounds, PopupManager.AbovePreferred, 0, 0, ToolTipSupport.FLAGS_HEAVYWEIGHT_TOOLTIP);
+            final String toolTip = toolTipText;
+            SwingUtilities.invokeLater(new Runnable() {
+                public void run() {
+                    final ToolTipView.ExpandableTooltip et = ToolTipView.createExpandableTooltip(toolTip);
+                    et.addExpansionListener(new ActionListener() {
+                        @Override
+                        public void actionPerformed(ActionEvent e) {
+                            et.setBorder(BorderFactory.createLineBorder(et.getForeground()));
+                            et.removeAll();
+                            et.setWidthCheck(false);
+                            final ToolTipView ttView = ToolTipView.getToolTipView(expression, var);
+                            et.add(ttView);
+                            et.revalidate();
+                            et.repaint();
+                            SwingUtilities.invokeLater(new Runnable() {
+                                public @Override void run() {
+                                    EditorUI eui = Utilities.getEditorUI(ep);
+                                    if (eui != null) {
+                                        ttView.setToolTipSupport(eui.getToolTipSupport());
+                                        eui.getToolTipSupport().setToolTip(et, PopupManager.ViewPortBounds, PopupManager.AbovePreferred, 0, 0, ToolTipSupport.FLAGS_HEAVYWEIGHT_TOOLTIP);
+                                    } else {
+                                        firePropertyChange (PROP_SHORT_DESCRIPTION, null, toolTip);
+                                    }
+                                }
+                            });
                         }
                     });
+                    EditorUI eui = Utilities.getEditorUI(ep);
+                    if (eui != null) {
+                        eui.getToolTipSupport().setToolTip(et);
+                    } else {
+                        firePropertyChange (PROP_SHORT_DESCRIPTION, null, toolTip);
+                    }
                 }
             });
-            Utilities.getEditorUI(ep).getToolTipSupport().setToolTip(et);
         } else {
             firePropertyChange (PROP_SHORT_DESCRIPTION, null, toolTipText);
         }
@@ -427,9 +446,9 @@ public class ToolTipAnnotation extends Annotation implements Runnable {
                             isValid[0] = false;
                             return;
                         }
-                        if (kind == Tree.Kind.CLASS && className[0].length() == 0) {
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(kind) && className[0].length() == 0) {
                             TypeElement typeElement = (TypeElement)controller.getTrees().getElement(path);
-                            className[0] = typeElement.getQualifiedName().toString();
+                            className[0] = ElementUtilities.getBinaryName(typeElement);
                         }
                         path = path.getParentPath();
                     }
@@ -440,36 +459,38 @@ public class ToolTipAnnotation extends Annotation implements Runnable {
         parsingTask.cancel(false); // for the case that scanning has not finished yet
         if (!isValid[0]) return false;
         if (className[0].length() > 0) {
-            Set superTypeNames = new HashSet<String>();
+            Set<String> superTypeNames = new HashSet<String>();
             This thisVar = currentFrame.getThisVariable();
-            // [TODO] how to obtain class name in static context?
             if (thisVar != null) {
                 String fqn = thisVar.getType();
-                // remove anonymous inner class part
-                int index = fqn.lastIndexOf('$');
-                while (index >= 0) {
-                    if ((index < fqn.length() - 1) && Character.isDigit(fqn.charAt(index + 1))) {
-                        fqn = fqn.substring(0, index);
-                        index = fqn.lastIndexOf('$');
-                    } else {
-                        break;
-                    }
-                }
-                superTypeNames.add(fqn.replace('$', '.'));
+                addClassNames(fqn, superTypeNames);
                 ObjectVariable superTypeVar = thisVar.getSuper();
                 while (superTypeVar != null) {
-                    fqn = superTypeVar.getType().replace('$', '.');
+                    fqn = superTypeVar.getType();
                     superTypeNames.add(fqn);
                     superTypeVar = superTypeVar.getSuper();
                 }
             } else {
-                superTypeNames.add(currentFrame.getClassName());
+                addClassNames(currentFrame.getClassName(), superTypeNames);
             }
             if (!superTypeNames.contains(className[0])) return false;
         }
         return true;
     }
 
+    // include the class name plus all enclosing classes
+    private static void addClassNames(String fqn, Set<String> typeNames) {
+        do {
+            typeNames.add(fqn);
+            int i = fqn.lastIndexOf('$');
+            if (i > 0) {
+                fqn = fqn.substring(0, i);
+            } else {
+                fqn = null;
+            }
+        } while(fqn != null);
+    }
+
     private String resolveTypeName (final int offset, Document doc) {
         final String[] result = new String[1];
         result[0] = null;
