@@ -67,6 +67,7 @@ import org.netbeans.spi.debugger.jpda.SourcePathProvider;
 
 import org.netbeans.spi.debugger.ui.EditorContextDispatcher;
 import org.openide.ErrorManager;
+import org.openide.filesystems.FileObject;
 import org.openide.util.Exceptions;
 import org.openide.util.Utilities;
 
@@ -164,6 +165,10 @@ public class EditorContextBridge {
                     if (s.length () > 0)
                         return CLASS;
                 }
+                FileObject fo = EditorContextDispatcher.getDefault().getMostRecentFile();
+                if (fo != null && "text/x-java".equals(fo.getMIMEType())) { // NOI18N
+                    return LINE;
+                }
             }
         } catch (java.awt.IllegalComponentStateException icsex) {}
         return null;
@@ -502,8 +507,9 @@ public class EditorContextBridge {
                         return null;
                     }
                 } catch (Exception ex) {
-                    ErrorManager.getDefault().notify(ex);
-                    return null;
+                    // Ignore if the context does not provide this functionality
+                    //ErrorManager.getDefault().notify(ex);
+                    //return null;
                 }
             }
             return s;
