@@ -61,6 +61,8 @@ import org.netbeans.spi.viewmodel.NodeModel;
 import org.openide.util.NbBundle;
 
 import org.netbeans.modules.debugger.jpda.ui.models.WatchesNodeModelFilter;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
+import org.netbeans.spi.debugger.DebuggerServiceRegistrations;
 import org.openide.util.NbPreferences;
 import org.openide.util.datatransfer.PasteType;
 import org.openide.windows.Mode;
@@ -74,6 +76,24 @@ import org.openide.windows.WindowManager;
  *
  * @author Jan Jancura, Maros Sandor
  */
+@DebuggerServiceRegistrations({
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/LocalsView",
+                                 types=NodeActionsProviderFilter.class,
+                                 position=600),
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/ResultsView",
+                                 types=NodeActionsProviderFilter.class,
+                                 position=600),
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/ToolTipView",
+                                 types=NodeActionsProviderFilter.class,
+                                 position=600),
+                                 
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/WatchesView",
+                                 types={ NodeActionsProviderFilter.class,
+                                         NodeModelFilter.class,
+                                         TableModelFilter.class,
+                                         TreeModelFilter.class },
+                                 position=600)
+})
 public class FixedWatchesManager implements TreeModelFilter, 
 NodeActionsProviderFilter, ExtendedNodeModelFilter, TableModelFilter {
             
@@ -153,7 +173,7 @@ NodeActionsProviderFilter, ExtendedNodeModelFilter, TableModelFilter {
     public void deleteAllFixedWatches() {
         Collection nodes = new ArrayList(fixedWatches.keySet());
         for (Iterator iter = nodes.iterator(); iter.hasNext();) {
-            fixedWatches.remove(new KeyWrapper(iter.next()));
+            fixedWatches.remove(iter.next());
             fireModelChanged(new ModelEvent.NodeChanged(FixedWatchesManager.this,
                 TreeModel.ROOT,
                 ModelEvent.NodeChanged.CHILDREN_MASK));
@@ -252,6 +272,9 @@ NodeActionsProviderFilter, ExtendedNodeModelFilter, TableModelFilter {
         NodeActionsProvider original, 
         Object node
     ) throws UnknownTypeException {
+        if (fixedWatches.containsKey (new KeyWrapper(node))) {
+            return ;
+        }
         original.performDefaultAction (node);
     }
 
@@ -260,7 +283,37 @@ NodeActionsProviderFilter, ExtendedNodeModelFilter, TableModelFilter {
         Action [] actions = original.getActions (node);
         List myActions = new ArrayList();
         if (fixedWatches.containsKey (new KeyWrapper(node))) {
-            myActions.add (0, DELETE_ACTION);
+            KeyStroke deleteKey = KeyStroke.getKeyStroke ("DELETE");
+            int deleteIndex = -1;
+            int editIndex = -1;
+            for (int i = 0; i < actions.length; i++) {
+                if (actions[i] != null) {
+                    if (deleteKey.equals(actions[i].getValue(Action.ACCELERATOR_KEY))) {
+                        deleteIndex = i;
+                    }
+                    if (Boolean.TRUE.equals(actions[i].getValue("edit"))) {
+                        editIndex = i;
+                    }
+                }
+            }
+            if (deleteIndex >= 0) {
+                actions = Arrays.copyOf(actions, actions.length);
+                if (deleteIndex >= 0) {
+                    actions[deleteIndex] = DELETE_ACTION;
+                }
+            } else {
+                myActions.add (0, DELETE_ACTION);
+            }
+            if (editIndex >= 0) {
+                if (editIndex == actions.length - 1) {
+                    actions = Arrays.copyOf(actions, actions.length - 1);
+                } else {
+                    Action[] actions2 = new Action[actions.length - 1];
+                    System.arraycopy(actions, 0, actions2, 0, editIndex);
+                    System.arraycopy(actions, editIndex + 1, actions2, editIndex, actions2.length - editIndex);
+                    actions = actions2;
+                }
+            }
         } else
         if (node instanceof Variable) {
             myActions.add (CREATE_FIXED_WATCH_ACTION);
@@ -370,6 +423,9 @@ NodeActionsProviderFilter, ExtendedNodeModelFilter, TableModelFilter {
     }
 
     public boolean canRename(ExtendedNodeModel original, Object node) throws UnknownTypeException {
+        if (fixedWatches.containsKey (new KeyWrapper(node))) {
+            return false;
+        }
         return original.canRename(node);
     }
 
