@@ -45,6 +45,7 @@ package org.netbeans.modules.debugger.jpda.ui;
 import java.util.LinkedHashMap;
 import java.util.Map;
 import org.netbeans.api.debugger.Properties;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.openide.util.NbBundle;
 
 /**
@@ -319,7 +320,7 @@ public class VariablesFormatter implements Cloneable {
         VariablesFormatter charSequence = new VariablesFormatter(NbBundle.getMessage(VariablesFormatter.class, "MSG_CharSequenceFormatter"));
         charSequence.setClassTypes("java.lang.CharSequence");
         charSequence.setIncludeSubTypes(true);
-        charSequence.setChildrenFormatCode(null);
+        charSequence.setChildrenFormatCode("");
         charSequence.setChildrenExpandTestCode("false");
         charSequence.setValueFormatCode("toString()");
         charSequence.isDefault = true;
@@ -360,6 +361,7 @@ public class VariablesFormatter implements Cloneable {
 
 
 
+    @DebuggerServiceRegistration(types=Properties.Reader.class)
     public static class ReaderWriter implements Properties.Reader {
 
         public String[] getSupportedClassNames() {
