@@ -52,10 +52,12 @@ import com.sun.source.tree.Tree;
 import com.sun.source.util.SourcePositions;
 import com.sun.source.util.TreePath;
 import com.sun.source.util.Trees;
-import java.awt.AWTKeyStroke;
+import java.awt.Component;
 import java.awt.Dimension;
-import java.awt.KeyboardFocusManager;
+import java.awt.Graphics;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
+import java.io.FileNotFoundException;
 import java.lang.reflect.InvocationTargetException;
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -70,25 +72,22 @@ import org.netbeans.api.editor.DialogBinding;
 import org.openide.awt.Mnemonics;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.URLMapper;
-import org.openide.loaders.DataObject;
-import org.openide.loaders.DataObjectNotFoundException;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 
 import javax.swing.*;
 import javax.swing.border.EmptyBorder;
-import javax.swing.border.CompoundBorder;
 import java.util.*;
 import java.awt.BorderLayout;
 import java.awt.EventQueue;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
 import java.awt.event.ActionListener;
-import java.awt.event.KeyEvent;
+import java.io.BufferedReader;
 import java.io.IOException;
+import java.io.InputStreamReader;
 import java.lang.ref.WeakReference;
 import java.lang.reflect.Method;
 import java.util.concurrent.Future;
+import java.util.logging.Logger;
 import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.element.AnnotationValue;
 import javax.lang.model.element.Element;
@@ -98,6 +97,7 @@ import javax.lang.model.type.DeclaredType;
 import javax.lang.model.type.ErrorType;
 import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.Elements;
+import javax.swing.border.Border;
 import javax.swing.text.Document;
 import javax.swing.text.StyledDocument;
 import org.netbeans.api.debugger.Session;
@@ -106,13 +106,12 @@ import org.netbeans.api.java.source.CancellableTask;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
-import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.editor.EditorUI;
+import org.netbeans.editor.Utilities;
 import org.netbeans.modules.java.preprocessorbridge.spi.WrapperFactory;
 import org.netbeans.spi.debugger.jpda.EditorContext;
 import org.netbeans.spi.debugger.ui.EditorContextDispatcher;
 import org.openide.ErrorManager;
-import org.openide.cookies.EditorCookie;
 import org.openide.text.NbDocument;
 import org.openide.util.HelpCtx;
 import org.openide.util.RequestProcessor;
@@ -124,6 +123,8 @@ import org.openide.util.RequestProcessor;
  */
 public class WatchPanel {
 
+    private static final Logger logger = Logger.getLogger(WatchPanel.class.getName());
+
     private JPanel panel;
     private JEditorPane editorPane;
     private String expression;
@@ -187,108 +188,202 @@ public class WatchPanel {
                 csf = d.getCurrentCallStackFrame();
             }
         }
+        boolean adjustContext = true;
+        Context c;
         if (csf != null) {
             Session session = en.lookupFirst(null, Session.class);
             String language = session.getCurrentLanguage();
             SourcePath sp = en.lookupFirst(null, SourcePath.class);
-            Context c = new Context();
+            c = new Context();
             c.url = sp.getURL(csf, language);
             c.line = csf.getLineNumber(language);
-            if (c.line == -1) {
-                c.line = 1;
-            }
             c.debugger = d;
-            return c;
+            if (c.line > 0) {
+                adjustContext = false;
+                c.line--;
+            }
         } else {
             EditorContext context = EditorContextBridge.getContext();
             String url = context.getCurrentURL();
             if (url != null && url.length() > 0) {
-                Context c = new Context();
+                c = new Context();
                 c.url = url;
                 c.line = context.getCurrentLineNumber();
-                if (c.line == -1) {
-                    c.line = 1;
-                }
                 c.debugger = d;
-                return c;
             } else {
                 url = EditorContextDispatcher.getDefault().getMostRecentURLAsString();
                 if (url != null && url.length() > 0) {
-                    Context c = new Context();
+                    c = new Context();
                     c.url = url;
                     c.line = EditorContextDispatcher.getDefault().getMostRecentLineNumber();
-                    if (c.line == -1) {
-                        c.line = 1;
-                    }
                     c.debugger = d;
-                    return c;
                 } else {
                     return null;
                 }
             }
         }
+        if (adjustContext) {
+            adjustLine(c);
+        }
+        return c;
+    }
+
+    private static void adjustLine(Context c) {
+        if (c.line == -1) {
+            c.line = 1;
+        }
+        URL url;
+        try {
+            url = new URL(c.url);
+        } catch (MalformedURLException ex) {
+            return ;
+        }
+        FileObject fo = URLMapper.findFileObject(url);
+        if (fo == null) {
+            return ;
+        }
+        if (!"java".equalsIgnoreCase(fo.getExt())) {
+            // we do not understand other languages
+            return ;
+        }
+        BufferedReader br;
+        try {
+            br = new BufferedReader(new InputStreamReader(fo.getInputStream()));
+        } catch (FileNotFoundException ex) {
+            return ;
+        }
+        try {
+            int line = findClassLine(br);
+            line = findMethodLine(line, br);
+            if (c.line < line) {
+                c.line = line;
+            }
+        } catch (IOException ioex) {
+        } finally {
+            try {
+                br.close();
+            } catch (IOException ex) {
+            }
+        }
+    }
+
+    private static int findClassLine(BufferedReader br) throws IOException {
+        int l = 1;
+        String line;
+        boolean comment = false;
+        boolean classDecl = false;
+        for (; (line = br.readLine()) != null; l++) {
+            if (classDecl) {
+                if (line.indexOf('{') >= 0) {
+                    return l + 1;
+                } else {
+                    continue;
+                }
+            }
+            boolean slash = false;
+            boolean asterix = false;
+            for (int i = 0; i < line.length(); i++) {
+                char c = line.charAt(i);
+                if (comment) {
+                    if (asterix && c == '/') {
+                        comment = false;
+                        asterix = false;
+                        continue;
+                    }
+                    asterix = c == '*';
+                    continue;
+                }
+                if (slash && c == '*') {
+                    comment = true;
+                    slash = false;
+                    continue;
+                }
+                if (c == '/') {
+                    if (slash) {
+                        // comment, ignore the rest of the line
+                        break;
+                    }
+                    slash = true;
+                }
+                if (c == 'c' && line.length() > (i+"class".length()) && "lass".equals(line.substring(i+1, i+5))) {
+                    // class declaration
+                    if (line.indexOf('{', i+5) > 0) {
+                        return l + 1;
+                    }
+                }
+            }
+        }
+        return 1; // Did not find anything interesting
     }
     
+    private static int findMethodLine(int l, BufferedReader br) throws IOException {
+        int origLine = l;
+        String line;
+        boolean isParenthesis = false;
+        boolean isThrows = false;
+        for (; (line = br.readLine()) != null; l++) {
+            int i = 0;
+            if (!isParenthesis && (i = line.indexOf(')')) >= 0 || isParenthesis) {
+                isParenthesis = true;
+                if (!isThrows) {
+                    for (i++; i < line.length() && Character.isWhitespace(line.charAt(i)); i++) ;
+                    if ((i+"throws".length()) < line.length() && "throws".equals(line.substring(i, i+"throws".length()))) {
+                        isThrows = true;
+                    }
+                }
+                if (isThrows) {
+                    i = line.indexOf("{", i);
+                    if (i < 0) i = line.length();
+                }
+                if (i < line.length()) {
+                    if (line.charAt(i) == '{') {
+                        return l;
+                    } else {
+                        isParenthesis = false;
+                    }
+                }
+            }
+        }
+        return origLine;
+    }
+
     public static void setupContext(final JEditorPane editorPane, String url, int line) {
         setupContext(editorPane, url, line, null);
     }
 
-    public static void setupContext(final JEditorPane editorPane, String url, int line, final JPDADebugger debugger) {
+    public static void setupContext(final JEditorPane editorPane, String url, final int line, final JPDADebugger debugger) {
         final FileObject file;
-        final StyledDocument doc;
         try {
             file = URLMapper.findFileObject (new URL (url));
             if (file == null) {
                 return;
             }
-            try {
-                DataObject dobj = DataObject.find (file);
-                EditorCookie ec = (EditorCookie) dobj.getCookie(EditorCookie.class);
-                if (ec == null) {
-                    return;
-                }
-                try {
-                    doc = ec.openDocument();
-                } catch (IOException ex) {
-                    ErrorManager.getDefault().notify(ex);
-                    return;
-                }
-            } catch (DataObjectNotFoundException ex) {
-                // null dobj
-                return;
-            }
         } catch (MalformedURLException e) {
             // null dobj
             return;
         }
-        try {
-            final int offset = NbDocument.findLineOffset(doc, line - 1);
-            //editorPane.getDocument().putProperty(javax.swing.text.Document.StreamDescriptionProperty, dobj);
-            //System.err.println("WatchPanel.setupContext("+file+", "+line+", "+offset+")");
-            Runnable bindComponentToDocument = new Runnable() {
-                public void run() {
-                    String origText = editorPane.getText();
-                    DialogBinding.bindComponentToDocument(doc, offset, 0, editorPane);
-                    Document editPaneDoc = editorPane.getDocument();
-                    editPaneDoc.putProperty("org.netbeans.modules.editor.java.JavaCompletionProvider.skipAccessibilityCheck", "true");
-                    editPaneDoc.putProperty(WrapperFactory.class,
-                            debugger != null ? new MyWrapperFactory(debugger, file, doc) : null);
-                    editorPane.setText(origText);
-                }
-            };
-            if (EventQueue.isDispatchThread()) {
-                bindComponentToDocument.run();
-            } else {
-                try {
-                    SwingUtilities.invokeAndWait(bindComponentToDocument);
-                } catch (InterruptedException ex) {
-                    Exceptions.printStackTrace(ex);
-                } catch (InvocationTargetException ex) {
-                    Exceptions.printStackTrace(ex);
-                }
+        //System.err.println("WatchPanel.setupContext("+file+", "+line+", "+offset+")");
+        Runnable bindComponentToDocument = new Runnable() {
+            public void run() {
+                String origText = editorPane.getText();
+                DialogBinding.bindComponentToFile(file, (line >= 0) ? line : 0, 0, 0, editorPane);
+                Document editPaneDoc = editorPane.getDocument();
+                editPaneDoc.putProperty("org.netbeans.modules.editor.java.JavaCompletionProvider.skipAccessibilityCheck", "true");
+                editPaneDoc.putProperty(WrapperFactory.class,
+                        debugger != null ? new MyWrapperFactory(debugger, file) : null);
+                editorPane.setText(origText);
+            }
+        };
+        if (EventQueue.isDispatchThread()) {
+            bindComponentToDocument.run();
+        } else {
+            try {
+                SwingUtilities.invokeAndWait(bindComponentToDocument);
+            } catch (InterruptedException ex) {
+                Exceptions.printStackTrace(ex);
+            } catch (InvocationTargetException ex) {
+                Exceptions.printStackTrace(ex);
             }
-        } catch (IndexOutOfBoundsException ioobex) {
-            ErrorManager.getDefault().notify(ErrorManager.INFORMATIONAL, ioobex);
         }
         setupUI(editorPane);
     }
@@ -339,18 +434,10 @@ public class WatchPanel {
                 }
             }
         }
-        editorPane = new JEditorPane();//expression); // NOI18N
-        editorPane.setText(expression);
+        JComponent [] editorComponents = Utilities.createSingleLineEditor("text/plain");
+        JScrollPane sp = (JScrollPane) editorComponents[0];
+        editorPane = (JEditorPane) editorComponents[1];
 
-        ActionListener editorPaneUpdated = new ActionListener() {
-            public void actionPerformed(ActionEvent e) {
-                editorPane.setText (expression);
-                editorPane.selectAll ();
-            }
-        };
-        setupContext(editorPane, editorPaneUpdated);
-        
-        JScrollPane sp = createScrollableLineEditor(editorPane);
         int h = sp.getPreferredSize().height;
         int w = Math.min(70*editorPane.getFontMetrics(editorPane.getFont()).charWidth('a'),
                          org.openide.windows.WindowManager.getDefault().getMainWindow().getSize().width);
@@ -375,6 +462,15 @@ public class WatchPanel {
         editorPane.setText (expression);
         editorPane.selectAll ();
 
+        ActionListener editorPaneUpdated = new ActionListener() {
+            @Override
+            public void actionPerformed(ActionEvent e) {
+                editorPane.setText (expression);
+                editorPane.selectAll ();
+            }
+        };
+        setupContext(editorPane, editorPaneUpdated);
+
         textLabel.setLabelFor (editorPane);
         HelpCtx.setHelpIDString(editorPane, "debug.customize.watch");
         editorPane.requestFocus ();
@@ -385,56 +481,8 @@ public class WatchPanel {
     public String getExpression() {
         return editorPane.getText().trim();
     }
-    
-    public static JScrollPane createScrollableLineEditor(JEditorPane editorPane) {
-        // Remove control keys:
-        KeyStroke enterKs = KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0);
-        KeyStroke escKs = KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0);
-        KeyStroke tabKs = KeyStroke.getKeyStroke(KeyEvent.VK_TAB, 0);
-        InputMap im = editorPane.getInputMap();
-        im.put(enterKs, "none");
-        im.put(escKs, "none");
-        im.put(tabKs, "none");
-        
-        final JScrollPane sp = new JScrollPane(JScrollPane.VERTICAL_SCROLLBAR_NEVER,
-                                         JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
-                
-        editorPane.setBorder (
-            new CompoundBorder (editorPane.getBorder(),
-            new EmptyBorder (0, 0, 0, 0))
-        );
-        
-        JTextField referenceTextField = new JTextField("M");
-        JPanel panel = new JPanel(new GridBagLayout());
-        panel.setBackground(referenceTextField.getBackground());
-        sp.setBorder(referenceTextField.getBorder());
-        sp.setBackground(referenceTextField.getBackground());
-        
-        GridBagConstraints gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
-        gridBagConstraints.anchor = java.awt.GridBagConstraints.LINE_START;
-        gridBagConstraints.weightx = 1.0;
-        panel.add(editorPane, gridBagConstraints);
-        sp.setViewportView(panel);
-        
-        int preferredHeight = referenceTextField.getPreferredSize().height;
-        Dimension spDim = sp.getPreferredSize();
-        if (spDim.height < preferredHeight) {
-            sp.setPreferredSize(referenceTextField.getPreferredSize());
-        } else {
-            sp.setPreferredSize(spDim);
-        }
-        sp.setMinimumSize(spDim);
-        
-        setupUI(editorPane);
-        
-        Set<AWTKeyStroke> tfkeys = referenceTextField.getFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS);
-        editorPane.setFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS, tfkeys);
-        tfkeys = referenceTextField.getFocusTraversalKeys(KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS);
-        editorPane.setFocusTraversalKeys(KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS, tfkeys);
-        return sp;
-    }
 
+    
     private static String getSelectedIdentifier (
         StyledDocument doc,
         JEditorPane ep,
@@ -497,7 +545,7 @@ public class WatchPanel {
         private WeakReference<JPDADebugger> debuggerRef;
         private FileObject fileObject;
 
-        public MyWrapperFactory(JPDADebugger debugger, FileObject file, StyledDocument doc) {
+        public MyWrapperFactory(JPDADebugger debugger, FileObject file) {
             debuggerRef = new WeakReference(debugger);
             this.fileObject = file;
         }
@@ -663,7 +711,51 @@ public class WatchPanel {
             trees.printMessage(arg0, arg1, arg2, arg3);
         }
 
+        @Override
+        public String getDocComment(TreePath path) {
+            return trees.getDocComment(path);
+        }
+
+    }
+
+    public static final class DelegatingBorder implements Border {
+
+        private Border delegate;
+        private Insets insets;// = new Insets(1, 1, 1, 1);
+
+        public DelegatingBorder(Border delegate, Insets insets) {
+            this.delegate = delegate;
+            this.insets = insets;
+        }
+
+        @Override
+        public void paintBorder(Component c, Graphics g, int x, int y, int width, int height) {
+            //logger.fine("Delegate paintBorder("+c+", "+g+", "+x+", "+y+", "+width+", "+height+")");
+            delegate.paintBorder(c, g, x, y, width, height);
+        }
+
+        public Insets getInsets() {
+            return insets;
+        }
+
+        public void setInsets(Insets insets) {
+            this.insets = insets;
+        }
+
+        @Override
+        public Insets getBorderInsets(Component c) {
+            //logger.fine("Delegate getBorderInsets() = "+delegate.getBorderInsets(c));
+            //Insets insets = delegate.getBorderInsets(c);
+            //insets.top = 0;
+            //insets.bottom = 0;
+            return insets;
+        }
+
+        @Override
+        public boolean isBorderOpaque() {
+            return delegate.isBorderOpaque();
+        }
+
     }
 
 }
-
