@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,25 +47,23 @@ package org.netbeans.modules.debugger.jpda.ui.actions;
 import java.awt.event.ActionEvent;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
-import javax.swing.ImageIcon;
 
 import org.netbeans.api.debugger.ActionsManager;
 import org.netbeans.api.debugger.Breakpoint;
 import org.netbeans.api.debugger.DebuggerManager;
+import org.netbeans.api.debugger.jpda.ClassLoadUnloadBreakpoint;
 import org.netbeans.api.debugger.jpda.FieldBreakpoint;
 import org.netbeans.api.debugger.jpda.JPDABreakpoint;
 import org.netbeans.api.debugger.jpda.LineBreakpoint;
 import org.netbeans.api.debugger.jpda.MethodBreakpoint;
 
 import org.netbeans.modules.debugger.jpda.ui.EditorContextBridge;
+import org.netbeans.modules.debugger.jpda.ui.breakpoints.ClassBreakpointPanel;
 import org.netbeans.modules.debugger.jpda.ui.breakpoints.FieldBreakpointPanel;
 import org.netbeans.modules.debugger.jpda.ui.breakpoints.MethodBreakpointPanel;
 
-import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
-import org.openide.util.Task;
-import org.openide.util.Utilities;
 
 
 /**
@@ -119,69 +120,78 @@ public class ToggleMethodFieldBreakpointAction extends AbstractAction {//impleme
      */
     
     public void actionPerformed (ActionEvent evt) {
-        Task[] toggleBpTaskPtr = new Task[] { null };
-        if (!submitFieldOrMethodBreakpoint(toggleBpTaskPtr)) {
-            Task toggleBpTask = DebuggerManager.getDebuggerManager().getActionsManager().postAction(ActionsManager.ACTION_TOGGLE_BREAKPOINT);
-            synchronized (toggleBpTaskPtr) {
-                toggleBpTaskPtr[0] = toggleBpTask;
-                toggleBpTaskPtr.notify();
-            }
+        if (!submitFieldOrMethodOrClassBreakpoint()) {
+            // Do the toggle BP action directly in this AWT so that it gets the correct current line number.
+            DebuggerManager.getDebuggerManager().getActionsManager().doAction(ActionsManager.ACTION_TOGGLE_BREAKPOINT);
         }
     }
     
-    private boolean submitFieldOrMethodBreakpoint(final Task[] toggleBpTaskPtr) {
+    private boolean submitFieldOrMethodOrClassBreakpoint() {
         // 1) get class name & element info
+        final String[] classDeclaration = new String[] { null };
+        java.awt.IllegalComponentStateException cdex;
         final String[] className = new String[] { null };
         java.awt.IllegalComponentStateException cex;
-        try {
-            className[0] = EditorContextBridge.getContext().getCurrentClassName();
-            cex = null;
-        } catch (java.awt.IllegalComponentStateException icsex) {
-            cex = icsex;
-        }
         final String[] fieldName = new String[] { null };
         java.awt.IllegalComponentStateException fex;
-        try {
-            fieldName[0] = EditorContextBridge.getContext().getCurrentFieldName();
-            fex = null;
-        } catch (java.awt.IllegalComponentStateException icsex) {
-            fex = icsex;
-        }
         final String methodName;
         final String methodSignature;
         java.awt.IllegalComponentStateException mex;
-        if (fex != null || fieldName[0] == null || fieldName[0].length() == 0) {
-            fieldName[0] = null;
-            String[] methodInfo;
+        try {
+            classDeclaration[0] = EditorContextBridge.getCurrentClassDeclaration();
+            cdex = null;
+        } catch (java.awt.IllegalComponentStateException icsex) {
+            cdex = icsex;
+        }
+        if (classDeclaration[0] == null) {
             try {
-                methodInfo = EditorContextBridge.getContext().getCurrentMethodDeclaration();
-                mex = null;
+                className[0] = EditorContextBridge.getContext().getCurrentClassName();
+                cex = null;
             } catch (java.awt.IllegalComponentStateException icsex) {
-                mex = icsex;
-                methodInfo = null;
+                cex = icsex;
             }
-            if (methodInfo != null) {
-                methodName = methodInfo[0];
-                methodSignature = methodInfo[1];
-                if (methodInfo[2] != null) {
-                    className[0] = methodInfo[2];
+            try {
+                fieldName[0] = EditorContextBridge.getContext().getCurrentFieldName();
+                fex = null;
+            } catch (java.awt.IllegalComponentStateException icsex) {
+                fex = icsex;
+            }
+            if (fieldName[0] == null || fieldName[0].length() == 0) {
+                fieldName[0] = null;
+                String[] methodInfo;
+                try {
+                    methodInfo = EditorContextBridge.getContext().getCurrentMethodDeclaration();
+                    mex = null;
+                } catch (java.awt.IllegalComponentStateException icsex) {
+                    mex = icsex;
+                    methodInfo = null;
+                }
+                if (methodInfo != null) {
+                    methodName = methodInfo[0];
+                    methodSignature = methodInfo[1];
+                    if (methodInfo[2] != null) {
+                        className[0] = methodInfo[2];
+                    }
+                } else if (mex == null) {
+                    return false;
+                } else {
+                    methodName = null;
+                    methodSignature = null;
                 }
-            } else if (mex == null) {
-                return false;
             } else {
+                mex = null;
                 methodName = null;
                 methodSignature = null;
             }
         } else {
-            mex = null;
-            methodName = null;
-            methodSignature = null;
+            methodName = methodSignature = null;
+            cex = fex = mex = null;
         }
-        if (cex != null || fex != null || mex != null) {
+        if (cdex != null || cex != null || fex != null || mex != null) {
             final int ln = EditorContextBridge.getContext().getCurrentLineNumber ();
             final String url = EditorContextBridge.getContext().getCurrentURL ();
             final java.awt.IllegalComponentStateException[] exs = new java.awt.IllegalComponentStateException[]
-                    { cex, fex, mex };
+                    { cdex, cex, fex, mex };
             synchronized (this) {
                 if (postponedToggleRP == null) {
                     postponedToggleRP = new RequestProcessor("Postponed ToggleMethodFieldBreakpointAction", 1);
@@ -190,28 +200,20 @@ public class ToggleMethodFieldBreakpointAction extends AbstractAction {//impleme
             postponedToggleRP.post(new Runnable() {
                 public void run() {
                     // Re-try to submit the field or method breakpoint again
-                    String cn = (exs[0] != null) ? exs[0].getMessage() : className[0];
-                    String fn = (exs[1] != null) ? exs[1].getMessage() : fieldName[0];
-                    String mn = (exs[2] != null) ? exs[2].getMessage() : methodName;
-                    String ms = (exs[2] != null) ? exs[2].getLocalizedMessage() : methodSignature;
+                    String cdn = (exs[0] != null) ? exs[0].getMessage() : classDeclaration[0];
+                    String cn = (exs[1] != null) ? exs[1].getMessage() : className[0];
+                    String fn = (exs[2] != null) ? exs[2].getMessage() : fieldName[0];
+                    String mn = (exs[3] != null) ? exs[3].getMessage() : methodName;
+                    String ms = (exs[3] != null) ? exs[3].getLocalizedMessage() : methodSignature;
                     if (fn != null && fn.length() == 0) fn = null;
-                    if (submitFieldOrMethodBreakpoint(cn, fn, mn, ms, url, ln)) {
+                    if (cdn != null) {
+                        cn = cdn;
+                        fn = mn = ms = null;
+                    } else if (fn == null && mn == null) {
+                        return ; // line breakpoint only, which was submitted already.
+                    }
+                    if (submitFieldOrMethodOrClassBreakpoint(cn, fn, mn, ms, null, ln)) {
                         // We've submitted a field or method breakpoint, so delete the line one:
-                        Task toggleBpTask = null;
-                        if (toggleBpTaskPtr != null) {
-                            synchronized (toggleBpTaskPtr) {
-                                if (toggleBpTaskPtr[0] == null) {
-                                    try {
-                                        toggleBpTaskPtr.wait();
-                                    } catch (InterruptedException ex) {}
-                                    toggleBpTask = toggleBpTaskPtr[0];
-                                }
-                            }
-                        }
-                        // Wait for the line breakpoint to be actually submitted
-                        if (toggleBpTask != null) {
-                            toggleBpTask.waitFinished();
-                        }
                         LineBreakpoint lb = ToggleBreakpointActionProvider.findBreakpoint (
                             url, ln
                         );
@@ -225,9 +227,15 @@ public class ToggleMethodFieldBreakpointAction extends AbstractAction {//impleme
         } else {
             int ln = EditorContextBridge.getContext().getCurrentLineNumber ();
             String url = EditorContextBridge.getContext().getCurrentURL ();
-            return submitFieldOrMethodBreakpoint(className[0], fieldName[0],
-                                                 methodName, methodSignature,
-                                                 url, ln);
+            if (classDeclaration[0] != null) {
+                return submitFieldOrMethodOrClassBreakpoint(classDeclaration[0], null,
+                                                            null, null,
+                                                            url, ln);
+            } else {
+                return submitFieldOrMethodOrClassBreakpoint(className[0], fieldName[0],
+                                                            methodName, methodSignature,
+                                                            url, ln);
+            }
         }
         
         /*
@@ -259,19 +267,24 @@ public class ToggleMethodFieldBreakpointAction extends AbstractAction {//impleme
          */
     }
         
-    private boolean submitFieldOrMethodBreakpoint(String className, String fieldName,
-                                                  String methodName, String methodSignature,
-                                                  String url, int line) {
+    private boolean submitFieldOrMethodOrClassBreakpoint(String className, String fieldName,
+                                                         String methodName, String methodSignature,
+                                                         String url, int line) {
+        if (className == null) {
+            return false;   // Can not do anything without the class name
+        }
         // 2) find and remove existing line breakpoint
         JPDABreakpoint b;
         if (fieldName != null) {
             b = findBreakpoint (className, fieldName);
         } else if (methodName != null) {
             b = findBreakpoint (className, methodName, methodSignature);
+        } else if (className != null) {
+            b = findBreakpoint (className);
         } else {
             return false;
         }
-        if (b == null) {
+        if (b == null && url != null) {
             b = ToggleBreakpointActionProvider.findBreakpoint(url, line);
         }
         DebuggerManager d = DebuggerManager.getDebuggerManager();
@@ -284,10 +297,13 @@ public class ToggleMethodFieldBreakpointAction extends AbstractAction {//impleme
         if (fieldName != null) {
             b = FieldBreakpoint.create(className, fieldName, FieldBreakpoint.TYPE_MODIFICATION | FieldBreakpoint.TYPE_ACCESS);
             b.setPrintText(NbBundle.getMessage(FieldBreakpointPanel.class, "CTL_Field_Breakpoint_Print_Text"));
-        } else {
+        } else if (methodName != null) {
             b = MethodBreakpoint.create(className, methodName);
             ((MethodBreakpoint) b).setMethodSignature(methodSignature);
             b.setPrintText(NbBundle.getMessage(MethodBreakpointPanel.class, "CTL_Method_Breakpoint_Print_Text"));
+        } else {
+            b = ClassLoadUnloadBreakpoint.create(className, false, ClassLoadUnloadBreakpoint.TYPE_CLASS_LOADED_UNLOADED);
+            b.setPrintText (NbBundle.getMessage(ClassBreakpointPanel.class, "CTL_Class_Breakpoint_Print_Text"));
         }
         d.addBreakpoint(b);
         return true;
@@ -319,6 +335,36 @@ public class ToggleMethodFieldBreakpointAction extends AbstractAction {//impleme
         return b;
     }
     
+    private static ClassLoadUnloadBreakpoint findBreakpoint(String className) {
+        Breakpoint[] breakpoints = DebuggerManager.getDebuggerManager().getBreakpoints();
+        for (int i = 0; i < breakpoints.length; i++) {
+            if (!(breakpoints[i] instanceof ClassLoadUnloadBreakpoint)) {
+                continue;
+            }
+            ClassLoadUnloadBreakpoint cb = (ClassLoadUnloadBreakpoint) breakpoints[i];
+            String[] classFilters = cb.getClassFilters();
+            int j;
+            for (j = 0; j < classFilters.length; j++) {
+                if (match(className, classFilters[j])) {
+                    break;
+                }
+            }
+            if (j < classFilters.length) {
+                String[] exClassFilters = cb.getClassExclusionFilters();
+                for (j = 0; j < exClassFilters.length; j++) {
+                    if (match(className, exClassFilters[j])) {
+                        j = -1;
+                        break;
+                    }
+                }
+                if (j >= 0) {
+                    return cb;
+                }
+            }
+        }
+        return null;
+    }
+
     private static FieldBreakpoint findBreakpoint(String className, String fieldName) {
         Breakpoint[] breakpoints = DebuggerManager.getDebuggerManager().getBreakpoints();
         for (int i = 0; i < breakpoints.length; i++) {
