@@ -47,6 +47,8 @@ package org.netbeans.modules.debugger.jpda.ui.debugging;
 import java.awt.event.ActionEvent;
 import java.awt.event.HierarchyEvent;
 import java.awt.event.HierarchyListener;
+import java.lang.ref.Reference;
+import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -68,6 +70,7 @@ import org.openide.util.NbPreferences;
 import org.netbeans.modules.debugger.jpda.ui.models.DebuggingMonitorModel;
 import org.netbeans.modules.debugger.jpda.ui.models.DebuggingNodeModel;
 import org.netbeans.modules.debugger.jpda.ui.models.DebuggingTreeModel;
+import org.openide.awt.Mnemonics;
 import org.openide.util.ImageUtilities;
 import org.openide.util.actions.Presenter;
 
@@ -232,7 +235,7 @@ public final class FiltersDescriptor {
         
         private boolean isSelected;
         private Group group;
-        private JToggleButton toggleButton; // [TODO]
+        private Reference<JToggleButton> toggleButtonRef;
         
         Item (String name, String displayName, String tooltip,
                 boolean isSelected, Icon selectedIcon) {
@@ -274,26 +277,22 @@ public final class FiltersDescriptor {
                 return;
             }
             isSelected = state;
-            toggleButton.setSelected(state);
+            JToggleButton toggleButton = toggleButtonRef.get();
+            if (toggleButton != null) {
+                toggleButton.setSelected(state);
+            }
             if (state && group != null) {
                 for (Item item : group.getItems()) {
                     if (item != this && item.isSelected()) {
-                        JToggleButton tb = item.getToggleButton();
-                        item.isSelected = false; // do not call item.setSelected() here
-                        item.writeValue();
-                        tb.setSelected(false);
+                        item.setSelected(false);
                     } // if
                 } // for
             } // if
             writeValue();
         }
 
-        public JToggleButton getToggleButton() {
-            return toggleButton;
-        }
-        
         public void setToggleButton(JToggleButton button) {
-            toggleButton = button;
+            toggleButtonRef = new WeakReference<JToggleButton>(button);
 //            if (group != null && isSelected) {
 //                toggleButton.setEnabled(false);
 //            }
@@ -382,7 +381,12 @@ public final class FiltersDescriptor {
         /** Creates a new instance of SortByNameAction */
         SortAction (Item item) {
             this.filterItem = item;
-            putValue(Action.NAME, item.getDisplayName());
+            String displayName = item.getDisplayName();
+            int i = Mnemonics.findMnemonicAmpersand(displayName);
+            if (i >= 0) {
+                displayName = displayName.substring(0, i) + displayName.substring(i+1);
+            }
+            putValue(Action.NAME, displayName);
             putValue(Action.SMALL_ICON, item.getIcon());
         }
 
@@ -392,7 +396,8 @@ public final class FiltersDescriptor {
         }
 
         protected final JRadioButtonMenuItem obtainMenuItem () {
-            JRadioButtonMenuItem menuItem = new JRadioButtonMenuItem((String)getValue(Action.NAME));
+            JRadioButtonMenuItem menuItem = new JRadioButtonMenuItem();
+            Mnemonics.setLocalizedText(menuItem, filterItem.getDisplayName());
             menuItem.setAction(this);
             menuItem.addHierarchyListener(new ParentChangeListener(menuItem));
             menuItem.setSelected(filterItem.isSelected);
@@ -453,7 +458,8 @@ public final class FiltersDescriptor {
         }
 
         private JMenuItem createSubmenu () {
-            JMenuItem menu = new JMenu(NbBundle.getMessage(FiltersDescriptor.class, "LBL_FilterSubmenu")); //NOI18N
+            JMenuItem menu = new JMenu();
+            Mnemonics.setLocalizedText(menu, NbBundle.getMessage(FiltersDescriptor.class, "LBL_FilterSubmenu"));
             JMenuItem menuItem;
             String filterName;
             for (Item item : filtersDesc.filters) {
@@ -462,6 +468,7 @@ public final class FiltersDescriptor {
                 }
                 filterName = item.getName();
                 menuItem = new JCheckBoxMenuItem(item.getDisplayName(), item.isSelected());
+                Mnemonics.setLocalizedText(menuItem, item.getDisplayName());
                 menuItem.addActionListener(this);
                 menuItem.putClientProperty(PROP_FILTER_NAME, filterName);
                 menu.add(menuItem);
