@@ -56,6 +56,7 @@ import org.netbeans.api.debugger.jpda.LineBreakpoint;
 import org.netbeans.api.debugger.jpda.MethodBreakpoint;
 import org.netbeans.api.debugger.jpda.ThreadBreakpoint;
 import org.netbeans.modules.debugger.jpda.ui.EditorContextBridge;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.netbeans.spi.viewmodel.ModelEvent;
 import org.netbeans.spi.viewmodel.NodeModel;
 import org.netbeans.spi.viewmodel.ModelListener;
@@ -67,6 +68,7 @@ import org.openide.util.NbBundle;
 /**
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistration(path="BreakpointsView", types=NodeModel.class)
 public class BreakpointsNodeModel implements NodeModel {
 
     public static final String BREAKPOINT =
@@ -551,7 +553,7 @@ public class BreakpointsNodeModel implements NodeModel {
     private JPDABreakpoint currentBreakpoint;
     private String bold (JPDABreakpoint b, String name) {
         return b == currentBreakpoint ?
-            BoldVariablesTableModelFilterFirst.toHTML (
+            BoldVariablesTableModelFilter.toHTML (
                 name,
                 true,
                 false,
