@@ -69,11 +69,13 @@ import org.netbeans.api.debugger.jpda.JPDAThread;
 import org.netbeans.api.debugger.jpda.JPDAThreadGroup;
 import org.netbeans.modules.debugger.jpda.ui.SourcePath;
 import org.netbeans.modules.debugger.jpda.ui.debugging.FiltersDescriptor;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.netbeans.spi.viewmodel.NodeActionsProvider;
 import org.netbeans.spi.viewmodel.ModelListener;
 import org.netbeans.spi.viewmodel.UnknownTypeException;
 import org.netbeans.spi.viewmodel.Models;
 import org.netbeans.spi.viewmodel.TreeModel;
+import org.openide.awt.Mnemonics;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.util.actions.Presenter;
@@ -82,6 +84,9 @@ import org.openide.util.actions.Presenter;
 /**
  * @author   Martin Entlicher
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/DebuggingView",
+                             types=NodeActionsProvider.class,
+                             position=700)
 public class DebuggingActionsProvider implements NodeActionsProvider {
 
     private JPDADebugger debugger;
@@ -94,6 +99,7 @@ public class DebuggingActionsProvider implements NodeActionsProvider {
     private Action INTERRUPT_ACTION;
     private Action COPY_TO_CLBD_ACTION;
     private Action LANGUAGE_SELECTION;
+    private Action GO_TO_SOURCE_ACTION;
 
 
     public DebuggingActionsProvider (ContextProvider lookupProvider) {
@@ -107,6 +113,7 @@ public class DebuggingActionsProvider implements NodeActionsProvider {
         COPY_TO_CLBD_ACTION = createCOPY_TO_CLBD_ACTION(requestProcessor);
         POP_TO_HERE_ACTION = createPOP_TO_HERE_ACTION(requestProcessor);
         LANGUAGE_SELECTION = new LanguageSelection(session);
+        GO_TO_SOURCE_ACTION = createGO_TO_SOURCE_ACTION(requestProcessor);
     }
     
 
@@ -183,25 +190,33 @@ public class DebuggingActionsProvider implements NodeActionsProvider {
     );
     }
 
-    static Action GO_TO_SOURCE_ACTION = Models.createAction (
-        NbBundle.getBundle(DebuggingActionsProvider.class).getString("CTL_ThreadAction_GoToSource_Label"),
-        new Models.ActionPerformer () {
-            public boolean isEnabled (Object node) {
-                if (!(node instanceof CallStackFrame)) {
-                    return false;
-                } else if (DebuggingTreeModel.isMethodInvoking(((CallStackFrame) node).getThread())) {
-                    return false;
+    static final Action createGO_TO_SOURCE_ACTION(final RequestProcessor requestProcessor) {
+        return Models.createAction (
+            NbBundle.getBundle(DebuggingActionsProvider.class).getString("CTL_ThreadAction_GoToSource_Label"),
+            new Models.ActionPerformer () {
+                public boolean isEnabled (Object node) {
+                    if (!(node instanceof CallStackFrame)) {
+                        return false;
+                    } else if (DebuggingTreeModel.isMethodInvoking(((CallStackFrame) node).getThread())) {
+                        return false;
+                    }
+                    return isGoToSourceSupported ((CallStackFrame) node);
                 }
-                return isGoToSourceSupported ((CallStackFrame) node);
-            }
-            
-            public void perform (Object[] nodes) {
-                goToSource((CallStackFrame) nodes [0]);
-            }
-        },
-        Models.MULTISELECTION_TYPE_EXACTLY_ONE
-    
-    );
+
+                public void perform (final Object[] nodes) {
+                    // Do not do expensive actions in AWT,
+                    // It can also block if it can not procceed for some reason
+                    requestProcessor.post(new Runnable() {
+                        public void run() {
+                            goToSource((CallStackFrame) nodes [0]);
+                        }
+                    });
+                }
+            },
+            Models.MULTISELECTION_TYPE_EXACTLY_ONE
+
+        );
+    }
 
     static final Action createPOP_TO_HERE_ACTION(final RequestProcessor requestProcessor) {
         return Models.createAction (
@@ -352,7 +367,8 @@ public class DebuggingActionsProvider implements NodeActionsProvider {
         }
 
         public JMenuItem getPopupPresenter() {
-            JMenu displayAsPopup = new JMenu(NbBundle.getMessage(DebuggingActionsProvider.class, "CTL_Session_Popup_Language"));
+            JMenu displayAsPopup = new JMenu();
+            Mnemonics.setLocalizedText(displayAsPopup, NbBundle.getMessage(DebuggingActionsProvider.class, "CTL_Session_Popup_Language"));
 
             String [] languages = session.getSupportedLanguages();
             String currentLanguage = session.getCurrentLanguage();
@@ -547,10 +563,19 @@ public class DebuggingActionsProvider implements NodeActionsProvider {
     }
 
     private static boolean isGoToSourceSupported (CallStackFrame f) {
-        String language = DebuggerManager.getDebuggerManager ().
-            getCurrentSession ().getCurrentLanguage ();
+        String path = DebuggingNodeModel.getCachedFramePath(f);
+        String clazz = null;
+        if (path == null) {
+            clazz = DebuggingNodeModel.getCachedFrameClass(f);
+            if (clazz == null) {
+                return true; // Nothing cached, but go-to-source can be tried...
+            }
+        }
         SourcePath sp = DebuggerManager.getDebuggerManager().getCurrentEngine().lookupFirst(null, SourcePath.class);
-        return sp.sourceAvailable (f, language);
+        if (path != null) {
+            return sp.sourceAvailable(path.replace(java.io.File.separatorChar, '/'), true);
+        }
+        return sp.sourceAvailable(sp.convertClassNameToRelativePath(clazz), true);
     }
     
     private static void goToSource(final CallStackFrame frame) {
