@@ -49,6 +49,8 @@ import com.sun.jdi.ObjectCollectedException;
 import com.sun.jdi.VMDisconnectedException;
 import java.awt.Color;
 import java.awt.datatransfer.Transferable;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -64,6 +66,8 @@ import java.util.prefs.PreferenceChangeListener;
 import java.util.prefs.Preferences;
 import javax.swing.Action;
 import org.netbeans.api.debugger.jpda.CallStackFrame;
+import org.netbeans.api.debugger.jpda.DeadlockDetector;
+import org.netbeans.api.debugger.jpda.DeadlockDetector.Deadlock;
 import org.netbeans.api.debugger.jpda.Field;
 
 import org.netbeans.api.debugger.jpda.JPDAClassType;
@@ -72,6 +76,7 @@ import org.netbeans.api.debugger.jpda.JPDAThread;
 import org.netbeans.api.debugger.jpda.MonitorInfo;
 import org.netbeans.api.debugger.jpda.ObjectVariable;
 import org.netbeans.spi.debugger.ContextProvider;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.netbeans.spi.debugger.ui.Constants;
 import org.netbeans.spi.viewmodel.ExtendedNodeModel;
 import org.netbeans.spi.viewmodel.ExtendedNodeModelFilter;
@@ -97,6 +102,9 @@ import org.openide.util.datatransfer.PasteType;
 /**
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/DebuggingView",
+                             types=Model.class,
+                             position=600)
 public class DebuggingMonitorModel implements ExtendedNodeModelFilter, 
 NodeActionsProviderFilter, TableModel, Constants {
     
@@ -127,18 +135,22 @@ NodeActionsProviderFilter, TableModel, Constants {
         private JPDADebugger debugger;
         private final Set<JPDAThread> threadsAskedForMonitors = new WeakSet<JPDAThread>();
         private final Set<CallStackFrame> framesAskedForMonitors = new WeakSet<CallStackFrame>();
+        private final DeadlockDetector deadlockDetector;
+        private boolean isDeadlock;
         private Preferences preferences = NbPreferences.forModule(getClass()).node("debugging"); // NOI18N
         private PreferenceChangeListener prefListener;
 
         private ModelListener modelListener;
-        private Model modelEventSource;
+        private DebuggingTreeModel modelEventSource;
     
-        Children(JPDADebugger debugger, ModelListener modelListener, Model modelEventSource) {
+        Children(JPDADebugger debugger, ModelListener modelListener, DebuggingTreeModel modelEventSource) {
             this.debugger = debugger;
             this.modelListener = modelListener;
             this.modelEventSource = modelEventSource;
             prefListener = new MonitorPreferenceChangeListener();
             preferences.addPreferenceChangeListener(WeakListeners.create(PreferenceChangeListener.class, prefListener, preferences));
+            deadlockDetector = debugger.getThreadsCollector().getDeadlockDetector();
+            deadlockDetector.addPropertyChangeListener(new DeadlockListener());
         }
 
         public Object[] getChildren (
@@ -152,7 +164,7 @@ NodeActionsProviderFilter, TableModel, Constants {
                 synchronized (threadsAskedForMonitors) {
                     threadsAskedForMonitors.add(t);
                 }
-                if (preferences.getBoolean(SHOW_MONITORS, false)) {
+                if (preferences.getBoolean(SHOW_MONITORS, false) || isDeadlock) {
                     try {
                         ObjectVariable contended = t.getContendedMonitor ();
                         ObjectVariable[] owned;
@@ -239,20 +251,24 @@ NodeActionsProviderFilter, TableModel, Constants {
             }*/
             if (o instanceof OwnedMonitors) {
                 OwnedMonitors om = (OwnedMonitors) o;
-                Object[] fo = new Object [to - from];
+                Object[] array;
                 if (om.monitors != null) {
-                    System.arraycopy (om.monitors, from, fo, 0, to - from);
+                    array = om.monitors;
                 } else {
-                    System.arraycopy (om.variables, from, fo, 0, to - from);
+                    array = om.variables;
                 }
+                from = Math.min(from, array.length);
+                to = Math.min(to, array.length);
+                Object[] fo = new Object[to - from];
+                System.arraycopy(array, from, fo, 0, to - from);
                 return fo;
             }
             if (o instanceof Monitor) {
                 return model.getChildren (((Monitor) o).variable, from, to);
             }
             if (o instanceof CallStackFrame) {
-                if (preferences.getBoolean(SHOW_MONITORS, false)) {
-                    CallStackFrame frame = (CallStackFrame) o;
+                CallStackFrame frame = (CallStackFrame) o;
+                if (preferences.getBoolean(SHOW_MONITORS, false) || isDeadlock) {
                     List<MonitorInfo> monitors = frame.getOwnedMonitors();
                     int n = monitors.size();
                     if (n > 0) {
@@ -267,7 +283,7 @@ NodeActionsProviderFilter, TableModel, Constants {
                     }
                 } else {
                     synchronized (framesAskedForMonitors) {
-                        framesAskedForMonitors.add((CallStackFrame) o);
+                        framesAskedForMonitors.add(frame);
                     }
                 }
             }
@@ -333,7 +349,7 @@ NodeActionsProviderFilter, TableModel, Constants {
             if (o instanceof ObjectVariable)
                 return true;
             if (o instanceof CallStackFrame) {
-                if (preferences.getBoolean(SHOW_MONITORS, false)) {
+                if (preferences.getBoolean(SHOW_MONITORS, false) || isDeadlock) {
                     return false;
                 } else {
                     synchronized (framesAskedForMonitors) {
@@ -344,10 +360,10 @@ NodeActionsProviderFilter, TableModel, Constants {
             return model.isLeaf (o);
         }
 
-        void setModelListener (ModelListener l, Model modelEventSource) {
+        /*void setModelListener (ModelListener l, DebuggingTreeModel modelEventSource) {
             modelListener = l;
             this.modelEventSource = modelEventSource;
-        }
+        }*/
 
         private void fireModelChange(ModelEvent me) {
             modelListener.modelChanged(me);
@@ -358,27 +374,43 @@ NodeActionsProviderFilter, TableModel, Constants {
             public void preferenceChange(PreferenceChangeEvent evt) {
                 String key = evt.getKey();
                 if (SHOW_MONITORS.equals(key)) {
+                    isDeadlock = false;
                     List<JPDAThread> threads;
                     synchronized (threadsAskedForMonitors) {
                         threads = new ArrayList(threadsAskedForMonitors);
                     }
                     for (JPDAThread t : threads) {
-                        fireModelChange(new ModelEvent.NodeChanged(modelEventSource,
-                                        t, ModelEvent.NodeChanged.CHILDREN_MASK));
+                        modelEventSource.refreshCache(t);
                     }
                     List<CallStackFrame> frames;
                     synchronized (framesAskedForMonitors) {
                         frames = new ArrayList(framesAskedForMonitors);
                     }
+                    for (CallStackFrame frame : frames) {
+                        modelEventSource.refreshCache(frame);
+                    }
                     for (CallStackFrame frame : frames) {
                         fireModelChange(new ModelEvent.NodeChanged(modelEventSource,
                                         frame, ModelEvent.NodeChanged.CHILDREN_MASK));
                     }
+                    for (JPDAThread t : threads) {
+                        fireModelChange(new ModelEvent.NodeChanged(modelEventSource,
+                                        t, ModelEvent.NodeChanged.CHILDREN_MASK));
+                    }
                 }
             }
 
         }
 
+        private class DeadlockListener implements PropertyChangeListener {
+
+            public void propertyChange(PropertyChangeEvent evt) {
+                Set<Deadlock> deadlocks = deadlockDetector.getDeadlocks();
+                isDeadlock = deadlocks.size() > 0;
+            }
+
+        }
+
     }
     
     
@@ -401,7 +433,7 @@ NodeActionsProviderFilter, TableModel, Constants {
             if (nodesInDeadlock != null) {
                 synchronized (nodesInDeadlock) {
                     if (nodesInDeadlock.contains(v)) {
-                        monitorText = BoldVariablesTableModelFilterFirst.toHTML(
+                        monitorText = BoldVariablesTableModelFilter.toHTML(
                                 monitorText,
                                 false, false, Color.RED);
                     }
@@ -433,7 +465,7 @@ NodeActionsProviderFilter, TableModel, Constants {
             if (nodesInDeadlock != null) {
                 synchronized (nodesInDeadlock) {
                     if (nodesInDeadlock.contains(v)) {
-                        monitorText = BoldVariablesTableModelFilterFirst.toHTML(
+                        monitorText = BoldVariablesTableModelFilter.toHTML(
                                 monitorText,
                                 false, false, Color.RED);
                     }
