@@ -60,6 +60,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.WeakHashMap;
+import java.util.prefs.PreferenceChangeEvent;
+import java.util.prefs.PreferenceChangeListener;
 import java.util.prefs.Preferences;
 import org.netbeans.api.debugger.Breakpoint;
 import org.netbeans.api.debugger.Session;
@@ -79,6 +81,7 @@ import org.netbeans.api.debugger.jpda.MethodBreakpoint;
 import org.netbeans.api.debugger.jpda.ObjectVariable;
 import org.netbeans.api.debugger.jpda.ThreadBreakpoint;
 import org.netbeans.spi.debugger.ContextProvider;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 
 import org.netbeans.spi.viewmodel.ExtendedNodeModel;
 import org.netbeans.spi.viewmodel.ModelEvent;
@@ -100,6 +103,9 @@ import org.openide.util.datatransfer.PasteType;
  *
  * @author martin
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/DebuggingView",
+                             types=ExtendedNodeModel.class,
+                             position=400)
 public class DebuggingNodeModel implements ExtendedNodeModel {
 
     public static final String CURRENT_THREAD =
@@ -145,7 +151,10 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
     private final Set nodesInDeadlock = new HashSet();
     private static final Map<JPDADebugger, Set> nodesInDeadlockByDebugger = new WeakHashMap<JPDADebugger, Set>();
     private final Preferences preferences = NbPreferences.forModule(getClass()).node("debugging"); // NOI18N
+    private final PreferenceChangeListener prefListener;
     private final RequestProcessor rp;
+    private final Session session;
+    private final PropertyChangeListener sessionLanguageListener;
     
     public DebuggingNodeModel(ContextProvider lookupProvider) {
         debugger = lookupProvider.lookupFirst(null, JPDADebugger.class);
@@ -154,6 +163,13 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
         deadlockDetector = debugger.getThreadsCollector().getDeadlockDetector();
         deadlockDetector.addPropertyChangeListener(new DeadlockListener());
         rp = lookupProvider.lookupFirst(null, RequestProcessor.class);
+        session = lookupProvider.lookupFirst(null, Session.class);
+        sessionLanguageListener = new SessionLanguageListener();
+        session.addPropertyChangeListener(Session.PROP_CURRENT_LANGUAGE,
+                WeakListeners.propertyChange(sessionLanguageListener,
+                                             new ListenerDetaching(Session.PROP_CURRENT_LANGUAGE, session)));
+        prefListener = new DebuggingPreferenceChangeListener();
+        preferences.addPreferenceChangeListener(WeakListeners.create(PreferenceChangeListener.class, prefListener, preferences));
     }
     
     public static Set getNodesInDeadlock(JPDADebugger debugger) {
@@ -179,12 +195,12 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
             JPDAThread currentThread = debugger.getCurrentThread();
             if (t == currentThread && (!DebuggingTreeExpansionModelFilter.isExpanded(debugger, node) ||
                     !t.isSuspended())) {
-                return BoldVariablesTableModelFilterFirst.toHTML(
+                return BoldVariablesTableModelFilter.toHTML(
                         getDisplayName(t, showPackageNames, this),
                         true, false, c);
             } else {
                 if (c != null) {
-                    return BoldVariablesTableModelFilterFirst.toHTML(
+                    return BoldVariablesTableModelFilter.toHTML(
                         getDisplayName(t, showPackageNames, this),
                         false, false, c);
                 } else {
@@ -194,7 +210,7 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
         }
         if (node instanceof JPDAThreadGroup) {
             if (isCurrent((JPDAThreadGroup) node) && !DebuggingTreeExpansionModelFilter.isExpanded(debugger, node)) {
-                return BoldVariablesTableModelFilterFirst.toHTML (
+                return BoldVariablesTableModelFilter.toHTML (
                     ((JPDAThreadGroup) node).getName (),
                     true,
                     false,
@@ -216,17 +232,29 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
             // Do not call JDI in AWT
             //CallStackFrame currentFrame = debugger.getCurrentCallStackFrame();
             //if (f.equals(currentFrame)) {
+            String frameDescr;
+            synchronized (frameDescriptionsByFrame) {
+                frameDescr = frameDescriptionsByFrame.get(f);
+                if (frameDescr == null) {
+                    loadFrameDescription(f, showPackageNames);
+                    return BoldVariablesTableModelFilter.toHTML(
+                            NbBundle.getMessage(DebuggingNodeModel.class, "CTL_Frame_Loading"),
+                            false,
+                            false,
+                            Color.LIGHT_GRAY);
+                }
+            }
             if (isCurrent) {
-                return BoldVariablesTableModelFilterFirst.toHTML(
-                        CallStackNodeModel.getCSFName(null, f, showPackageNames),
+                return BoldVariablesTableModelFilter.toHTML(
+                        frameDescr,
                         true, false, c);
             } else {
                 if (c != null) {
-                    return BoldVariablesTableModelFilterFirst.toHTML(
-                            CallStackNodeModel.getCSFName(null, f, showPackageNames),
+                    return BoldVariablesTableModelFilter.toHTML(
+                            frameDescr,
                             false, false, c);
                 } else {
-                    return CallStackNodeModel.getCSFName(null, f, showPackageNames);
+                    return frameDescr;
                 }
             }
         }
@@ -238,6 +266,10 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
      * These are loaded lazily, since we must not load call stack frames in AWT EQ.
      */
     private static final Map<JPDAThread, String> frameDescriptionsByThread = new WeakHashMap<JPDAThread, String>();
+
+    private final Map<CallStackFrame, String> frameDescriptionsByFrame = new WeakHashMap<CallStackFrame, String>();
+
+    private static final Map<CallStackFrame, String[]> framePathAndClass = new WeakHashMap<CallStackFrame, String[]>();
     
     public static String getDisplayName(JPDAThread t, boolean showPackageNames) throws UnknownTypeException {
         return getDisplayName(t, showPackageNames, null);
@@ -364,15 +396,20 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
                                              final JPDAThread t,
                                              final boolean showPackageNames,
                                              final DebuggingNodeModel model) {
-        RequestProcessor rp;
+        final Session s;
         try {
             JPDADebugger debugger = (JPDADebugger) t.getClass().getMethod("getDebugger").invoke(t);
-            Session s = (Session) debugger.getClass().getMethod("getSession").invoke(debugger);
-            rp = s.lookupFirst(null, RequestProcessor.class);
+            s = (Session) debugger.getClass().getMethod("getSession").invoke(debugger);
         } catch (Exception e) {
             Exceptions.printStackTrace(e);
             return ;
         }
+        RequestProcessor rp;
+        if (model != null && model.rp != null) {
+            rp = model.rp;
+        } else {
+            rp = s.lookupFirst(null, RequestProcessor.class);
+        }
         if (rp == null) {
             // Debugger is finishing
             return ;
@@ -386,7 +423,7 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
                         try {
                             CallStackFrame[] sf = t.getCallStack (0, 1);
                             if (sf.length > 0) {
-                                frame = CallStackNodeModel.getCSFName (null, sf[0], showPackageNames);
+                                frame = CallStackNodeModel.getCSFName (s, sf[0], showPackageNames);
                             }
                         } catch (AbsentInformationException e) {
                         }
@@ -406,6 +443,48 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
         });
     }
 
+    private void loadFrameDescription(final CallStackFrame f, final boolean showPackageNames) {
+        rp.post(new Runnable() {
+            @Override
+            public void run() {
+                String frameDescr = CallStackNodeModel.getCSFName(session, f, showPackageNames);
+                synchronized (frameDescriptionsByFrame) {
+                    frameDescriptionsByFrame.put(f, frameDescr);
+                }
+                String[] pathAndClass = new String[2];
+                try {
+                    pathAndClass[0] = f.getSourcePath(session.getCurrentLanguage());
+                } catch (AbsentInformationException ex) {
+                }
+                pathAndClass[1] = f.getClassName();
+                synchronized (framePathAndClass) {
+                    framePathAndClass.put(f, pathAndClass);
+                }
+                fireDisplayNameChanged(f);
+            }
+        });
+    }
+
+    static String getCachedFramePath(CallStackFrame f) {
+        synchronized (framePathAndClass) {
+            String[] pathAndClass = framePathAndClass.get(f);
+            if (pathAndClass != null) {
+                return pathAndClass[0];
+            }
+        }
+        return null;
+    }
+
+    static String getCachedFrameClass(CallStackFrame f) {
+        synchronized (framePathAndClass) {
+            String[] pathAndClass = framePathAndClass.get(f);
+            if (pathAndClass != null) {
+                return pathAndClass[1];
+            }
+        }
+        return null;
+    }
+
     public static String getIconBase(JPDAThread thread) {
         Breakpoint b = thread.getCurrentBreakpoint();
         if (b != null) {
@@ -552,7 +631,7 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
             if (DebuggingTreeModel.isMethodInvoking(sf.getThread())) {
                 return "";
             }
-            return CallStackNodeModel.getCSFToolTipText(sf);
+            return CallStackNodeModel.getCSFToolTipText(session, sf);
         }
         if (node instanceof JPDAThreadGroup) {
             return ((JPDAThreadGroup) node).getName ();
@@ -638,6 +717,17 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
             ml.modelChanged (event);
         }
     }
+
+    private void fireTreeChanged() {
+        List<ModelListener> ls;
+        synchronized (listeners) {
+            ls = new ArrayList<ModelListener>(listeners);
+        }
+        ModelEvent event = new ModelEvent.TreeChanged(this);
+        for (ModelListener ml : ls) {
+            ml.modelChanged (event);
+        }
+    }
     
     private void watch(JPDAThread t) {
         synchronized (threadStateUpdaters) {
@@ -775,16 +865,19 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
             if (JPDADebugger.PROP_CURRENT_CALL_STACK_FRAME.equals(evt.getPropertyName())) {
                 CallStackFrame currentFrame = debugger.getCurrentCallStackFrame();
                 CallStackFrame lastcurrentFrame = null;
+                JPDAThread lastCurrentFrameThread;
+                synchronized (this) {
+                    lastCurrentFrameThread = lastCurrentFrameThreadRef.get();
+                }
+                if (lastCurrentFrameThread != null) {
+                    try {
+                        CallStackFrame[] frames = lastCurrentFrameThread.getCallStack(lastCurrentFrameDepth, lastCurrentFrameDepth + 1);
+                        if (frames.length > 0) {
+                            lastcurrentFrame = frames[0];
+                        }
+                    } catch (AbsentInformationException aiex) {}
+                }
                 synchronized (this) {
-                    JPDAThread lastCurrentFrameThread = lastCurrentFrameThreadRef.get();
-                    if (lastCurrentFrameThread != null) {
-                        try {
-                            CallStackFrame[] frames = lastCurrentFrameThread.getCallStack(lastCurrentFrameDepth, lastCurrentFrameDepth + 1);
-                            if (frames.length > 0) {
-                                lastcurrentFrame = frames[0];
-                            }
-                        } catch (AbsentInformationException aiex) {}
-                    }
                     //lastcurrentFrame = lastCurrentFrame;//Ref.get();
                     //lastCurrentFrameRef = new WeakReference(currentFrame);
                     //lastCurrentFrame = currentFrame;
@@ -836,4 +929,46 @@ public class DebuggingNodeModel implements ExtendedNodeModel {
         
     }
     
+    private final class DebuggingPreferenceChangeListener implements PreferenceChangeListener {
+
+        @Override
+        public void preferenceChange(PreferenceChangeEvent evt) {
+            String key = evt.getKey();
+            if (DebuggingNodeModel.SHOW_PACKAGE_NAMES.equals(key)) {
+                synchronized (frameDescriptionsByFrame) {
+                    frameDescriptionsByFrame.clear();
+                }
+            }
+        }
+    }
+
+    private final class SessionLanguageListener implements PropertyChangeListener {
+
+        @Override
+        public void propertyChange(PropertyChangeEvent evt) {
+            synchronized (frameDescriptionsByFrame) {
+                frameDescriptionsByFrame.clear();
+            }
+            synchronized (framePathAndClass) {
+                framePathAndClass.clear();
+            }
+            fireTreeChanged();
+        }
+        
+    }
+
+    private final static class ListenerDetaching {
+
+        private String propertyName;
+        private Session session;
+
+        ListenerDetaching(String propertyName, Session session) {
+            this.propertyName = propertyName;
+            this.session = session;
+        }
+
+        public void removePropertyChangeListener(PropertyChangeListener l) {
+            session.removePropertyChangeListener(propertyName, l);
+        }
+    }
 }
