@@ -71,7 +71,10 @@ import org.netbeans.api.debugger.jpda.JPDAThread;
 import org.netbeans.api.debugger.jpda.JPDAThreadGroup;
 import org.netbeans.modules.debugger.jpda.ui.models.SourcesModel.AbstractColumn;
 import org.netbeans.spi.debugger.ContextProvider;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
+import org.netbeans.spi.debugger.ui.ColumnModelRegistration;
 
+import org.netbeans.spi.viewmodel.AsynchronousModelFilter;
 import org.netbeans.spi.viewmodel.ModelEvent;
 import org.netbeans.spi.viewmodel.ModelListener;
 import org.netbeans.spi.viewmodel.TreeModel;
@@ -87,6 +90,9 @@ import org.openide.util.WeakListeners;
  *
  * @author martin
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/DebuggingView",
+                             types={TreeModel.class, AsynchronousModelFilter.class},
+                             position=10000)
 public class DebuggingTreeModel extends CachedChildrenTreeModel {
     
     public static final String SORT_ALPHABET = "sort.alphabet";
@@ -350,13 +356,29 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
     }
 
     public void removeModelListener (ModelListener l) {
+        boolean destroyListeners = false;
         synchronized (listeners) {
             listeners.remove (l);
             if (listeners.size () == 0 && listener != null) {
                 listener.destroy ();
                 listener = null;
+                destroyListeners = true;
             }
         }
+        if (destroyListeners) {
+            destroyThreadStateListeners();
+            clearCache();
+        }
+    }
+
+    private void destroyThreadStateListeners() {
+        synchronized (threadStateListeners) {
+            for (Map.Entry<JPDAThread, ThreadStateListener> entry : threadStateListeners.entrySet()) {
+                PropertyChangeListener pcl = entry.getValue().getThreadPropertyChangeListener();
+                ((Customizer) entry.getKey()).removePropertyChangeListener(pcl);
+            }
+            threadStateListeners.clear();
+        }
     }
 
     private void fireModelChange(ModelEvent me) {
@@ -382,6 +404,19 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
         fireModelChange(ev);
     }
 
+    private void fireNodeChildrenChanged (Object node) {
+        //System.err.println("FIRE node children changed ("+node+")");
+        //Thread.dumpStack();
+        try {
+            recomputeChildren();
+        } catch (UnknownTypeException ex) {
+            Exceptions.printStackTrace(ex);
+            return ;
+        }
+        ModelEvent ev = new ModelEvent.NodeChanged(this, node, ModelEvent.NodeChanged.CHILDREN_MASK);
+        fireModelChange(ev);
+    }
+
 
     /**
      * Listens on JPDADebugger state property and updates all threads hierarchy.
@@ -445,30 +480,40 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
         public void propertyChange (PropertyChangeEvent e) {
             //System.err.println("ThreadsTreeModel.propertyChange("+e+")");
             //System.err.println("    "+e.getPropertyName()+", "+e.getOldValue()+" => "+e.getNewValue());
-            JPDAThreadGroup tg;
+            boolean showThreadGroups = preferences.getBoolean(SHOW_THREAD_GROUPS, false);
+            JPDAThreadGroup tg = null;
             if (e.getPropertyName() == JPDADebugger.PROP_THREAD_STARTED) {
                 JPDAThread t = (JPDAThread) e.getNewValue();
-                tg = t.getParentThreadGroup();
+                if (showThreadGroups) {
+                    tg = t.getParentThreadGroup();
+                }
             } else if (e.getPropertyName() == JPDADebugger.PROP_THREAD_DIED) {
                 JPDAThread t = (JPDAThread) e.getOldValue();
-                tg = t.getParentThreadGroup();
-                while (tg != null && tg.getThreads().length == 0 && tg.getThreadGroups().length == 0) {
-                    tg = tg.getParentThreadGroup();
+                if (showThreadGroups) {
+                    tg = t.getParentThreadGroup();
+                    /*while (tg != null && tg.getThreads().length == 0 && tg.getThreadGroups().length == 0) {
+                        tg = tg.getParentThreadGroup();
+                    }*/
                 }
             } else if (e.getPropertyName() == JPDADebugger.PROP_THREAD_GROUP_ADDED) {
-                tg = (JPDAThreadGroup) e.getNewValue();
-                tg = tg.getParentThreadGroup();
+                if (showThreadGroups) {
+                    tg = (JPDAThreadGroup) e.getNewValue();
+                    tg = tg.getParentThreadGroup();
+                }
             } else {
                 return ;
             }
-            Collection nodes = new ArrayList();
-            if (tg == null || !preferences.getBoolean(SHOW_THREAD_GROUPS, false)) {
+            List nodes = new ArrayList();
+            if (tg == null || !showThreadGroups) {
                 nodes.add(ROOT);
             } else if (tg != null) {
                 do {
-                    nodes.add(tg);
+                    nodes.add(0, tg);
                     tg = tg.getParentThreadGroup();
                 } while (tg != null);
+                if (showThreadGroups) {
+                    nodes.add(0, ROOT);
+                }
             }
             synchronized (this) {
                 if (task == null) {
@@ -494,7 +539,7 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
                     nodesToRefresh.clear();
                 }
                 for (Object node : nodes) {
-                    tm.fireNodeChanged(node);
+                    tm.fireNodeChildrenChanged(node);
                 }
             }
         }
@@ -502,12 +547,23 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
 
     
     private void fireThreadStateChanged (JPDAThread node) {
+        boolean showThreadGroups = preferences.getBoolean(SHOW_THREAD_GROUPS, false);
         if (preferences.getBoolean(SHOW_SUSPENDED_THREADS_ONLY, false)) {
-            fireNodeChanged(ROOT);
+            Object parent = null;
+            if (showThreadGroups) {
+                parent = node.getParentThreadGroup();
+            }
+            if (parent == null) parent = ROOT;
+            fireNodeChildrenChanged(parent);
         } else if (!preferences.getBoolean(SHOW_SYSTEM_THREADS, false)
                    && isSystem(node)) {
 
-            fireNodeChanged(ROOT);
+            Object parent = null;
+            if (showThreadGroups) {
+                parent = node.getParentThreadGroup();
+            }
+            if (parent == null) parent = ROOT;
+            fireNodeChildrenChanged(parent);
         }
         try {
             recomputeChildren(node);
@@ -534,10 +590,13 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
         // currently waiting / running refresh task
         // there is at most one
         private RequestProcessor.Task task;
+        private final PropertyChangeListener propertyChangeListener;
+        private boolean wasMethodInvoke = false;
         
         public ThreadStateListener(JPDAThread t) {
             this.tr = new WeakReference(t);
-            ((Customizer) t).addPropertyChangeListener(WeakListeners.propertyChange(this, t));
+            this.propertyChangeListener = WeakListeners.propertyChange(this, t);
+            ((Customizer) t).addPropertyChangeListener(propertyChangeListener);
         }
 
         public void propertyChange(PropertyChangeEvent evt) {
@@ -548,16 +607,28 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
             // gets suspended or is resumed
             // When thread is resumed because of a method invocation, do the
             // refresh only if the method takes a long time.
-            boolean isMethodInvoking = "methodInvoke".equals(evt.getPropagationId());
+            boolean isMethodInvoking = "methodInvoke".equals(evt.getPropagationId());   // NOI18N
             boolean suspended = t.isSuspended();
             if (suspended || !isMethodInvoking) {
                 synchronized (this) {
                     if (task == null) {
                         task = RP.create(new Refresher());
                     }
-                    task.schedule(suspended ? 200 : 1000);
+                    int delay;
+                    if (!suspended || wasMethodInvoke) {
+                        delay = 1000;
+                    } else {
+                        delay = 200;
+                    }
+                    //Logger.getLogger("DEBUGGING").severe("isMethodInvoking = "+isMethodInvoking+", suspended = "+suspended+", wasMethodInvoke = "+wasMethodInvoke+" => delay = "+delay);
+                    task.schedule(delay);
                 }
             }
+            wasMethodInvoke = isMethodInvoking;
+        }
+
+        PropertyChangeListener getThreadPropertyChangeListener() {
+            return propertyChangeListener;
         }
         
         private class Refresher extends Object implements Runnable {
@@ -592,6 +663,7 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
      * Defines model for one table view column. Can be used together with 
      * {@link org.netbeans.spi.viewmodel.TreeModel} for tree table view representation.
      */
+    @ColumnModelRegistration(path="netbeans-JPDASession/DebuggingView", position=100)
     public static class DefaultDebuggingColumn extends AbstractColumn {
 
         /**
@@ -638,6 +710,7 @@ public class DebuggingTreeModel extends CachedChildrenTreeModel {
      * Defines model for one table view column. Can be used together with 
      * {@link org.netbeans.spi.viewmodel.TreeModel} for tree table view representation.
      */
+    @ColumnModelRegistration(path="netbeans-JPDASession/DebuggingView", position=200)
     public static class DebuggingSuspendColumn extends AbstractColumn {
 
         /**
