@@ -65,7 +65,12 @@ import javax.swing.filechooser.FileFilter;
 import org.netbeans.api.debugger.Properties;
 import org.netbeans.spi.debugger.ContextProvider;
 import org.netbeans.api.debugger.jpda.JPDADebugger;
+import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.modules.debugger.jpda.ui.SourcePath;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
+import org.netbeans.spi.debugger.ui.ColumnModelRegistration;
+import org.netbeans.spi.debugger.ui.ColumnModelRegistrations;
+import org.netbeans.spi.debugger.ui.EditorContextDispatcher;
 import org.netbeans.spi.viewmodel.CheckNodeModel;
 import org.netbeans.spi.viewmodel.CheckNodeModelFilter;
 import org.netbeans.spi.viewmodel.ColumnModel;
@@ -78,6 +83,7 @@ import org.netbeans.spi.viewmodel.TableModel;
 import org.netbeans.spi.viewmodel.TreeModel;
 import org.netbeans.spi.viewmodel.ModelListener;
 import org.netbeans.spi.viewmodel.NodeModel;
+import org.netbeans.spi.viewmodel.NodeModelFilter;
 import org.netbeans.spi.viewmodel.UnknownTypeException;
 import org.openide.DialogDisplayer;
 import org.openide.ErrorManager;
@@ -92,6 +98,7 @@ import org.openide.util.datatransfer.PasteType;
 /**
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/SourcesView", types={ NodeActionsProvider.class, NodeModelFilter.class, TreeModel.class })
 public class SourcesModel implements TreeModel, CheckNodeModelFilter, /*ExtendedNodeModelFilter,*/
 NodeActionsProvider {
 
@@ -361,6 +368,7 @@ NodeActionsProvider {
         for (int x = 0; x < roots.length; x++) {
             sourceRootsSet.add(roots[x]);
         }
+        additionalSourceRoots = new LinkedHashSet(Arrays.asList(sourcePath.getAdditionalSourceRoots()));
     }
 
     /*// ExtendedNodeModelFilter:
@@ -446,6 +454,10 @@ NodeActionsProvider {
      * Defines model for one table view column. Can be used together with
      * {@link org.netbeans.spi.viewmodel.TreeModel} for tree table view representation.
      */
+    @ColumnModelRegistrations({
+        @ColumnModelRegistration(path="SourcesView/netbeans-JPDASession/Current"),
+        @ColumnModelRegistration(path="SourcesView/netbeans-JPDASession/Remote")
+    })
     public static class DefaultSourcesColumn extends AbstractColumn {
 
         /**
@@ -491,6 +503,22 @@ NodeActionsProvider {
 
     private JFileChooser newSourceFileChooser;
 
+    private static File getCurrentSourceRoot() {
+        FileObject fo = EditorContextDispatcher.getDefault().getMostRecentFile();
+        if (fo == null) {
+            return null;
+        }
+        ClassPath cp = ClassPath.getClassPath(fo, ClassPath.SOURCE);
+        if (cp == null) {
+            return null;
+        }
+        fo = cp.findOwnerRoot(fo);
+        if (fo == null) {
+            return null;
+        }
+        return FileUtil.toFile(fo);
+    }
+
     private final Action NEW_SOURCE_ROOT_ACTION = new AbstractAction(
             NbBundle.getMessage(SourcesModel.class, "CTL_SourcesModel_Action_AddSrc")) {
         public void actionPerformed (ActionEvent e) {
@@ -517,6 +545,10 @@ NodeActionsProvider {
 
                 });
             }
+            File currentSourceRoot = getCurrentSourceRoot();
+            if (currentSourceRoot != null) {
+                newSourceFileChooser.setSelectedFile(currentSourceRoot);
+            }
             int state = newSourceFileChooser.showDialog(org.openide.windows.WindowManager.getDefault().getMainWindow(),
                                       NbBundle.getMessage(SourcesModel.class, "CTL_SourcesModel_AddSrc_Btn"));
             if (state == JFileChooser.APPROVE_OPTION) {
