@@ -54,6 +54,8 @@ import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import java.util.prefs.PreferenceChangeEvent;
 import java.util.prefs.PreferenceChangeListener;
 import java.util.prefs.Preferences;
@@ -67,6 +69,8 @@ import org.netbeans.api.debugger.jpda.Variable;
 import org.netbeans.modules.debugger.jpda.ui.CodeEvaluator;
 import org.netbeans.modules.debugger.jpda.ui.views.VariablesViewButtons;
 import org.netbeans.spi.debugger.ContextProvider;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
+import org.netbeans.spi.debugger.DebuggerServiceRegistrations;
 import org.netbeans.spi.debugger.jpda.VariablesFilter;
 import org.netbeans.spi.viewmodel.ExtendedNodeModel;
 import org.netbeans.spi.viewmodel.ModelEvent;
@@ -91,6 +95,32 @@ import org.openide.util.datatransfer.PasteType;
  *
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistrations({
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/LocalsView",
+                                 types={ TreeModelFilter.class,
+                                         ExtendedNodeModelFilter.class,
+                                         TableModelFilter.class,
+                                         NodeActionsProviderFilter.class },
+                                 position=400),
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/ResultsView",
+                                 types={ TreeModelFilter.class,
+                                         ExtendedNodeModelFilter.class,
+                                         TableModelFilter.class,
+                                         NodeActionsProviderFilter.class },
+                                 position=400),
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/ToolTipView",
+                                 types={ TreeModelFilter.class,
+                                         ExtendedNodeModelFilter.class,
+                                         TableModelFilter.class,
+                                         NodeActionsProviderFilter.class },
+                                 position=400),
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/WatchesView",
+                                 types={ TreeModelFilter.class,
+                                         ExtendedNodeModelFilter.class,
+                                         TableModelFilter.class,
+                                         NodeActionsProviderFilter.class },
+                                 position=400)
+})
 public class VariablesTreeModelFilter implements TreeModelFilter, 
 ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
     
@@ -112,9 +142,8 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
         this.lookupProvider = lookupProvider;
         evaluationRP = lookupProvider.lookupFirst(null, RequestProcessor.class);
         evalListener = new EvaluatorListener();
-        CodeEvaluator.addResultListener(evalListener);
+        CodeEvaluator.addResultListener(WeakListeners.propertyChange(evalListener, new ResultListenerRemoval()));
         prefListener = new VariablesPreferenceChangeListener();
-        preferences.addPreferenceChangeListener(prefListener);
         preferences.addPreferenceChangeListener(WeakListeners.create(
                 PreferenceChangeListener.class, prefListener, preferences));
         Properties properties = Properties.getDefault().getProperties("debugger.options.JPDA"); // NOI18N
@@ -148,6 +177,52 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
                 Thread.currentThread().interrupt();
             }
         }
+        loadAllTypes(o); // Initialize all types, implemented interfaces and super classes
+    }
+
+    private static boolean hasAllTypes(Object o) {
+        if (!(o instanceof ObjectVariable)) return true;
+        ObjectVariable ov = (ObjectVariable) o;
+        boolean hasAllInterfaces;
+        try {
+            java.lang.reflect.Method hasAllInterfacesMethod = ov.getClass().getMethod("hasAllTypes");
+            hasAllInterfacesMethod.setAccessible(true);
+            hasAllInterfaces = (Boolean) hasAllInterfacesMethod.invoke(ov);
+        } catch (Exception ex) {
+            Exceptions.printStackTrace(ex);
+            hasAllInterfaces = true;
+        }
+        return hasAllInterfaces;
+        
+    }
+
+    private static void loadAllTypes(Object o) {
+        if (!(o instanceof ObjectVariable)) return ;
+        ObjectVariable ov = (ObjectVariable) o;
+        // TODO: List<JPDAClassType> ov.loadAllTypes();
+        try {
+            java.lang.reflect.Method loadAllTypesMethod = ov.getClass().getMethod("loadAllTypes");
+            loadAllTypesMethod.setAccessible(true);
+            loadAllTypesMethod.invoke(ov);
+        } catch (Exception ex) {
+            Exceptions.printStackTrace(ex);
+        }
+    }
+
+    private static List<JPDAClassType> getAllInterfaces(Object o) {
+        if (!(o instanceof ObjectVariable)) return null;
+        ObjectVariable ov = (ObjectVariable) o;
+        // TODO: List<JPDAClassType> ov.getAllInterfaces();
+        List<JPDAClassType> allInterfaces;
+        try {
+            java.lang.reflect.Method allInterfacesMethod = ov.getClass().getMethod("getAllInterfaces");
+            allInterfacesMethod.setAccessible(true);
+            allInterfaces = (List<JPDAClassType>) allInterfacesMethod.invoke(ov);
+        } catch (Exception ex) {
+            Exceptions.printStackTrace(ex);
+            allInterfaces = null;
+        }
+        return allInterfaces;
     }
     
     private void postEvaluationMonitor(Object o, Runnable whenEvaluated) {
@@ -359,6 +434,9 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
     
     public String getIconBase (final NodeModel original, final Object node) 
     throws UnknownTypeException {
+        Logger.getLogger(VariablesTreeModelFilter.class.getName()).log(Level.WARNING,
+                "Obsolete getIconBase() method was called!",
+                new IllegalStateException("getIconBaseWithExtension() should be called!"));
         final String[] unfilteredIconBase = new String[] { null };
         VariablesFilter vf = getFilter (node, true, new Runnable() {
             public void run() {
@@ -526,21 +604,19 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
 
         Variable v = (Variable) o;
 
-        String type;
+        String type = null;
         if (checkEvaluated) {
-            boolean evaluated;
+            boolean evaluated = true;
+            if (!hasAllTypes(v)) {
+                evaluated = false;
+            }
             if (v instanceof Refreshable) {
                 synchronized (v) { // Do the test and retrieve of type in synch
                     evaluated = ((Refreshable) v).isCurrent();
                     if (evaluated) {
                         type = v.getType();
-                    } else {
-                        type = null;
                     }
                 }
-            } else {
-                evaluated = true;
-                type = v.getType();
             }
             if (!evaluated) {
                 if (whenEvaluated != null) {
@@ -548,7 +624,8 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
                 }
                 return null;
             }
-        } else {
+        }
+        if (type == null) {
             type = v.getType();
         }
 
@@ -557,16 +634,8 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
 
         if (!(o instanceof ObjectVariable)) return null;
         ObjectVariable ov = (ObjectVariable) o;
-        // TODO: List<JPDAClassType> ov.getAllInterfaces();
-        List<JPDAClassType> allInterfaces;
-        try {
-            java.lang.reflect.Method allInterfacesMethod = ov.getClass().getMethod("getAllInterfaces");
-            allInterfacesMethod.setAccessible(true);
-            allInterfaces = (List<JPDAClassType>) allInterfacesMethod.invoke(ov);
-        } catch (Exception ex) {
-            Exceptions.printStackTrace(ex);
-            allInterfaces = null;
-        }
+        
+        List<JPDAClassType> allInterfaces = getAllInterfaces(o);
         if (allInterfaces != null) {
             for (JPDAClassType ct : allInterfaces) {
                 type = ct.getName();
@@ -575,7 +644,7 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
             }
         }
         // Consider ancestors as the type + it's ancestors
-        while (ov != null) {
+        while ((ov = ov.getSuper ()) != null) {
             type = null;
             // Check for evaluation before type is retrieved:
             if (checkEvaluated) {
@@ -604,7 +673,6 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
             }
             vf = (VariablesFilter) ancestorToFilterL.get (type);
             if (vf != null) return vf;
-            ov = ov.getSuper ();
         }
         return null;
     }
@@ -726,5 +794,12 @@ ExtendedNodeModelFilter, TableModelFilter, NodeActionsProviderFilter, Runnable {
         }
 
     }
+    
+    private static class ResultListenerRemoval {
+        
+        public void removePropertyChangeListener(PropertyChangeListener l) {
+            CodeEvaluator.removeResultListener(l);
+        }
+    }
 
 }
