@@ -60,6 +60,7 @@ import org.netbeans.spi.viewmodel.ModelListener;
 import org.netbeans.spi.viewmodel.UnknownTypeException;
 import org.netbeans.modules.debugger.jpda.ui.WatchPanel;
 import org.netbeans.spi.debugger.ContextProvider;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.netbeans.spi.viewmodel.NodeActionsProviderFilter;
 import org.openide.util.NbBundle;
 import org.openide.util.HelpCtx;
@@ -69,6 +70,9 @@ import org.openide.DialogDisplayer;
 /**
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/WatchesView",
+                             types=NodeActionsProvider.class,
+                             position=620)
 public class WatchesActionsProvider implements NodeActionsProvider {
 
     
@@ -110,12 +114,6 @@ public class WatchesActionsProvider implements NodeActionsProvider {
         },
         Models.MULTISELECTION_TYPE_ANY
     );
-    static { 
-        DELETE_ACTION.putValue (
-            Action.ACCELERATOR_KEY,
-            KeyStroke.getKeyStroke ("DELETE")
-        );
-    };
     private static final Action CUSTOMIZE_ACTION = Models.createAction (
         NbBundle.getBundle(WatchesActionsProvider.class).getString("CTL_WatchAction_Customize"),
         new Models.ActionPerformer () {
@@ -128,6 +126,13 @@ public class WatchesActionsProvider implements NodeActionsProvider {
         },
         Models.MULTISELECTION_TYPE_EXACTLY_ONE
     );
+    static {
+        DELETE_ACTION.putValue (
+            Action.ACCELERATOR_KEY,
+            KeyStroke.getKeyStroke ("DELETE")
+        );
+        CUSTOMIZE_ACTION.putValue("edit", Boolean.TRUE);
+    };
     
     
     private ContextProvider contextProvider;
