@@ -52,6 +52,8 @@ import java.util.prefs.Preferences;
 import javax.swing.Icon;
 import javax.swing.JButton;
 import javax.swing.JToggleButton;
+import javax.swing.UIManager;
+import javax.swing.border.EmptyBorder;
 import org.netbeans.api.options.OptionsDisplayer;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
@@ -74,7 +76,7 @@ public class VariablesViewButtons {
         button.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
                 System.setProperty(SHOW_FORMATTERS_PROP_NAME, "true"); // NOI18N
-                OptionsDisplayer.getDefault().open("Advanced/org-netbeans-modules-debugger-jpda-ui-options-JavaDebuggerAdvancedOption"); // NOI18N
+                OptionsDisplayer.getDefault().open("Advanced/JavaDebugger"); // NOI18N
             }
         });
         return button;
@@ -100,6 +102,7 @@ public class VariablesViewButtons {
         Dimension size = new Dimension(icon.getIconWidth() + 8, icon.getIconHeight() + 8);
         button.setPreferredSize(size);
         button.setMargin(new Insets(1, 1, 1, 1));
+        button.setBorder(new EmptyBorder(button.getBorder().getBorderInsets(button)));
         button.setToolTipText(tooltip);
         button.setFocusable(false);
         return button;
@@ -113,6 +116,10 @@ public class VariablesViewButtons {
         Dimension size = new Dimension(icon.getIconWidth() + 8, icon.getIconHeight() + 8);
         toggleButton.setPreferredSize(size);
         toggleButton.setMargin(new Insets(1, 1, 1, 1));
+        if (!"Aqua".equals(UIManager.getLookAndFeel().getID())) { //NOI18N
+            // We do not want an ugly border with the exception of Mac, where it paints the toggle state!
+            toggleButton.setBorder(new EmptyBorder(toggleButton.getBorder().getBorderInsets(toggleButton)));
+        }
         toggleButton.setToolTipText(tooltip);
         toggleButton.setFocusable(false);
         return toggleButton;
