@@ -197,6 +197,12 @@ public class Generate {
                 new Class [] { com.sun.jdi.ObjectCollectedException.class,
                                com.sun.jdi.request.InvalidRequestStateException.class })));
         EXCEPTIONS_BY_METHODS.put(com.sun.jdi.request.EventRequest.class.getName(), EventRequestExceptions);
+        Map<String, Set<Class>> EventRequestManagerExceptions = new LinkedHashMap<String, Set<Class>>();
+        EventRequestManagerExceptions.put("deleteEventRequest", Collections.singleton((Class)
+                com.sun.jdi.request.InvalidRequestStateException.class));
+        EventRequestManagerExceptions.put("deleteEventRequests", Collections.singleton((Class)
+                com.sun.jdi.request.InvalidRequestStateException.class));
+        EXCEPTIONS_BY_METHODS.put(com.sun.jdi.request.EventRequestManager.class.getName(), EventRequestManagerExceptions);
 
         Map<String, Set<Class>> EventSetExceptions = new LinkedHashMap<String, Set<Class>>();
         // IllegalThreadStateException is thrown through JDWPException when INVALID_THREAD is received from JDWP.
@@ -535,11 +541,37 @@ public class Generate {
             }
         }
         w.write(" {\n");
+        w.write("        if (org.netbeans.modules.debugger.jpda.JDIExceptionReporter.isLoggable()) {\n");
+        w.write("            org.netbeans.modules.debugger.jpda.JDIExceptionReporter.logCallStart(\n"+
+                "                    \""+className+"\",\n"+
+                "                    \""+mName+"\",\n"+
+                "                    \"JDI CALL: "+className+"({0})."+mName+"(");
+        for (int i = 0; i < paramNames.length; i++) {
+            if (i > 0) {
+                w.write(", ");
+            }
+            w.write("{"+Integer.toString(i+1)+"}");
+        }
+        w.write(")\",\n"+
+                "                    new Object[] {a");
+        for (int i = 0; i < paramNames.length; i++) {
+            w.write(", ");
+            w.write(paramNames[i]);
+        }
+        w.write("});\n");
+        w.write("        }\n"); // if
+        
+        boolean isVoidReturn = "void".equals(rType);
+        if (!isVoidReturn) {
+            w.write("        Object retValue = null;\n");
+        }
+
         w.write("        try {\n");
 
         StringBuffer exec = new StringBuffer();
-        if (!"void".equals(rType)) {
-            exec.append("            return ");
+        if (!isVoidReturn) {
+            exec.append("            ").append(rType).append(" ret;\n");
+            exec.append("            ret = ");
         } else {
             exec.append("            ");
         }
@@ -551,6 +583,10 @@ public class Generate {
             exec.append(paramNames[i]);
         }
         exec.append(");\n");
+        if (!isVoidReturn) {
+            exec.append("            retValue = ret;\n");
+            exec.append("            return ret;\n");
+        }
         w.write(methodImpl(className, mName, exec.toString()));
 
         w.write("        }");
@@ -566,8 +602,11 @@ public class Generate {
             w.write(" catch (");
             w.write(cex.getName());
             w.write(" ex) {\n");
+            if (!isVoidReturn) {
+                w.write("            retValue = ex;\n");
+            }
             if (com.sun.jdi.InternalException.class.equals(cex)) {
-                w.write("            org.netbeans.modules.debugger.jpda.JDIExceptionReporter.report(ex);\n");
+                w.write(reportOfJDIException(className, mName, "ex"));
             }
             if (defaultReturn != null && SILENT_EXCEPTIONS.contains(cex)) {
                 w.write("            return "+defaultReturn+";\n");
@@ -576,7 +615,34 @@ public class Generate {
             }
             w.write("        }");
         }
-        w.write("\n    }\n\n");
+        if (!isVoidReturn) {
+            for (int i = 0; i < exceptionTypes.length; i++) {
+                w.write(" catch (");
+                w.write(exceptionTypes[i].getName());
+                w.write(" ex) {\n");
+                w.write("            retValue = ex;\n");
+                w.write("            throw ex;\n        }");
+            }
+            w.write(" catch (Error err) {\n");
+            w.write("            retValue = err;\n");
+            w.write("            throw err;\n");
+            w.write("        } catch (RuntimeException rex) {\n");
+            w.write("            retValue = rex;\n");
+            w.write("            throw rex;\n        }");
+
+        }
+        w.write(" finally {\n");
+        w.write("            if (org.netbeans.modules.debugger.jpda.JDIExceptionReporter.isLoggable()) {\n");
+        w.write("                org.netbeans.modules.debugger.jpda.JDIExceptionReporter.logCallEnd(\n"+
+                "                        \""+className+"\",\n"+
+                "                        \""+mName+"\",\n"+
+                (isVoidReturn ?
+                "                        org.netbeans.modules.debugger.jpda.JDIExceptionReporter.RET_VOID);\n" :
+                "                        retValue);\n"));
+        //w.write("                logger.log(java.util.logging.Level.FINER, \"          returned after {0} ns\", (t2 - t1));\n");
+        w.write("            }\n");
+        w.write("        }\n");
+        w.write("    }\n\n");
     }
 
     public static void writeHigherVersionClasses(File dir, Class c,
@@ -789,10 +855,11 @@ public class Generate {
         }
         w.write(" {\n");
         String higherVersionClass;
+        String higherVersionClassName;
         int higherVersionClassIndex = className.indexOf("/*");
         if (higherVersionClassIndex > 0) {
             higherVersionClassIndex += 2;
-            String higherVersionClassName = className.substring(higherVersionClassIndex, className.indexOf("*/"));
+            higherVersionClassName = className.substring(higherVersionClassIndex, className.indexOf("*/"));
             higherVersionClass = higherVersionClassName.substring(higherVersionClassName.lastIndexOf('.') + 1);
             higherVersionClass = Character.toLowerCase(higherVersionClass.charAt(0)) + higherVersionClass.substring(1) + "Class";
             w.write("        Class "+higherVersionClass+";\n"+
@@ -804,15 +871,42 @@ public class Generate {
 
         } else {
             higherVersionClass = null;
+            higherVersionClassName = null;
         }
+        w.write("        if (org.netbeans.modules.debugger.jpda.JDIExceptionReporter.isLoggable()) {\n");
+        w.write("            org.netbeans.modules.debugger.jpda.JDIExceptionReporter.logCallStart(\n"+
+                "                    \""+className+"\",\n"+
+                "                    \""+mName+"\",\n"+
+                "                    \"JDI CALL: "+className+"({0})."+mName+"(");
+        for (int i = 0; i < paramNames.length; i++) {
+            if (i > 0) {
+                w.write(", ");
+            }
+            w.write("{"+Integer.toString(i+1)+"}");
+        }
+        w.write(")\",\n"+
+                "                    new Object[] {a");
+        for (int i = 0; i < paramNames.length; i++) {
+            w.write(", ");
+            w.write(paramNames[i]);
+        }
+        w.write("});\n");
+        w.write("        }\n"); // if
+
+        boolean isVoidReturn = "void".equals(rType);
+        if (!isVoidReturn) {
+            w.write("        Object retValue = null;\n");
+        }
+
         w.write("        try {\n");
 
         StringBuffer exec = new StringBuffer();
-        if (!"void".equals(rType)) {
+        if (!isVoidReturn) {
             if ("boolean".equals(rType)) rType = "Boolean";
             if ("int".equals(rType)) rType = "Integer";
             if ("long".equals(rType)) rType = "Long";
-            exec.append("            return ("+rType+") ");
+            exec.append("            ").append(rType).append(" ret;\n");
+            exec.append("            ret = (").append(rType).append(") ");
         } else {
             exec.append("            ");
         }
@@ -845,19 +939,38 @@ public class Generate {
             exec.append(paramNames[i]);
         }
         exec.append(");\n");
+        if (!isVoidReturn) {
+            exec.append("            retValue = ret;\n");
+            exec.append("            return ret;\n");
+        }
         w.write(methodImpl(className, mName, exec.toString()));
 
 
         w.write("        } catch (NoSuchMethodException ex) {\n");
+        if (!isVoidReturn) {
+            w.write("            retValue = ex;\n");
+        }
         w.write("            throw new IllegalStateException(ex);\n");
         w.write("        } catch (SecurityException ex) {\n");
+        if (!isVoidReturn) {
+            w.write("            retValue = ex;\n");
+        }
         w.write("            throw new IllegalStateException(ex);\n");
         w.write("        } catch (IllegalAccessException ex) {\n");
+        if (!isVoidReturn) {
+            w.write("            retValue = ex;\n");
+        }
         w.write("            throw new IllegalStateException(ex);\n");
         w.write("        } catch (IllegalArgumentException ex) {\n");
+        if (!isVoidReturn) {
+            w.write("            retValue = ex;\n");
+        }
         w.write("            throw new IllegalStateException(ex);\n");
         w.write("        } catch (java.lang.reflect.InvocationTargetException ex) {\n");
         w.write("            Throwable t = ex.getTargetException();\n");
+        if (!isVoidReturn) {
+            w.write("            retValue = t;\n");
+        }
 
         // First re-throw the checked exceptions:
         for (int i = 0; i < exceptionTypes.size(); i++) {
@@ -871,7 +984,9 @@ public class Generate {
             Class cex = it.next();
             w.write("            if (t instanceof "+cex.getName()+") {\n");
             if (com.sun.jdi.InternalException.class.equals(cex)) {
-                w.write("                org.netbeans.modules.debugger.jpda.JDIExceptionReporter.report(("+com.sun.jdi.InternalException.class.getName()+") t);\n");
+                String c = higherVersionClassName;
+                if (c == null) c = className;
+                w.write("    "+reportOfJDIException(c, mName, "("+com.sun.jdi.InternalException.class.getName()+") t"));
             }
             if (defaultReturn != null && SILENT_EXCEPTIONS.contains(cex)) {
                 w.write("                return "+defaultReturn+";\n");
@@ -882,6 +997,16 @@ public class Generate {
             //w.write("        } catch (");
         }
         w.write("            throw new IllegalStateException(t);\n");
+        w.write("        }");
+        w.write(" finally {\n");
+        w.write("            if (org.netbeans.modules.debugger.jpda.JDIExceptionReporter.isLoggable()) {\n");
+        w.write("                org.netbeans.modules.debugger.jpda.JDIExceptionReporter.logCallEnd(\n"+
+                "                        \""+className+"\",\n"+
+                "                        \""+mName+"\",\n"+
+                (isVoidReturn ?
+                "                        org.netbeans.modules.debugger.jpda.JDIExceptionReporter.RET_VOID);\n" :
+                "                        retValue);\n"));
+        w.write("            }\n");
         w.write("        }\n");
         w.write("    }\n\n");
     }
@@ -1084,6 +1209,21 @@ public class Generate {
         }
         return exec;
     }
+    
+    private static final String JDI_EXC_REPORT1 =
+            "            org.netbeans.modules.debugger.jpda.JDIExceptionReporter.report(";
+    private static final String JDI_EXC_REPORT2 =
+            ");\n";
+    
+    private static String reportOfJDIException(String className, String methodName, String ex) {
+        if (com.sun.jdi.Method.class.getName().equals(className) && methodName.equals("bytecodes")) {
+            return "            if (ex.errorCode() != 101) { // Ignore ABSENT_INFORMATION\n"+
+                   "    "+JDI_EXC_REPORT1+ex+JDI_EXC_REPORT2+
+                   "            }\n";
+        } else {
+            return JDI_EXC_REPORT1+ex+JDI_EXC_REPORT2;
+        }
+    }
 
     public static void main(String[] args) {
         /*if (args.length == 0) {
