@@ -49,6 +49,7 @@ import com.sun.jdi.Bootstrap;
 import com.sun.jdi.ClassType;
 import com.sun.jdi.IncompatibleThreadStateException;
 import com.sun.jdi.IntegerValue;
+import com.sun.jdi.InterfaceType;
 import com.sun.jdi.InternalException;
 import com.sun.jdi.InvalidStackFrameException;
 import com.sun.jdi.LocalVariable;
@@ -63,9 +64,6 @@ import com.sun.jdi.ThreadReference;
 import com.sun.jdi.TypeComponent;
 import com.sun.jdi.Value;
 import com.sun.jdi.VirtualMachine;
-import com.sun.jdi.request.EventRequest;
-import com.sun.jdi.request.EventRequestManager;
-import com.sun.jdi.request.InvalidRequestStateException;
 
 import java.awt.EventQueue;
 import java.beans.PropertyChangeEvent;
@@ -84,6 +82,7 @@ import java.lang.reflect.InvocationTargetException;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.Map;
+import java.util.WeakHashMap;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 import java.util.logging.Level;
@@ -103,7 +102,6 @@ import org.netbeans.api.debugger.jpda.JPDAThreadGroup;
 import org.netbeans.modules.debugger.jpda.actions.CompoundSmartSteppingListener;
 import org.netbeans.modules.debugger.jpda.jdi.ClassNotPreparedExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.InternalExceptionWrapper;
-import org.netbeans.modules.debugger.jpda.jdi.InvalidRequestStateExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ObjectCollectedExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.VMDisconnectedExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.models.ObjectTranslation;
@@ -142,8 +140,6 @@ import org.netbeans.modules.debugger.jpda.jdi.StackFrameWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ThreadReferenceWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ValueWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.VirtualMachineWrapper;
-import org.netbeans.modules.debugger.jpda.jdi.request.EventRequestManagerWrapper;
-import org.netbeans.modules.debugger.jpda.jdi.request.EventRequestWrapper;
 import org.netbeans.spi.debugger.DebuggerEngineProvider;
 import org.netbeans.spi.debugger.DelegatingSessionProvider;
 
@@ -154,6 +150,7 @@ import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
+import org.openide.util.WeakSet;
 import org.openide.util.lookup.Lookups;
 
 /**
@@ -161,6 +158,7 @@ import org.openide.util.lookup.Lookups;
 *
 * @author   Jan Jancura
 */
+@JPDADebugger.Registration(path="netbeans-JPDASession")
 public class JPDADebuggerImpl extends JPDADebugger {
 
     private static final Logger logger = Logger.getLogger("org.netbeans.modules.debugger.jpda");
@@ -173,7 +171,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     //private DebuggerEngine              debuggerEngine;
     private VirtualMachine              virtualMachine = null;
     private final Object                virtualMachineLock = new Object();
-    private Exception                   exception;
+    private Throwable                   throwable;
     private int                         state = 0;
     private final Object                stateLock = new Object();
     private Operator                    operator;
@@ -200,6 +198,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     private final Object                threadsCollectorLock = new Object();
     private final Map<Long, String>     markedObjects = new LinkedHashMap<Long, String>();
     private final Map<String, ObjectVariable> markedObjectLabels = new LinkedHashMap<String, ObjectVariable>();
+    private final Map<ClassType, List>  allInterfacesMap = new WeakHashMap<ClassType, List>();
 
     private StackFrame      altCSF = null;  //PATCH 48174
 
@@ -244,6 +243,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      * @see #STATE_STOPPED
      * @see #STATE_DISCONNECTED
      */
+    @Override
     public int getState () {
         synchronized (stateLock) {
             return state;
@@ -255,6 +255,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return value of suspend property
      */
+    @Override
     public int getSuspend () {
         synchronized (stateLock) {
             return suspend;
@@ -266,6 +267,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @param s a new value of suspend property
      */
+    @Override
     public void setSuspend (int s) {
         int old;
         synchronized (stateLock) {
@@ -281,6 +283,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return current thread or null
      */
+    @Override
     public JPDAThread getCurrentThread () {
         return currentThread;
     }
@@ -290,6 +293,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return current stack frame or null
      */
+    @Override
     public CallStackFrame getCurrentCallStackFrame () {
         synchronized (currentThreadAndFrameLock) {
             return currentCallStackFrame;
@@ -303,6 +307,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return current value of given expression
      */
+    @Override
     public Variable evaluate (String expression) throws InvalidExpressionException {
         return evaluate(expression, null, null);
     }
@@ -347,11 +352,12 @@ public class JPDADebuggerImpl extends JPDADebugger {
      * Waits till the Virtual Machine is started and returns
      * {@link DebuggerStartException} if any.
      *
-     * @throws DebuggerStartException is some problems occurres during debugger
+     * @throws DebuggerStartException if some problems occurs during debugger
      *         start
      *
      * @see AbstractDICookie#getVirtualMachine()
      */
+    @Override
     public void waitRunning () throws DebuggerStartException {
         waitRunning(0);
     }
@@ -361,7 +367,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return <code>true</code> when debugger started or finished in the mean time,
      *         <code>false</code> when the debugger is still starting
-     * @throws DebuggerStartException is some problems occurres during debugger
+     * @throws DebuggerStartException if some problems occurs during debugger
      *         start
      *
      * @see AbstractDICookie#getVirtualMachine()
@@ -370,26 +376,26 @@ public class JPDADebuggerImpl extends JPDADebugger {
         synchronized (LOCK2) {
             int state = getState();
             if (state == STATE_DISCONNECTED) {
-                if (exception != null)
-                    throw new DebuggerStartException (exception);
+                if (throwable != null)
+                    throw new DebuggerStartException (throwable);
                 else
                     return true;
             }
-            if (!starting && state != STATE_STARTING || exception != null) {
+            if (!starting && state != STATE_STARTING || throwable != null) {
                 return true; // We're already running
             }
             try {
-                logger.fine("JPDADebuggerImpl.waitRunning(): starting = "+starting+", state = "+state+", exception = "+exception);
+                logger.fine("JPDADebuggerImpl.waitRunning(): starting = "+starting+", state = "+state+", exception = "+throwable);
                 LOCK2.wait (timeout);
-                if ((starting || state == STATE_STARTING) && exception == null) {
+                if ((starting || state == STATE_STARTING) && throwable == null) {
                     return false; // We're still not running and the time expired
                 }
             } catch (InterruptedException e) {
                  throw new DebuggerStartException (e);
             }
 
-            if (exception != null)
-                throw new DebuggerStartException (exception);
+            if (throwable != null)
+                throw new DebuggerStartException (throwable);
             else
                 return true;
         }
@@ -400,6 +406,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return <code>true</code> if this debugger supports Pop action
      */
+    @Override
     public boolean canPopFrames () {
         VirtualMachine vm = getVirtualMachine ();
         if (vm == null) return false;
@@ -412,6 +419,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return <code>true</code> if this debugger supports fix & continue
      */
+    @Override
     public boolean canFixClasses () {
         VirtualMachine vm = getVirtualMachine ();
         if (vm == null) return false;
@@ -424,7 +432,9 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @param classes a map from class names to be fixed to byte[]
      */
+    @Override
     public void fixClasses (Map<String, byte[]> classes) {
+        PropertyChangeEvent evt = null;
         accessLock.writeLock().lock();
         try {
             // 1) redefine classes
@@ -464,7 +474,9 @@ public class JPDADebuggerImpl extends JPDADebugger {
                     if (t.getStackDepth () < 2) return;
                     CallStackFrame frame;
                     try {
-                        frame = t.getCallStack(0, 1)[0]; // Retrieve the new, possibly obsoleted frame and check it.
+                        CallStackFrame[] frames = t.getCallStack(0, 1);
+                        if (frames.length == 0) return ;
+                        frame = frames[0]; // Retrieve the new, possibly obsoleted frame and check it.
                     } catch (AbsentInformationException ex) {
                         return;
                     }
@@ -473,7 +485,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
                     if (frame.isObsolete () && ((CallStackFrameImpl) frame).canPop()) {
                         frame.popFrame ();
                         setState (STATE_RUNNING);
-                        updateCurrentCallStackFrame (t);
+                        evt = updateCurrentCallStackFrameNoFire (t);
                         setState (STATE_STOPPED);
                     }
                 } catch (InvalidStackFrameException ex) {
@@ -483,24 +495,32 @@ public class JPDADebuggerImpl extends JPDADebugger {
         } finally {
             accessLock.writeLock().unlock();
         }
+        if (evt != null) {
+            firePropertyChange(evt);
+        }
     }
 
     public void fixBreakpoints() {
-        Session s = getSession();
-        DebuggerEngine de = s.getEngineForLanguage ("Java");
-        BreakpointsEngineListener bel = null;
-        List lazyListeners = de.lookup(null, LazyActionsManagerListener.class);
-        for (int li = 0; li < lazyListeners.size(); li++) {
-            Object service = lazyListeners.get(li);
-            if (service instanceof BreakpointsEngineListener) {
-                bel = (BreakpointsEngineListener) service;
-                break;
-            }
-        }
         // Just reset the time stamp so that new line numbers are taken.
         EditorContextBridge.getContext().disposeTimeStamp(this);
         EditorContextBridge.getContext().createTimeStamp(this);
-        if (bel != null) bel.fixBreakpointImpls ();
+        Session s = getSession();
+        DebuggerEngine de = s.getEngineForLanguage ("Java");
+        if (de == null) {
+            de = s.getCurrentEngine();
+        }
+        if (de != null) {
+            BreakpointsEngineListener bel = null;
+            List lazyListeners = de.lookup(null, LazyActionsManagerListener.class);
+            for (int li = 0; li < lazyListeners.size(); li++) {
+                Object service = lazyListeners.get(li);
+                if (service instanceof BreakpointsEngineListener) {
+                    bel = (BreakpointsEngineListener) service;
+                    break;
+                }
+            }
+            if (bel != null) bel.fixBreakpointImpls ();
+        }
     }
 
     public Session getSession() {
@@ -514,6 +534,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     private Boolean canBeModified;
     private final Object canBeModifiedLock = new Object();
 
+    @Override
     public boolean canBeModified() {
         VirtualMachine vm = getVirtualMachine ();
         if (vm == null) return false;
@@ -532,6 +553,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      *
      * @return instance of SmartSteppingFilter
      */
+    @Override
     public SmartSteppingFilter getSmartSteppingFilter () {
         if (smartSteppingFilter == null) {
             smartSteppingFilter = lookupProvider.lookupFirst(null, SmartSteppingFilter.class);
@@ -561,6 +583,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
      * @param breakpoint a breakpoint to be changed
      * @param event a event to be fired
      */
+    @Override
     public void fireBreakpointEvent (
         JPDABreakpoint breakpoint,
         JPDABreakpointEvent event
@@ -573,6 +596,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     *
     * @param l new listener.
     */
+    @Override
     public void addPropertyChangeListener (PropertyChangeListener l) {
         pcs.addPropertyChangeListener (l);
     }
@@ -582,6 +606,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     *
     * @param l removed listener.
     */
+    @Override
     public void removePropertyChangeListener (PropertyChangeListener l) {
         pcs.removePropertyChangeListener (l);
     }
@@ -591,6 +616,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     *
     * @param l new listener.
     */
+    @Override
     public void addPropertyChangeListener (String propertyName, PropertyChangeListener l) {
         pcs.addPropertyChangeListener (propertyName, l);
     }
@@ -600,6 +626,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
     *
     * @param l removed listener.
     */
+    @Override
     public void removePropertyChangeListener (String propertyName, PropertyChangeListener l) {
         pcs.removePropertyChangeListener (propertyName, l);
     }
@@ -608,13 +635,14 @@ public class JPDADebuggerImpl extends JPDADebugger {
     // internal interface ......................................................
 
     public void popFrames (ThreadReference thread, StackFrame frame) {
+        PropertyChangeEvent evt = null;
         accessLock.readLock().lock();
         try {
             JPDAThreadImpl threadImpl = getThread(thread);
             setState (STATE_RUNNING);
             try {
                 threadImpl.popFrames(frame);
-                updateCurrentCallStackFrame (threadImpl);
+                evt = updateCurrentCallStackFrameNoFire(threadImpl);
             } catch (IncompatibleThreadStateException ex) {
                 ErrorManager.getDefault().notify(ex);
             } finally {
@@ -623,14 +651,17 @@ public class JPDADebuggerImpl extends JPDADebugger {
         } finally {
             accessLock.readLock().unlock();
         }
+        if (evt != null) {
+            firePropertyChange(evt);
+        }
     }
 
-    public void setException (Exception e) {
+    public void setException (Throwable t) {
         if (logger.isLoggable(Level.FINE)) {
-            logger.fine("JPDADebuggerImpl.setException("+e+")");
+            logger.fine("JPDADebuggerImpl.setException("+t+")");
         }
         synchronized (LOCK2) {
-            exception = e;
+            throwable = t;
             starting = false;
             LOCK2.notifyAll ();
         }
@@ -717,7 +748,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
 
     // * Might be changed to return a variable with disabled collection. When not used any more,
     // * it's collection must be enabled again.
-    private Value evaluateIn (EvaluatorExpression expression, CallStackFrame csf, ObjectVariable var) throws InvalidExpressionException {
+    public Value evaluateIn (EvaluatorExpression expression, CallStackFrame csf, ObjectVariable var) throws InvalidExpressionException {
         Variable variable = evaluateGeneric(expression, csf, var);
         if (variable instanceof JDIVariable) {
             return ((JDIVariable) variable).getJDIValue();
@@ -777,8 +808,11 @@ public class JPDADebuggerImpl extends JPDADebugger {
                 try {
                     ThreadReference t = StackFrameWrapper.thread(sf);
                     JPDAThread tr = getThread(t);
-                    c = tr.getCallStack(0, 1)[0];
-                    csf = (CallStackFrameImpl) c;
+                    CallStackFrame[] stackFrames = tr.getCallStack(0, 1);
+                    if (stackFrames.length > 0) {
+                        c = stackFrames[0];
+                        csf = (CallStackFrameImpl) c;
+                    }
                 } catch (InternalExceptionWrapper ex) {
                 } catch (InvalidStackFrameExceptionWrapper ex) {
                 } catch (VMDisconnectedExceptionWrapper ex) {
@@ -792,37 +826,47 @@ public class JPDADebuggerImpl extends JPDADebugger {
         }
 
         JPDAThread frameThread = csf.getThread();
-        Lock lock = ((JPDAThreadImpl) frameThread).accessLock.writeLock();
+        JPDAThreadImpl frameThreadImpl = (JPDAThreadImpl) frameThread;
+        //Object pendingAction = frameThreadImpl.getPendingAction();
+        //if (pendingAction != null) { For the case that evaluation should be blocked by pending action
+        //    //return frameThreadImpl.getPendingVariable(pendingActions);
+        //    throw new InvalidExpressionException(frameThreadImpl.getPendingString(pendingAction));
+        //}
+        Lock lock = frameThreadImpl.accessLock.writeLock();
         lock.lock();
         Variable vr;
         try {
+            if (!frameThread.isSuspended() && !((JPDAThreadImpl) frameThread).isSuspendedNoFire()) {
+                // Thread not suspended => Can not start evaluation
+                throw new InvalidExpressionException
+                    (NbBundle.getMessage(JPDADebuggerImpl.class, "MSG_NoCurrentContextStackFrame"));
+            }
             ObjectReference v = null;
             if (var instanceof JDIVariable) {
                 v = (ObjectReference) ((JDIVariable) var).getJDIValue();
             }
             Evaluator.Result result;
-            final List<EventRequest>[] disabledBreakpoints = new List[] { null };
             final JPDAThreadImpl[] resumedThread = new JPDAThreadImpl[] { null };
             try {
                 StackFrame sf = csf.getStackFrame();
                 int stackDepth = csf.getFrameDepth();
                 final ThreadReference tr = StackFrameWrapper.thread(sf);
                 Runnable methodToBeInvokedNotifier = new Runnable() {
+                        @Override
                         public void run() {
-                            if (disabledBreakpoints[0] == null) {
+                            if (resumedThread[0] == null) {
                                 JPDAThreadImpl theResumedThread = getThread(tr);
                                 try {
                                     theResumedThread.notifyMethodInvoking();
                                 } catch (PropertyVetoException pvex) {
                                     throw new RuntimeException(
                                         new InvalidExpressionException (pvex.getMessage()));
+                                } catch (ThreadDeath td) {
+                                    throw td;
+                                } catch (Throwable t) {
+                                    Exceptions.printStackTrace(t);
                                 }
-                                try {
-                                    disabledBreakpoints[0] = disableAllBreakpoints();
-                                    resumedThread[0] = theResumedThread;
-                                } catch (InternalExceptionWrapper ex) {
-                                } catch (VMDisconnectedExceptionWrapper ex) {
-                                }
+                                resumedThread[0] = theResumedThread;
                             }
                         }
                     };
@@ -859,9 +903,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
                     throw rex;
                 }
             } finally {
-                if (disabledBreakpoints[0] != null) {
-                    enableAllBreakpoints (disabledBreakpoints[0]);
-                }
                 if (resumedThread[0] != null) {
                     resumedThread[0].notifyMethodInvokeDone();
                 }
@@ -931,7 +972,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
             boolean threadSuspended = false;
             JPDAThread frameThread = null;
             CallStackFrameImpl csf = null;
-            List<EventRequest> l = null;
             try {
                 // Remember the current stack frame, it might be necessary to re-set.
                 csf = (CallStackFrameImpl) getCurrentCallStackFrame ();
@@ -946,12 +986,16 @@ public class JPDADebuggerImpl extends JPDADebugger {
                     threadSuspended = true;
                 } catch (PropertyVetoException pvex) {
                     throw new InvalidExpressionException (pvex.getMessage());
-                }
-                try {
-                    l = disableAllBreakpoints();
-                } catch (InternalExceptionWrapper ex) {
-                } catch (VMDisconnectedExceptionWrapper ex) {
-                    return null;
+                } catch (RuntimeException rex) {
+                    // Give up
+                    thread.notifyMethodInvokeDone();
+                    throw rex;
+                } catch (ThreadDeath td) {
+                    throw td;
+                } catch (Error e) {
+                    // Give up
+                    thread.notifyMethodInvokeDone();
+                    throw e;
                 }
                 try {
                     Value v = org.netbeans.modules.debugger.jpda.expr.TreeEvaluator.
@@ -977,9 +1021,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
                 }
                 throw ieex;
             } finally {
-                if (l != null) {
-                    enableAllBreakpoints (l);
-                }
                 if (threadSuspended) {
                     thread.notifyMethodInvokeDone();
                 }
@@ -1046,10 +1087,10 @@ public class JPDADebuggerImpl extends JPDADebugger {
             return (String) tcGenericSignatureMethod.invoke
                 (component, new Object[0]);
         } catch (IllegalAccessException e) {
-            e.printStackTrace();
+            Exceptions.printStackTrace(e);
             return null;    // should not happen
         } catch (InvocationTargetException e) {
-            e.printStackTrace();
+            Exceptions.printStackTrace(e);
             return null;    // should not happen
         }
     }
@@ -1059,10 +1100,10 @@ public class JPDADebuggerImpl extends JPDADebugger {
         try {
             return (String) lvGenericSignatureMethod.invoke(component, new Object[0]);
         } catch (IllegalAccessException e) {
-            e.printStackTrace();
+            Exceptions.printStackTrace(e);
             return null;    // should not happen
         } catch (InvocationTargetException e) {
-            e.printStackTrace();
+            Exceptions.printStackTrace(e);
             return null;    // should not happen
         }
     }
@@ -1388,6 +1429,11 @@ public class JPDADebuggerImpl extends JPDADebugger {
     }
 
     public List<PropertyChangeEvent> notifySuspendAll(boolean doFire, boolean explicitelyPaused) {
+        return notifySuspendAll(doFire, explicitelyPaused, null);
+    }
+
+    public List<PropertyChangeEvent> notifySuspendAll(boolean doFire, boolean explicitelyPaused,
+                                                      Set<ThreadReference> ignoredThreads) {
         Collection threads = threadsTranslation.getTranslated();
         List<PropertyChangeEvent> events = new ArrayList<PropertyChangeEvent>(threads.size());
         for (Iterator it = threads.iterator(); it.hasNext(); ) {
@@ -1397,7 +1443,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
                 boolean invalid = (status == JPDAThread.STATE_NOT_STARTED ||
                                    status == JPDAThread.STATE_UNKNOWN ||
                                    status == JPDAThread.STATE_ZOMBIE);
-                if (!invalid) {
+                if (!invalid && (ignoredThreads == null || !ignoredThreads.contains(((JPDAThreadImpl) threadOrGroup).getThreadReference()))) {
                     try {
                         PropertyChangeEvent event = ((JPDAThreadImpl) threadOrGroup).notifySuspended(doFire, explicitelyPaused);
                         if (event != null) {
@@ -1450,9 +1496,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
         } finally {
             accessLock.readLock().unlock();
         }
-        if (operator.flushStaledEvents()) {
-            return ;
-        }
         PropertyChangeEvent stateChangeEvent;
         //notifyToBeResumedAll();
         VirtualMachine vm;
@@ -1542,9 +1585,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
         } finally {
             accessLock.readLock().unlock();
         }
-        if (operator.flushStaledEvents()) {
-            return false;
-        }
         setState (STATE_RUNNING);
         return true;
     }
@@ -1560,9 +1600,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
         } finally {
             accessLock.readLock().unlock();
         }
-        if (operator.flushStaledEvents()) {
-            return ;
-        }
         setState (STATE_RUNNING);
         currentThread.resume();
     }
@@ -1603,12 +1640,23 @@ public class JPDADebuggerImpl extends JPDADebugger {
         }
     }
 
+    private Set<JPDAThreadGroup> interestedThreadGroups = new WeakSet<JPDAThreadGroup>();
+
+    public void interestedInThreadGroup(JPDAThreadGroup tg) {
+        interestedThreadGroups.add(tg);
+    }
+
+    public boolean isInterestedInThreadGroups() {
+        return !interestedThreadGroups.isEmpty();
+    }
+
     public ThreadsCache getThreadsCache() {
         synchronized (threadsCollectorLock) {
             if (threadsCache == null) {
                 threadsCache = new ThreadsCache(this);
                 threadsCache.addPropertyChangeListener(new PropertyChangeListener() {
                     //  Re-fire the changes
+                    @Override
                     public void propertyChange(PropertyChangeEvent evt) {
                         String propertyName = evt.getPropertyName();
                         if (ThreadsCache.PROP_THREAD_STARTED.equals(propertyName)) {
@@ -1880,16 +1928,27 @@ public class JPDADebuggerImpl extends JPDADebugger {
         return thread;
     }
 
-    private void updateCurrentCallStackFrame (JPDAThread thread) {
+    private PropertyChangeEvent updateCurrentCallStackFrameNoFire (JPDAThread thread) {
+        CallStackFrame oldSF;
+        CallStackFrame newSF;
         if ((thread == null) || (thread.getStackDepth () < 1)) {
-            setCurrentCallStackFrame (null);
+            newSF = null;
         } else {
             try {
-                setCurrentCallStackFrame (thread.getCallStack (0, 1) [0]);
+                CallStackFrame[] csfs = thread.getCallStack(0, 1);
+                if (csfs.length > 0) {
+                    newSF = csfs[0];
+                } else {
+                    newSF = null;
+                }
             } catch (AbsentInformationException e) {
-                setCurrentCallStackFrame (null);
+                newSF = null;
             }
         }
+        oldSF = setCurrentCallStackFrameNoFire(newSF);
+        if (oldSF == newSF) return null;
+        else return new PropertyChangeEvent(this, PROP_CURRENT_CALL_STACK_FRAME,
+                                            oldSF, newSF);
     }
 
     private CallStackFrame getTopFrame(JPDAThread thread) {
@@ -1898,7 +1957,12 @@ public class JPDADebuggerImpl extends JPDADebugger {
             callStackFrame = null;
         } else {
             try {
-                callStackFrame = thread.getCallStack(0, 1) [0];
+                CallStackFrame[] csfs = thread.getCallStack(0, 1);
+                if (csfs.length > 0) {
+                    callStackFrame = csfs[0];
+                } else {
+                    callStackFrame = null;
+                }
             } catch (AbsentInformationException e) {
                 callStackFrame = null;
             }
@@ -1918,61 +1982,6 @@ public class JPDADebuggerImpl extends JPDADebugger {
                                             old, callStackFrame);
     }
 
-    private List<EventRequest> disableAllBreakpoints () throws InternalExceptionWrapper, VMDisconnectedExceptionWrapper {
-        logger.fine ("disableAllBreakpoints() start.");
-        List<EventRequest> l = new ArrayList<EventRequest>();
-        VirtualMachine vm = getVirtualMachine ();
-        if (vm == null) return l;
-        EventRequestManager erm = VirtualMachineWrapper.eventRequestManager (vm);
-        l.addAll (EventRequestManagerWrapper.accessWatchpointRequests (erm));
-        l.addAll (EventRequestManagerWrapper.breakpointRequests (erm));
-        l.addAll (EventRequestManagerWrapper.classPrepareRequests (erm));
-        l.addAll (EventRequestManagerWrapper.classUnloadRequests (erm));
-        l.addAll (EventRequestManagerWrapper.exceptionRequests (erm));
-        l.addAll (EventRequestManagerWrapper.methodEntryRequests (erm));
-        l.addAll (EventRequestManagerWrapper.methodExitRequests (erm));
-        l.addAll (EventRequestManagerWrapper.modificationWatchpointRequests (erm));
-//        l.addAll (erm.stepRequests ());
-        l.addAll (EventRequestManagerWrapper.threadDeathRequests (erm));
-        l.addAll (EventRequestManagerWrapper.threadStartRequests (erm));
-        int i = l.size () - 1;
-        for (; i >= 0; i--)
-            if (!EventRequestWrapper.isEnabled (l.get (i)))
-                l.remove (i);
-            else
-                try {
-                    EventRequestWrapper.disable(l.get(i));
-                } catch (ObjectCollectedExceptionWrapper ex) {
-                } catch (InvalidRequestStateExceptionWrapper ex) {
-                }
-        operator.breakpointsDisabled();
-        logger.fine ("disableAllBreakpoints() end.");
-        return l;
-    }
-
-    private void enableAllBreakpoints (List<EventRequest> l) {
-        logger.fine ("enableAllBreakpoints() start.");
-        operator.breakpointsEnabled();
-        int i, k = l.size ();
-        for (i = 0; i < k; i++)
-            try {
-                EventRequestWrapper.enable (l.get (i));
-            } catch (IllegalThreadStateException ex) {
-                // see #53163
-                // this can occurr if there is some "old" StepRequest and
-                // thread named in the request has died
-            } catch (ObjectCollectedExceptionWrapper ocex) {
-                // Something in the request was collected.
-            } catch (InvalidRequestStateException ex) {
-                // workaround for #51176
-            } catch (InvalidRequestStateExceptionWrapper ex) {
-            } catch (InternalExceptionWrapper ex) {
-            } catch (VMDisconnectedExceptionWrapper ex) {
-                return ;
-            }
-        logger.fine ("enableAllBreakpoints() end.");
-    }
-
     private void checkJSR45Languages (JPDAThread t) {
         if (t.getStackDepth () > 0)
             try {
@@ -2027,6 +2036,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
             "netbeans-jpda-JSR45DICookie-" + language,
             new Object[] {
                 new DelegatingSessionProvider () {
+                    @Override
                     public Session getSession (
                         DebuggerInfo debuggerInfo
                     ) {
@@ -2038,6 +2048,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
         );
     }
 
+    @Override
     public JPDAStep createJPDAStep(int size, int depth) {
         Session session = lookupProvider.lookupFirst(null, Session.class);
         return new JPDAStepImpl(this, session, size, depth);
@@ -2051,7 +2062,9 @@ public class JPDADebuggerImpl extends JPDADebugger {
         }
     }*/
 
+    @Override
     public List<JPDAClassType> getAllClasses() {
+        //assert !java.awt.EventQueue.isDispatchThread() : "All classes retrieving in AWT Event Queue!";
         List<ReferenceType> classes;
         synchronized (virtualMachineLock) {
             if (virtualMachine == null) {
@@ -2063,6 +2076,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
         return new ClassTypeList(this, classes);
     }
 
+    @Override
     public List<JPDAClassType> getClassesByName(String name) {
         List<ReferenceType> classes;
         synchronized (virtualMachineLock) {
@@ -2077,6 +2091,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
 
     @Override
     public long[] getInstanceCounts(List<JPDAClassType> classTypes) throws UnsupportedOperationException {
+            //assert !java.awt.EventQueue.isDispatchThread() : "Instance counts retrieving in AWT Event Queue!";
             VirtualMachine vm;
             synchronized (virtualMachineLock) {
                 vm = virtualMachine;
@@ -2103,6 +2118,7 @@ public class JPDADebuggerImpl extends JPDADebugger {
             }
     }
 
+    @Override
     public boolean canGetInstanceInfo() {
         synchronized (virtualMachineLock) {
             return virtualMachine != null && virtualMachine.canGetInstanceInfo();
@@ -2128,6 +2144,75 @@ public class JPDADebuggerImpl extends JPDADebugger {
         }
     }
 
+    public List<JPDAClassType> getAllInterfaces(ClassType ct) {
+        try {
+            List allInterfaces;
+            boolean toCompute = false;
+            synchronized (allInterfacesMap) {
+                allInterfaces = allInterfacesMap.get(ct);
+                if (allInterfaces == null) {
+                    allInterfaces = new ArrayList();
+                    allInterfaces.add("computing");             // NOI18N
+                    allInterfacesMap.put(ct, allInterfaces);
+                    toCompute = true;
+                }
+            }
+            if (toCompute) {
+                List<InterfaceType> interfaces = null;
+                try {
+                    //assert !javax.swing.SwingUtilities.isEventDispatchThread();
+                    interfaces = ClassTypeWrapper.allInterfaces0(ct);
+                } finally {
+                    if (interfaces == null) {
+                        synchronized (allInterfacesMap) {
+                            allInterfacesMap.remove(ct);
+                        }
+                    }
+                    synchronized (allInterfaces) {
+                        allInterfaces.clear();
+                        if (interfaces != null) {
+                            for (InterfaceType it : interfaces) {
+                                allInterfaces.add(new JPDAClassTypeImpl(this, it));
+                            }
+                        }
+                        allInterfaces.notifyAll();
+                    }
+                }
+            } else {
+                synchronized (allInterfaces) {
+                    if (allInterfaces.contains("computing")) {  // NOI18N
+                        try {
+                            allInterfaces.wait();
+                        } catch (InterruptedException ex) {
+                            return null;
+                        }
+                    }
+                }
+            }
+            return Collections.unmodifiableList(allInterfaces);
+        } catch (ClassNotPreparedExceptionWrapper cnpex) {
+            return null;
+        }
+    }
+
+    public boolean hasAllInterfaces(ClassType ct) {
+        List allInterfaces;
+        synchronized (allInterfacesMap) {
+            allInterfaces = allInterfacesMap.get(ct);
+        }
+        if (allInterfaces == null) {
+            return false;
+        } else {
+            synchronized (allInterfaces) {
+                if (allInterfaces.contains("computing")) {      // NOI18N
+                    return false;
+                }
+            }
+        }
+        return true;
+    }
+
+
     private static class DebuggerReentrantReadWriteLock extends ReentrantReadWriteLock {
 
         private ReadLock readerLock;
