@@ -65,6 +65,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.locks.Lock;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -146,13 +147,29 @@ public class JPDAStepImpl extends JPDAStep implements Executor {
         }
         SourcePath sourcePath = ((JPDADebuggerImpl) debugger).getEngineContext();
         boolean[] setStoppedStateNoContinue = new boolean[] { false };
-        trImpl.accessLock.readLock().lock();
+        int suspendPolicy = debuggerImpl.getSuspend();
+        Lock lock;
+        if (suspendPolicy == JPDADebugger.SUSPEND_EVENT_THREAD) {
+            lock = trImpl.accessLock.writeLock();
+        } else {
+            lock = debuggerImpl.accessLock.writeLock();
+        }
+        lock.lock();
         try {
             ((JPDAThreadImpl) tr).waitUntilMethodInvokeDone();
             EventRequestManager erm = VirtualMachineWrapper.eventRequestManager(vm);
             //Remove all step requests -- TODO: Do we want it?
             List<StepRequest> stepRequests = EventRequestManagerWrapper.stepRequests(erm);
-            EventRequestManagerWrapper.deleteEventRequests(erm, stepRequests);
+            try {
+                EventRequestManagerWrapper.deleteEventRequests(erm, stepRequests);
+            } catch (InvalidRequestStateExceptionWrapper irex) {
+                List<StepRequest> assureDeletedAllstepRequests = new ArrayList<StepRequest>(stepRequests);
+                for (StepRequest sr : assureDeletedAllstepRequests) {
+                    try {
+                        EventRequestManagerWrapper.deleteEventRequest(erm, sr);
+                    } catch (InvalidRequestStateExceptionWrapper ex) {}
+                }
+            }
             for (StepRequest stepRequest : stepRequests) {
                 //SingleThreadedStepWatch.stepRequestDeleted(stepRequest);
                 debuggerImpl.getOperator().unregister(stepRequest);
@@ -207,7 +224,7 @@ public class JPDAStepImpl extends JPDAStep implements Executor {
         } catch (VMDisconnectedExceptionWrapper ex) {
         } catch (ObjectCollectedExceptionWrapper ex) {
         } finally {
-            trImpl.accessLock.readLock().unlock();
+            lock.unlock();
         }
         if (setStoppedStateNoContinue[0]) {
             debuggerImpl.setStoppedStateNoContinue(trImpl.getThreadReference());
@@ -319,8 +336,19 @@ public class JPDAStepImpl extends JPDAStep implements Executor {
             nextOperationLocations = expr.findNextOperationLocations(codeIndex);
         } else {
             Location[] locations = expr.getLocations();
-            nextOperationLocations = new ExpressionPool.OperationLocation[] {
-                new ExpressionPool.OperationLocation(ops[opIndex], locations[opIndex], opIndex) };
+            ExpressionPool.OperationLocation[] opLoc = new ExpressionPool.OperationLocation[ops.length - opIndex];
+            int opLocIndex = 0;
+            for (int i = opIndex; i < opLoc.length; i++) {
+                if (i == opIndex || locations[i].codeIndex() > locations[opIndex].codeIndex()) {
+                    opLoc[opLocIndex++] = new ExpressionPool.OperationLocation(ops[i], locations[i], i);
+                }
+            }
+            if (opLocIndex == opLoc.length) {
+                nextOperationLocations = opLoc;
+            } else {
+                nextOperationLocations = new ExpressionPool.OperationLocation[opLocIndex];
+                System.arraycopy(opLoc, 0, nextOperationLocations, 0, opLocIndex);
+            }
         }
         boolean isNextOperationFromDifferentExpression = false;
         if (nextOperationLocations != null) {
@@ -464,7 +492,9 @@ public class JPDAStepImpl extends JPDAStep implements Executor {
             try {
                 EventRequestManager erm = VirtualMachineWrapper.eventRequestManager(vm);
                 EventRequest eventRequest = EventWrapper.request(event);
-                EventRequestManagerWrapper.deleteEventRequest(erm, eventRequest);
+                try {
+                    EventRequestManagerWrapper.deleteEventRequest(erm, eventRequest);
+                } catch (InvalidRequestStateExceptionWrapper ex) {}
                 debuggerImpl.getOperator().unregister(eventRequest);
                 /*if (eventRequest instanceof StepRequest) {
                     SingleThreadedStepWatch.stepRequestDeleted((StepRequest) eventRequest);
@@ -529,13 +559,21 @@ public class JPDAStepImpl extends JPDAStep implements Executor {
             if (operationBreakpoints != null) {
                 for (Iterator<BreakpointRequest> it = operationBreakpoints.iterator(); it.hasNext(); ) {
                     BreakpointRequest br = it.next();
-                    EventRequestManagerWrapper.deleteEventRequest(erm, br);
+                    try {
+                        EventRequestManagerWrapper.deleteEventRequest(erm, br);
+                    } catch (InvalidRequestStateExceptionWrapper ex) {
+                        Exceptions.printStackTrace(ex);
+                    }
                     debuggerImpl.getOperator().unregister(br);
                 }
                 this.operationBreakpoints = null;
             }
             if (boundaryStepRequest != null) {
-                EventRequestManagerWrapper.deleteEventRequest(erm, boundaryStepRequest);
+                try {
+                    EventRequestManagerWrapper.deleteEventRequest(erm, boundaryStepRequest);
+                } catch (InvalidRequestStateExceptionWrapper ex) {
+                    Exceptions.printStackTrace(ex);
+                }
                 //SingleThreadedStepWatch.stepRequestDeleted(boundaryStepRequest);
                 debuggerImpl.getOperator().unregister(boundaryStepRequest);
             }
@@ -764,7 +802,9 @@ public class JPDAStepImpl extends JPDAStep implements Executor {
         try {
             EventRequestManager erm = VirtualMachineWrapper.eventRequestManager(vm);
             for (EventRequest er : requestsToCancel) {
-                EventRequestManagerWrapper.deleteEventRequest(erm, er);
+                try {
+                    EventRequestManagerWrapper.deleteEventRequest(erm, er);
+                } catch (InvalidRequestStateExceptionWrapper ex) {}
                 debuggerImpl.getOperator ().unregister (er);
             }
         } catch (VMDisconnectedExceptionWrapper e) {
