@@ -51,12 +51,14 @@ import org.netbeans.spi.debugger.ContextProvider;
 import org.netbeans.api.debugger.jpda.JPDADebugger;
 import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
 import org.netbeans.modules.debugger.jpda.ThreadsCollectorImpl;
+import org.netbeans.spi.debugger.ActionsProvider;
 
 
 /**
  *
  * @author  Jan Jancura
  */
+@ActionsProvider.Registration(path="netbeans-JPDASession", actions={"continue"})
 public class ContinueActionProvider extends JPDADebuggerActionProvider {
     
     private ThreadsCollectorImpl threadsCollector;
@@ -81,7 +83,7 @@ public class ContinueActionProvider extends JPDADebuggerActionProvider {
     
     @Override
     public void postAction(Object action, final Runnable actionPerformedNotifier) {
-        doLazyAction(new Runnable() {
+        doLazyAction(action, new Runnable() {
             public void run() {
                 try {
                     getDebuggerImpl ().resume ();
