@@ -52,6 +52,7 @@ import org.netbeans.api.debugger.ActionsManager;
 import org.netbeans.spi.debugger.ContextProvider;
 import org.netbeans.api.debugger.jpda.JPDADebugger;
 import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
+import org.netbeans.spi.debugger.ActionsProvider;
 
 
 /**
@@ -59,6 +60,7 @@ import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
 *
 * @author   Jan Jancura
 */
+@ActionsProvider.Registration(path="netbeans-JPDASession", actions={"kill"})
 public class KillActionProvider extends JPDADebuggerActionProvider {
 
 
