@@ -106,6 +106,7 @@ import org.openide.NotifyDescriptor;
 import org.netbeans.modules.debugger.jpda.models.CallStackFrameImpl;
 import org.netbeans.modules.debugger.jpda.models.JPDAThreadImpl;
 import org.netbeans.modules.debugger.jpda.util.Executor;
+import org.netbeans.spi.debugger.ActionsProvider;
 import org.netbeans.spi.debugger.jpda.EditorContext;
 import org.netbeans.spi.debugger.jpda.EditorContext.Operation;
 import org.openide.ErrorManager;
@@ -117,6 +118,7 @@ import org.openide.util.NbBundle;
  *
  * @author  Martin Entlicher
  */
+@ActionsProvider.Registration(path="netbeans-JPDASession", actions={"runIntoMethod"})
 public class RunIntoMethodActionProvider extends ActionsProviderSupport 
                                          implements PropertyChangeListener,
                                                     ActionsManagerListener {
@@ -437,9 +439,11 @@ public class RunIntoMethodActionProvider extends ActionsProviderSupport
                             ((JPDAStepImpl) boundaryStepPtr[0]).cancel();
                         }
                         try {
-                            EventRequestManagerWrapper.deleteEventRequest(
-                                    VirtualMachineWrapper.eventRequestManager(vm),
-                                    brReq);
+                            try {
+                                EventRequestManagerWrapper.deleteEventRequest(
+                                        VirtualMachineWrapper.eventRequestManager(vm),
+                                        brReq);
+                            } catch (InvalidRequestStateExceptionWrapper ex) {}
                             debugger.getOperator().unregister(brReq);
                         } catch (InternalExceptionWrapper e) {
                         } catch (VMDisconnectedExceptionWrapper e) {
@@ -498,6 +502,7 @@ public class RunIntoMethodActionProvider extends ActionsProviderSupport
                                 request);
                     } catch (InternalExceptionWrapper ex) {
                     } catch (VMDisconnectedExceptionWrapper ex) {
+                    } catch (InvalidRequestStateExceptionWrapper irex) {
                     }
                 }
             }
