@@ -110,16 +110,20 @@ import org.openide.util.Exceptions;
  *
  * @author  Jan Jancura
  */
+@ActionsProvider.Registration(path="netbeans-JPDASession", actions={"stepOver", "stepOut"})
 public class StepActionProvider extends JPDADebuggerActionProvider 
 implements Executor {
-    
+
     private StepRequest             stepRequest;
     private ContextProvider         lookupProvider;
     private MethodExitBreakpointListener lastMethodExitBreakpointListener;
+    private boolean                 isSyntheticLocation;
     //private SingleThreadedStepWatch stepWatch;
     private boolean smartSteppingStepOut;
     private Properties p;
-
+    private String className;
+    private String methodName;
+    private int depth;
     
     private static boolean ssverbose = 
         System.getProperty ("netbeans.debugger.smartstepping") != null;
@@ -165,7 +169,7 @@ implements Executor {
     
     public void postAction(final Object action,
                            final Runnable actionPerformedNotifier) {
-        doLazyAction(new Runnable() {
+        doLazyAction(action, new Runnable() {
             public void run() {
                 try {
                     runAction(action);
@@ -177,38 +181,41 @@ implements Executor {
     }
     
     public void runAction(final Object action) {
-        runAction(action, true);
+        runAction(action, true, null);
     }
 
-    private void runAction(final Object action, boolean doResume) {
+    private void runAction(final Object action, boolean doResume, Lock lock) {
         //S ystem.out.println("\nStepAction.doAction");
         int suspendPolicy = getDebuggerImpl().getSuspend();
         JPDAThreadImpl resumeThread = (JPDAThreadImpl) getDebuggerImpl().getCurrentThread();
-        Lock lock;
-        if (suspendPolicy == JPDADebugger.SUSPEND_EVENT_THREAD) {
-            lock = resumeThread.accessLock.writeLock();
-        } else {
-            lock = getDebuggerImpl().accessLock.writeLock();
-        }
-        lock.lock();
+        boolean locked = lock == null;
         try {
-            // 1) init info about current state & remove old
-            //    requests in the current thread
-            // We have to assure that the thread is suspended so that we
-            // do not randomly resume threads
-            while (!resumeThread.isSuspended()) {
-                // The thread is not suspended, release the lock so that others
-                // can process what they want with the resumed thread...
-                lock.unlock();
-                Thread.yield();
-                try {
-                    Thread.sleep(100); // Wait for a moment
-                } catch (InterruptedException iex) {}
-                lock.lock(); // Take the lock again to repeat the test
-                if (!resumeThread.isSuspended() && !resumeThread.isInStep() && !resumeThread.isMethodInvoking()) {
-                    // Explicitely suspend the thread if it's not in a step
-                    // or in a method invocation:
-                    resumeThread.suspend();
+            if (lock == null) {
+                if (suspendPolicy == JPDADebugger.SUSPEND_EVENT_THREAD) {
+                    lock = resumeThread.accessLock.writeLock();
+                } else {
+                    lock = getDebuggerImpl().accessLock.writeLock();
+                }
+                lock.lock();
+
+                // 1) init info about current state & remove old
+                //    requests in the current thread
+                // We have to assure that the thread is suspended so that we
+                // do not randomly resume threads
+                while (!resumeThread.isSuspended()) {
+                    // The thread is not suspended, release the lock so that others
+                    // can process what they want with the resumed thread...
+                    lock.unlock();
+                    Thread.yield();
+                    try {
+                        Thread.sleep(100); // Wait for a moment
+                    } catch (InterruptedException iex) {}
+                    lock.lock(); // Take the lock again to repeat the test
+                    if (!resumeThread.isSuspended() && !resumeThread.isInStep() && !resumeThread.isMethodInvoking()) {
+                        // Explicitely suspend the thread if it's not in a step
+                        // or in a method invocation:
+                        resumeThread.suspend();
+                    }
                 }
             }
             resumeThread.waitUntilMethodInvokeDone();
@@ -252,6 +259,9 @@ implements Executor {
                 getDebuggerImpl ().getOperator ().unregister(stepRequest);
                 return ;
             }
+            className = resumeThread.getClassName ();
+            methodName = resumeThread.getMethodName ();
+            depth = resumeThread.getStackDepth();
             if (logger.isLoggable(Level.FINE)) {
                 logger.fine("JDI Request (action "+action+"): " + stepRequest);
             }
@@ -279,7 +289,9 @@ implements Executor {
         } catch (ObjectCollectedExceptionWrapper e) {
             // Thread was collected - ignore the step
         } finally {
-            lock.unlock();
+            if (locked && lock != null) {
+                lock.unlock();
+            }
         }
         //S ystem.out.println("/nStepAction.doAction end");
     }
@@ -367,43 +379,42 @@ implements Executor {
             int suspendPolicy = getDebuggerImpl().getSuspend();
             
             // Synthetic method?
-            try {
-                if (TypeComponentWrapper.isSynthetic(LocationWrapper.method(StackFrameWrapper.location(ThreadReferenceWrapper.frame(tr, 0))))) {
-                    //S ystem.out.println("In synthetic method -> STEP OVER/OUT again");
-                    
-                    int step = StepRequestWrapper.depth((StepRequest) EventWrapper.request(ev));
-                    VirtualMachine vm = getDebuggerImpl ().getVirtualMachine ();
-                    if (vm == null) {
-                        return false; // The session has finished
-                    }
-                    stepRequest = EventRequestManagerWrapper.createStepRequest(VirtualMachineWrapper.eventRequestManager(vm),
-                        tr,
-                        StepRequest.STEP_LINE,
-                        step
-                    );
-                    EventRequestWrapper.addCountFilter(stepRequest, 1);
-                    getDebuggerImpl ().getOperator ().register (stepRequest, this);
-                    EventRequestWrapper.setSuspendPolicy(stepRequest, suspendPolicy);
-                    try {
-                        EventRequestWrapper.enable(stepRequest);
-                    } catch (IllegalThreadStateException itsex) {
-                        // the thread named in the request has died.
-                        getDebuggerImpl ().getOperator ().unregister(stepRequest);
-                        stepRequest = null;
-                    } catch (InvalidRequestStateExceptionWrapper irse) {
-                        Exceptions.printStackTrace(irse);
-                        getDebuggerImpl ().getOperator ().unregister(stepRequest);
-                        stepRequest = null;
-                    }
-                    return true;
+            if (isSyntheticLocation) {
+                //S ystem.out.println("In synthetic method -> STEP OVER/OUT again");
+
+                int step = StepRequestWrapper.depth((StepRequest) EventWrapper.request(ev));
+                VirtualMachine vm = getDebuggerImpl ().getVirtualMachine ();
+                if (vm == null) {
+                    removeBPListener();
+                    return false; // The session has finished
                 }
-            } catch (IncompatibleThreadStateException e) {
-                Exceptions.printStackTrace(e);
-                logger.fine("Incompatible Thread State: " + e.getLocalizedMessage());
-            } catch (IllegalThreadStateExceptionWrapper e) {
-                return false;
-            } catch (InvalidStackFrameExceptionWrapper e) {
-                Exceptions.printStackTrace(e);
+                stepRequest = EventRequestManagerWrapper.createStepRequest(VirtualMachineWrapper.eventRequestManager(vm),
+                    tr,
+                    StepRequest.STEP_LINE,
+                    step
+                );
+                EventRequestWrapper.addCountFilter(stepRequest, 1);
+                getDebuggerImpl ().getOperator ().register (stepRequest, this);
+                EventRequestWrapper.setSuspendPolicy(stepRequest, suspendPolicy);
+                try {
+                    EventRequestWrapper.enable(stepRequest);
+                } catch (IllegalThreadStateException itsex) {
+                    // the thread named in the request has died.
+                    getDebuggerImpl ().getOperator ().unregister(stepRequest);
+                    stepRequest = null;
+                    removeBPListener();
+                } catch (InvalidRequestStateExceptionWrapper irse) {
+                    Exceptions.printStackTrace(irse);
+                    getDebuggerImpl ().getOperator ().unregister(stepRequest);
+                    stepRequest = null;
+                    removeBPListener();
+                }
+                return true;
+            }
+            if (depth == 1 && "main".equals(methodName) && !"java.lang.Thread".equals(this.className) &&
+                "java.lang.Thread".equals(className) && "exit".equals(getDebuggerImpl ().getThread (tr).getMethodName())) {
+                // Hack for not stepping into Thread.exit() when stepping *over* from main() method.
+                return true; // Resume to let the thread die and the app to finish.
             }
             
             // Stop execution here?
@@ -430,17 +441,17 @@ implements Executor {
             boolean stepThrough = useStepFilters && p.getBoolean("StepThroughFilters", false);
             if (!stepThrough || smartSteppingStepOut) {
                 // Assure that the action does not resume anything. Resume is done by Operator.
-                getStepIntoActionProvider ().runAction(ActionsManager.ACTION_STEP_OUT, false);
+                getStepIntoActionProvider ().runAction(ActionsManager.ACTION_STEP_OUT, false, lock);
             } else {
                 // Assure that the action does not resume anything. Resume is done by Operator.
                 int origDepth = StepRequestWrapper.depth(sr);
                 if (origDepth == StepRequest.STEP_OVER) {
-                    runAction(ActionsManager.ACTION_STEP_OVER, false);
+                    runAction(ActionsManager.ACTION_STEP_OVER, false, lock);
                     //getStepIntoActionProvider ().runAction(StepIntoActionProvider.ACTION_SMART_STEP_INTO, false);
                 } else if (origDepth == StepRequest.STEP_OUT) {
-                    runAction(ActionsManager.ACTION_STEP_OUT, false);
+                    runAction(ActionsManager.ACTION_STEP_OUT, false, lock);
                 } else { // if (origDepth == StepRequest.STEP_INTO) {
-                    getStepIntoActionProvider ().runAction(StepIntoActionProvider.ACTION_SMART_STEP_INTO, false);
+                    getStepIntoActionProvider ().runAction(StepIntoActionProvider.ACTION_SMART_STEP_INTO, false, lock);
                 }
             }
             //S ystem.out.println("/nStepAction.exec end - resume");
@@ -469,6 +480,14 @@ implements Executor {
             stepWatch.done();
             stepWatch = null;
         }*/
+        if (!isSyntheticLocation && lastMethodExitBreakpointListener != null) {
+            lastMethodExitBreakpointListener.destroy();
+            lastMethodExitBreakpointListener = null;
+        }
+    }
+
+    private void removeBPListener() {
+        isSyntheticLocation = false;
         if (lastMethodExitBreakpointListener != null) {
             lastMethodExitBreakpointListener.destroy();
             lastMethodExitBreakpointListener = null;
@@ -479,28 +498,37 @@ implements Executor {
         Variable returnValue = null;
         if (lastMethodExitBreakpointListener != null) {
             returnValue = lastMethodExitBreakpointListener.getReturnValue();
+        }
+        isSyntheticLocation = !setLastOperation(tr, getDebuggerImpl(), returnValue);
+        if (!isSyntheticLocation && lastMethodExitBreakpointListener != null) {
             lastMethodExitBreakpointListener.destroy();
             lastMethodExitBreakpointListener = null;
         }
-        setLastOperation(tr, getDebuggerImpl(), returnValue);
     }
 
-    public static void setLastOperation(ThreadReference tr, JPDADebuggerImpl debugger, Variable returnValue) throws VMDisconnectedExceptionWrapper {
+    public static boolean setLastOperation(ThreadReference tr, JPDADebuggerImpl debugger, Variable returnValue) throws VMDisconnectedExceptionWrapper {
         Location loc;
         try {
             loc = StackFrameWrapper.location(ThreadReferenceWrapper.frame(tr, 0));
         } catch (IncompatibleThreadStateException itsex) {
             Exceptions.printStackTrace(itsex);
             logger.fine("Incompatible Thread State: "+itsex.getLocalizedMessage());
-            return ;
+            return true;
         } catch (IllegalThreadStateExceptionWrapper itsex) {
-            return ;
+            return true;
         } catch (InternalExceptionWrapper iex) {
-            return ;
+            return true;
         } catch (InvalidStackFrameExceptionWrapper iex) {
-            return ;
+            return true;
         } catch (ObjectCollectedExceptionWrapper iex) {
-            return ;
+            return true;
+        }
+        try {
+            if (TypeComponentWrapper.isSynthetic0(LocationWrapper.method(loc))) {
+                // Ignore synthetic methods
+                return false;
+            }
+        } catch (InternalExceptionWrapper ex) {
         }
         Session currentSession = DebuggerManager.getDebuggerManager().getCurrentSession();
         String language = currentSession == null ? null : currentSession.getCurrentLanguage();
@@ -509,14 +537,14 @@ implements Executor {
         try {
             url = sourcePath.getURL(loc, language);
         } catch (InternalExceptionWrapper iex) {
-            return ;
+            return true;
         } catch (ObjectCollectedExceptionWrapper iex) {
-            return ;
+            return true;
         }
         ExpressionPool exprPool = debugger.getExpressionPool();
         ExpressionPool.Expression expr = exprPool.getExpressionAt(loc, url);
         if (expr == null) {
-            return ;
+            return true;
         }
         Operation[] ops = expr.getOperations();
         // code index right after the method call (step out)
@@ -526,7 +554,7 @@ implements Executor {
             codeIndex = (int) LocationWrapper.codeIndex(loc);
             bytecodes = MethodWrapper.bytecodes(LocationWrapper.method(loc));
         } catch (InternalExceptionWrapper iex) {
-            return ;
+            return false;
         }
         if (codeIndex >= 5 && (bytecodes[codeIndex - 5] & 0xFF) == 185) { // invokeinterface
             codeIndex -= 5;
@@ -538,23 +566,20 @@ implements Executor {
         if (opIndex >= 0 && ops[opIndex].getBytecodeIndex() == codeIndex) {
             lastOperation = ops[opIndex];
         } else {
-            return ;
+            return true;
         }
         lastOperation.setReturnValue(returnValue);
         JPDAThreadImpl jtr = debugger.getThread(tr);
         jtr.addLastOperation(lastOperation);
         jtr.setCurrentOperation(lastOperation);
+        return true;
     }
     
     private StepIntoActionProvider stepIntoActionProvider;
     
     private StepIntoActionProvider getStepIntoActionProvider () {
         if (stepIntoActionProvider == null) {
-            List l = lookupProvider.lookup (null, ActionsProvider.class);
-            int i, k = l.size ();
-            for (i = 0; i < k; i++)
-                if (l.get (i) instanceof StepIntoActionProvider)
-                    stepIntoActionProvider = (StepIntoActionProvider) l.get (i);
+            stepIntoActionProvider = StepIntoActionProvider.instanceByContext.get(lookupProvider).get();
         }
         return stepIntoActionProvider;
     }
