@@ -44,10 +44,14 @@
 
 package org.netbeans.modules.debugger.jpda.breakpoints;
 
+import com.sun.jdi.event.Event;
+import com.sun.jdi.request.EventRequest;
 import java.awt.EventQueue;
 import java.beans.PropertyChangeListener;
+import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.IdentityHashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.logging.Logger;
 
@@ -56,6 +60,9 @@ import org.netbeans.api.debugger.DebuggerEngine;
 import org.netbeans.api.debugger.DebuggerManager;
 import org.netbeans.api.debugger.DebuggerManagerListener;
 import org.netbeans.api.debugger.LazyActionsManagerListener;
+import org.netbeans.api.debugger.Properties;
+import org.netbeans.modules.debugger.jpda.jdi.InternalExceptionWrapper;
+import org.netbeans.modules.debugger.jpda.jdi.VMDisconnectedExceptionWrapper;
 import org.netbeans.spi.debugger.ContextProvider;
 import org.netbeans.api.debugger.Session;
 import org.netbeans.api.debugger.Watch;
@@ -81,6 +88,7 @@ import org.openide.util.Exceptions;
  *
  * @author   Jan Jancura
  */
+@LazyActionsManagerListener.Registration(path="netbeans-JPDASession/Java")
 public class BreakpointsEngineListener extends LazyActionsManagerListener 
 implements PropertyChangeListener, DebuggerManagerListener {
     
@@ -229,13 +237,20 @@ implements PropertyChangeListener, DebuggerManagerListener {
 
     // helper methods ..........................................................
     
-    private Map<Breakpoint, BreakpointImpl> breakpointToImpl = new IdentityHashMap<Breakpoint, BreakpointImpl>();
+    private final Map<Breakpoint, BreakpointImpl> breakpointToImpl = new IdentityHashMap<Breakpoint, BreakpointImpl>();
+    private final BreakpointImpl preliminaryBreakpointImpl = new PreliminaryBreakpointImpl();
     
     private void createBreakpointImpls () {
         Breakpoint[] bs = DebuggerManager.getDebuggerManager ().getBreakpoints ();
         int i, k = bs.length;
         for (i = 0; i < k; i++)
             createBreakpointImpl (bs [i]);
+        Properties p = Properties.getDefault().getProperties("debugger.options.JPDA");
+        boolean doCatchExceptions = p.getBoolean("CatchExceptions", false);
+        if (doCatchExceptions) {
+            ExceptionBreakpoint eb = ExceptionBreakpoint.create(java.lang.Throwable.class.getName(), ExceptionBreakpoint.TYPE_EXCEPTION_UNCATCHED);
+            createBreakpointImpl(eb);
+        }
     }
     
     private void removeBreakpointImpls () {
@@ -263,96 +278,113 @@ implements PropertyChangeListener, DebuggerManagerListener {
         }
     }
     
-    public synchronized void fixBreakpointImpls () {
-        Iterator<BreakpointImpl> i = breakpointToImpl.values ().iterator ();
-        while (i.hasNext ())
-            i.next ().fixed ();
+    public void fixBreakpointImpls () {
+        List<BreakpointImpl> bpis;
+        synchronized (breakpointToImpl) {
+            bpis = new ArrayList<BreakpointImpl>(breakpointToImpl.size());
+            Iterator<BreakpointImpl> i = breakpointToImpl.values ().iterator ();
+            while (i.hasNext ()) {
+                BreakpointImpl bpi = i.next();
+                if (bpi == preliminaryBreakpointImpl) {
+                    continue;
+                }
+                bpis.add(bpi);
+            }
+        }
+        for (BreakpointImpl bpi : bpis) {
+            bpi.fixed ();
+        }
     }
 
-    private synchronized void createBreakpointImpl (Breakpoint b) {
-        if (breakpointToImpl.containsKey (b)) return;
-        if (!(b instanceof JPDABreakpoint)) return ;
-        JPDADebugger bDebugger;
-        try {
-            // TODO: bDebugger = ((JPDADebugger) b).getSession();
-            java.lang.reflect.Method getSessionMethod = JPDABreakpoint.class.getDeclaredMethod("getSession");
-            getSessionMethod.setAccessible(true);
-            bDebugger = (JPDADebugger) getSessionMethod.invoke(b);
-        } catch (Exception ex) {
-            bDebugger = null;
-            Exceptions.printStackTrace(ex);
-        }
-        if (bDebugger != null && !bDebugger.equals(debugger)) {
-            return ;
+    private void createBreakpointImpl (Breakpoint b) {
+        synchronized (breakpointToImpl) {
+            if (breakpointToImpl.containsKey (b)) return;
+            if (!(b instanceof JPDABreakpoint)) return ;
+            JPDADebugger bDebugger;
+            try {
+                // TODO: bDebugger = ((JPDADebugger) b).getSession();
+                java.lang.reflect.Method getSessionMethod = JPDABreakpoint.class.getDeclaredMethod("getSession");
+                getSessionMethod.setAccessible(true);
+                bDebugger = (JPDADebugger) getSessionMethod.invoke(b);
+            } catch (Exception ex) {
+                bDebugger = null;
+                Exceptions.printStackTrace(ex);
+            }
+            if (bDebugger != null && !bDebugger.equals(debugger)) {
+                return ;
+            }
+            breakpointToImpl.put(b, preliminaryBreakpointImpl);
         }
+        BreakpointImpl bpi;
         if (b instanceof LineBreakpoint) {
-            breakpointToImpl.put (
-                b,
-                new LineBreakpointImpl (
+            bpi = new LineBreakpointImpl (
                     (LineBreakpoint) b,
                     breakpointsReader,
                     debugger,
                     session,
                     engineContext
-                )
-            );
+                    );
         } else
         if (b instanceof ExceptionBreakpoint) {
-            breakpointToImpl.put (
-                b,
-                new ExceptionBreakpointImpl (
+            bpi = new ExceptionBreakpointImpl (
                     (ExceptionBreakpoint) b,
                     debugger,
                     session
-                )
-            );
+                    );
         } else
         if (b instanceof MethodBreakpoint) {
-            breakpointToImpl.put (
-                b,
-                new MethodBreakpointImpl (
+            bpi = new MethodBreakpointImpl (
                     (MethodBreakpoint) b,
                     debugger,
                     session
-                )
-            );
+                    );
         } else
         if (b instanceof FieldBreakpoint) {
-            breakpointToImpl.put (
-                b,
-                new FieldBreakpointImpl (
+            bpi = new FieldBreakpointImpl (
                     (FieldBreakpoint) b,
                     debugger,
                     session
-                )
-            );
+                    );
         } else
         if (b instanceof ThreadBreakpoint) {
-            breakpointToImpl.put (
-                b,
-                new ThreadBreakpointImpl (
+            bpi = new ThreadBreakpointImpl (
                     (ThreadBreakpoint) b,
                     debugger,
                     session
-                )
-            );
+                    );
         } else
         if (b instanceof ClassLoadUnloadBreakpoint) {
-            breakpointToImpl.put (
-                b,
-                new ClassBreakpointImpl (
+            bpi = new ClassBreakpointImpl (
                     (ClassLoadUnloadBreakpoint) b,
                     debugger,
                     session
-                )
-            );
+                    );
+        } else {
+            bpi = null;
+        }
+        BreakpointImpl bpiToRemove = null;
+        synchronized (breakpointToImpl) {
+            if (bpi == null) {
+                breakpointToImpl.remove(b);
+            } else {
+                if (!breakpointToImpl.containsKey(b)) {
+                    // There already was a request to remove this
+                    bpiToRemove = bpi;
+                } else {
+                    breakpointToImpl.put(b, bpi);
+                }
+            }
+        }
+        logger.finer("BreakpointsEngineListener: created impl "+bpi+" for "+b);
+        if (bpiToRemove != null) {
+            bpiToRemove.remove();
+            logger.finer("BreakpointsEngineListener: removed impl "+bpiToRemove);
         }
-        logger.finer("BreakpointsEngineListener: created impl "+breakpointToImpl.get(b)+" for "+b);
     }
 
     private boolean removeBreakpointImpl (Breakpoint b) {
         BreakpointImpl impl;
-        synchronized (this) {
+        synchronized (breakpointToImpl) {
             impl = breakpointToImpl.remove(b);
             if (impl == null) return false;
         }
@@ -360,4 +392,38 @@ implements PropertyChangeListener, DebuggerManagerListener {
         impl.remove ();
         return true;
     }
+
+    private static final class PreliminaryBreakpointImpl extends BreakpointImpl {
+
+        public PreliminaryBreakpointImpl() {
+            super(null, null, null, null);
+        }
+
+        @Override
+        protected void setRequests() {}
+
+        @Override
+        protected EventRequest createEventRequest(EventRequest oldRequest) throws InternalExceptionWrapper, VMDisconnectedExceptionWrapper {
+            throw new UnsupportedOperationException("Not supported yet.");
+        }
+
+        @Override
+        public boolean processCondition(Event event) {
+            throw new UnsupportedOperationException("Not supported yet.");
+        }
+
+        @Override
+        public boolean exec(Event event) {
+            throw new UnsupportedOperationException("Not supported yet.");
+        }
+
+        @Override
+        public void removed(EventRequest eventRequest) {}
+
+        @Override
+        protected void remove() {
+            // do nothing
+        }
+
+    }
 }
