@@ -49,7 +49,6 @@ import com.sun.jdi.ArrayType;
 import com.sun.jdi.CharValue;
 import com.sun.jdi.ClassObjectReference;
 import com.sun.jdi.ClassType;
-import com.sun.jdi.InterfaceType;
 import com.sun.jdi.Method;
 import com.sun.jdi.ObjectReference;
 import com.sun.jdi.PrimitiveValue;
@@ -93,6 +92,7 @@ import org.netbeans.modules.debugger.jpda.jdi.TypeComponentWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.TypeWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.VMDisconnectedExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.ValueWrapper;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.WeakListeners;
 
@@ -100,7 +100,7 @@ import org.openide.util.WeakListeners;
 /**
  * @author   Jan Jancura
  */
-class AbstractObjectVariable extends AbstractVariable implements ObjectVariable {
+public class AbstractObjectVariable extends AbstractVariable implements ObjectVariable {
     // Customized for add/removePropertyChangeListener
     // Cloneable for fixed watches
     
@@ -110,15 +110,31 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
     private Field[]         fields;
     private Field[]         staticFields;
     private Field[]         inheritedFields;
-    private volatile boolean refreshFields;
+    private boolean         refreshFields;
+    private final Object    fieldsLock = new Object();
+
+    private com.sun.jdi.Type valueType;
+    private String           valueTypeName;
+    private final boolean[]  valueTypeLoaded = new boolean[] { false };
+    private Super            superClass;
+    private final boolean[]  superClassLoaded = new boolean[] { false };
     
     private DebuggetStateListener stateChangeListener = new DebuggetStateListener();
 
     
-    AbstractObjectVariable (
+    public AbstractObjectVariable (
         JPDADebuggerImpl debugger,
         Value value,
         String id
+    ) {
+        this(debugger, value, (com.sun.jdi.Type) null, id);
+    }
+
+    protected AbstractObjectVariable (
+        JPDADebuggerImpl debugger,
+        Value value,
+        com.sun.jdi.Type valueType,
+        String id
     ) {
         super(debugger, value, id);
         /*if (value instanceof ObjectReference) {
@@ -129,11 +145,21 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
                 ObjectReferenceWrapper.disableCollection((ObjectReference) value);
             } catch (Exception ex) {}
         }*/
+        if (valueType != null) {
+            this.valueType = valueType;
+            try {
+                this.valueTypeName = TypeWrapper.name(valueType);
+            } catch (InternalExceptionWrapper ex) {
+                Exceptions.printStackTrace(ex);
+            } catch (VMDisconnectedExceptionWrapper ex) {
+            }
+            this.valueTypeLoaded[0] = true;
+        }
         debugger.addPropertyChangeListener(
                 WeakListeners.propertyChange(stateChangeListener, debugger));
     }
 
-    AbstractObjectVariable (JPDADebuggerImpl debugger, Value value, String genericSignature,
+    public AbstractObjectVariable (JPDADebuggerImpl debugger, Value value, String genericSignature,
                       String id) {
         this(debugger, value, id);
         try {
@@ -159,10 +185,12 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
         if (v instanceof ArrayReference) {
             return ArrayReferenceWrapper.length0((ArrayReference) v);
         } else {
-            if (fields == null || refreshFields) {
-                initFields ();
+            synchronized (fieldsLock) {
+                if (fields == null || refreshFields) {
+                    initFields ();
+                }
+                return fields.length;
             }
-            return fields.length;
         }
     }
 
@@ -217,17 +245,19 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
                 return elements;
             } else {
                 //either the fields are cached or we have to init them
-                if (fields == null || refreshFields) {
-                    initFields ();
+                synchronized (fieldsLock) {
+                    if (fields == null || refreshFields) {
+                        initFields ();
+                    }
+                    if (to != 0) {
+                        to = Math.min(fields.length, to);
+                        from = Math.min(fields.length, from);
+                        Field[] fv = new Field [to - from];
+                        System.arraycopy (fields, from, fv, 0, to - from);
+                        return fv;
+                    }
+                    return fields;
                 }
-                if (to != 0) {
-                    to = Math.min(fields.length, to);
-                    from = Math.min(fields.length, from);
-                    Field[] fv = new Field [to - from];
-                    System.arraycopy (fields, from, fv, 0, to - from);
-                    return fv;
-                }
-                return fields;
             }
         } catch (InternalExceptionWrapper e) {
             return new Field[] {};
@@ -248,17 +278,19 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
         if (v == null || v instanceof ArrayReference) {
             return new Field[] {};
         }
-        if (fields == null || refreshFields) {
-            initFields ();
+        synchronized (fieldsLock) {
+            if (fields == null || refreshFields) {
+                initFields ();
+            }
+            if (to != 0) {
+                to = Math.min(staticFields.length, to);
+                from = Math.min(staticFields.length, from);
+                Field[] fv = new Field[to - from];
+                System.arraycopy (staticFields, from, fv, 0, to - from);
+                return fv;
+            }
+            return staticFields;
         }
-        if (to != 0) {
-            to = Math.min(staticFields.length, to);
-            from = Math.min(staticFields.length, from);
-            Field[] fv = new Field[to - from];
-            System.arraycopy (staticFields, from, fv, 0, to - from);
-            return fv;
-        }
-        return staticFields;
     }
 
     /**
@@ -271,49 +303,88 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
         if (v == null || v instanceof ArrayReference) {
             return new Field[] {};
         }
-        if (fields == null || refreshFields) {
-            initFields ();
+        synchronized (fieldsLock) {
+            if (fields == null || refreshFields) {
+                initFields ();
+            }
+            if (to != 0) {
+                to = Math.min(inheritedFields.length, to);
+                from = Math.min(inheritedFields.length, from);
+                Field[] fv = new Field[to - from];
+                System.arraycopy (inheritedFields, from, fv, 0, to - from);
+                return fv;
+            }
+            return inheritedFields;
         }
-        if (to != 0) {
-            to = Math.min(inheritedFields.length, to);
-            from = Math.min(inheritedFields.length, from);
-            Field[] fv = new Field[to - from];
-            System.arraycopy (inheritedFields, from, fv, 0, to - from);
-            return fv;
-        }
-        return inheritedFields;
     }
 
-    private volatile Super superClass;
-
     public Super getSuper () {
-        if (getInnerValue () == null) 
-            return null;
-        if (superClass != null) {
+        synchronized (superClassLoaded) {
+            if (!superClassLoaded[0]) {
+                try {
+                    Type t = getCachedType();
+                    if (t instanceof ClassType) {
+                        ClassType superType;
+                        //assert !java.awt.EventQueue.isDispatchThread();
+                        superType = ClassTypeWrapper.superclass((ClassType) t);
+                        if (superType != null) {
+                            Super s = new SuperVariable(
+                                    getDebugger(),
+                                    (ObjectReference) this.getInnerValue(),
+                                    superType,
+                                    getID()
+                                    );
+                            superClass = s;
+                        } else {
+                            superClass = null;
+                        }
+                    } else {
+                        superClass = null;
+                    }
+                } catch (ObjectCollectedExceptionWrapper ocex) {
+                    superClass = null;
+                } catch (InternalExceptionWrapper ex) {
+                    superClass = null;
+                } catch (VMDisconnectedExceptionWrapper e) {
+                    superClass = null;
+                } finally {
+                    superClassLoaded[0] = true;
+                }
+
+            }
             return superClass;
         }
-        try {
-            Type t = ValueWrapper.type(this.getInnerValue());
-            if (!(t instanceof ClassType)) 
-                return null;
-            ClassType superType;
-            superType = ClassTypeWrapper.superclass((ClassType) t);
-            if (superType == null) 
-                return null;
-            Super s = new SuperVariable(
-                    getDebugger(), 
-                    (ObjectReference) this.getInnerValue(),
-                    superType,
-                    getID()
-                    );
-            superClass = s;
-            return s;
-        } catch (ObjectCollectedExceptionWrapper ocex) {
-            return null;
-        } catch (InternalExceptionWrapper ex) {
-            return null;
-        } catch (VMDisconnectedExceptionWrapper e) {
-            return null;
+    }
+
+    public boolean hasAllTypes() {
+        if (getInnerValue () == null)
+            return true;
+        Type t;
+        synchronized (valueTypeLoaded) {
+            if (!valueTypeLoaded[0]) {
+                return false;
+            }
+            t = valueType;
+        }
+        if (t instanceof ClassType) {
+            ClassType ct = (ClassType) t;
+            if (!getDebugger().hasAllInterfaces(ct)) {
+                return false;
+            }
+            synchronized (superClassLoaded) {
+                if (!superClassLoaded[0]) {
+                    return false;
+                }
+            }
+        }
+        return true;
+    }
+
+    public void loadAllTypes() {
+        getAllInterfaces();
+        Super s = getSuper();
+        while (s != null) {
+            s = s.getSuper();
         }
     }
     
@@ -321,20 +392,11 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
         if (getInnerValue () == null)
             return null;
         try {
-            Type t = ValueWrapper.type(this.getInnerValue());
+            Type t = getCachedType();
             if (!(t instanceof ClassType))
                 return null;
-            List<InterfaceType> interfaces;
-            interfaces = ClassTypeWrapper.allInterfaces0((ClassType) t);
-            if (interfaces == null)
-                return null;
-            List<JPDAClassType> allInterfaces = new ArrayList<JPDAClassType>();
-            for (InterfaceType it : interfaces) {
-                allInterfaces.add(new JPDAClassTypeImpl(getDebugger(), it));
-            }
-            return allInterfaces;
-        } catch (ClassNotPreparedExceptionWrapper cnpex) {
-            return null;
+            ClassType ct = (ClassType) t;
+            return getDebugger().getAllInterfaces(ct);
         } catch (ObjectCollectedExceptionWrapper ocex) {
             return null;
         } catch (InternalExceptionWrapper ex) {
@@ -363,21 +425,53 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
      */
     public String getToStringValue (int maxLength) throws InvalidExpressionException {
         Value v = getInnerValue ();
-        return getToStringValue(v, getDebugger(), maxLength);
+        try {
+            return getToStringValue(v, getCachedType(), getDebugger(), maxLength);
+        } catch (InternalExceptionWrapper ex) {
+            return ex.getLocalizedMessage();
+        } catch (VMDisconnectedExceptionWrapper ex) {
+            return NbBundle.getMessage(AbstractVariable.class, "MSG_Disconnected");
+        } catch (ObjectCollectedExceptionWrapper ocex) {
+            return NbBundle.getMessage(AbstractVariable.class, "MSG_ObjCollected");
+        }
     }
-    
+
     static String getToStringValue (Value v, JPDADebuggerImpl debugger, int maxLength) throws InvalidExpressionException {
         if (v == null) return null;
+        com.sun.jdi.Type type;
         try {
-            if (!(ValueWrapper.type (v) instanceof ClassType))
+            type = ValueWrapper.type(v);
+        } catch (InternalExceptionWrapper ex) {
+            return ex.getLocalizedMessage();
+        } catch (VMDisconnectedExceptionWrapper ex) {
+            return NbBundle.getMessage(AbstractVariable.class, "MSG_Disconnected");
+        } catch (ObjectCollectedExceptionWrapper ocex) {
+            return NbBundle.getMessage(AbstractVariable.class, "MSG_ObjCollected");
+        }
+        return getToStringValue(v, type, debugger, maxLength);
+    }
+    
+    static String getToStringValue (Value v, com.sun.jdi.Type type, JPDADebuggerImpl debugger, int maxLength) throws InvalidExpressionException {
+        if (v == null) return null;
+        try {
+            if (!(type instanceof ClassType))
                 return AbstractVariable.getValue (v);
+            ClassType ct = (ClassType) type;
             if (v instanceof CharValue)
                 return "\'" + v.toString () + "\'";
+            /*JPDAThread ct = debugger.getCurrentThread();
+            if (ct != null) { For the case that toString() should be blocked by pending actions
+                Object pendingAction = ((JPDAThreadImpl) ct).getPendingAction();
+                if (pendingAction != null) {
+                    return ((JPDAThreadImpl) ct).getPendingString(pendingAction);
+                    //return "Action "+pendingActions.iterator().next()+" is pending...";
+                }
+            }*/
             boolean addQuotation = false;
             boolean addDots = false;
             StringReference sr;
             if (maxLength > 0 && maxLength < Integer.MAX_VALUE) {
-                Method toStringMethod = ClassTypeWrapper.concreteMethodByName((ClassType) ValueWrapper.type (v),
+                Method toStringMethod = ClassTypeWrapper.concreteMethodByName(ct,
                      "toString", "()Ljava/lang/String;");  // NOI18N
                 sr = (StringReference) debugger.invokeMethod (
                     (ObjectReference) v,
@@ -389,7 +483,7 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
                 sr = (StringReference) v;
                 addQuotation = true;
             } else {
-                Method toStringMethod = ClassTypeWrapper.concreteMethodByName((ClassType) ValueWrapper.type (v),
+                Method toStringMethod = ClassTypeWrapper.concreteMethodByName(ct,
                     "toString", "()Ljava/lang/String;");  // NOI18N
                 sr = (StringReference) debugger.invokeMethod (
                     (ObjectReference) v,
@@ -459,14 +553,15 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
             // 1) find corrent method
             Value v = this.getInnerValue ();
             if (v == null) return null;
+            ClassType ct = (ClassType) getCachedType();
             Method method = null;
             if (signature != null)
                 method = ClassTypeWrapper.concreteMethodByName(
-                        (ClassType) ValueWrapper.type(v),
+                        ct,
                         methodName, signature);
             else {
                 List l = ReferenceTypeWrapper.methodsByName(
-                        (ClassType) ValueWrapper.type(v),
+                        ct,
                         methodName);
                 int j, jj = l.size ();
                 for (j = 0; j < jj; j++)
@@ -481,12 +576,12 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
             // 2) method not found => print all method signatures
             if (method == null) {
                 List l = ReferenceTypeWrapper.methodsByName(
-                        (ClassType) ValueWrapper.type(v), methodName);
+                        ct, methodName);
                 int j, jj = l.size ();
                 for (j = 0; j < jj; j++)
                     System.out.println (TypeComponentWrapper.signature((Method) l.get (j)));
                 throw new NoSuchMethodException (
-                    TypeWrapper.name(ValueWrapper.type(v)) + "." +
+                    TypeWrapper.name(ct) + "." +
                         methodName + " : " + signature
                 );
             }
@@ -533,6 +628,24 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
     public Variable evaluate(String expression) throws InvalidExpressionException {
         return getDebugger().evaluate(expression, this);
     }
+
+    private com.sun.jdi.Type getCachedType() throws InternalExceptionWrapper, VMDisconnectedExceptionWrapper, ObjectCollectedExceptionWrapper {
+        synchronized (valueTypeLoaded) {
+            if (!valueTypeLoaded[0]) {
+                Value v = getInnerValue();
+                if (v != null) {
+                    //assert !java.awt.EventQueue.isDispatchThread();
+                    valueType = ValueWrapper.type(v);
+                    valueTypeName = TypeWrapper.name(valueType);
+                } else {
+                    valueType = null;
+                    valueTypeName = "";
+                }
+                valueTypeLoaded[0] = true;
+            }
+            return valueType;
+        }
+    }
     
     /**
      * Declared type of this local.
@@ -542,10 +655,11 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
     @Override
     public String getType () {
         if (genericType != null) return genericType;
-        Value v = getInnerValue ();
-        if (v == null) return "";
         try {
-            return TypeWrapper.name(ValueWrapper.type(v));
+            synchronized (valueTypeLoaded) {
+                getCachedType();
+                return valueTypeName;
+            }
         } catch (InternalExceptionWrapper ex) {
             return ex.getLocalizedMessage();
         } catch (VMDisconnectedExceptionWrapper vmdex) {
@@ -559,10 +673,8 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
     
     @Override
     public JPDAClassType getClassType() {
-        Value value = getInnerValue();
-        if (value == null) return null;
         try {
-            com.sun.jdi.Type type = ValueWrapper.type (value);
+            com.sun.jdi.Type type = getCachedType();
             if (type instanceof ReferenceType) {
                 return new JPDAClassTypeImpl(getDebugger(), (ReferenceType) type);
             } else {
@@ -604,10 +716,17 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
                 ObjectReferenceWrapper.disableCollection((ObjectReference) v);
             } catch (Exception ex) {}
         }*/
-        fields = null;
-        staticFields = null;
-        inheritedFields = null;
-        superClass = null;
+        synchronized (fieldsLock) {
+            fields = null;
+            staticFields = null;
+            inheritedFields = null;
+        }
+        synchronized (superClassLoaded) {
+            superClassLoaded[0] = false;
+        }
+        synchronized (valueTypeLoaded) {
+            valueTypeLoaded[0] = false;
+        }
     }
     
     private static String getTypeDescription (PushbackReader signature) 
@@ -683,6 +802,8 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
     }
 
     private void initFields () {
+        // Called under synchronized (fieldsLock)
+        assert Thread.holdsLock(fieldsLock);
         refreshFields = false;
         Value value = getInnerValue();
         Type type;
@@ -986,7 +1107,9 @@ class AbstractObjectVariable extends AbstractVariable implements ObjectVariable
                 Object newValue = evt.getNewValue();
                 if (newValue instanceof Integer &&
                     JPDADebugger.STATE_RUNNING == ((Integer) newValue).intValue()) {
-                    AbstractObjectVariable.this.refreshFields = true;
+                    synchronized (AbstractObjectVariable.this.fieldsLock) {
+                        AbstractObjectVariable.this.refreshFields = true;
+                    }
                 }
             }
         }
