@@ -48,6 +48,7 @@ import com.sun.jdi.AbsentInformationException;
 import com.sun.jdi.IncompatibleThreadStateException;
 import com.sun.jdi.InvalidStackFrameException;
 import com.sun.jdi.Location;
+import com.sun.jdi.Method;
 import com.sun.jdi.NativeMethodException;
 import com.sun.jdi.ObjectReference;
 import com.sun.jdi.PrimitiveValue;
@@ -58,9 +59,13 @@ import com.sun.jdi.VMDisconnectedException;
 import com.sun.jdi.Value;
 
 import com.sun.jdi.request.EventRequest;
+import com.sun.jdi.request.EventRequestManager;
+import com.sun.jdi.request.StepRequest;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 
 import org.netbeans.api.debugger.Session;
 import org.netbeans.api.debugger.jpda.CallStackFrame;
@@ -71,6 +76,7 @@ import org.netbeans.api.debugger.jpda.MonitorInfo;
 import org.netbeans.api.debugger.jpda.This;
 import org.netbeans.modules.debugger.jpda.EditorContextBridge;
 import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
+import org.netbeans.modules.debugger.jpda.jdi.ClassNotPreparedExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.IllegalThreadStateExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.InternalExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.InvalidRequestStateExceptionWrapper;
@@ -111,8 +117,8 @@ public class CallStackFrameImpl implements CallStackFrame {
     private int                 depth;
     private JPDADebuggerImpl    debugger;
     //private AST                 ast;
-    private Operation           currentOperation;
-    private EqualsInfo          equalsInfo;
+    private volatile Operation  currentOperation;
+    private final EqualsInfo    equalsInfo;
     private boolean             valid;
     
     public CallStackFrameImpl (
@@ -159,11 +165,11 @@ public class CallStackFrameImpl implements CallStackFrame {
         }
     }
     
-    public synchronized Operation getCurrentOperation(String struts) {
+    public Operation getCurrentOperation(String struts) {
         return currentOperation;
     }
     
-    public synchronized void setCurrentOperation(Operation operation) {
+    public void setCurrentOperation(Operation operation) {
         this.currentOperation = operation;
     }
 
@@ -195,6 +201,7 @@ public class CallStackFrameImpl implements CallStackFrame {
     */
     public synchronized String getClassName () {
         if (!valid && sfLocation == null) return "";
+        assert !java.awt.EventQueue.isDispatchThread();
         try {
             Location l = getStackFrameLocation();
             return ReferenceTypeWrapper.name(LocationWrapper.declaringType(l));
@@ -312,6 +319,7 @@ public class CallStackFrameImpl implements CallStackFrame {
     */
     public synchronized String getSourceName (String stratum) throws AbsentInformationException {
         if (!valid && sfLocation == null) return "";
+        assert !java.awt.EventQueue.isDispatchThread();
         try {
             Location l = getStackFrameLocation();
             return LocationWrapper.sourceName(l, stratum);
@@ -333,6 +341,7 @@ public class CallStackFrameImpl implements CallStackFrame {
      */
     public synchronized String getSourcePath (String stratum) throws AbsentInformationException {
         if (!valid && sfLocation == null) return "";
+        assert !java.awt.EventQueue.isDispatchThread();
         try {
             Location l = getStackFrameLocation();
             return LocationWrapper.sourcePath(l, stratum);
@@ -447,7 +456,7 @@ public class CallStackFrameImpl implements CallStackFrame {
             Location l = getStackFrameLocation();
             MethodArgument[] argumentNames = EditorContextBridge.getContext().getArguments(url, LocationWrapper.lineNumber(l));
             int n = argValues.size();
-            argumentNames = checkArgumentCount(argumentNames, n);
+            argumentNames = checkArgumentCount(argumentNames, argValues, n);
             //int n = Math.min(argValues.size(), argumentNames.length);
             LocalVariable[] arguments = new LocalVariable[n];
             for (int i = 0; i < n; i++) {
@@ -486,10 +495,74 @@ public class CallStackFrameImpl implements CallStackFrame {
         if (!JPDAUtils.IS_JDK_160_02) return null; // Can evaluate methods after pop since JDK 1.6.0_02
         JPDADebuggerImpl debuggerImpl = (JPDADebuggerImpl) debugger;
         thread.accessLock.writeLock().lock();
+        if (thread.isInStep()) {
+            // A next step is submitted, give this up
+            return null;
+        }
         try {
             try {
                 ThreadReference tr = thread.getThreadReference();
                 com.sun.jdi.VirtualMachine vm = MirrorWrapper.virtualMachine(tr);
+                EventRequestManager erm = VirtualMachineWrapper.eventRequestManager(vm);
+                List<StepRequest> stepRequests = EventRequestManagerWrapper.stepRequests(erm);
+                for (StepRequest sr : stepRequests) {
+                    if (tr == sr.thread()) {
+                        // There's a step request for this thread, we can not submit another...
+                        return null;
+                    }
+                }
+
+                int frameCount = 0;
+                try {
+                    frameCount = ThreadReferenceWrapper.frameCount0(tr);
+                } catch (IncompatibleThreadStateException itsex) {
+                    ErrorManager.getDefault().notify(itsex);
+                    return null;
+                }
+
+                Logger logger = Logger.getLogger(CallStackFrameImpl.class.getName());
+
+                // Find out if method <classType>.<methodName> is native:
+                String classType = operation.getMethodClassType();
+                String methodName = operation.getMethodName();
+                String methodDescriptor = null;
+                try {
+                    java.lang.reflect.Field methodDescriptorField = Operation.class.getDeclaredField("methodDescriptor");
+                    methodDescriptorField.setAccessible(true);
+                    methodDescriptor = (String) methodDescriptorField.get(operation);
+                } catch (Exception ex) {
+                    Exceptions.printStackTrace(ex);
+                }
+                if (logger.isLoggable(Level.FINE)) {
+                    logger.fine("findOperationArguments(): Operation method name = '"+operation.getMethodName()+"', method descriptor = '"+methodDescriptor+"', class type = '"+operation.getMethodClassType()+"'");
+                }
+
+                List<ReferenceType> classes = VirtualMachineWrapper.classesByName0(vm, classType);
+                for (ReferenceType clazz : classes) {
+                    try {
+                        List<Method> methods;
+                        if (methodDescriptor != null) {
+                            methods = ReferenceTypeWrapper.methodsByName(clazz, methodName, methodDescriptor);
+                        } else {
+                            methods = ReferenceTypeWrapper.methodsByName(clazz, methodName);
+                        }
+                        if (logger.isLoggable(Level.FINE)) {
+                            logger.fine("  Methods = "+methods);
+                        }
+                        for (Method method : methods) {
+                            if (method.isNative()) {
+                                List<LocalVariable> noArgsList = new ArrayList<LocalVariable>(1);
+                                noArgsList.add(new ArgumentObjectVariable(debuggerImpl,
+                                                             null,
+                                                             NbBundle.getMessage(CallStackFrameImpl.class, "MSG_NoArgsForNative"),
+                                                             ""));
+                                return noArgsList;
+                            }
+                        }
+                    } catch (ClassNotPreparedExceptionWrapper ex) {
+                    }
+                }
+
                 com.sun.jdi.request.StepRequest step = EventRequestManagerWrapper.createStepRequest(
                         VirtualMachineWrapper.eventRequestManager(vm),
                         tr,
@@ -530,6 +603,11 @@ public class CallStackFrameImpl implements CallStackFrame {
                 StackFrame sf = null;
                 List<com.sun.jdi.Value> arguments = null;
                 try {
+                    int newFrameCount = ThreadReferenceWrapper.frameCount0(tr);
+                    if (!(newFrameCount > frameCount)) {
+                        // Oops, we're not in the desired method...
+                        return null;
+                    }
                     sf = ThreadReferenceWrapper.frames(tr, 0, 1).get(0);
                     arguments = getArgumentValues(sf);
                 } catch (IncompatibleThreadStateException itsex) {
@@ -570,9 +648,10 @@ public class CallStackFrameImpl implements CallStackFrame {
                         ErrorManager.getDefault().notify(itsex);
                         return null;
                     }
-                    argumentNames = checkArgumentCount(argumentNames, arguments.size());
-                    List<LocalVariable> argumentList = new ArrayList<LocalVariable>(arguments.size());
-                    for (int i = 0; i < arguments.size(); i++) {
+                    int n = arguments.size();
+                    argumentNames = checkArgumentCount(argumentNames, arguments, n);
+                    List<LocalVariable> argumentList = new ArrayList<LocalVariable>(n);
+                    for (int i = 0; i < n; i++) {
                         com.sun.jdi.Value value = arguments.get(i);
                         if (value instanceof ObjectReference) {
                             argumentList.add(
@@ -613,11 +692,18 @@ public class CallStackFrameImpl implements CallStackFrame {
         return null;
     }
     
-    private static MethodArgument[] checkArgumentCount(MethodArgument[] argumentNames, int size) {
+    private static MethodArgument[] checkArgumentCount(MethodArgument[] argumentNames, List<Value> argValues, int size) {
         if (argumentNames == null || argumentNames.length != size) {
             argumentNames = new MethodArgument[size];
             for (int i = 0; i < argumentNames.length; i++) {
-                argumentNames[i] = new MethodArgument(NbBundle.getMessage(CallStackFrameImpl.class, "CTL_MethodArgument", (i+1)), null, null, null);
+                Value v = argValues.get(i);
+                String type;
+                if (v != null) {
+                    type = v.type().name();
+                } else {
+                    type = Object.class.getName();
+                }
+                argumentNames[i] = new MethodArgument(NbBundle.getMessage(CallStackFrameImpl.class, "CTL_MethodArgument", (i+1)), type, null, null);
             }
         }
         return argumentNames;
@@ -813,10 +899,15 @@ public class CallStackFrameImpl implements CallStackFrame {
         return equalsInfo.equals(frame.equalsInfo);
     }
     
-    public synchronized int hashCode () {
+    public int hashCode () {
         return equalsInfo.hashCode();
     }
 
+    @Override
+    public String toString() {
+        return "CallStackFrameImpl["+thread+", depth = "+depth+"]";
+    }
+
     public List<MonitorInfo> getOwnedMonitors() {
         List<MonitorInfo> threadMonitors;
         try {
@@ -842,20 +933,13 @@ public class CallStackFrameImpl implements CallStackFrame {
         
         private JPDAThread thread;
         private int depth;
-        private ReferenceType locationType;
-        private String locationMethodName;
-        private String locationMethodSignature;
-        private long locationCodeIndex;
+        private Location location;
         
         public EqualsInfo(JPDADebuggerImpl debugger, StackFrame sf, int depth) {
             try {
                 thread = debugger.getThread(StackFrameWrapper.thread(sf));
                 this.depth = depth;
-                Location l = StackFrameWrapper.location(sf);
-                locationType = LocationWrapper.declaringType(l);
-                locationMethodName = TypeComponentWrapper.name(LocationWrapper.method(l));
-                locationMethodSignature = TypeComponentWrapper.signature(LocationWrapper.method(l));
-                locationCodeIndex = LocationWrapper.codeIndex(l);
+                this.location = StackFrameWrapper.location(sf);
             } catch (VMDisconnectedExceptionWrapper e) {
                 thread = null;
             } catch (InternalExceptionWrapper e) {
@@ -873,16 +957,14 @@ public class CallStackFrameImpl implements CallStackFrame {
             EqualsInfo ei = (EqualsInfo) obj;
             return thread == ei.thread &&
                    depth == ei.depth &&
-                   (locationType == null && ei.locationType == null || locationType != null && locationType.equals(ei.locationType)) &&
-                   (locationMethodName == null && ei.locationMethodName == null || locationMethodName != null && locationMethodName.equals(ei.locationMethodName)) &&
-                   (locationMethodSignature == null && ei.locationMethodSignature == null || locationMethodSignature != null && locationMethodSignature.equals(ei.locationMethodSignature)) &&
-                   locationCodeIndex == ei.locationCodeIndex;
+                   (location == ei.location ||
+                    location != null && location.equals(ei.location));
         }
 
         @Override
         public int hashCode() {
             if (thread == null) return 0;
-            return (thread.hashCode() << 8 + depth + locationType.hashCode() << 4 + locationCodeIndex);
+            return (thread.hashCode() << 8 + depth + (location != null ? location.hashCode() << 4 : 0));
         }
         
     }
