@@ -50,6 +50,7 @@ import org.netbeans.spi.debugger.ContextProvider;
 import org.netbeans.api.debugger.jpda.JPDADebugger;
 import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
 import org.netbeans.modules.debugger.jpda.actions.CheckDeadlocksAction;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
 import org.netbeans.spi.viewmodel.NodeActionsProvider;
 import org.netbeans.spi.viewmodel.UnknownTypeException;
 import org.netbeans.spi.viewmodel.Models;
@@ -63,6 +64,9 @@ import org.openide.util.RequestProcessor;
 /**
  * @author   Martin Entlicher
  */
+@DebuggerServiceRegistration(path="netbeans-JPDASession/DebuggingView",
+                             types=NodeActionsProviderFilter.class,
+                             position=300)
 public class DebuggingActionsProviderFilter implements NodeActionsProviderFilter {
 
     private Action SUSPEND_ALL_ACTION = Models.createAction (
