@@ -65,6 +65,7 @@ import org.netbeans.api.debugger.jpda.ClassVariable;
 import org.netbeans.api.debugger.jpda.Field;
 import org.netbeans.api.debugger.jpda.JPDAClassType;
 import org.netbeans.api.debugger.jpda.ObjectVariable;
+import org.netbeans.api.debugger.jpda.Super;
 import org.netbeans.modules.debugger.jpda.JPDADebuggerImpl;
 import org.netbeans.modules.debugger.jpda.expr.EvaluatorVisitor;
 import org.netbeans.modules.debugger.jpda.jdi.ClassNotPreparedExceptionWrapper;
@@ -141,7 +142,7 @@ public class JPDAClassTypeImpl implements JPDAClassType {
         return new AbstractObjectVariable(debugger, cl, "Loader "+getName());
     }
     
-    public SuperVariable getSuperClass() {
+    public Super getSuperClass() {
         if (classType instanceof ClassType) {
             try {
                 return new SuperVariable(debugger, null, ClassTypeWrapper.superclass((ClassType) classType), getName());
@@ -210,27 +211,21 @@ public class JPDAClassTypeImpl implements JPDAClassType {
             return Collections.emptyList();
         }
         List<Field> staticFields = new ArrayList<Field>();
+        String parentID = getName();
         for (int i = 0; i < allFieldsOrig.size(); i++) {
             Value value = null;
             com.sun.jdi.Field origField = allFieldsOrig.get(i);
             try {
                 if (TypeComponentWrapper.isStatic(origField)) {
-                    if (loggerValue.isLoggable(Level.FINE)) {
-                        loggerValue.fine("STARTED : " + classType + ".getValue(" + origField + ")");
-                    }
-                    value = ReferenceTypeWrapper.getValue(classType, origField);
-                    if (loggerValue.isLoggable(Level.FINE)) {
-                        loggerValue.fine("FINISHED: " + classType + ".getValue(" + origField + ") = " + value);
-                    }
-                    if (value instanceof PrimitiveValue) {
-                        staticFields.add(new FieldVariable(debugger, (PrimitiveValue) value, origField, "", (ObjectReference) null));
+                    if (origField.signature().length() == 1) {
+                        // Must be a primitive type or the void type
+                        staticFields.add(new FieldVariable(debugger, origField, parentID, null));
                     } else {
-                        staticFields.add(new ObjectFieldVariable(debugger, (ObjectReference) value, origField, "", (ObjectReference) null));
+                        staticFields.add(new ObjectFieldVariable(debugger, origField, parentID,
+                                JPDADebuggerImpl.getGenericSignature(origField), null));
                     }
                 }
             } catch (InternalExceptionWrapper ex) {
-            } catch (ObjectCollectedExceptionWrapper ex) {
-                return Collections.emptyList();
             } catch (VMDisconnectedExceptionWrapper ex) {
                 return Collections.emptyList();
             }
@@ -244,6 +239,7 @@ public class JPDAClassTypeImpl implements JPDAClassType {
                     return cachedInstanceCount;
                 }
             }*/
+            //assert !java.awt.EventQueue.isDispatchThread() : "Instance counts retrieving in AWT Event Queue!";
             try {
                 long[] counts = VirtualMachineWrapper.instanceCounts(MirrorWrapper.virtualMachine(classType), Collections.singletonList(classType));
                 return counts[0];
@@ -258,6 +254,7 @@ public class JPDAClassTypeImpl implements JPDAClassType {
     }
     
     public List<ObjectVariable> getInstances(long maxInstances) {
+            //assert !java.awt.EventQueue.isDispatchThread() : "Instances retrieving in AWT Event Queue!";
             final List<ObjectReference> instances;
             try {
                 instances = ReferenceTypeWrapper.instances(classType, maxInstances);
