@@ -83,6 +83,8 @@ import org.netbeans.modules.debugger.jpda.jdi.InvalidStackFrameExceptionWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.LocationWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.StackFrameWrapper;
 import org.netbeans.modules.debugger.jpda.jdi.VMDisconnectedExceptionWrapper;
+import org.netbeans.spi.debugger.DebuggerServiceRegistration;
+import org.netbeans.spi.debugger.DebuggerServiceRegistrations;
 import org.openide.util.RequestProcessor;
 import org.openide.util.WeakListeners;
 
@@ -90,6 +92,14 @@ import org.openide.util.WeakListeners;
 /**
  * @author   Jan Jancura
  */
+@DebuggerServiceRegistrations({
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/LocalsView",
+                                 types={TreeModel.class},
+                                 position=11000),
+    @DebuggerServiceRegistration(path="netbeans-JPDASession/ToolTipView",
+                                 types={TreeModel.class},
+                                 position=11000)
+})
 public class LocalsTreeModel implements TreeModel, PropertyChangeListener {
 
 
@@ -105,6 +115,7 @@ public class LocalsTreeModel implements TreeModel, PropertyChangeListener {
     
     private JPDADebuggerImpl    debugger;
     private Listener            listener;
+    private PropertyChangeListener varChangeListener;
     private final List<ModelListener> listeners = new ArrayList<ModelListener>();
     private PropertyChangeListener[] varListeners;
     //private Map                 cachedLocals = new WeakHashMap();
@@ -114,6 +125,9 @@ public class LocalsTreeModel implements TreeModel, PropertyChangeListener {
     public LocalsTreeModel (ContextProvider lookupProvider) {
         debugger = (JPDADebuggerImpl) lookupProvider.
             lookupFirst (null, JPDADebugger.class);
+        varChangeListener = new VarChangeListener();
+        debugger.varChangeSupport.addPropertyChangeListener(
+                WeakListeners.propertyChange(varChangeListener, debugger.varChangeSupport));
     }
     
     public Object getRoot () {
@@ -695,6 +709,18 @@ public class LocalsTreeModel implements TreeModel, PropertyChangeListener {
     
     
     // innerclasses ............................................................
+
+    private class VarChangeListener implements PropertyChangeListener {
+
+        @Override
+        public void propertyChange(PropertyChangeEvent evt) {
+            Object var = evt.getSource();
+            if (var instanceof Variable) {
+                fireNodeChanged(var);
+            }
+        }
+
+    }
     
     private static class Listener implements PropertyChangeListener {
         
