@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -24,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -44,44 +47,30 @@ package org.netbeans.modules.derby;
 import java.io.File;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.netbeans.api.java.platform.JavaPlatform;
-import org.netbeans.api.java.platform.JavaPlatformManager;
-import org.netbeans.api.java.platform.Specification;
-import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileUtil;
-import org.openide.modules.SpecificationVersion;
 import org.openide.util.Utilities;
 
 /**
  *
- * @author Andrei Badea
+ * @author Andrei Badea, Jiri Rechtacek
  */
 public class JDKDerbyHelper {
 
-    private static final  Logger LOGGER = Logger.getLogger(JDKDerbyHelper.class.getName());
+    private static final Logger LOGGER = Logger.getLogger(JDKDerbyHelper.class.getName());
+    private static final JDKDerbyHelper INSTANCE = new JDKDerbyHelper();
+    private final String javaHome;
+    private final String javaVersion;
 
-    private final JavaPlatform platform;
-
-    public static JDKDerbyHelper forDefaultPlatform() {
-        return new JDKDerbyHelper(JavaPlatformManager.getDefault().getDefaultPlatform());
+    public static JDKDerbyHelper forDefault() {
+        return INSTANCE;
     }
 
-    private JDKDerbyHelper(JavaPlatform javaPlatform) {
-        this.platform = javaPlatform;
+    private JDKDerbyHelper() {
+        this.javaHome = System.getProperty("java.home");
+        this.javaVersion = System.getProperty("java.version");
     }
 
     public boolean canBundleDerby() {
-        Specification specification = platform.getSpecification();
-        if (specification == null) {
-            return false;
-        }
-        SpecificationVersion version = specification.getVersion();
-        if (version == null) {
-            return false;
-        }
-        if (version.compareTo(new SpecificationVersion("1.6")) < 0) { // NOI18N
-            return false;
-        }
+        // IMHO, most JDK1.6 contains Java DB
         return true;
     }
 
@@ -89,6 +78,26 @@ public class JDKDerbyHelper {
         if (!canBundleDerby()) {
             return null;
         }
+        // find in registration by NBI
+        String derbyHome = DerbyRegistration.getRegisteredDerbyHome();
+        if (derbyHome != null) {
+            LOGGER.log(Level.FINE, "Registered JavaDB:  " + derbyHome);
+            File derbyHomeFile = new File(derbyHome);
+            String result = testDerbyInstallLocation(derbyHomeFile);
+            if (result != null) {
+                return result;
+            }
+        }
+
+        // find in JDK
+        File locInJDK = getLocationInJDK(javaHome);
+        if (locInJDK != null) {
+            LOGGER.log(Level.FINE, "JavaDB in JDK(" + javaVersion + "):  " + locInJDK);
+            String result = testDerbyInstallLocation(locInJDK);
+            if (result != null) {
+                return result;
+            }
+        }
         // see issue 83144
         if (Utilities.isWindows()) {
             LOGGER.log(Level.FINE, "Operating system: Windows");
@@ -117,18 +126,18 @@ public class JDKDerbyHelper {
                 return result;
             }
         }
-        for (Object dir : platform.getInstallFolders()) {
-            FileObject derbyDir = ((FileObject)dir).getFileObject("db"); // NOI18N
-            if (derbyDir != null) {
-                String result = testDerbyInstallLocation(FileUtil.toFile(derbyDir));
-                if (result != null) {
-                    return result;
-                }
-            }
-        }
+
         return null;
     }
 
+    private static File getLocationInJDK(String javaHome) {
+        File dir = new File(javaHome);
+        assert dir != null && dir.exists() && dir.isDirectory() : "java.home is directory";
+        // path to JavaDB in JDK6
+        File loc = new File(dir.getParentFile(), "db"); // NOI18N
+        return loc != null && loc.exists() && loc.isDirectory() ? loc : null;
+    }
+
     private static String testDerbyInstallLocation(File directory) {
         LOGGER.log(Level.FINE, "Testing directory: {0}", directory);
         if (Util.isDerbyInstallLocation(directory)) {
