@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -52,8 +55,6 @@ import org.netbeans.api.db.explorer.ConnectionManager;
 import org.netbeans.api.db.explorer.DatabaseConnection;
 import org.netbeans.api.db.explorer.JDBCDriver;
 import org.netbeans.api.db.explorer.JDBCDriverManager;
-import org.netbeans.api.java.platform.JavaPlatform;
-import org.netbeans.api.java.platform.JavaPlatformManager;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.modules.derby.api.DerbyDatabases;
@@ -64,7 +65,6 @@ import org.openide.execution.NbProcessDescriptor;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Cancellable;
-import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.util.Utilities;
@@ -93,18 +93,20 @@ public class RegisterDerby implements DatabaseRuntime {
     static Process process = null;
     
     /** Creates a new instance of RegisterDerby */
-    private RegisterDerby() {
-    }
+    private RegisterDerby() {}
     
     public static synchronized RegisterDerby getDefault(){
-        if (reg==null)
+        if (reg==null) {
             reg= new RegisterDerby();
+            DerbyActivator.activate();
+        }
         return reg;
     }
     
     /**
      * Whether this runtime accepts this connection string.
      */
+    @Override
     public boolean acceptsDatabaseURL(String url){
         return url.trim().startsWith("jdbc:derby://localhost"); // NOI18N
     }
@@ -112,6 +114,7 @@ public class RegisterDerby implements DatabaseRuntime {
     /**
      * Is database server up and running.
      */
+    @Override
     public boolean isRunning(){
         if (process!=null){
             try{
@@ -126,6 +129,7 @@ public class RegisterDerby implements DatabaseRuntime {
         
     }
     
+    @Override
     public String getJDBCDriverClass() {
         return DerbyOptions.DRIVER_CLASS_NET;
     }
@@ -133,6 +137,7 @@ public class RegisterDerby implements DatabaseRuntime {
     /**
      * Can the database be started from inside the IDE?
      */
+    @Override
     public boolean canStart(){
         // issue 81619: should only try to start if the location is set
         return DerbyOptions.getDefault().getLocation().length() > 0;
@@ -141,6 +146,7 @@ public class RegisterDerby implements DatabaseRuntime {
     /**
      * Start the database server.
      */
+    @Override
     public void start(){
         start(START_TIMEOUT);
     }
@@ -171,6 +177,7 @@ public class RegisterDerby implements DatabaseRuntime {
      */
     void postCreateNewDatabase(final String databaseName, final String user, final String password) throws Exception {
         RequestProcessor.getDefault().post(new Runnable() {
+            @Override
             public void run () {
                 try {
                     // DerbyDatabases.createDatabase would start the database too, but
@@ -248,11 +255,6 @@ public class RegisterDerby implements DatabaseRuntime {
         return new String[] { "DERBY_INSTALL=" + location }; // NOI18N
     }
     
-    private JavaPlatform getJavaPlatform() {
-        JavaPlatformManager jpm = JavaPlatformManager.getDefault();
-        return jpm.getDefaultPlatform(); 
-    }
-    
     /**
      * Start the database server, and wait some time (in milliseconds) to make sure the server is active.
      *
@@ -272,11 +274,8 @@ public class RegisterDerby implements DatabaseRuntime {
         }
         try {
             ExecSupport ee= new ExecSupport();
-            ee.setStringToLookFor("" + getPort());
-            FileObject javaFO = getJavaPlatform().findTool("java");
-            if (javaFO == null)
-                throw new Exception (NbBundle.getMessage(RegisterDerby.class, "EXC_JavaExecutableNotFound"));
-            String java = FileUtil.toFile(javaFO).getAbsolutePath();
+            ee.setStringToLookFor("" + getPort()); // NOI18N
+            String java = getJavaExecutable();
             
             // create the derby.properties file
             createDerbyPropertiesFile();
@@ -325,6 +324,7 @@ public class RegisterDerby implements DatabaseRuntime {
         boolean started = false;
         String waitMessage = NbBundle.getMessage(RegisterDerby.class, "MSG_StartingDerby");
         ProgressHandle progress = ProgressHandleFactory.createHandle(waitMessage, new Cancellable() {
+            @Override
             public boolean cancel() {
                 return execSupport.interruptWaiting();
             }
@@ -354,17 +354,13 @@ public class RegisterDerby implements DatabaseRuntime {
     /**
      * Stop the database server.
      */
+    @Override
     public void stop(){
         try {
             if (process==null){//nothing to stop...
                 return;
             }
-            //BufferedWriter processIn = new BufferedWriter(new OutputStreamWriter(process.getOutputStream()));
-            //processIn.write("q\ny\n");
-            //processIn.flush();
-            String java = FileUtil.toFile(getJavaPlatform().findTool("java")).getAbsolutePath();
-            if (java == null)
-                throw new Exception (NbBundle.getMessage(RegisterDerby.class, "EXC_JavaExecutableNotFound"));
+            String java = getJavaExecutable();
             // java -Dderby.system.home="<userdir/derby>" -classpath  
             //     "<DERBY_INSTALL>/lib/derby.jar:<DERBY_INSTALL>/lib/derbytools.jar:<DERBY_INSTALL>/lib/derbynet.jar"
             //     org.apache.derby.drda.NetworkServerControl shutdown
@@ -395,6 +391,20 @@ public class RegisterDerby implements DatabaseRuntime {
             process=null;
         }
     }
+
+    private static String getJavaExecutable() {
+        File javaExe = new File(System.getProperty("java.home"), "/bin/java" + (Utilities.isWindows() ? ".exe" : "")); // NOI18N
+        assert javaExe != null && javaExe.exists() && javaExe.canExecute() : javaExe + " exists and it's executable.";
+        FileObject javaFO = FileUtil.toFileObject(javaExe);
+        if (javaFO == null) {
+            throw new RuntimeException (NbBundle.getMessage(RegisterDerby.class, "EXC_JavaExecutableNotFound"));
+        }
+        String java = FileUtil.toFile(javaFO).getAbsolutePath();
+        if (java == null) {
+            throw new RuntimeException (NbBundle.getMessage(RegisterDerby.class, "EXC_JavaExecutableNotFound"));
+        }
+        return java;
+    }
     
     private void disconnectAllDerbyConnections() {
         DatabaseConnection[] dbconn = ConnectionManager.getDefault().getConnections();
