@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -46,6 +49,7 @@ import java.net.URI;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Set;
+import org.netbeans.modules.derby.DerbyDatabasesImpl;
 import org.netbeans.modules.derby.DerbyOptions;
 import org.netbeans.modules.derby.test.TestBase;
 import org.openide.modules.InstalledFileLocator;
@@ -100,7 +104,7 @@ public class DerbyDatabasesTest extends TestBase {
     public void testExtractSampleDatabase() throws Exception {
         setLookup(new Object[] { new SampleDatabaseLocator() });
 
-        DerbyDatabases.extractSampleDatabase("newdb");
+        DerbyDatabasesImpl.getDefault().extractSampleDatabase("newdb");
         File newDBDir = new File(systemHome, "newdb");
         Set sampleDBFiles = new HashSet(Arrays.asList(newDBDir.list()));
 
@@ -118,7 +122,7 @@ public class DerbyDatabasesTest extends TestBase {
 
         assertEquals("There should be no files in the sample directory", 0, sampleDir.listFiles().length);
 
-        DerbyDatabases.extractSampleDatabase("sample");
+        DerbyDatabasesImpl.getDefault().extractSampleDatabase("sample");
 
         assertEquals("Should not have extracted the sample database to an existing directory", 0, sampleDir.listFiles().length);
     }
