@@ -167,14 +167,16 @@ class DiffViewManager implements ChangeListener {
         return master;
     }
     
-    private int rightHeightCached;
+    private int rightHeightCached, leftHeightCached;
     private void updateDifferences() {
         assert EventQueue.isDispatchThread();
         int mds = master.getDiffSerial();
-        if (mds <= cachedDiffSerial && rightContentPanel.getEditorPane().getSize().height == rightHeightCached) {
+        int currentLeftHeight = getHeight(leftContentPanel.getEditorPane()), currentRightHeight = getHeight(rightContentPanel.getEditorPane());
+        if (mds <= cachedDiffSerial && currentRightHeight == rightHeightCached && currentLeftHeight == leftHeightCached) {
             return;
         }
-        rightHeightCached = rightContentPanel.getEditorPane().getSize().height;
+        rightHeightCached = currentRightHeight;
+        leftHeightCached = currentLeftHeight;
         cachedDiffSerial = mds;
         computeDecorations();
         master.getEditorPane1().getLinesActions().repaint();
@@ -193,16 +195,10 @@ class DiffViewManager implements ChangeListener {
     }
 
     public HighLight[] getSecondHighlights() {
-        if (EventQueue.isDispatchThread()) {
-            updateDifferences();
-        }
         return secondHilitesCached;
     }
 
     public HighLight[] getFirstHighlights() {
-        if (EventQueue.isDispatchThread()) {
-            updateDifferences();
-        }
         return firstHilitesCached;
     }
     
@@ -405,9 +401,13 @@ class DiffViewManager implements ChangeListener {
             Difference difference = diffs[i];
             DecoratedDifference dd = new DecoratedDifference(difference, canRollback(document, difference));
             Rectangle leftStartRect = getRectForView(leftContentPanel.getEditorPane(), rootLeftView, difference.getFirstStart() - 1, false);
-            Rectangle leftEndRect = getRectForView(leftContentPanel.getEditorPane(), rootLeftView, difference.getFirstEnd() - 1, true);
+            Rectangle leftEndRect = difference.getType() == Difference.ADD 
+                    ? getRectForView(leftContentPanel.getEditorPane(), rootLeftView, difference.getFirstStart(), false)
+                    : getRectForView(leftContentPanel.getEditorPane(), rootLeftView, difference.getFirstEnd() - 1, true);
             Rectangle rightStartRect = getRectForView(rightContentPanel.getEditorPane(), rootRightView, difference.getSecondStart() - 1, false);
-            Rectangle rightEndRect = getRectForView(rightContentPanel.getEditorPane(), rootRightView, difference.getSecondEnd() - 1, true);
+            Rectangle rightEndRect = difference.getType() == Difference.DELETE
+                    ? getRectForView(rightContentPanel.getEditorPane(), rootRightView, difference.getSecondStart(), false)
+                    : getRectForView(rightContentPanel.getEditorPane(), rootRightView, difference.getSecondEnd() - 1, true);
             if (leftStartRect == null || leftEndRect == null || rightStartRect == null || rightEndRect == null) {
                 decorations = new DecoratedDifference[0];
                 break;
@@ -415,12 +415,12 @@ class DiffViewManager implements ChangeListener {
             if (difference.getType() == Difference.ADD) {
                 dd.topRight = rightStartRect.y;
                 dd.bottomRight = rightEndRect.y + rightEndRect.height;
-                dd.topLeft = leftStartRect.y + leftStartRect.height;
+                dd.topLeft = leftEndRect.y == 0 ? leftStartRect.y + leftStartRect.height : leftEndRect.y;
                 dd.floodFill = true;
             } else if (difference.getType() == Difference.DELETE) {
                 dd.topLeft = leftStartRect.y;
                 dd.bottomLeft = leftEndRect.y + leftEndRect.height;
-                dd.topRight = rightStartRect.y + rightStartRect.height;
+                dd.topRight = rightEndRect.y == 0 ? rightStartRect.y + rightStartRect.height : rightEndRect.y;
                 dd.floodFill = true;
             } else {
                 dd.topRight = rightStartRect.y;
@@ -434,18 +434,24 @@ class DiffViewManager implements ChangeListener {
         decorationsCached = decorations;
     }
 
-    private Rectangle getRectForView (JTextComponent comp, View rootView, int lineNumber, boolean endOffset) {
-        if (lineNumber == -1 || lineNumber >= rootView.getViewCount()) {
-            return new Rectangle();
-        }
-        Rectangle rect = null;
-        View view = rootView.getView(lineNumber);
-        try {
-            rect = view == null ? null : comp.modelToView(endOffset ? view.getEndOffset() - 1 : view.getStartOffset());
-        } catch (BadLocationException ex) {
-            //
-        }
-        return rect;
+    private Rectangle getRectForView (final JTextComponent comp, final View rootView, final int lineNumber, final boolean endOffset) {
+        final Rectangle[] rect = new Rectangle[1];
+        Utilities.runViewHierarchyTransaction(comp, true, new Runnable() {
+            @Override
+            public void run() {
+                if (lineNumber == -1 || lineNumber >= rootView.getViewCount()) {
+                    rect[0] = new Rectangle();
+                    return;
+                }
+                View view = rootView.getView(lineNumber);
+                try {
+                    rect[0] = view == null ? null : comp.modelToView(endOffset ? view.getEndOffset() - 1 : view.getStartOffset());
+                } catch (BadLocationException ex) {
+                    //
+                }
+            }
+        });
+        return rect[0];
     }
 
     private boolean canRollback(Document doc, Difference diff) {
@@ -481,7 +487,7 @@ class DiffViewManager implements ChangeListener {
     }
 
     private int computeLeftOffsetToMatchDifference(DifferencePosition differenceMatchStart, int rightOffset, Rectangle[] positions) {
-        Rectangle leftStartRect = positions[0], leftEndRect = positions[0], rightStartRect = positions[2], rightEndRect = positions[3];
+        Rectangle leftStartRect = positions[0], leftEndRect = positions[1], rightStartRect = positions[2], rightEndRect = positions[3];
         Difference diff = differenceMatchStart.getDiff();
         boolean matchStart = differenceMatchStart.isStart();
         
@@ -493,11 +499,14 @@ class DiffViewManager implements ChangeListener {
         } else {
             if (diff.getType() == Difference.ADD) {
                 value = leftStartRect.y;        // kde zacina prva, 180
-                valueSecond = rightStartRect.y + rightStartRect.height; // kde by zacinala druha, napr. 230
+                if (rightStartRect.y == 0) {
+                    value -= rightStartRect.height;
+                }
+                valueSecond = rightEndRect.y + rightStartRect.height; // kde by zacinala druha, napr. 230
             } else {
                 value = leftEndRect.y + leftEndRect.height;        // kde zacina prva, 180
                 if (diff.getType() == Difference.DELETE) {
-                    value += leftEndRect.height;
+                    value += leftStartRect.height;
                     valueSecond = rightStartRect.y + rightStartRect.height; // kde by zacinala druha, napr. 230
                 } else {
                     valueSecond = rightEndRect.y + rightEndRect.height; // kde by zacinala druha, napr. 230
@@ -560,6 +569,24 @@ class DiffViewManager implements ChangeListener {
             mydivider.paint(mydivider.getGraphics());
         }
     }
+
+    private int getHeight (final DecoratedEditorPane editorPane) {
+        final int height[] = new int[1];
+        editorPane.getDocument().render(new Runnable () {
+            @Override
+            public void run() {
+                try {
+                    Rectangle rec = editorPane.modelToView(editorPane.getDocument().getLength());
+                    if (rec != null) {
+                        height[0] = (int) (rec.getY() + rec.getHeight());
+                    }
+                } catch (BadLocationException ex) {
+                    //
+                }
+            }
+        });
+        return height[0];
+    }
     
     public static class DifferencePosition {
         
