@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -45,6 +48,7 @@ import junit.framework.TestCase;
 import java.io.*;
 
 import org.netbeans.api.diff.Difference;
+import org.netbeans.junit.NbTestCase;
 import org.netbeans.modules.diff.builtin.provider.BuiltInDiffProvider;
 
 /**
@@ -52,7 +56,7 @@ import org.netbeans.modules.diff.builtin.provider.BuiltInDiffProvider;
  *
  * @author Maros Sandor
  */
-public class UnifiedDiffTest extends TestCase {
+public class UnifiedDiffTest extends NbTestCase {
     
     private File    dataRootDir;
     private File[]  testFiles;
@@ -66,7 +70,7 @@ public class UnifiedDiffTest extends TestCase {
 
     protected void setUp() throws Exception {
         //data.root.dir defined in project.properties
-        dataRootDir = new File(System.getProperty("data.root.dir"));
+        dataRootDir = getDataDir();
         diffProvider = new BuiltInDiffProvider();
         initPermutations();
     }
