@@ -42,17 +42,22 @@
 package org.netbeans.modules.nativeexecution.api.util;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.Writer;
 import java.util.Arrays;
-import java.util.HashMap;
 import java.util.concurrent.Callable;
 import java.util.concurrent.Future;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import javax.swing.event.ChangeListener;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
+import org.netbeans.modules.nativeexecution.api.NativeProcess;
+import org.netbeans.modules.nativeexecution.api.NativeProcess.State;
 import org.netbeans.modules.nativeexecution.api.NativeProcessBuilder;
+import org.netbeans.modules.nativeexecution.api.util.FileInfoProvider.StatInfo;
 import org.netbeans.modules.nativeexecution.support.NativeTaskExecutorService;
 import org.netbeans.modules.nativeexecution.support.SignalSupport;
+import org.openide.util.Exceptions;
 
 /**
  * An utility class that simplifies usage of Native Execution Support Module
@@ -60,9 +65,6 @@ import org.netbeans.modules.nativeexecution.support.SignalSupport;
  */
 public final class CommonTasksSupport {
 
-    private final static HashMap<ExecutionEnvironment, SignalSupport> ssMap =
-            new HashMap<ExecutionEnvironment, SignalSupport>();
-
     private CommonTasksSupport() {
     }
 
@@ -98,7 +100,7 @@ public final class CommonTasksSupport {
             final String dstFileName,
             final Writer error) {
 
-        return SftpSupport.downloadFile(srcFileName, srcExecEnv, dstFileName, error);
+        return SftpSupport.getInstance(srcExecEnv).downloadFile(srcFileName, dstFileName, error);
     }
 
     /**
@@ -124,7 +126,109 @@ public final class CommonTasksSupport {
             final File dstFile,
             final Writer error) {
 
-        return SftpSupport.downloadFile(srcFileName, srcExecEnv, dstFile.getAbsolutePath(), error);
+        return SftpSupport.getInstance(srcExecEnv).downloadFile(srcFileName, dstFile.getAbsolutePath(), error);
+    }
+
+    /**
+     * Read remote file content
+     *
+     * @param srcFileName full path to the source file with file name
+     * @param srcExecEnv execution environment that describes the host to copy file from
+     * @param offset in source file
+     * @param count number of reading bytes
+     * @param error if not <tt>NULL</tt> and some error occurs during reading,
+     *        an error message will be written to this <tt>Writer</tt>.
+     * @return byte array with file content. Returns byte[0] in case error. Result can be less of count in case end of file.
+     */
+    public static byte[] readFile(
+            final String srcFileName,
+            final ExecutionEnvironment srcExecEnv,
+            final long offset, final int count,
+            final Writer error) {
+
+        int bs = 512;
+        long iseek = offset / bs;
+        long endOffset = offset + count;
+        long cnt = (endOffset / bs);
+        if (endOffset%bs > 0) {
+            cnt++;
+        }
+        cnt -= iseek;
+        byte[] buffer = new byte[(int)cnt * bs];
+
+        NativeProcessBuilder npb = NativeProcessBuilder.newProcessBuilder(srcExecEnv);
+        if (iseek > 0) {
+            // iseek paremeter is Solaris and Mac OS X only.
+            //npb.setExecutable("/bin/dd").setArguments("if=" + srcFileName, "ibs=" + bs, "iseek=" + iseek, "count=" + cnt); // NOI18N
+            npb.setExecutable("/bin/dd").setArguments("if=" + srcFileName, "ibs=" + bs, "skip=" + iseek, "count=" + cnt); // NOI18N
+        } else {
+            npb.setExecutable("/bin/dd").setArguments("if=" + srcFileName, "ibs=" + bs, "count=" + cnt); // NOI18N
+        }
+
+        int actual = -1;
+
+        try {
+            NativeProcess process = npb.call();
+            if (process.getState() == State.ERROR) {
+                String err = ProcessUtils.readProcessErrorLine(process);
+                if (iseek > 0) {
+                    throw new IOException("Cannot start /bin/dd if=" + srcFileName + " ibs=" + bs + " skip=" + iseek + " count=" + cnt + ": " + err); // NOI18N
+                } else {
+                    throw new IOException("Cannot start /bin/dd if=" + srcFileName + " ibs=" + bs + " count=" + cnt + ": " + err); // NOI18N
+                }
+            }
+
+            int start = 0;
+            int rest = buffer.length;
+            actual = 0;
+            while(true) {
+                int readed = process.getInputStream().read(buffer, start, rest);
+                if (readed <= 0) {
+                    break;
+                }
+                start += readed;
+                rest -= readed;
+                actual += readed;
+                if (rest <= 0) {
+                    break;
+                }
+            }
+            int rc = 0;
+
+            try {
+                rc = process.waitFor();
+            } catch (InterruptedException ex) {
+                throw new IOException("/bin/dd was interrupted"); // NOI18N
+            }
+
+            if (rc != 0) {
+                String err = ProcessUtils.readProcessErrorLine(process);
+                throw new IOException("Error while reading " + srcFileName + ": " + err); // NOI18N
+            }
+        } catch (IOException ex) {
+            if (error != null) {
+                try {
+                    error.write(ex.getMessage());
+                    error.flush();
+                } catch (IOException ex1) {
+                    Exceptions.printStackTrace(ex1);
+                }
+            }
+            return new byte[0];
+        }
+        int extra = (int) (offset % bs);
+        if (actual - extra < 0) {
+            return new byte[0];
+        }
+        int res_size = Math.min(actual - extra, count);
+        byte[] result = new byte[res_size];
+        System.arraycopy(buffer, extra, result, 0, res_size);
+        return result;
+    }
+
+    public static Future<UploadStatus> uploadFile(UploadParameters parameters) {
+        parameters = parameters.copy();
+        return SftpSupport.getInstance(parameters.dstExecEnv).uploadFile(parameters);
     }
 
     /**
@@ -138,21 +242,20 @@ public final class CommonTasksSupport {
      * @param dstExecEnv execution environment that describes destination host
      * @param dstFileName destination filename on the host, specified by
      *        <tt>dstExecEnv</tt>
-     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal)
+     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal);
+     * if it is less than zero, the default mask is used (for existent files, it stays the same it was, for new files as specified by umask command))
      * @param error if not <tt>NULL</tt> and some error occurs during upload,
      *        an error message will be written to this <tt>Writer</tt>.
-     * @return a <tt>Future&lt;Integer&gt;</tt> representing pending completion
-     *         of the upload task. The result of this Future is the exit
-     *         code of the copying routine. 0 indicates that the file was
-     *         successfully uplodaded. Result other than 0 indicates an error.
+     * @return a <tt>Future&lt;UploadStatus&gt;</tt> representing pending completion
+     *         of the upload task.
      */
-    public static Future<Integer> uploadFile(
+    public static Future<UploadStatus> uploadFile(
             final String srcFileName,
             final ExecutionEnvironment dstExecEnv,
             final String dstFileName,
-            final int mask, final Writer error) {
-
-        return SftpSupport.uploadFile(srcFileName, dstExecEnv, dstFileName, mask, error, false);
+            final int mask) {
+        return SftpSupport.getInstance(dstExecEnv).uploadFile(new UploadParameters(
+                new File(srcFileName), dstExecEnv, dstFileName, mask, false, null));
     }
 
     /**
@@ -166,23 +269,23 @@ public final class CommonTasksSupport {
      * @param dstExecEnv execution environment that describes destination host
      * @param dstFileName destination filename on the host, specified by
      *        <tt>dstExecEnv</tt>
-     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal)
+     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal);
+     * if it is less than zero, the default mask is used (for existent files, it stays the same it was, for new files as specified by umask command))
      * @param error if not <tt>NULL</tt> and some error occurs during upload,
      *        an error message will be written to this <tt>Writer</tt>.
      * @param checkMd5 if true, then the source file will be copied to destination only if
      *        destination does not exist or exists but its md5 sum differs from local one
-     * @return a <tt>Future&lt;Integer&gt;</tt> representing pending completion
-     *         of the upload task. The result of this Future is the exit
-     *         code of the copying routine. 0 indicates that the file was
-     *         successfully uplodaded. Result other than 0 indicates an error.
+     * @return a <tt>Future&lt;UploadStatus&gt;</tt> representing pending completion
+     *         of the upload task. 
      */
-    public static Future<Integer> uploadFile(
+    public static Future<UploadStatus> uploadFile(
             final String srcFileName,
             final ExecutionEnvironment dstExecEnv,
             final String dstFileName,
-            final int mask, final Writer error, boolean checkMd5) {
+            final int mask, boolean checkMd5) {
 
-        return SftpSupport.uploadFile(srcFileName, dstExecEnv, dstFileName, mask, error, checkMd5);
+        return SftpSupport.getInstance(dstExecEnv).uploadFile(new UploadParameters(
+                new File(srcFileName), dstExecEnv, dstFileName, mask, checkMd5, null));
     }
 
     /**
@@ -196,21 +299,20 @@ public final class CommonTasksSupport {
      * @param dstExecEnv execution environment that describes destination host
      * @param dstFileName destination filename on the host, specified by
      *        <tt>dstExecEnv</tt>
-     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal)
+     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal);
+     * if it is less than zero, the default mask is used (for existent files, it stays the same it was, for new files as specified by umask command))
      * @param error if not <tt>NULL</tt> and some error occurs during upload,
      *        an error message will be written to this <tt>Writer</tt>.
-     * @return a <tt>Future&lt;Integer&gt;</tt> representing pending completion
-     *         of the upload task. The result of this Future is the exit
-     *         code of the copying routine. 0 indicates that the file was
-     *         successfully uplodaded. Result other than 0 indicates an error.
+     * @return a <tt>Future&lt;UploadStatus&gt;</tt> representing pending completion
+     *         of the upload task.
      */
-    public static Future<Integer> uploadFile(
+    public static Future<UploadStatus> uploadFile(
             final File srcFile,
             final ExecutionEnvironment dstExecEnv,
             final String dstFileName,
-            final int mask, final Writer error) {
+            final int mask) {
 
-        return SftpSupport.uploadFile(srcFile.getAbsolutePath(), dstExecEnv, dstFileName, mask, error, false);
+        return SftpSupport.getInstance(dstExecEnv).uploadFile(new UploadParameters(srcFile, dstExecEnv, dstFileName, mask, false, null));
     }
 
     /**
@@ -224,23 +326,23 @@ public final class CommonTasksSupport {
      * @param dstExecEnv execution environment that describes destination host
      * @param dstFileName destination filename on the host, specified by
      *        <tt>dstExecEnv</tt>
-     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal)
+     * @param mask file mode creation mask (see uname(1), chmod(1)) (in octal);
+     * if it is less than zero, the default mask is used (for existent files, it stays the same it was, for new files as specified by umask command))
      * @param error if not <tt>NULL</tt> and some error occurs during upload,
      *        an error message will be written to this <tt>Writer</tt>.
      * @param checkMd5 if true, then the source file will be copied to destination only if
      *        destination does not exist or exists but its md5 sum differs from local one
-     * @return a <tt>Future&lt;Integer&gt;</tt> representing pending completion
-     *         of the upload task. The result of this Future is the exit
-     *         code of the copying routine. 0 indicates that the file was
-     *         successfully uplodaded. Result other than 0 indicates an error.
+     * @return a <tt>Future&lt;UploadStatus&gt;</tt> representing pending completion
+     *         of the upload task.
      */
-    public static Future<Integer> uploadFile(
+    public static Future<UploadStatus> uploadFile(
             final File srcFile,
             final ExecutionEnvironment dstExecEnv,
             final String dstFileName,
-            final int mask, final Writer error, boolean checkMd5) {
+            final int mask, boolean checkMd5) {
 
-        return SftpSupport.uploadFile(srcFile.getAbsolutePath(), dstExecEnv, dstFileName, mask, error, checkMd5);
+        return SftpSupport.getInstance(dstExecEnv).uploadFile(new UploadParameters(
+                srcFile, dstExecEnv, dstFileName, mask, checkMd5, null));
     }
 
     /**
@@ -276,6 +378,7 @@ public final class CommonTasksSupport {
             this.error = error;
         }
 
+        @Override
         public Integer call() throws Exception {
             NativeProcessBuilder npb = NativeProcessBuilder.newProcessBuilder(execEnv);
             npb.setExecutable(cmd).setArguments(args);
@@ -373,19 +476,152 @@ public final class CommonTasksSupport {
         final String descr = "Sending signal " + signal + " to " + pid; // NOI18N
 
         return NativeTaskExecutorService.submit(new Callable<Integer>() {
-
+            @Override
             public Integer call() throws Exception {
-                SignalSupport support = null;
-                synchronized (ssMap) {
-                    support = ssMap.get(execEnv);
-                    if (support == null) {
-                        support = SignalSupport.getSignalSupportFor(execEnv);
-                        ssMap.put(execEnv, support);
-                    }
-                }
-
+                SignalSupport support = SignalSupport.getSignalSupportFor(execEnv);
                 return support.kill(signal, pid);
             }
         }, descr);
     }
+
+    /**
+     * Sends the signal to the process group.
+     *
+     * @param execEnv  execution environment of the process
+     * @param pid  pid of the process
+     * @param signal  signal name, e.g. "SIGKILL", "SIGUSR1"
+     * @param error  if not <tt>null</tt> and some error occurs,
+     *        an error message will be written to this <tt>Writer</tt>
+     * @return a <tt>Future&lt;Integer&gt;</tt> representing exit code
+     *         of the signal task. <tt>0</tt> means success, any other value
+     *         means failure.
+     */
+    public static Future<Integer> sendSignalGrp(final ExecutionEnvironment execEnv, final int pid, final Signal signal, final Writer error) {
+        final String descr = "Sending signal " + signal + " to " + pid + " group"; // NOI18N
+
+        return NativeTaskExecutorService.submit(new Callable<Integer>() {
+            @Override
+            public Integer call() throws Exception {
+                SignalSupport support = SignalSupport.getSignalSupportFor(execEnv);
+                return support.killgrp(signal, pid);
+            }
+        }, descr);
+    }
+
+    public static class UploadStatus {
+        private final int exitCode;
+        private final String error;
+        private final FileInfoProvider.StatInfo statInfo;
+
+        /*packge*/ UploadStatus(int exitCode, String error, StatInfo statInfo) {
+            this.exitCode = exitCode;
+            this.error = error;
+            this.statInfo = statInfo;
+        }
+
+        public boolean isOK() {
+            return exitCode == 0;
+        }
+        
+        public int getExitCode() {
+            return exitCode;
+        }
+       
+        public String getError() {
+            return error;
+        }
+
+        public StatInfo getStatInfo() {
+            return statInfo;
+        }
+    }
+    
+    /**
+     * A class (an analog of C struct) that contains upload parameters.
+     */
+    public static class UploadParameters  {
+        
+        /**
+         * specifies full path to the source file on the local host
+         */
+        public final File srcFile;
+
+        /** */
+        public final ExecutionEnvironment dstExecEnv;
+
+        /**
+         * destination filename on the host, specified by <tt>dstExecEnv</tt>
+         */
+        public final String dstFileName;
+
+        /**
+         * File mode creation mask (see uname(1), chmod(1)), in octal.
+         * iIf it is less than zero (which is the default),
+         * then the default mask is used (for existent files, it stays the same it was,
+         * for new files as specified by umask command))
+         */
+        public int mask;
+
+        /** */
+        public ChangeListener callback;
+
+        /**
+         * Of true, then the source file will be copied to destination only if
+         * destination does not exist or exists but its md5 sum differs from local one
+         */
+        public boolean checkMd5;
+
+        public UploadParameters(File srcFile, ExecutionEnvironment dstExecEnv, String dstFileName) {
+            this.srcFile = srcFile;
+            this.dstExecEnv = dstExecEnv;
+            this.dstFileName = dstFileName;
+            mask = -1;
+            callback = null;
+            checkMd5 = false;
+        }
+
+        public UploadParameters(File srcFile, ExecutionEnvironment dstExecEnv, String dstFileName, int mask) {
+            this(srcFile, dstExecEnv, dstFileName, mask, false, null);
+        }
+
+        public UploadParameters(File srcFile, ExecutionEnvironment dstExecEnv, String dstFileName, int mask, boolean checkMd5, ChangeListener callback) {
+            this(srcFile, dstExecEnv, dstFileName);
+            this.mask = mask;
+            this.checkMd5 = checkMd5;
+            this.callback = callback;
+        }
+
+        /*package*/ UploadParameters copy() {
+            return new UploadParameters(srcFile, dstExecEnv, dstFileName, mask, checkMd5, callback);
+        }
+    }
+
+    /**
+     * Queue a signal to a process (sigqueue)
+     *
+     * @param execEnv  execution environment of the process
+     * @param pid  pid of the process
+     * @param signo  signal number
+     * @param value  signal value
+     * @param error  if not <tt>null</tt> and some error occurs,
+     *        an error message will be written to this <tt>Writer</tt>
+     * @return a <tt>Future&lt;Integer&gt;</tt> representing exit code
+     *         of the signal task. <tt>0</tt> means success, any other value
+     *         means failure.
+     */
+    public static Future<Integer> sigqueue(final ExecutionEnvironment execEnv,
+            final int pid,
+            final int signo,
+            final int value,
+            final Writer error) {
+        final String descr = "Sigqueue " + signo + " with value " + value + " to " + pid; // NOI18N
+
+        return NativeTaskExecutorService.submit(new Callable<Integer>() {
+            @Override
+            public Integer call() throws Exception {
+                SignalSupport support = SignalSupport.getSignalSupportFor(execEnv);
+                return support.sigqueue(pid, signo, value);
+            }
+        }, descr);
+    }
 }
