@@ -41,66 +41,71 @@
  */
 package org.netbeans.modules.nativeexecution.api.util;
 
+import com.jcraft.jsch.Channel;
 import com.jcraft.jsch.JSch;
 import com.jcraft.jsch.JSchException;
-import com.jcraft.jsch.Session;
-import com.jcraft.jsch.UserInfo;
 import java.awt.event.ActionEvent;
 import java.io.IOException;
-import java.net.InetSocketAddress;
-import java.net.Socket;
-import java.net.SocketAddress;
+import java.util.AbstractList;
 import java.util.ArrayList;
-import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
-import java.util.concurrent.Callable;
-import java.util.concurrent.CancellationException;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.ExecutionException;
-import java.util.concurrent.Future;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.TimeoutException;
 import java.util.logging.Level;
+import java.util.prefs.Preferences;
 import javax.swing.AbstractAction;
+import javax.swing.Action;
 import javax.swing.SwingUtilities;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.modules.nativeexecution.ConnectionManagerAccessor;
 import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
+import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
 import org.netbeans.modules.nativeexecution.api.HostInfo;
+import org.netbeans.modules.nativeexecution.jsch.JSchChannelsSupport;
+import org.netbeans.modules.nativeexecution.jsch.JSchConnectionTask;
 import org.netbeans.modules.nativeexecution.support.Authentication;
 import org.netbeans.modules.nativeexecution.support.Logger;
 import org.netbeans.modules.nativeexecution.support.NativeTaskExecutorService;
-import org.netbeans.modules.nativeexecution.support.RemoteUserInfo;
-import org.netbeans.modules.nativeexecution.support.ui.AuthTypeSelectorDlg;
 import org.netbeans.modules.nativeexecution.support.ui.AuthenticationSettingsPanel;
-import org.openide.util.Cancellable;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
-import org.openide.util.RequestProcessor;
+import org.openide.util.NbPreferences;
 
 /**
  *
  * @author ak119685
  */
 public final class ConnectionManager {
+    
+    public static class CancellationException extends Exception {
+
+        public CancellationException() {
+        }
+        
+        public CancellationException(String message) {
+            super(message);
+        }        
+    }
 
     private static final java.util.logging.Logger log = Logger.getInstance();
-    private static final boolean USE_JZLIB = Boolean.getBoolean("jzlib"); // NOI18N
-    private static final int JSCH_CONNECTION_TIMEOUT = Integer.getInteger("jsch.connection.timeout", 10000); // NOI18N
-    private static final int SOCKET_CREATION_TIMEOUT = Integer.getInteger("socket.connection.timeout", 10000); // NOI18N
-    private static final boolean UNIT_TEST_MODE = Boolean.getBoolean("nativeexecution.mode.unittest"); // NOI18N
-    // Connections are always established sequently in connectorThread
-    private static final RequestProcessor connectorThread = new RequestProcessor("ConnectionManager queue", 1); // NOI18N
-    // Map that contains all connected sessions;
-    private static final HashMap<ExecutionEnvironment, Session> sessions = new HashMap<ExecutionEnvironment, Session>();
     // Actual sessions pools. One per host
-    private static final HashMap<ExecutionEnvironment, JSch> jschPool = new HashMap<ExecutionEnvironment, JSch>();
+    private static final ConcurrentHashMap<ExecutionEnvironment, JSchChannelsSupport> channelsSupport = new ConcurrentHashMap<ExecutionEnvironment, JSchChannelsSupport>();
     private static List<ConnectionListener> connectionListeners = new CopyOnWriteArrayList<ConnectionListener>();
+    private static final Object channelsSupportLock = new Object();
     private static HashMap<ExecutionEnvironment, ConnectToAction> connectionActions = new HashMap<ExecutionEnvironment, ConnectToAction>();
     // Instance of the ConnectionManager
     private static final ConnectionManager instance = new ConnectionManager();
+    private static final ConcurrentHashMap<ExecutionEnvironment, JSch> jschPool =
+            new ConcurrentHashMap<ExecutionEnvironment, JSch>();
+    private static final ConcurrentHashMap<ExecutionEnvironment, JSchConnectionTask> connectionTasks =
+            new ConcurrentHashMap<ExecutionEnvironment, JSchConnectionTask>();
+    private static final boolean UNIT_TEST_MODE = Boolean.getBoolean("nativeexecution.mode.unittest"); // NOI18N
+
+    private final AbstractList<ExecutionEnvironment> recentConnections = new ArrayList<ExecutionEnvironment>();
 
     static {
         ConnectionManagerAccessor.setDefault(new ConnectionManagerAccessorImpl());
@@ -131,6 +136,7 @@ public final class ConnectionManager {
                 }
             });
         }
+        restoreRecentConnectionsList();
     }
 
     public void addConnectionListener(ConnectionListener listener) {
@@ -143,11 +149,61 @@ public final class ConnectionManager {
         connectionListeners.remove(listener);
     }
 
+    public List<ExecutionEnvironment> getRecentConnections() {
+        synchronized (recentConnections) {
+            return Collections.unmodifiableList(new ArrayList<ExecutionEnvironment>(recentConnections));
+        }
+    }
+
+    /*package-local for test purposes*/ void updateRecentConnectionsList(ExecutionEnvironment execEnv) {
+        synchronized (recentConnections) {
+            recentConnections.remove(execEnv);
+            recentConnections.add(0, execEnv);
+            storeRecentConnectionsList();
+        }
+    }
+
+    /*package-local for test purposes*/ void storeRecentConnectionsList() {
+        Preferences prefs = NbPreferences.forModule(ConnectionManager.class);
+        synchronized (recentConnections) {
+            for (int i = 0; i < recentConnections.size(); i++) {
+                prefs.put(getConnectoinsHistoryKey(i), ExecutionEnvironmentFactory.toUniqueID(recentConnections.get(i)));
+            }
+        }
+    }
+
+    /*package-local for test purposes*/ void restoreRecentConnectionsList() {
+        Preferences prefs = NbPreferences.forModule(ConnectionManager.class);
+        synchronized (recentConnections) {
+            recentConnections.clear();
+            int idx = 0;
+            while (true) {
+                String id = prefs.get(getConnectoinsHistoryKey(idx), null);
+                if (id == null) {
+                    break;
+                }
+                recentConnections.add(ExecutionEnvironmentFactory.fromUniqueID(id));
+                idx++;
+            }
+        }
+    }
+
+    private static String getConnectoinsHistoryKey(int idx) {
+        return ConnectionManager.class.getName() + "_connection.history_" + idx; //NOI18N
+    }
+
+    /** for test purposes only; package-local */ void clearRecentConnectionsList() {
+        synchronized (recentConnections) {
+            recentConnections.clear();
+        }
+    }
+
     private void fireConnected(ExecutionEnvironment execEnv) {
         // No need to lock - use thread-safe collection
         for (ConnectionListener connectionListener : connectionListeners) {
             connectionListener.connected(execEnv);
         }
+        updateRecentConnectionsList(execEnv);
     }
 
     private void fireDisconnected(ExecutionEnvironment execEnv) {
@@ -168,16 +224,12 @@ public final class ConnectionManager {
         if (execEnv.isLocal()) {
             return true;
         }
-
-        synchronized (sessions) {
-            if (sessions.containsKey(execEnv)) {
-                return sessions.get(execEnv).isConnected();
-            }
-
-            return false;
-        }
+        JSchChannelsSupport support = channelsSupport.get(execEnv); // it's a ConcurrentHashMap => no lock is needed
+        return (support != null) && support.isConnected();
     }
 
+    private static final int RETRY_MAX = 10;
+
     /**
      *
      * @param env <tt>ExecutionEnvironment</tt> to connect to.
@@ -194,87 +246,95 @@ public final class ConnectionManager {
             return;
         }
 
-        int attempts = 2;
+        JSch jsch = jschPool.get(env);
 
-        while (attempts > 0) {
-            if (doConnect(env, true)) {
-                break;
-            }
-
-            // For non-unit-tests-mode will itterate
-            // while either connection is established or
-            // is cancelled implicitly.
-
-            if (UNIT_TEST_MODE) {
-                attempts--;
+        if (jsch == null) {
+            jsch = new JSch();
+            JSch old = jschPool.putIfAbsent(env, jsch);
+            if (old != null) {
+                jsch = old;
             }
         }
 
+        if (!UNIT_TEST_MODE) {
+            initiateConnection(env, jsch);
+        } else {
+            // Attempt to workaround "Auth fail" in tests, see IZ 190458
+            // We try to reconnect up to 10 times if "Auth fail" exception happens
+            int retry = RETRY_MAX;
+            IOException ex = null;
+            while (retry > 0) {
+                try {
+                    initiateConnection(env, jsch);
+                    return;
+                } catch (IOException e) {
+                    if (!(e.getCause() instanceof JSchException)) {
+                        throw e;
+                    }
+                    if (!"Auth fail".equals(e.getCause().getMessage())) { //NOI18N
+                        throw e;
+                    }
+                    ex = e;
+                }
+                System.out.println("AUTH_FAIL: Connection failed, re-runing test " + retry); // NOI18N
+                retry--;
+            }
+            System.out.println("AUTH_FAIL: Retry limit reached"); // NOI18N
+            throw ex;
+        }
     }
 
-    private boolean doConnect(final ExecutionEnvironment env, final boolean fetchHostInfo) throws IOException, CancellationException {
+    private void initiateConnection(final ExecutionEnvironment env, final JSch jsch) throws IOException, CancellationException {
+        JSchConnectionTask connectionTask;
+
+        synchronized (connectionTasks) {
+            connectionTask = connectionTasks.get(env);
+
+            if (connectionTask == null) {
+                connectionTask = new JSchConnectionTask(jsch, env);
+                connectionTask.start();
+                connectionTasks.put(env, connectionTask);
+            }
+        }
 
-        final ConnectionTask connectionTask = new ConnectionTask(env);
-        final Future<Session> connectionTaskResult = connectorThread.submit(connectionTask);
         final ProgressHandle ph = ProgressHandleFactory.createHandle(
                 loc("ConnectionManager.Connecting", // NOI18N
                 env.toString()), connectionTask);
 
         ph.start();
 
-        Session session = null;
-
         try {
-            session = connectionTaskResult.get();
+            JSchChannelsSupport cs = connectionTask.getResult();
+
+            if (cs != null) {
+                synchronized (channelsSupportLock) {
+                    channelsSupport.put(env, cs);
+                }
+            } else {
+                JSchConnectionTask.Problem problem = connectionTask.getProblem();
+                switch (problem.type) {
+                    case CONNECTION_CANCELLED:
+                        throw new CancellationException("Connection cancelled for " + env); // NOI18N
+                    default:
+                        // Note that AUTH_FAIL is generated not only on bad password,
+                        // but on socket timeout as well. These cases are
+                        // indistinguishable based on information from JSch.
+                        throw new IOException(env.getDisplayName() + ": " + problem.type.name(), problem.cause); // NOI18N
+                    }
+            }
+
+            HostInfo hostInfo = HostInfoUtils.getHostInfo(env);
+            log.log(Level.FINE, "New connection established: {0} - {1}", new String[]{env.toString(), hostInfo.getOS().getName()}); // NOI18N
+
+            fireConnected(env);
         } catch (InterruptedException ex) {
-            // should not occur
-            //but is is occurred when user cancel connection in the CND connection Wizard
-            //catch it here and throw CancellationException
-            throw new CancellationException("Connection cancelled for " + env); // NOI18N
+            // don't report interrupted exception
         } catch (ExecutionException ex) {
-            // should not occur
-            // any exception thrown from the connectionTask will be wrapped
-            // in this one...
             Exceptions.printStackTrace(ex);
         } finally {
             ph.finish();
+            connectionTasks.remove(env);
         }
-
-        if (connectionTask.cancelled) {
-            throw new CancellationException("Connection cancelled for " + env); // NOI18N
-        }
-
-        if (connectionTask.problem != null) {
-            if (connectionTask.problem == Problem.AUTH_FAIL) {
-                // Note that AUTH_FAIL is generated not only on bad password,
-                // but on socket timeout as well. These cases are
-                // indistinguishable based on information from JSch.
-                log.log(Level.FINE, "JSch problem connecting to {0}: {1}", new Object[]{env, connectionTask.problem}); // NOI18N
-                if (!UNIT_TEST_MODE) {
-                    // Do not clean password when running unit tests.
-                    // We want to be able to repeat the connection attempt.
-                    PasswordManager.getInstance().clearPassword(env);
-                }
-                return false;
-            } else {
-                throw new IOException(env.getDisplayName() + ": " + connectionTask.problem.name()); // NOI18N
-            }
-        }
-
-        assert session != null;
-
-        synchronized (sessions) {
-            sessions.put(env, session);
-        }
-
-        if (fetchHostInfo) {
-            HostInfo hostInfo = HostInfoUtils.getHostInfo(env);
-            log.log(Level.FINE, "New connection established: {0} - {1}", new String[]{env.toString(), hostInfo.getOS().getName()}); // NOI18N
-        }
-
-        fireConnected(env);
-
-        return true;
     }
 
     public static ConnectionManager getInstance() {
@@ -311,44 +371,15 @@ public final class ConnectionManager {
         return NbBundle.getMessage(ConnectionManager.class, key, params);
     }
 
-    /**
-     *
-     * @param execEnv
-     * @param restoreLostConnection
-     * @return returns previously created session.
-     * If execEnv was not connected before - returns null
-     * disregarding the restoreLostConnection flag.
-     * It also could return null if attempt to restore
-     * lost connection failed.
-     */
-    private Session getSession(ExecutionEnvironment execEnv, boolean restoreLostConnection) {
-        synchronized (sessions) {
-            if (sessions.containsKey(execEnv)) {
-                int attempts = 3;
-
-                while (attempts-- > 0) {
-                    Session session = sessions.get(execEnv);
-
-                    if (!restoreLostConnection || session.isConnected()) {
-                        return session;
-                    }
-
-                    try {
-                        reconnect(execEnv);
-                    } catch (IOException ex) {
-                        return null;
-                    }
+    private void reconnect(ExecutionEnvironment env) throws IOException {
+        synchronized (channelsSupportLock) {
+            if (channelsSupport.containsKey(env)) {
+                try {
+                    channelsSupport.get(env).reconnect(env);
+                } catch (JSchException ex) {
+                    throw new IOException(ex);
                 }
             }
-
-            return null;
-        }
-    }
-
-    private void reconnect(ExecutionEnvironment env) throws IOException {
-        synchronized (sessions) {
-            disconnectImpl(env);
-            connectTo(env);
         }
     }
 
@@ -357,30 +388,22 @@ public final class ConnectionManager {
         PasswordManager.getInstance().onExplicitDisconnect(env);
     }
 
-    private void disconnectImpl(ExecutionEnvironment env) {
-        synchronized (sessions) {
-            Session session = sessions.remove(env);
-            if (session != null) {
-                session.disconnect();
+    private void disconnectImpl(final ExecutionEnvironment env) {
+        synchronized (channelsSupportLock) {
+            if (channelsSupport.containsKey(env)) {
+                JSchChannelsSupport cs = channelsSupport.remove(env);
+                cs.disconnect();
                 fireDisconnected(env);
             }
-
-            JSch jsch = jschPool.get(env);
-
-            if (jsch != null) {
-                jschPool.remove(env);
-            }
         }
     }
 
     private static void shutdown() {
         log.fine("Shutting down Connection Manager");
-        Collection<ExecutionEnvironment> connectedEnvs;
-        synchronized (sessions) {
-            connectedEnvs = new ArrayList<ExecutionEnvironment>(sessions.keySet());
-        }
-        for (ExecutionEnvironment env : connectedEnvs) {
-            ConnectionManager.getInstance().disconnect(env);
+        synchronized (channelsSupportLock) {
+            for (JSchChannelsSupport cs : channelsSupport.values()) {
+                cs.disconnect();
+            }
         }
     }
 
@@ -404,178 +427,6 @@ public final class ConnectionManager {
         jschPool.remove(env);
     }
 
-    private static final class ConnectionTask implements Callable<Session>, Cancellable {
-
-        private final ExecutionEnvironment env;
-        private volatile boolean cancelled = false;
-        private volatile Problem problem = null;
-
-        private ConnectionTask(final ExecutionEnvironment env) {
-            this.env = env;
-        }
-
-        @Override
-        public Session call() throws Exception {
-            Session newSession = null;
-            try {
-                try {
-                    env.prepareForConnection();
-                } catch (Throwable th) {
-                    problem = Problem.ENV_PREPARE_ERROR;
-                    return null;
-                }
-
-                if (cancelled) {
-                    return null;
-                }
-
-                if (!isReachable()) {
-                    problem = Problem.HOST_UNREACHABLE;
-                    return null;
-                }
-
-                if (cancelled) {
-                    return null;
-                }
-
-                UserInfo userInfo = new RemoteUserInfo(env, !UNIT_TEST_MODE);
-
-                JSch jsch = jschPool.get(env);
-
-                if (jsch == null) {
-                    jsch = new JSch();
-                    jschPool.put(env, jsch);
-                    if (!initJsch(env)) {
-                        jschPool.remove(env);
-                        cancelled = true;
-                        return null;
-                    }
-                }
-
-                newSession = jsch.getSession(env.getUser(), env.getHostAddress(), env.getSSHPort());
-                newSession.setUserInfo(userInfo);
-
-                if (USE_JZLIB) {
-                    newSession.setConfig("compression.s2c", "zlib@openssh.com,zlib,none"); // NOI18N
-                    newSession.setConfig("compression.c2s", "zlib@openssh.com,zlib,none"); // NOI18N
-                    newSession.setConfig("compression_level", "9"); // NOI18N
-                }
-
-                try {
-                    // connect methods tries to handle auth fail
-                    // itself by re-asking for password 6 times
-                    // only after 6th attempt it throws an exception
-                    newSession.connect(JSCH_CONNECTION_TIMEOUT);
-                } catch (JSchException e) {
-                    log.log(Level.FINE, "JSchException connecting to " + env, e); // NOI18N
-                    if (e.getMessage().equals("Auth fail")) { // NOI18N
-                        problem = Problem.AUTH_FAIL;
-                        return null;
-                    } else if (e.getMessage().equals("Auth cancel")) { // NOI18N
-                        cancelled = true;
-                        return null;
-                    } else if (e.getMessage().contains("java.net.SocketTimeoutException") // NOI18N
-                            || e.getMessage().contains("timeout")) { // NOI18N
-                        problem = Problem.CONNECTION_TIMEOUT;
-                        return null;
-                    }
-                    problem = Problem.CONNECTION_FAILED;
-                } catch (CancellationException ex) {
-                    log.log(Level.FINE, "CancellationException", ex); // NOI18N
-                    cancelled = true;
-                    return null;
-                }
-            } catch (Throwable th) {
-                Exceptions.printStackTrace(th);
-                problem = Problem.CONNECTION_FAILED;
-            }
-
-            return newSession;
-        }
-
-        public Problem getProblem() {
-            return problem;
-        }
-
-        private boolean isReachable() throws IOException {
-            // IZ#165591 - Trying to connect to wrong host breaks remote host setup (for other hosts)
-            // To prevent this first try to just open a socket and
-            // go to the jsch code in case of success only.
-
-            // The important thing here is that we still need to be interruptable
-            // In case of wrong IP address (unreachable) the SocketImpl's connect()
-            // method may hang in system call for a long period of time, being
-            // insensitive to interrupts.
-            // So do this in a separate thread...
-
-            Callable<Boolean> checker = new Callable<Boolean>() {
-
-                @Override
-                public Boolean call() throws Exception {
-                    final Socket socket = new Socket();
-                    final SocketAddress addressToConnect =
-                            new InetSocketAddress(env.getHostAddress(), env.getSSHPort());
-                    try {
-                        socket.connect(addressToConnect, SOCKET_CREATION_TIMEOUT);
-                    } catch (Exception ioe) {
-                        return false;
-                    } finally {
-                        socket.close();
-                    }
-                    return true;
-                }
-            };
-
-            final Future<Boolean> task = NativeTaskExecutorService.submit(
-                    checker, "Host " + env.getHost() + " availability test"); // NOI18N
-
-            while (!cancelled && !task.isDone()) {
-                try {
-                    task.get(500, TimeUnit.MILLISECONDS);
-                } catch (InterruptedException ex) {
-                    // normally should never happen
-                } catch (ExecutionException ex) {
-                    // normally should never happen
-                } catch (TimeoutException ex) {
-                    // OK.. still be waiting
-                }
-            }
-
-            boolean result = false;
-
-            if (task.isDone()) {
-                try {
-                    result = task.get();
-                } catch (Exception ex) {
-                    // normally should never happen
-                }
-            }
-
-            return result;
-        }
-
-        @Override
-        public boolean cancel() {
-            cancelled = true;
-            return true;
-        }
-    }
-
-    private static boolean initJsch(ExecutionEnvironment env) {
-        Authentication auth = Authentication.getFor(env);
-
-        if (!auth.isDefined()) {
-            AuthTypeSelectorDlg dlg = new AuthTypeSelectorDlg();
-            if (!dlg.initAuthentication(auth)) {
-                return false;
-            }
-        } else {
-            auth.apply();
-        }
-
-        return true;
-    }
-
     /**
      * onConnect will be invoked ONLY if this action has initiated a new
      * connection.
@@ -618,21 +469,34 @@ public final class ConnectionManager {
         }
     }
 
-    private enum Problem {
-
-        ENV_PREPARE_ERROR,
-        AUTH_FAIL,
-        HOST_UNREACHABLE,
-        CONNECTION_FAILED,
-        CONNECTION_TIMEOUT,
-    }
-
     private static final class ConnectionManagerAccessorImpl
             extends ConnectionManagerAccessor {
 
         @Override
-        public Session getConnectionSession(ExecutionEnvironment env, boolean restoreLostConnection) {
-            return instance.getSession(env, restoreLostConnection);
+        public Channel openAndAcquireChannel(ExecutionEnvironment env, String type, boolean waitIfNoAvailable) throws InterruptedException, JSchException, IOException {
+            synchronized (channelsSupportLock) {
+                if (channelsSupport.containsKey(env)) {
+                    JSchChannelsSupport cs = channelsSupport.get(env);
+                    return cs.acquireChannel(type, waitIfNoAvailable);
+                }
+            }
+
+            return null;
+        }
+
+        @Override
+        public void closeAndReleaseChannel(final ExecutionEnvironment env, final Channel channel) throws JSchException {
+            JSchChannelsSupport cs = null;
+
+            synchronized (channelsSupportLock) {
+                if (channelsSupport.containsKey(env)) {
+                    cs = channelsSupport.get(env);
+                }
+            }
+
+            if (cs != null && channel != null) {
+                cs.releaseChannel(channel);
+            }
         }
 
         @Override
@@ -652,7 +516,7 @@ public final class ConnectionManager {
                 }
 
                 try {
-                    String knownHosts = auth.getKnownHosts();
+                    String knownHosts = auth.getKnownHostsFile();
                     if (knownHosts != null) {
                         jsch.setKnownHosts(knownHosts);
                     }
@@ -663,17 +527,12 @@ public final class ConnectionManager {
                 switch (auth.getType()) {
                     case SSH_KEY:
                         try {
-                            jsch.addIdentity(auth.getKey());
+                            jsch.addIdentity(auth.getSSHKeyFile());
                         } catch (JSchException ex) {
                             Exceptions.printStackTrace(ex);
                         }
                 }
             }
         }
-
-        @Override
-        public boolean doConnect(ExecutionEnvironment execEnv, boolean fetchHostInfo) throws IOException, CancellationException {
-            return instance.doConnect(execEnv, fetchHostInfo);
-        }
     }
 }
