@@ -46,7 +46,7 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.Arrays;
 import java.util.Random;
-import java.util.concurrent.CancellationException;
+import org.netbeans.modules.nativeexecution.api.util.ConnectionManager.CancellationException;
 import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.Before;
@@ -59,6 +59,7 @@ import org.netbeans.modules.nativeexecution.api.HostInfo;
 import org.netbeans.modules.nativeexecution.api.NativeProcessBuilder;
 import org.netbeans.modules.nativeexecution.test.ForAllEnvironments;
 import org.netbeans.modules.nativeexecution.test.NativeExecutionBaseTestSuite;
+import org.netbeans.modules.nativeexecution.test.NativeExecutionTestSupport;
 import org.openide.util.Exceptions;
 
 /**
@@ -109,6 +110,35 @@ public class HostInfoUtilsTest extends NativeExecutionBaseTestCase {
 //            Exceptions.printStackTrace(ex);
 //        }
 //    }
+
+    @org.junit.Test
+    public void testCpuFamily() throws Exception {
+        class Pair {
+            public Pair(String mspec, HostInfo.CpuFamily cpuFamily) {
+                this.mspec = mspec;
+                this.cpuFamily = cpuFamily;
+            }
+            public final String mspec;
+            public final HostInfo.CpuFamily cpuFamily;
+        }
+        Pair[] pairs = new Pair[] {
+            new Pair("intel-S2", HostInfo.CpuFamily.X86),
+            new Pair("sparc-S2", HostInfo.CpuFamily.SPARC),
+            new Pair("intel-Linux", HostInfo.CpuFamily.X86)
+//            new Pair("intel-FreeBSD", HostInfo.CpuFamily.X86)
+        };
+        for (Pair pair : pairs) {
+            ExecutionEnvironment env = NativeExecutionTestSupport.getTestExecutionEnvironment(pair.mspec);
+            if (env == null) {
+                System.err.printf("Warning: execution environment not found for mspec %s\n", pair.mspec);
+            } else {
+                ConnectionManager.getInstance().connectTo(env);
+                HostInfo hostInfo = HostInfoUtils.getHostInfo(env);
+                assertEquals("CPU family for " + env, pair.cpuFamily, hostInfo.getCpuFamily());
+            }
+        }
+    }
+
     /**
      * This test assures that only first call to getHostInfo does the job.
      * So any subsequent call should return cached result.
@@ -149,9 +179,9 @@ public class HostInfoUtilsTest extends NativeExecutionBaseTestCase {
 
             // As SlowHostInfoProviderEnabled we know that fetching info will
             // take at least 3 seconds. From the other hand it should not take
-            // more than 10 seconds (as we are on the localhost).
+            // more than 30 seconds (as we are on the localhost).
 
-            int count = 20;
+            int count = 60;
 
             while (!HostInfoUtils.isHostInfoAvailable(local)) {
                 try {
@@ -172,8 +202,8 @@ public class HostInfoUtilsTest extends NativeExecutionBaseTestCase {
                 Exceptions.printStackTrace(ex);
             }
 
-            assertTrue("HostInfo MUST be available already (10 seconds passed)", count > 0); // NOI18N
-            assertTrue("HostInfo cannot be available already (only " + ((20 - count) * 2) + " seconds passed)", count < 15); // NOI18N
+            assertTrue("HostInfo MUST be available already (30 seconds passed)", count > 0); // NOI18N
+            assertTrue("HostInfo cannot be available already (only " + ((60 - count) / 2) + " seconds passed)", count < 55); // NOI18N
 
             long startTime = System.currentTimeMillis();
             HostInfoUtils.dumpInfo(HostInfoUtils.getHostInfo(local), System.out);
