@@ -61,13 +61,13 @@ import javax.swing.undo.AbstractUndoableEdit;
 import javax.swing.undo.CannotUndoException;
 import org.netbeans.api.editor.completion.Completion;
 import org.netbeans.editor.BaseDocument;
-import org.netbeans.editor.Formatter;
 import org.netbeans.editor.Utilities;
 import org.netbeans.lib.editor.codetemplates.api.CodeTemplate;
 import org.netbeans.lib.editor.codetemplates.spi.CodeTemplateInsertRequest;
 import org.netbeans.lib.editor.codetemplates.spi.CodeTemplateParameter;
 import org.netbeans.lib.editor.codetemplates.spi.CodeTemplateProcessor;
 import org.netbeans.lib.editor.codetemplates.spi.CodeTemplateProcessorFactory;
+import org.netbeans.lib.editor.codetemplates.storage.CodeTemplateSettingsImpl.OnExpandAction;
 import org.netbeans.lib.editor.codetemplates.textsync.TextRegion;
 import org.netbeans.lib.editor.codetemplates.textsync.TextRegionManager;
 import org.netbeans.lib.editor.codetemplates.textsync.TextRegionManagerEvent;
@@ -77,6 +77,8 @@ import org.netbeans.lib.editor.codetemplates.textsync.TextSyncGroup;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
 import org.netbeans.lib.editor.util.CharacterConversions;
 import org.netbeans.lib.editor.util.swing.DocumentUtilities;
+import org.netbeans.modules.editor.indent.api.Indent;
+import org.netbeans.modules.editor.indent.api.Reformat;
 
 /**
  * Code template allows the client to paste itself into the given
@@ -125,14 +127,16 @@ public final class CodeTemplateInsertHandler implements TextRegionManagerListene
 
     private String completeInsertString;
 
-    private Formatter formatter;
+    private Reformat formatter;
+    private Indent indenter;   
     
     private TextSyncGroup textSyncGroup;
     
     public CodeTemplateInsertHandler(
         CodeTemplate codeTemplate,
         JTextComponent component, 
-        Collection<? extends CodeTemplateProcessorFactory> processorFactories
+        Collection<? extends CodeTemplateProcessorFactory> processorFactories,
+        OnExpandAction onExpandAction
     ) {
         this.codeTemplate = codeTemplate;
         this.component = component;
@@ -149,6 +153,25 @@ public final class CodeTemplateInsertHandler implements TextRegionManagerListene
         for (CodeTemplateProcessorFactory factory : processorFactories) {
             processors.add(factory.createProcessor(this.request));
         }
+        
+        for (CodeTemplateParameter parameter : masterParameters) {
+            if (CodeTemplateParameter.NO_FORMAT_PARAMETER_NAME.equals(parameter.getName()) && onExpandAction != OnExpandAction.NOOP) {
+                onExpandAction = OnExpandAction.INDENT;
+                break;
+            }
+            if (CodeTemplateParameter.NO_INDENT_PARAMETER_NAME.equals(parameter.getName())) {
+                onExpandAction = OnExpandAction.NOOP;
+                break;
+            }
+        }
+        switch (onExpandAction) {
+            case FORMAT:
+                formatter = Reformat.get(component.getDocument());
+                break;
+            case INDENT:
+                indenter = Indent.get(component.getDocument());
+                break;
+        }
 
         if (TIMERS.isLoggable(Level.FINE)) {
             LogRecord rec = new LogRecord(Level.FINE, "CodeTemplateInsertHandler"); // NOI18N
@@ -182,7 +205,10 @@ public final class CodeTemplateInsertHandler implements TextRegionManagerListene
     }
     
     public void setParametrizedText(String parametrizedText) {
-        this.parametrizedText = CharacterConversions.lineSeparatorToLineFeed(parametrizedText);
+        int idx = 0;
+        while(idx < parametrizedText.length() && Character.isWhitespace(parametrizedText.charAt(idx)))
+            idx++;
+        this.parametrizedText = CharacterConversions.lineSeparatorToLineFeed(idx > 0 ? parametrizedText.substring(idx) : parametrizedText);
         parseParametrizedText();
     }
 
@@ -247,30 +273,25 @@ public final class CodeTemplateInsertHandler implements TextRegionManagerListene
         // Build insert string outside of the atomic lock
         completeInsertString = getInsertText();
 
-        BaseDocument bdoc = (doc instanceof BaseDocument)
-                ? (BaseDocument)doc
-                : null;
-        // Need to lock formatter first because CT's multiline text will be reformatted
-        formatter = null;
-        if (bdoc != null) {
-            formatter = bdoc.getFormatter();
-            if (formatter != null) {
-                formatter.reformatLock();
-            }
-        }
+        if (formatter != null)
+            formatter.lock();
+        if (indenter != null)
+            indenter.lock();
         try {
-            if (bdoc != null) {
-                bdoc.runAtomicAsUser(this);
+            if (doc instanceof BaseDocument) {
+                ((BaseDocument) doc).runAtomicAsUser(this);
             } else { // Otherwise run without atomic locking
                 this.run();
             }
         } finally {
-            if (bdoc != null) {
-                if (formatter != null) {
-                    formatter.reformatUnlock();
-                }
+            if (formatter != null) {
+                formatter.unlock();
                 formatter = null;
             }
+            if (indenter != null) {
+                indenter.unlock();
+                indenter = null;
+            }
             completeInsertString = null;
         }
     }
@@ -298,7 +319,6 @@ public final class CodeTemplateInsertHandler implements TextRegionManagerListene
             }
 
             // insert the complete text
-            int insertOffset = component.getCaretPosition();
             completeTextRegion.updateBounds(null, 
                     TextRegion.createFixedPosition(completeInsertString.length()));
 
@@ -344,8 +364,11 @@ public final class CodeTemplateInsertHandler implements TextRegionManagerListene
             this.inserted = true;
             
             if (bdoc != null) {
-                formatter.reformat(bdoc, pos.getOffset(),
-                        pos.getOffset() + completeInsertString.length());
+                component.setCaretPosition(caretTextRegion.startOffset());
+                if (formatter != null)
+                    formatter.reformat(pos.getOffset(), pos.getOffset() + completeInsertString.length());
+                if (indenter != null)
+                    indenter.reindent(pos.getOffset(), pos.getOffset() + completeInsertString.length());
             }
 
             if (!released) {
