@@ -73,6 +73,7 @@ import org.openide.awt.HtmlBrowser;
 import org.openide.awt.StatusDisplayer;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
+import org.openide.util.RequestProcessor;
 
 /**
  *
@@ -99,6 +100,8 @@ public class DocumentationScrollPane extends JScrollPane {
     private static final int ACTION_JAVADOC_OPEN_SOURCE = 4;
     private static final int ACTION_JAVADOC_COPY = 5;
 
+    private static final RequestProcessor RP = new RequestProcessor(DocumentationScrollPane.class);
+
     private JButton bBack, bForward, bGoToSource, bShowWeb;    
     private HTMLDocView view;
     
@@ -445,9 +448,18 @@ public class DocumentationScrollPane extends JScrollPane {
             if (e != null && HyperlinkEvent.EventType.ACTIVATED.equals(e.getEventType())) {
                 final String desc = e.getDescription();
                 if (desc != null) {
-                    CompletionDocumentation doc = currentDocumentation.resolveLink(desc);
-                    if (doc != null)
-                        setData(doc);
+                    RP.post(new Runnable() {
+                        public @Override void run() {
+                            final CompletionDocumentation doc = currentDocumentation.resolveLink(desc);
+                            if (doc != null) {
+                                EventQueue.invokeLater(new Runnable() {
+                                    public @Override void run() {
+                                        setData(doc);
+                                    }
+                                });
+                            }
+                        }
+                    });
                 }                    
             }
         }
