@@ -62,7 +62,6 @@ import org.netbeans.api.editor.mimelookup.MimePath;
 import org.netbeans.api.lexer.LanguagePath;
 import org.netbeans.api.lexer.TokenHierarchy;
 import org.netbeans.api.lexer.TokenSequence;
-import org.netbeans.editor.GuardedDocument;
 import org.netbeans.lib.editor.util.swing.MutablePositionRegion;
 import org.netbeans.modules.editor.indent.spi.Context;
 import org.netbeans.modules.editor.indent.spi.ExtraLock;
@@ -423,15 +422,14 @@ public final class TaskHandler {
             Document doc = handler.document();
             List<Context.Region> indentRegions = new ArrayList<Context.Region>();
             try {
-                if (languagePath != null) {
-                    int endOffset = handler.endPos().getOffset();
-                    if (endOffset >= doc.getLength())
-                        endOffset = Integer.MAX_VALUE;
-                    int startOffset = handler.startPos().getOffset();
-                    if (LOG.isLoggable(Level.FINE)) {
-                        LOG.fine("indentRegions: startOffset=" + startOffset + ", endOffset=" + endOffset + '\n'); //NOI18N
-                    }
-
+                int startOffset = handler.startPos().getOffset();
+                int endOffset = handler.endPos().getOffset();
+                if (endOffset > doc.getLength())
+                    endOffset = Integer.MAX_VALUE;
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.fine("indentRegions: startOffset=" + startOffset + ", endOffset=" + endOffset + '\n'); //NOI18N
+                }
+                if (languagePath != null && startOffset < endOffset) {
                     List<TokenSequence<?>> tsl = TokenHierarchy.get(doc).tokenSequenceList(languagePath,
                             startOffset, endOffset);
                     for (TokenSequence<?> ts : tsl) {
@@ -464,10 +462,10 @@ public final class TaskHandler {
                 }
                 
                 // Filter out guarded regions
-                if (indentRegions.size() > 0 && doc instanceof GuardedDocument) {
-                    MutablePositionRegion region = IndentSpiPackageAccessor.get().positionRegion(indentRegions.get(0));
-                    int regionStartOffset = region.getStartOffset();
-                    GuardedDocument gdoc = (GuardedDocument)doc;
+//                if (indentRegions.size() > 0 && doc instanceof GuardedDocument) {
+//                    MutablePositionRegion region = IndentSpiPackageAccessor.get().positionRegion(indentRegions.get(0));
+//                    int regionStartOffset = region.getStartOffset();
+//                    GuardedDocument gdoc = (GuardedDocument)doc;
 //                    int gbStartOffset = guardedBlocks.adjustToBlockEnd(region.getEndOffset());
 //                    MarkBlockChain guardedBlocks = gdoc.getGuardedBlockChain();
 //                    if (guardedBlocks != null && guardedBlocks.getChain() != null) {
@@ -500,7 +498,7 @@ public final class TaskHandler {
 //                            }
 //                        }
 //                    }
-                }
+//                }
             } catch (BadLocationException e) {
                 Exceptions.printStackTrace(e);
                 indentRegions = Collections.emptyList();
