@@ -110,6 +110,10 @@ import org.netbeans.api.editor.settings.SimpleValueNames;
 import org.netbeans.lib.editor.util.swing.DocumentListenerPriority;
 import org.netbeans.modules.editor.lib2.EditorPreferencesDefaults;
 import org.netbeans.modules.editor.lib.SettingsConversions;
+import org.netbeans.modules.editor.lib2.view.DocumentView;
+import org.netbeans.modules.editor.lib2.view.ViewHierarchy;
+import org.netbeans.modules.editor.lib2.view.ViewHierarchyEvent;
+import org.netbeans.modules.editor.lib2.view.ViewHierarchyListener;
 import org.openide.util.WeakListeners;
 
 /**
@@ -119,6 +123,7 @@ import org.openide.util.WeakListeners;
 * @version 1.00
 */
 
+@SuppressWarnings("ClassWithMultipleLoggers")
 public class BaseCaret implements Caret,
 MouseListener, MouseMotionListener, PropertyChangeListener,
 DocumentListener, ActionListener, 
@@ -139,6 +144,9 @@ AtomicLockListener, FoldHierarchyListener {
     // -J-Dorg.netbeans.editor.BaseCaret.level=FINEST
     private static final Logger LOG = Logger.getLogger(BaseCaret.class.getName());
     
+    // -J-Dorg.netbeans.editor.BaseCaret.EDT.level=FINE - check that setDot() and other operations in EDT only
+    private static final Logger LOG_EDT = Logger.getLogger(BaseCaret.class.getName() + ".EDT");
+
     static {
         // Compatibility debugging flags mapping to logger levels
         if (Boolean.getBoolean("netbeans.debug.editor.caret.focus") && LOG.getLevel().intValue() < Level.FINE.intValue())
@@ -235,8 +243,6 @@ AtomicLockListener, FoldHierarchyListener {
     */
     protected Color textBackColor;
 
-    private transient FocusListener focusListener;
-
     /** Whether the text is being modified under atomic lock.
      * If so just one caret change is fired at the end of all modifications.
      */
@@ -261,7 +267,7 @@ AtomicLockListener, FoldHierarchyListener {
      */
     private boolean updateAfterFoldHierarchyChange;
     private FoldHierarchyListener weakFHListener;
-
+    
     /**
      * Whether at least one typing change occurred during possibly several atomic operations.
      */
@@ -286,6 +292,7 @@ AtomicLockListener, FoldHierarchyListener {
     };
     private PreferenceChangeListener weakPrefsListener = null;
     
+    private boolean caretUpdatePending;
     
     public BaseCaret() {
         listenerImpl = new ListenerImpl();
@@ -344,35 +351,49 @@ AtomicLockListener, FoldHierarchyListener {
      *  and assigned or false otherwise.
      */
     private boolean updateCaretBounds() {
-        JTextComponent c = component;
+        final JTextComponent c = component;
+        final boolean[] ret = { false };
         if (c != null) {
-            int offset = getDot();
-            Rectangle newCaretBounds;
-            try {
-                newCaretBounds = c.getUI().modelToView(
-                        c, offset, Position.Bias.Forward);
-                // [TODO] Temporary fix - impl should remember real bounds computed by paintCustomCaret()
-                if (newCaretBounds != null) {
-                    newCaretBounds.width = Math.max(newCaretBounds.width, 2);
-                }
+            final Document doc = c.getDocument();
+            doc.render(new Runnable() {
+                @Override
+                public void run() {
+                    int offset = getDot();
+                    if (offset > doc.getLength()) {
+                        offset = doc.getLength();
+                    }
+                    if (doc != null) {
+                        CharSequence docText = org.netbeans.lib.editor.util.swing.DocumentUtilities.getText(doc);
+                        dotChar[0] = docText.charAt(offset);
+                    }
+                    Rectangle newCaretBounds;
+                    try {
+                        DocumentView docView = DocumentView.get(c);
+                        if (docView != null) {
+                            // docView.syncViewsRebuild(); // Make sure pending views changes are resolved
+                        }
+                        newCaretBounds = c.getUI().modelToView(
+                                c, offset, Position.Bias.Forward);
+                        // [TODO] Temporary fix - impl should remember real bounds computed by paintCustomCaret()
+                        if (newCaretBounds != null) {
+                            newCaretBounds.width = Math.max(newCaretBounds.width, 2);
+                        }
 
-                BaseDocument doc = Utilities.getDocument(c);
-                if (doc != null) {
-                    doc.getChars(offset, this.dotChar, 0, 1);
+                    } catch (BadLocationException e) {
+                        newCaretBounds = null;
+                        Utilities.annotateLoggable(e);
+                    }
+                    if (newCaretBounds != null) {
+                        LOG.log(Level.FINE, "updateCaretBounds: old={0}, new={1}, offset={2}",
+                                new Object[]{caretBounds, newCaretBounds, offset}); //NOI18N
+                        caretBounds = newCaretBounds;
+                        ret[0] = true;
+                    }
                 }
-            } catch (BadLocationException e) {
-                newCaretBounds = null;
-                Utilities.annotateLoggable(e);
-            }
-        
-            if (newCaretBounds != null) {
-                LOG.log(Level.FINE, "updateCaretBounds: old={0}, new={1}", new Object [] { caretBounds, newCaretBounds }); //NOI18N
-                caretBounds = newCaretBounds;
-                return true;
-            }
+            });
         }
         LOG.log(Level.FINE, "updateCaretBounds: no change, old={0}", caretBounds); //NOI18N
-        return false;
+        return ret[0];
     }
 
     /** Called when UI is being installed into JTextComponent */
@@ -405,6 +426,7 @@ AtomicLockListener, FoldHierarchyListener {
         component.addFocusListener(listenerImpl);
         component.addMouseListener(this);
         component.addMouseMotionListener(this);
+        ViewHierarchy.get(component).addViewHierarchyListener(listenerImpl);
 
         EditorUI editorUI = Utilities.getEditorUI(component);
         editorUI.addPropertyChangeListener( this );
@@ -447,6 +469,8 @@ AtomicLockListener, FoldHierarchyListener {
         c.removeFocusListener(listenerImpl);
         c.removeMouseListener(this);
         c.removeMouseMotionListener(this);
+        ViewHierarchy.get(c).removeViewHierarchyListener(listenerImpl);
+
         
         EditorUI editorUI = Utilities.getEditorUI(c);
         editorUI.removePropertyChangeListener(this);
@@ -647,10 +671,10 @@ AtomicLockListener, FoldHierarchyListener {
      *  scrolled to the position of the caret.
      */
     protected void update(boolean scrollViewToCaret) {
+        caretUpdatePending = false;
         JTextComponent c = component;
         if (c != null) {
             BaseTextUI ui = (BaseTextUI)c.getUI();
-            EditorUI editorUI = ui.getEditorUI();
             BaseDocument doc = Utilities.getDocument(c);
             if (doc != null) {
                 Rectangle oldCaretBounds = caretBounds; // no need to deep copy
@@ -1053,6 +1077,12 @@ AtomicLockListener, FoldHierarchyListener {
      */
     
     public void setDot(int offset, Rectangle scrollRect, int scrollPolicy, boolean expandFold) {
+        if (LOG_EDT.isLoggable(Level.FINE)) { // Only permit operations in EDT
+            if (!SwingUtilities.isEventDispatchThread()) {
+                throw new IllegalStateException("BaseCaret.setDot() not in EDT: offset=" + offset); // NOI18N
+            }
+        }
+
         if (LOG.isLoggable(Level.FINE)) {
             LOG.fine("setDot: offset=" + offset); //NOI18N
             if (LOG.isLoggable(Level.FINEST)) {
@@ -1145,6 +1175,12 @@ AtomicLockListener, FoldHierarchyListener {
      * @deprecated use #setDot(int) preceded by <code>JComponent.scrollRectToVisible()</code>.
      */
     public void moveDot(int offset, Rectangle scrollRect, int scrollPolicy) {
+        if (LOG_EDT.isLoggable(Level.FINE)) { // Only permit operations in EDT
+            if (!SwingUtilities.isEventDispatchThread()) {
+                throw new IllegalStateException("BaseCaret.moveDot() not in EDT: offset=" + offset); // NOI18N
+            }
+        }
+
         if (LOG.isLoggable(Level.FINE)) {
             LOG.fine("moveDot: offset=" + offset); //NOI18N
         }
@@ -1635,8 +1671,20 @@ AtomicLockListener, FoldHierarchyListener {
         });
     }
     
+    void scheduleCaretUpdate() {
+        if (!caretUpdatePending) {
+            caretUpdatePending = true;
+            SwingUtilities.invokeLater(new Runnable() {
+                @Override
+                public void run() {
+                    update(false);
+                }
+            });
+        }
+    }
+    
     private class ListenerImpl extends ComponentAdapter
-    implements FocusListener {
+    implements FocusListener, ViewHierarchyListener {
 
         ListenerImpl() {
         }
@@ -1730,6 +1778,13 @@ AtomicLockListener, FoldHierarchyListener {
             }
         }
 
+        @Override
+        public void viewHierarchyChanged(ViewHierarchyEvent evt) {
+            if (getDot() >= evt.affectedStartOffset()) {
+                scheduleCaretUpdate();
+            }
+        }
+        
     } // End of ListenerImpl class
 
     public final void refresh() {
