@@ -106,7 +106,7 @@ public class BaseTextUI extends BasicTextUI implements
     
     private AbstractDocument lastDocument;
 
-    private int atomicModCount;
+    private int atomicModCount = -1;
     
     /** Instance of the <tt>GetFocusedComponentAction</tt> */
     private static final GetFocusedComponentAction gfcAction
@@ -273,7 +273,9 @@ public class BaseTextUI extends BasicTextUI implements
             return;
         }
 
-        super.uninstallUI(c);
+        if (getComponent() != null) {
+            super.uninstallUI(c);
+        }
 
         prefs.removePreferenceChangeListener(weakListener);
         prefs = null;
@@ -284,6 +286,7 @@ public class BaseTextUI extends BasicTextUI implements
             BaseDocument doc = Utilities.getDocument(comp);
             if (doc != null) {
                 doc.removeDocumentListener(this);
+                doc.removeAtomicLockListener(this);
             }
 
             comp.setKeymap(null);
@@ -432,6 +435,7 @@ public class BaseTextUI extends BasicTextUI implements
                                   
             if (newDoc != null) {
                 newDoc.addDocumentListener(this);
+                atomicModCount = -1;
                 newDoc.addAtomicLockListener(this);
             }
         } else if ("ancestor".equals(propName)) { // NOI18N
@@ -449,45 +453,47 @@ public class BaseTextUI extends BasicTextUI implements
 
     /** Insert to document notification. */
     public void insertUpdate(DocumentEvent evt) {
-        try {
-            checkLengthyAtomicEdit();
-            BaseDocumentEvent bevt = (BaseDocumentEvent)evt;
-            EditorUI eui = getEditorUI();
-            int y = getYFromPos(evt.getOffset());
-            int lineHeight = eui.getLineHeight();
-            int syntaxY = getYFromPos(bevt.getSyntaxUpdateOffset());
-            // !!! patch for case when DocMarksOp.eolMark is at the end of document
-            if (bevt.getSyntaxUpdateOffset() == evt.getDocument().getLength()) {
-                syntaxY += lineHeight;
-            }
-            if (getComponent().isShowing()) {
-                eui.repaint(y, Math.max(lineHeight, syntaxY - y));
-            }
-        } catch (BadLocationException ex) {
-            Utilities.annotateLoggable(ex);
-        }
+        checkLengthyAtomicEdit();
+        // No longer trigger syntax update related repaint
+//        try {
+//            BaseDocumentEvent bevt = (BaseDocumentEvent)evt;
+//            EditorUI eui = getEditorUI();
+//            int y = getYFromPos(evt.getOffset());
+//            int lineHeight = eui.getLineHeight();
+//            int syntaxY = getYFromPos(bevt.getSyntaxUpdateOffset());
+//            // !!! patch for case when DocMarksOp.eolMark is at the end of document
+//            if (bevt.getSyntaxUpdateOffset() == evt.getDocument().getLength()) {
+//                syntaxY += lineHeight;
+//            }
+//            if (getComponent().isShowing()) {
+//                eui.repaint(y, Math.max(lineHeight, syntaxY - y));
+//            }
+//        } catch (BadLocationException ex) {
+//            Utilities.annotateLoggable(ex);
+//        }
     }
     
     /** Remove from document notification. */
     public void removeUpdate(DocumentEvent evt) {
-        try {
-            checkLengthyAtomicEdit();
-            BaseDocumentEvent bevt = (BaseDocumentEvent)evt;
-            EditorUI eui = getEditorUI();
-            int y = getYFromPos(evt.getOffset());
-            int lineHeight = eui.getLineHeight();
-            int syntaxY = getYFromPos(bevt.getSyntaxUpdateOffset());
-            // !!! patch for case when DocMarksOp.eolMark is at the end of document
-            if (bevt.getSyntaxUpdateOffset() == evt.getDocument().getLength()) {
-                syntaxY += lineHeight;
-            }
-            if (getComponent().isShowing()) {
-                eui.repaint(y, Math.max(lineHeight, syntaxY - y));
-            }
-
-        } catch (BadLocationException ex) {
-            Utilities.annotateLoggable(ex);
-        }
+        checkLengthyAtomicEdit();
+        // No longer trigger syntax update related repaint
+//        try {
+//            BaseDocumentEvent bevt = (BaseDocumentEvent)evt;
+//            EditorUI eui = getEditorUI();
+//            int y = getYFromPos(evt.getOffset());
+//            int lineHeight = eui.getLineHeight();
+//            int syntaxY = getYFromPos(bevt.getSyntaxUpdateOffset());
+//            // !!! patch for case when DocMarksOp.eolMark is at the end of document
+//            if (bevt.getSyntaxUpdateOffset() == evt.getDocument().getLength()) {
+//                syntaxY += lineHeight;
+//            }
+//            if (getComponent().isShowing()) {
+//                eui.repaint(y, Math.max(lineHeight, syntaxY - y));
+//            }
+//
+//        } catch (BadLocationException ex) {
+//            Utilities.annotateLoggable(ex);
+//        }
     }
 
     /** The change in document notification.
@@ -508,34 +514,39 @@ public class BaseTextUI extends BasicTextUI implements
     }
 
     private void checkLengthyAtomicEdit() {
-        if (++atomicModCount == LENGTHY_ATOMIC_EDIT_THRESHOLD) {
-            View rootView = getRootView(getComponent());
-            View view;
-            if (rootView != null && rootView.getViewCount() > 0 &&
-                    (view = rootView.getView(0)) instanceof org.netbeans.modules.editor.lib2.view.DocumentView)
-            {
-                ((org.netbeans.modules.editor.lib2.view.DocumentView)view).updateLengthyAtomicEdit(+1);
+        if (atomicModCount != -1) {
+            if (++atomicModCount == LENGTHY_ATOMIC_EDIT_THRESHOLD) {
+                View rootView = getRootView(getComponent());
+                View view;
+                if (rootView != null && rootView.getViewCount() > 0 &&
+                        (view = rootView.getView(0)) instanceof org.netbeans.modules.editor.lib2.view.DocumentView)
+                {
+                    ((org.netbeans.modules.editor.lib2.view.DocumentView)view).updateLengthyAtomicEdit(+1);
+                }
             }
         }
     }
 
     @Override
     public void atomicLock(AtomicLockEvent evt) {
+        assert (atomicModCount == -1);
         atomicModCount = 0;
     }
 
     @Override
     public void atomicUnlock(AtomicLockEvent evt) {
-        if (atomicModCount >= LENGTHY_ATOMIC_EDIT_THRESHOLD) {
-            View rootView = getRootView(getComponent());
-            View view;
-            if (rootView != null && rootView.getViewCount() > 0 &&
-                    (view = rootView.getView(0)) instanceof org.netbeans.modules.editor.lib2.view.DocumentView)
-            {
-                ((org.netbeans.modules.editor.lib2.view.DocumentView)view).updateLengthyAtomicEdit(-1);
+        if (atomicModCount != -1) {
+            if (atomicModCount >= LENGTHY_ATOMIC_EDIT_THRESHOLD) {
+                View rootView = getRootView(getComponent());
+                View view;
+                if (rootView != null && rootView.getViewCount() > 0 &&
+                        (view = rootView.getView(0)) instanceof org.netbeans.modules.editor.lib2.view.DocumentView)
+                {
+                    ((org.netbeans.modules.editor.lib2.view.DocumentView)view).updateLengthyAtomicEdit(-1);
+                }
             }
+            atomicModCount = -1;
         }
-        atomicModCount = 0;
     }
 
     
