@@ -45,50 +45,67 @@
 package org.netbeans.editor;
 
 import java.awt.AWTKeyStroke;
+import java.awt.Component;
+import java.awt.Dimension;
 import java.awt.Rectangle;
 import java.awt.Frame;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
+import java.awt.Graphics;
 import java.awt.Insets;
 import java.awt.KeyboardFocusManager;
+import java.awt.Point;
 import java.awt.Shape;
 import java.awt.event.ActionEvent;
 import java.awt.event.KeyEvent;
 import java.awt.geom.Rectangle2D;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.prefs.Preferences;
+import javax.swing.SwingConstants;
 import javax.swing.SwingUtilities;
 import javax.swing.Action;
 import javax.swing.InputMap;
 import javax.swing.JComponent;
 import javax.swing.JEditorPane;
-import javax.swing.JPanel;
 import javax.swing.JScrollPane;
 import javax.swing.JTextField;
+import javax.swing.JViewport;
 import javax.swing.KeyStroke;
-import javax.swing.border.CompoundBorder;
+import javax.swing.LookAndFeel;
+import javax.swing.UIManager;
+import javax.swing.border.Border;
 import javax.swing.border.EmptyBorder;
+import javax.swing.event.DocumentEvent;
+import javax.swing.event.DocumentListener;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.EditorKit;
 import javax.swing.text.Document;
-import javax.swing.text.Position;
+import javax.swing.text.Position.Bias;
 import javax.swing.text.TextAction;
 import javax.swing.text.Caret;
 import javax.swing.plaf.TextUI;
 import javax.swing.text.AbstractDocument;
 import javax.swing.text.Element;
+import javax.swing.text.Position;
 import javax.swing.text.View;
 import org.netbeans.api.editor.EditorRegistry;
 import org.netbeans.api.editor.mimelookup.MimeLookup;
+import org.netbeans.api.editor.settings.SimpleValueNames;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
+import org.netbeans.lib.editor.util.swing.DocumentListenerPriority;
 import org.netbeans.lib.editor.util.swing.DocumentUtilities;
+import org.netbeans.modules.editor.indent.api.Reformat;
+import org.netbeans.modules.editor.indent.spi.CodeStylePreferences;
 import org.netbeans.modules.editor.lib.drawing.DrawEngineDocView;
+import org.netbeans.modules.editor.lib2.EditorPreferencesDefaults;
 import org.netbeans.modules.editor.lib2.EditorPreferencesKeys;
 import org.netbeans.modules.editor.lib2.highlighting.HighlightingManager;
 import org.netbeans.modules.editor.lib2.view.DocumentView;
 import org.netbeans.modules.editor.lib2.view.EditorView;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 
 /**
@@ -130,7 +147,9 @@ public class Utilities {
     public static final int CASE_SWITCH = 2;
     
     /** Fake TextAction for getting the info of the focused component */
-    private static TextAction focusedComponentAction;    
+    private static TextAction focusedComponentAction;
+
+    private static final Logger logger = Logger.getLogger(Utilities.class.getName());
     
     private Utilities() {
         // instantiation has no sense
@@ -344,6 +363,13 @@ public class Utilities {
     */
     public static int getPositionAbove(JTextComponent c, int offset, int x)
     throws BadLocationException {
+        if (BaseKit.LINEWRAP_ENABLED) {
+            // Ignore returned bias
+            offset = c.getUI().getNextVisualPositionFrom(c,
+                              offset, Bias.Forward, SwingConstants.NORTH, null);
+            return offset;
+        }
+        
         int rowStart = getRowStart(c, offset);
         int endInit = c.getUI().getNextVisualPositionFrom(c,
                               rowStart, Position.Bias.Forward, javax.swing.SwingConstants.WEST, null);
@@ -423,6 +449,13 @@ public class Utilities {
     */
     public static int getPositionBelow(JTextComponent c, int offset, int x)
     throws BadLocationException {
+        if (BaseKit.LINEWRAP_ENABLED) {
+            // Ignore returned bias
+            offset = c.getUI().getNextVisualPositionFrom(c,
+                              offset, Bias.Forward, SwingConstants.SOUTH, null);
+            return offset;
+        }
+        
 	int startInit = getRowEnd(c, offset) + 1;
 
         Rectangle2D r = modelToView(c, startInit);
@@ -658,7 +691,7 @@ public class Utilities {
     public static int getLineOffset(BaseDocument doc, int offset)
     throws BadLocationException {
         
-        checkOffsetValid(offset, doc.getLength() + 1);
+        checkOffsetValid(doc, offset);
 
         Element lineRoot = doc.getParagraphElement(0).getParentElement();
         return lineRoot.getElementIndex(offset);
@@ -984,26 +1017,29 @@ public class Utilities {
      * @param endOffset offset at which the formatting ends
      * @return length of the reformatted code
      */
-    public static int reformat (final BaseDocument doc, final int startOffset, final int endOffset)
-    throws BadLocationException {
-        final Formatter formatter = doc.getFormatter();
-        formatter.reformatLock();
+    public static int reformat (final BaseDocument doc, final int startOffset, final int endOffset) throws BadLocationException {
+        final Reformat formatter = Reformat.get(doc);
+        formatter.lock();
         try {
-            final Object[] result = new Object [1];
-            doc.runAtomicAsUser (new Runnable () {
-                public @Override void run () {
+            final Object[] result = new Object[1];
+            doc.runAtomicAsUser(new Runnable() {
+                public @Override void run() {
                     try {
-                        result [0] = formatter.reformat (doc, startOffset, endOffset);
+                        Position endPos = doc.createPosition(endOffset);
+                        formatter.reformat(startOffset, endOffset);
+                        result[0] = Math.max(endPos.getOffset() - startOffset, 0);
                     } catch (BadLocationException ex) {
-                        result [0] = ex;
+                        result[0] = ex;
                     }
                 }
             });
-            if (result [0] instanceof BadLocationException)
-                throw (BadLocationException) result [0];
-            return (Integer) result [0];
+            if (result[0] instanceof BadLocationException) {
+                throw (BadLocationException) result[0];
+            } else {
+                return (Integer) result[0];
+            }
         } finally {
-            formatter.reformatUnlock();
+            formatter.unlock();
         }
     }
 
@@ -1043,10 +1079,10 @@ public class Utilities {
     public static String getTabInsertString(BaseDocument doc, int offset)
     throws BadLocationException {
         int col = getVisualColumn(doc, offset);
-        Formatter f = doc.getFormatter();
-        boolean expandTabs = f.expandTabs();
+        Preferences prefs = CodeStylePreferences.get(doc).getPreferences();
+        boolean expandTabs = prefs.getBoolean(SimpleValueNames.EXPAND_TABS, EditorPreferencesDefaults.defaultExpandTabs);
         if (expandTabs) {
-            int spacesPerTab = f.getSpacesPerTab();
+            int spacesPerTab = prefs.getInt(SimpleValueNames.SPACES_PER_TAB, EditorPreferencesDefaults.defaultSpacesPerTab);
             int len = (col + spacesPerTab) / spacesPerTab * spacesPerTab - col;
             return new String(Analyzer.getSpacesBuffer(len), 0, len);
         } else { // insert pure tab
@@ -1062,7 +1098,8 @@ public class Utilities {
     public static int getNextTabColumn(BaseDocument doc, int offset)
     throws BadLocationException {
         int col = getVisualColumn(doc, offset);
-        int tabSize = doc.getFormatter().getSpacesPerTab();
+        Preferences prefs = CodeStylePreferences.get(doc).getPreferences();
+        int tabSize = prefs.getInt(SimpleValueNames.SPACES_PER_TAB, EditorPreferencesDefaults.defaultSpacesPerTab);
         return (col + tabSize) / tabSize * tabSize;
     }
 
@@ -1349,6 +1386,39 @@ public class Utilities {
         }
     }
 
+    /**
+     * Execute the given runnable with view hierarchy being locked.
+     * This is necessary when exploring the view hierarchy by views' methods
+     * since the views changes may happen due to changes from highlighting layers
+     * that cause the views to be rebuilt.
+     * @param component non-null text component of which the view hierarchy is being explored.
+     * @param readLockDocument if true lock the document before locking the view hierarchy.
+     *  This parameter should only be false if it's known that the document was already read/write-locked
+     *  prior calling this method.
+     * @r non-null runnable to execute.
+     */
+    public static void runViewHierarchyTransaction(final JTextComponent component,
+            boolean readLockDocument, final Runnable r)
+    {
+        Runnable wrapRun = new Runnable() {
+            @Override
+            public void run() {
+                if (HighlightingManager.LINEWRAP_ENABLED) {
+                    ((DocumentView) getDocumentView(component)).runTransaction(r);
+                } else {
+                    r.run();
+                }
+            }
+        };
+        Document doc;
+        if (readLockDocument && (doc = component.getDocument()) != null) {
+            doc.render(wrapRun);
+        } else {
+            wrapRun.run();
+        }
+        
+    }
+
     /**
      * Creates nice textual description of sequence of KeyStrokes. Usable for
      * displaying MultiKeyBindings. The keyStrokes are delimited by space.
@@ -1410,7 +1480,7 @@ public class Utilities {
     }
 
     private static void checkOffsetValid(Document doc, int offset) throws BadLocationException {
-        checkOffsetValid(offset, doc.getLength());
+        checkOffsetValid(offset, doc.getLength() + 1);
     }
 
     private static void checkOffsetValid(int offset, int limitOffset) throws BadLocationException {
@@ -1590,7 +1660,7 @@ public class Utilities {
             throw new IllegalArgumentException("No EditorKit for '" + mimeType + "' mimetype."); //NOI18N
         }
 
-        JEditorPane editorPane = new JEditorPane();
+        final JEditorPane editorPane = new JEditorPane();
         editorPane.setEditorKit(kit);
 
         editorPane.putClientProperty(
@@ -1608,8 +1678,7 @@ public class Utilities {
         im.put(tabKs, NO_ACTION);
 
         editorPane.setBorder (
-            new CompoundBorder (editorPane.getBorder(),
-            new EmptyBorder (0, 0, 0, 0))
+            new EmptyBorder (0, 0, 0, 0)
         );
 
         JTextField referenceTextField = new JTextField("M"); //NOI18N
@@ -1618,27 +1687,210 @@ public class Utilities {
         tfkeys = referenceTextField.getFocusTraversalKeys(KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS);
         editorPane.setFocusTraversalKeys(KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS, tfkeys);
 
-        JScrollPane sp = new JScrollPane(JScrollPane.VERTICAL_SCROLLBAR_NEVER, JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
-        sp.setBorder(referenceTextField.getBorder());
+        final Insets margin = referenceTextField.getMargin();
+        final Insets borderInsets = referenceTextField.getBorder().getBorderInsets(referenceTextField);
+        //logger.fine("createSingleLineEditor(): margin = "+margin+", borderInsets = "+borderInsets);
+        final JScrollPane sp = new JScrollPane(JScrollPane.VERTICAL_SCROLLBAR_NEVER,
+                                               JScrollPane.HORIZONTAL_SCROLLBAR_NEVER) {
+
+            @Override
+            public void setViewportView(Component view) {
+                if (view instanceof JComponent) {
+                    //logger.fine("createSingleLineEditor() setViewportView(): setting empty border with insets = "+borderInsets);
+                    ((JComponent) view).setBorder(new EmptyBorder(margin)); // borderInsets
+                }
+                if (view instanceof JEditorPane) {
+                    adjustScrollPaneSize(this, (JEditorPane) view);
+                }
+                super.setViewportView(view);
+            }
+
+        };
+        editorPane.addPropertyChangeListener(new PropertyChangeListener() {
+            @Override
+            public void propertyChange(PropertyChangeEvent evt) {
+                if ("editorKit".equals(evt.getPropertyName())) { // NOI18N
+                    adjustScrollPaneSize(sp, editorPane);
+                }
+            }
+        });
+
+
+        sp.setBorder(new DelegatingBorder(referenceTextField.getBorder(), borderInsets));
         sp.setBackground(referenceTextField.getBackground());
 
-        JPanel panel = new JPanel(new GridBagLayout());
-        panel.setBackground(referenceTextField.getBackground());
-        GridBagConstraints gridBagConstraints = new java.awt.GridBagConstraints();
-        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
-        gridBagConstraints.anchor = java.awt.GridBagConstraints.LINE_START;
-        gridBagConstraints.weightx = 1.0;
-        panel.add(editorPane, gridBagConstraints);
-        sp.setViewportView(panel);
-
         int preferredHeight = referenceTextField.getPreferredSize().height;
-        if (sp.getPreferredSize().height < preferredHeight) {
-            sp.setPreferredSize(referenceTextField.getPreferredSize());
-        }
-        sp.setMinimumSize(sp.getPreferredSize());
+        Dimension spDim = sp.getPreferredSize();
+        spDim.height = preferredHeight;
+        spDim.height += margin.bottom + margin.top;//borderInsets.top + borderInsets.bottom;
+        sp.setPreferredSize(spDim);
+        sp.setMinimumSize(spDim);
+        sp.setMaximumSize(spDim);
+        
+        sp.setViewportView(editorPane);
+        
+        final DocumentListener manageViewListener = new ManageViewPositionListener(editorPane, sp);
+        DocumentUtilities.addDocumentListener(editorPane.getDocument(), manageViewListener, DocumentListenerPriority.AFTER_CARET_UPDATE);
+        editorPane.addPropertyChangeListener(new PropertyChangeListener() {
+            @Override
+            public void propertyChange(PropertyChangeEvent evt) {
+                if ("document".equals(evt.getPropertyName())) { // NOI18N
+                    Document oldDoc = (Document) evt.getOldValue();
+                    if (oldDoc != null) {
+                        DocumentUtilities.removeDocumentListener(oldDoc, manageViewListener, DocumentListenerPriority.AFTER_CARET_UPDATE);
+                    }
+                    Document newDoc = (Document) evt.getNewValue();
+                    if (newDoc != null) {
+                        DocumentUtilities.addDocumentListener(newDoc, manageViewListener, DocumentListenerPriority.AFTER_CARET_UPDATE);
+                    }
+                }
+            }
+        });
 
         return new JComponent [] { sp, editorPane };
     }
 
+    private static void adjustScrollPaneSize(JScrollPane sp, JEditorPane editorPane) {
+        int height;
+        //logger.fine("createSingleLineEditor(): editorPane's margin = "+editorPane.getMargin());
+        //logger.fine("createSingleLineEditor(): editorPane's insets = "+editorPane.getInsets());
+        Dimension prefSize = sp.getPreferredSize();
+        Insets borderInsets = sp.getBorder().getBorderInsets(sp);//sp.getInsets();
+        int vBorder = borderInsets.bottom + borderInsets.top;
+        EditorUI eui = org.netbeans.editor.Utilities.getEditorUI(editorPane);
+        if (logger.isLoggable(Level.FINE)) {
+            logger.fine("createSingleLineEditor(): editor UI = "+eui);
+            if (eui != null) {
+                logger.fine("createSingleLineEditor(): editor UI's line height = "+eui.getLineHeight());
+                logger.fine("createSingleLineEditor(): editor UI's line ascent = "+eui.getLineAscent());
+            }
+        }
+        if (eui != null) {
+            height = eui.getLineHeight();
+            if (height < eui.getLineAscent()) {
+                height = (eui.getLineAscent()*4)/3; // Hack for the case when line height = 1
+            }
+        } else {
+            java.awt.Font font = editorPane.getFont();
+            java.awt.FontMetrics fontMetrics = editorPane.getFontMetrics(font);
+            height = fontMetrics.getHeight();
+            //logger.fine("createSingleLineEditor(): editor's font = "+font+" with metrics = "+fontMetrics+", leading = "+fontMetrics.getLeading());
+            //logger.fine("createSingleLineEditor(): font's height = "+height);
+        }
+        height += vBorder + getLFHeightAdjustment();
+        //height += 2; // 2 for border
+        if (logger.isLoggable(Level.FINE)) {
+            logger.fine("createSingleLineEditor(): border vertical insets = "+borderInsets.bottom+" + "+borderInsets.top);
+            logger.fine("createSingleLineEditor(): computed height = "+height+", prefSize = "+prefSize);
+        }
+        if (prefSize.height < height) {
+            prefSize.height = height;
+            sp.setPreferredSize(prefSize);
+            sp.setMinimumSize(prefSize);
+            sp.setMaximumSize(prefSize);
+            java.awt.Container c = sp.getParent();
+            logger.fine("createSingleLineEditor(): setting a new height of ScrollPane = "+height);
+            if (c instanceof JComponent) {
+                ((JComponent) c).revalidate();
+            }
+        }
+    }
+
+    private static int getLFHeightAdjustment() {
+        LookAndFeel lf = UIManager.getLookAndFeel();
+        String lfID = lf.getID();
+        logger.fine("createSingleLineEditor(): current L&F = '"+lfID+"'");
+        if ("Metal".equals(lfID)) {
+            return 0;
+        }
+        if ("GTK".equals(lfID)) {
+            return 2;
+        }
+        if ("Motif".equals(lfID)) {
+            return 3;
+        }
+        if ("Nimbus".equals(lfID)) {
+            return 0;
+        }
+        if ("Aqua".equals(lfID)) {
+            return -2;
+        }
+        return 0;
+    }
+
+    private static final class ManageViewPositionListener implements DocumentListener {
+
+        private JEditorPane editorPane;
+        private JScrollPane sp;
+
+        public ManageViewPositionListener(JEditorPane editorPane, JScrollPane sp) {
+            this.editorPane = editorPane;
+            this.sp = sp;
+        }
+
+        @Override
+        public void insertUpdate(DocumentEvent e) {
+            changed();
+        }
+
+        @Override
+        public void removeUpdate(DocumentEvent e) {
+            changed();
+        }
+
+        @Override
+        public void changedUpdate(DocumentEvent e) {
+            changed();
+        }
+
+        private void changed() {
+            JViewport viewport = sp.getViewport();
+            Point viewPosition = viewport.getViewPosition();
+            if (viewPosition.x > 0) {
+                try {
+                    Rectangle textRect = editorPane.getUI().modelToView(editorPane, editorPane.getDocument().getLength());
+                    int textLength = textRect.x + textRect.width;
+                    int viewLength = viewport.getExtentSize().width;
+                    //System.out.println("Utilities.createSingleLineEditor(): spLength = "+sp.getSize().width+", viewLength = "+viewLength+", textLength = "+textLength+", viewPosition = "+viewPosition);
+                    if (textLength < (viewPosition.x + viewLength)) {
+                        viewPosition.x = Math.max(textLength - viewLength, 0);
+                        viewport.setViewPosition(viewPosition);
+                        //System.out.println("Utilities.createSingleLineEditor(): setting new view position = "+viewPosition);
+                    }
+                } catch (BadLocationException blex) {
+                    Exceptions.printStackTrace(blex);
+                }
+            }
+        }
+    }
+
+    private static final class DelegatingBorder implements Border {
+
+        private Border delegate;
+        private Insets insets;
+
+        public DelegatingBorder(Border delegate, Insets insets) {
+            this.delegate = delegate;
+            this.insets = insets;
+        }
+
+        @Override
+        public void paintBorder(Component c, Graphics g, int x, int y, int width, int height) {
+            //logger.fine("Delegate paintBorder("+c+", "+g+", "+x+", "+y+", "+width+", "+height+")");
+            delegate.paintBorder(c, g, x, y, width, height);
+        }
+
+        @Override
+        public Insets getBorderInsets(Component c) {
+            return insets;
+        }
+
+        @Override
+        public boolean isBorderOpaque() {
+            return delegate.isBorderOpaque();
+        }
+
+    }
+
     private static final String NO_ACTION = "no-action"; //NOI18N
 }
