@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -43,7 +46,6 @@ package org.netbeans.editor.ext;
 
 import java.awt.Rectangle;
 import java.awt.event.ActionEvent;
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.StringTokenizer;
 import java.util.prefs.Preferences;
@@ -64,7 +66,6 @@ import org.netbeans.editor.BaseAction;
 import org.netbeans.editor.Utilities;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.editor.SyntaxSupport;
-import org.netbeans.editor.Formatter;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
 import org.netbeans.lib.editor.util.swing.DocumentUtilities;
 import org.netbeans.modules.editor.lib.NavigationHistory;
@@ -367,7 +368,7 @@ public class ExtKit extends BaseKit {
         
         protected final void debugPopupMenuItem(JMenuItem item, Action action) {
             if (debugPopupMenu) {
-                StringBuffer sb = new StringBuffer("POPUP: "); // NOI18N
+                StringBuilder sb = new StringBuilder("POPUP: "); // NOI18N
                 if (item != null) {
                     sb.append('"'); //NOI18N
                     sb.append(item.getText());
@@ -830,22 +831,31 @@ public class ExtKit extends BaseKit {
         }
 
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
-            ToggleCommentAction action = null;
+            BaseAction action = null;
             
             if (delegateAction != null) {
                 action = delegateAction;
             } else {
                 BaseKit kit = Utilities.getKit(target);
                 Action a = kit == null ? null : kit.getActionByName(toggleCommentAction);
-                if (a instanceof ToggleCommentAction) {
-                    action = (ToggleCommentAction) a;
+                if (a instanceof BaseAction) {
+                    action = (BaseAction) a;
                 }
             }
 
-            if (action != null) {
+            if (action instanceof ToggleCommentAction) {
                 ((ToggleCommentAction) action).commentUncomment(evt, target, Boolean.TRUE);
             } else {
-                target.getToolkit().beep();
+                if (action != null) {
+                    action.putValue("force-comment", Boolean.TRUE); // NOI18N
+                    try {
+                        action.actionPerformed(evt, target);
+                    } finally {
+                        action.putValue("force-comment", null); // NOI18N
+                    }
+                } else {
+                    target.getToolkit().beep();
+                }
             }
         }
     } // End of CommentAction class
@@ -868,22 +878,31 @@ public class ExtKit extends BaseKit {
         }
 
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
-            ToggleCommentAction action = null;
+            BaseAction action = null;
             
             if (delegateAction != null) {
                 action = delegateAction;
             } else {
                 BaseKit kit = Utilities.getKit(target);
                 Action a = kit == null ? null : kit.getActionByName(toggleCommentAction);
-                if (a instanceof ToggleCommentAction) {
-                    action = (ToggleCommentAction) a;
+                if (a instanceof BaseAction) {
+                    action = (BaseAction) a;
                 }
             }
 
-            if (action != null) {
+            if (action instanceof ToggleCommentAction) {
                 ((ToggleCommentAction) action).commentUncomment(evt, target, Boolean.FALSE);
             } else {
-                target.getToolkit().beep();
+                if (action != null) {
+                    action.putValue("force-uncomment", Boolean.TRUE); // NOI18N
+                    try {
+                        action.actionPerformed(evt, target);
+                    } finally {
+                        action.putValue("force-uncomment", null); // NOI18N
+                    }
+                } else {
+                    target.getToolkit().beep();
+                }
             }
         }
     } // End of UncommentAction class
@@ -1022,7 +1041,10 @@ public class ExtKit extends BaseKit {
     }
 
 
-    // Completion customized actions
+    /** 
+     * @deprecated Please do not subclass this class. Use Typing Hooks instead, for details see
+     *   <a href="@org-netbeans-modules-editor-lib2@/overview-summary.html">Editor Library 2</a>.
+     */
 //    @EditorActionRegistration(
 //            name = defaultKeyTypedAction,
 //            shortDescription = editorBundleHash + defaultKeyTypedAction
@@ -1047,10 +1069,7 @@ public class ExtKit extends BaseKit {
             }
 
             if ((target != null) && (evt != null)) {
-                if ((cmd != null) && (cmd.length() == 1) &&
-                        ((mod & ActionEvent.ALT_MASK) == 0
-                         && (mod & ActionEvent.CTRL_MASK) == 0)
-                   ) {
+                if ((cmd != null) && (cmd.length() == 1)) {
                     // Check whether char that should reindent the line was inserted
                     checkIndentHotChars(target, cmd);
 
@@ -1060,33 +1079,18 @@ public class ExtKit extends BaseKit {
             }
         }
 
-        /** Check the characters that should cause reindenting the line. */
+        // --------------------------------------------------------------------
+        // SPI
+        // --------------------------------------------------------------------
+
+        /** 
+         * Check the characters that should cause reindenting the line. 
+         * 
+         * @deprecated Please use <a href="@org-netbeans-modules-editor-indent@/org/netbeans/modules/editor/indent/spi/support/AutomatedIndenting.html">AutomatedIndentig</a>
+         *   or Typing Hooks instead, for details see
+         *   <a href="@org-netbeans-modules-editor-lib2@/overview-summary.html">Editor Library 2</a>.
+         */
         protected void checkIndentHotChars(JTextComponent target, String typedText) {
-            BaseDocument doc = Utilities.getDocument(target);
-            if (doc != null) {
-                Caret caret = target.getCaret();
-                Formatter f = doc.getFormatter();
-                if (f instanceof ExtFormatter) {
-                    ExtFormatter ef = (ExtFormatter)f;
-                    int[] fmtBlk = ef.getReformatBlock(target, typedText);
-
-                    if (fmtBlk != null) {
-                        try {
-                            fmtBlk[0] = Utilities.getRowStart(doc, fmtBlk[0]);
-                            fmtBlk[1] = Utilities.getRowEnd(doc, fmtBlk[1]);
-
-                            //this was the of #18922, that causes the bug #20198
-                            //ef.reformat(doc, fmtBlk[0], fmtBlk[1]);
-
-                            //bugfix of the bug #20198. Bug #18922 is fixed too as well as #6968
-                            ef.reformat(doc, fmtBlk[0], fmtBlk[1], true);
-                            
-                        } catch (BadLocationException e) {
-                        } catch (IOException e) {
-                        }
-                    }
-                }
-            }
         }
 
 
@@ -1096,37 +1100,6 @@ public class ExtKit extends BaseKit {
          *   <a href="@org-netbeans-modules-editor-completion@/overview-summary.html">Editor Code Completion</a>.
          */
         protected void checkCompletion(JTextComponent target, String typedText) {
-// XXX: remove
-//            Completion completion = ExtUtilities.getCompletion(target);
-//
-//            BaseDocument doc = (BaseDocument)target.getDocument();
-//            ExtSyntaxSupport extSup = (ExtSyntaxSupport)doc.getSyntaxSupport();
-//            
-//            if (completion != null && typedText.length() > 0) {
-//                if( !completion.isPaneVisible() ) {
-//                    if (completion.isAutoPopupEnabled()) {
-//                        int result = extSup.checkCompletion( target, typedText, false );
-//                        if ( result == ExtSyntaxSupport.COMPLETION_POPUP ) {
-//                            completion.popup(true);
-//                        } else if ( result == ExtSyntaxSupport.COMPLETION_CANCEL ) {
-//                            completion.cancelRequest();
-//                        }
-//                    }
-//                } else {
-//                    int result = extSup.checkCompletion( target, typedText, true );
-//                    switch( result ) {
-//                        case ExtSyntaxSupport.COMPLETION_HIDE:
-//                            completion.setPaneVisible(false);
-//                            break;
-//                        case ExtSyntaxSupport.COMPLETION_REFRESH:
-//                            completion.refresh(false);
-//                            break;
-//                        case ExtSyntaxSupport.COMPLETION_POST_REFRESH:
-//                            completion.refresh(true);
-//                            break;
-//                    }
-//                }
-//            }
         }
     }
 
@@ -1204,6 +1177,10 @@ public class ExtKit extends BaseKit {
 
     }
 
+    /** 
+     * @deprecated Please do not subclass this class. Use Typing Hooks instead, for details see
+     *   <a href="@org-netbeans-modules-editor-lib2@/overview-summary.html">Editor Library 2</a>.
+     */
   public static class ExtDeleteCharAction extends DeleteCharAction {
 
     public ExtDeleteCharAction(String nm, boolean nextChar) {
