@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,7 +47,6 @@ package org.netbeans.modules.editor.lib;
 import java.util.List;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import javax.swing.event.UndoableEditEvent;
 import javax.swing.undo.CompoundEdit;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.lib.editor.util.GapList;
@@ -81,7 +83,7 @@ public final class BeforeSaveTasks {
                     " is already occupied by " + beforeSaveRunnable); // NOI18N
         }
         beforeSaveRunnable = new Runnable() {
-            public void run() {
+            public @Override void run() {
                 runTasks();
             }
         };
@@ -106,26 +108,31 @@ public final class BeforeSaveTasks {
      * @return true if the tasks was removed successfully or false if the task
      *  was not found (compared by <code>Object.equals()</code>).
      */
-    public synchronized boolean removeTask(Runnable task) {
+    public synchronized boolean removeTask(Task task) {
         return tasks.remove(task);
     }
     
     private void runTasks() {
-        doc.runAtomicAsUser (new Runnable () {
-            public void run () {
-                CompoundEdit atomicEdit = EditorPackageAccessor.get().markAtomicEditsNonSignificant(doc);
-                // Since these are before-save actions they should generally not prevent
-                // the save operation to succeed. Thus the possible exceptions thrown
-                // by the tasks will be notified but they will not prevent the save to succeed.
-                try {
-                    for (Task task : tasks) {
-                        task.run(atomicEdit);
+        try {
+            doc.runAtomicAsUser (new Runnable () {
+                public @Override void run () {
+                    CompoundEdit atomicEdit = EditorPackageAccessor.get().BaseDocument_markAtomicEditsNonSignificant(doc);
+                    // Since these are before-save actions they should generally not prevent
+                    // the save operation to succeed. Thus the possible exceptions thrown
+                    // by the tasks will be notified but they will not prevent the save to succeed.
+                    try {
+                        for (Task task : tasks) {
+                            task.run(atomicEdit);
+                        }
+                    } catch (Exception e) {
+                        LOG.log(Level.WARNING, "Exception thrown in before-save tasks", e); // NOI18N
                     }
-                } catch (Exception e) {
-                    LOG.log(Level.WARNING, "Exception thrown in before-save tasks", e); // NOI18N
+
                 }
-            }
-        });
+            });
+        } finally {
+            EditorPackageAccessor.get().BaseDocument_clearAtomicEdits(doc);
+        }
     }
 
     public interface Task {
