@@ -53,6 +53,7 @@ import java.awt.event.FocusListener;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
+import java.lang.ref.Reference;
 import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -295,7 +296,13 @@ public final class EditorRegistry {
             Item item = items;
             while (item != null) {
                 JTextComponent textComponent = item.get();
-                if (textComponent == null || (item.ignoreAncestorChange && c.isAncestorOf(textComponent))) {
+                if (LOG.isLoggable(Level.FINEST)) {
+                    LOG.finest(s2s(c) + " isAncestorOf " + s2s(textComponent) + " = " + (textComponent == null ? null : c.isAncestorOf(textComponent)) + '\n'); //NOI18N
+                    LOG.finest(s2s(c) + " isIgnoredAncestorOf " + s2s(textComponent) + " = " + (item.ignoredAncestor == null ? null : item.ignoredAncestor.get() == c) + '\n'); //NOI18N
+                }
+                if (textComponent == null || 
+                    (item.ignoreAncestorChange && (c.isAncestorOf(textComponent) || (item.ignoredAncestor != null && item.ignoredAncestor.get() == c)))
+                ) {
                     // Explicitly call focusLost() before physical removal from the registry.
                     // In practice this notification happens first before focusLost() from focus listener.
                     if (textComponent != null) {
@@ -596,10 +603,15 @@ public final class EditorRegistry {
         Item previous;
         
         /**
-         * Whether component should not be removed from registry upon removeNotify()
-         * since TabbedAdapter in NB winsys removes the component upon tab switching.
+         * Whether component should not be removed from registry upon removeNotify(),
+         * but later on when notifyClose() is called.
          */
         boolean ignoreAncestorChange;
+
+        /**
+         * The ancestor which was ignored in removeNotify().
+         */
+        Reference<Container> ignoredAncestor;
         
         /**
          * Timer for removal of component from registry after removeNotify() was called on component.
@@ -620,11 +632,13 @@ public final class EditorRegistry {
         
         static final FocusL INSTANCE = new FocusL();
 
+        @Override
         public void focusGained(FocusEvent e) {
             EditorRegistry.focusGained((JTextComponent)e.getSource(), e.getOppositeComponent());
 
         }
 
+        @Override
         public void focusLost(FocusEvent e) {
             EditorRegistry.focusLost((JTextComponent)e.getSource(), e.getOppositeComponent());
         }
@@ -635,6 +649,7 @@ public final class EditorRegistry {
         
         static final PropertyDocL INSTANCE = new PropertyDocL();
 
+        @Override
         public void propertyChange(PropertyChangeEvent evt) {
             if ("document".equals(evt.getPropertyName())) { //NOI18N
                 focusedDocumentChange((JTextComponent)evt.getSource(),
@@ -650,6 +665,7 @@ public final class EditorRegistry {
         
         private static final int BEFORE_REMOVE_DELAY = 2000; // 2000ms delay
 
+        @Override
         public void ancestorAdded(AncestorEvent event) {
             Item item = item(event.getComponent());
             if (item.runningTimer != null) {
@@ -659,9 +675,11 @@ public final class EditorRegistry {
             itemMadeDisplayable(item);
         }
 
+        @Override
         public void ancestorMoved(AncestorEvent event) {
         }
 
+        @Override
         public void ancestorRemoved(AncestorEvent event) {
             final JComponent component = event.getComponent();
             Item item = item(component);
@@ -676,7 +694,7 @@ public final class EditorRegistry {
                 // Only start timer when ancestor changes are not ignored.
                 item.runningTimer = new Timer(BEFORE_REMOVE_DELAY,
                     new ActionListener() {
-                        public void actionPerformed(ActionEvent e) {
+                        public @Override void actionPerformed(ActionEvent e) {
                             ArrayList<PropertyChangeEvent> events = new ArrayList<PropertyChangeEvent>();
                             synchronized (EditorRegistry.class) {
                                 Item item = item(component);
@@ -689,9 +707,11 @@ public final class EditorRegistry {
                     }
                 );
                 item.runningTimer.start();
+            } else {
+                Container c = SwingUtilities.getAncestorOfClass(ignoredAncestorClass, component);
+                item.ignoredAncestor = new WeakReference<Container>(c);
             }
         }
-        
     }
 
     private static final class PackageAccessor extends EditorApiPackageAccessor {
