@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -82,6 +85,14 @@ public final class HighlightingManager {
     // -J-Dorg.netbeans.modules.editor.lib2.highlighting.HighlightingManager.level=300
     private static final Logger LOG = Logger.getLogger(HighlightingManager.class.getName());
     
+    public static final boolean LINEWRAP_ENABLED;
+    static {
+        String value = System.getProperty("org.netbeans.editor.linewrap"); //NOI18N
+        LINEWRAP_ENABLED = (value != null)
+                ? !value.equalsIgnoreCase("false") //NOI18N
+                : true; // For 7.0 turned on by default
+    }
+
     public static synchronized HighlightingManager getInstance() {
         if (instance == null) {
             instance = new HighlightingManager();
@@ -117,20 +128,22 @@ public final class HighlightingManager {
 
         // The factories changes tracking
         private Lookup.Result<HighlightsLayerFactory> factories = null;
-        private LookupListener factoriesTracker = new LookupListener() {
-            public void resultChanged(LookupEvent ev) {
+        private final LookupListener factoriesTracker = new LookupListener() {
+            public @Override void resultChanged(LookupEvent ev) {
                 rebuildAllLayers();
             }
         };
+        private LookupListener weakFactoriesTracker = null;
 
         // The FontColorSettings changes tracking
         private Lookup.Result<FontColorSettings> settings = null;
-        private LookupListener settingsTracker = new LookupListener() {
-            public void resultChanged(LookupEvent ev) {
+        private final LookupListener settingsTracker = new LookupListener() {
+            public @Override void resultChanged(LookupEvent ev) {
 //                System.out.println("Settings tracker for '" + (lastKnownMimePaths == null ? "null" : lastKnownMimePaths[0].getPath()) + "'");
                 rebuildAllLayers();
             }
         };
+        private LookupListener weakSettingsTracker = null;
 
         private final JTextComponent pane;
         private HighlightsLayerFilter paneFilter;
@@ -143,9 +156,10 @@ public final class HighlightingManager {
         private List<HighlightsContainer> allLayerContainers = null;
         
         // CompoundHighlightsContainers with containers from filtered layers
-        private final WeakHashMap<HighlightsLayerFilter, WeakReference<CompoundHighlightsContainer>> containers = 
-            new WeakHashMap<HighlightsLayerFilter, WeakReference<CompoundHighlightsContainer>>();
-        
+        private final WeakHashMap<HighlightsLayerFilter, WeakReference<MultiLayerContainer>> containers =
+            new WeakHashMap<HighlightsLayerFilter, WeakReference<MultiLayerContainer>>();
+
+        @SuppressWarnings("LeakingThisInConstructor")
         public Highlighting(JTextComponent pane) {
             this.pane = pane;
             this.paneFilter = new RegExpFilter(pane.getClientProperty(PROP_HL_INCLUDES), pane.getClientProperty(PROP_HL_EXCLUDES));
@@ -155,14 +169,14 @@ public final class HighlightingManager {
         }
 
         public synchronized HighlightsContainer getContainer(HighlightsLayerFilter filter) {
-            WeakReference<CompoundHighlightsContainer> ref = containers.get(filter);
-            CompoundHighlightsContainer container = ref == null ? null : ref.get();
+            WeakReference<MultiLayerContainer> ref = containers.get(filter);
+            MultiLayerContainer container = ref == null ? null : ref.get();
 
             if (container == null) {
-                container = new CompoundHighlightsContainer();
+                container = LINEWRAP_ENABLED ? new ProxyHighlightsContainer() : new CompoundHighlightsContainer();
                 rebuildContainer(pane.getDocument(), filter, container);
                 
-                containers.put(filter, new WeakReference<CompoundHighlightsContainer>(container));
+                containers.put(filter, new WeakReference<MultiLayerContainer>(container));
             }
 
             return container;
@@ -172,15 +186,31 @@ public final class HighlightingManager {
         //  PropertyChangeListener implementation
         // ----------------------------------------------------------------------
 
-        public void propertyChange(PropertyChangeEvent evt) {
+        public @Override void propertyChange(PropertyChangeEvent evt) {
             if (evt.getPropertyName() == null || PROP_DOCUMENT.equals(evt.getPropertyName())) {
-                rebuildAll();
+                Document doc = pane.getDocument();
+                if (doc != null) {
+                    doc.render(new Runnable() {
+                        @Override
+                        public void run() {
+                            rebuildAll();
+                        }
+                    });
+                }
             }
 
             if (PROP_HL_INCLUDES.equals(evt.getPropertyName()) || PROP_HL_EXCLUDES.equals(evt.getPropertyName())) {
-                synchronized (this) {
-                    paneFilter = new RegExpFilter(pane.getClientProperty(PROP_HL_INCLUDES), pane.getClientProperty(PROP_HL_EXCLUDES));
-                    rebuildAllContainers(pane.getDocument());
+                Document doc = pane.getDocument();
+                if (doc != null) {
+                    doc.render(new Runnable() {
+                        @Override
+                        public void run() {
+                            synchronized (this) {
+                                paneFilter = new RegExpFilter(pane.getClientProperty(PROP_HL_INCLUDES), pane.getClientProperty(PROP_HL_EXCLUDES));
+                                rebuildAllContainers(pane.getDocument());
+                            }
+                        }
+                    });
                 }
             }
         }
@@ -221,11 +251,13 @@ public final class HighlightingManager {
                 }
                 
                 // Unregister listeners
-                if (factories != null) {
-                    factories.removeLookupListener(factoriesTracker);
+                if (factories != null && weakFactoriesTracker != null) {
+                    factories.removeLookupListener(weakFactoriesTracker);
+                    weakFactoriesTracker = null;
                 }
-                if (settings != null) {
-                    settings.removeLookupListener(settingsTracker);
+                if (settings != null && weakSettingsTracker != null) {
+                    settings.removeLookupListener(weakSettingsTracker);
+                    weakSettingsTracker = null;
                 }
 
                 if (mimePaths != null) {
@@ -244,11 +276,13 @@ public final class HighlightingManager {
                 
                 // Start listening again
                 if (factories != null) {
-                    factories.addLookupListener(factoriesTracker);
+                    weakFactoriesTracker = WeakListeners.create(LookupListener.class, factoriesTracker, factories);
+                    factories.addLookupListener(weakFactoriesTracker);
                     factories.allItems(); // otherwise we won't get any events at all
                 }
                 if (settings != null) {
-                    settings.addLookupListener(settingsTracker);
+                    weakSettingsTracker = WeakListeners.create(LookupListener.class, settingsTracker, settings);
+                    settings.addLookupListener(weakSettingsTracker);
                     settings.allItems(); // otherwise we won't get any events at all
                 }
 
@@ -259,16 +293,16 @@ public final class HighlightingManager {
             }
         }
         
-        private synchronized void resetAllContainers() {
-            for(HighlightsLayerFilter filter : containers.keySet()) {
-                WeakReference<CompoundHighlightsContainer> ref = containers.get(filter);
-                CompoundHighlightsContainer container = ref == null ? null : ref.get();
-                
-                if (container != null) {
-                    container.resetCache();
-                }
-            }
-        }
+//        private synchronized void resetAllContainers() {
+//            for(HighlightsLayerFilter filter : containers.keySet()) {
+//                WeakReference<CompoundHighlightsContainer> ref = containers.get(filter);
+//                CompoundHighlightsContainer container = ref == null ? null : ref.get();
+//
+//                if (container != null) {
+//                    container.resetCache();
+//                }
+//            }
+//        }
 
         private synchronized void rebuildAllLayers() {
             if (inRebuildAllLayers) {
@@ -343,8 +377,8 @@ public final class HighlightingManager {
             }
 
             for(HighlightsLayerFilter filter : containers.keySet()) {
-                WeakReference<CompoundHighlightsContainer> ref = containers.get(filter);
-                CompoundHighlightsContainer container = ref == null ? null : ref.get();
+                WeakReference<MultiLayerContainer> ref = containers.get(filter);
+                MultiLayerContainer container = ref == null ? null : ref.get();
 
                 if (container != null) {
                     rebuildContainer(document, filter, container);
@@ -352,7 +386,7 @@ public final class HighlightingManager {
             }
         }
 
-        private synchronized void rebuildContainer(Document doc, HighlightsLayerFilter filter, CompoundHighlightsContainer container) {
+        private synchronized void rebuildContainer(Document doc, HighlightsLayerFilter filter, MultiLayerContainer container) {
             if (allLayers != null) {
                 List<? extends HighlightsLayer> filteredLayers = paneFilter.filterLayers(Collections.unmodifiableList(allLayers));
                 filteredLayers = filter.filterLayers(Collections.unmodifiableList(filteredLayers));
@@ -425,6 +459,7 @@ public final class HighlightingManager {
             this.excludes = buildPatterns(excludes);
         }
 
+        @Override
         public List<? extends HighlightsLayer> filterLayers(List<? extends HighlightsLayer> layers) {
             List<? extends HighlightsLayer> includedLayers;
             
