@@ -53,11 +53,14 @@ import java.awt.font.TextLayout;
 import java.awt.geom.Rectangle2D;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import javax.swing.JComponent;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
 import javax.swing.text.Element;
 import javax.swing.text.Position;
 import javax.swing.text.View;
+import org.netbeans.lib.editor.util.CharSequenceUtilities;
+import org.netbeans.lib.editor.util.swing.DocumentUtilities;
 
 /**
  * Base class for views in editor view hierarchy.
@@ -124,16 +127,6 @@ public abstract class EditorView extends View {
         return getEndOffset() - getStartOffset();
     }
 
-    /**
-     * Set textual length of the view.
-     *
-     * @param length &gt;=0 new textual length of the view.
-     * @return true if length change is supported or false if the view must be recreated.
-     */
-    public boolean setLength(int length) {
-        return false;
-    }
-
     /**
      * @return raw visual offset along parent's major axis. It must be post-processed
      *   by parent (if it uses gap-based storage) to become a real visual offset.
@@ -180,7 +173,9 @@ public abstract class EditorView extends View {
      * they might not be in the same order found in the model, or they just
      * might not allow access to some of the locations in the model.
      *
-     * @param offset the position to convert >= 0
+     * @param offset the position to convert >= 0. -1 can be passed to request
+     *  "first available position" at the view's start in the particular direction.
+     *  For example -1 with SwingConstants.WEST means getStartOffset().
      * @param bias bias for the offset.
      * @param alloc non-null bounds allocated to this view.
      * @param direction the direction from the current position that can
@@ -361,7 +356,11 @@ public abstract class EditorView extends View {
 
     @Override
     public String getToolTipText(float x, float y, Shape allocation) {
-        return getToolTipTextChecked(x, y, allocation); // Use coords in doubles
+            return getToolTipTextChecked(x, y, allocation); // Use coords in doubles
+    }
+
+    public JComponent getToolTip(double x, double y, Shape allocation) {
+        return null;
     }
 
     /**
@@ -405,38 +404,47 @@ public abstract class EditorView extends View {
     }
 
     public final String getDumpId() {
-        return getDumpName() + "@" + ViewUtils.toStringId(this);
+        return getDumpName() + "@" + ViewUtils.toStringId(this) + "#" + getViewCount(); // NOI18N
+    }
+
+    public void checkIntegrityIfLoggable() {
+        if (LOG.isLoggable(Level.FINE)) {
+            checkIntegrity(); // NOI18N
+        }
     }
 
     public void checkIntegrity() {
-        if (LOG.isLoggable(Level.FINE)) {
-            String err = findTreeIntegrityError(); // Check integrity of the document view
-            if (err != null) {
-                String msg = "View hierarchy INTEGRITY ERROR! - " + err;
-                LOG.fine(msg + "\nErrorneous view hierarchy:\n");
-                StringBuilder sb = new StringBuilder(200);
-                appendViewInfo(sb, 0, -2); // -2 means detailed info
-                LOG.fine(sb.toString());
-                // For finest level stop throw real ISE otherwise just log the stack
-                if (LOG.isLoggable(Level.FINEST)) {
-                    throw new IllegalStateException(msg);
-                } else {
-                    LOG.log(Level.INFO, msg, new Exception());
-                }
+        String err = findTreeIntegrityError(); // Check integrity of the document view
+        if (err != null) {
+            StringBuilder sb = new StringBuilder(200);
+            sb.append("View hierarchy INTEGRITY ERROR! - ").append(err);
+            sb.append("\nErrorneous view hierarchy:\n");
+            appendViewInfo(sb, 0, -2); // -2 means detailed info
+            // For finest level stop throw real ISE otherwise just log the stack
+            if (LOG.isLoggable(Level.FINEST)) {
+                throw new IllegalStateException(sb.toString());
+            } else {
+                LOG.log(Level.INFO, sb.toString(), new Exception());
             }
         }
     }
 
     public String findIntegrityError() {
-        return null;
+        String err = null;
+        if (getStartOffset() + getLength() != getEndOffset()) {
+            err = "getStartOffset()=" + getStartOffset() + " + getLength()=" + getLength() + // NOI18N
+                    " != getEndOffset()=" + getEndOffset(); // NOI18N
+        }
+        return err;
     }
 
     public String findTreeIntegrityError() {
         String err = findIntegrityError();
         if (err == null) { // Check children
             int viewCount = getViewCount();
-            int lastOffset = getStartOffset();
+            int startOffset = getStartOffset();
             int endOffset = getEndOffset();
+            int lastOffset = startOffset;
             for (int i = 0; i < viewCount; i++) {
                 EditorView child = (EditorView) getView(i);
                 if (child.getParent() != this) {
@@ -480,15 +488,20 @@ public abstract class EditorView extends View {
                 }
                 lastOffset = childEndOffset;
             }
+            if (viewCount > 0 && lastOffset != endOffset) {
+                err = "lastChild.getEndOffset()=" + lastOffset + " != endOffset=" + endOffset; // NOI18N
+            }
         }
         return err;
     }
 
     protected StringBuilder appendViewInfo(StringBuilder sb, int indent, int importantChildIndex) {
         sb.append(getDumpId()).append(':');
-        sb.append('<').append(getStartOffset());
+        int startOffset = getStartOffset();
+        int endOffset = getEndOffset();
+        sb.append('<').append(startOffset);
         sb.append(',');
-        sb.append(getEndOffset()).append('>');
+        sb.append(endOffset).append('>');
         View parent = getParent();
         if (parent instanceof EditorBoxView) {
             @SuppressWarnings("unchecked")
@@ -497,6 +510,27 @@ public abstract class EditorView extends View {
             sb.append(' ').append(axis).append('=').append(boxView.getViewVisualOffset(this));
             // Also append raw visual offset value
             sb.append("(R").append(getRawVisualOffset()).append(')');
+            // First few chars of view's text
+            Document doc = getDocument();
+            if (doc != null) {
+                CharSequence docText = DocumentUtilities.getText(doc);
+                if (endOffset <= docText.length() && DocumentView.LOG_SOURCE_TEXT) {
+                    int endTextOffset = Math.min(endOffset, startOffset + 7);
+                    sb.append(" \"");
+                    CharSequenceUtilities.debugText(sb, docText.subSequence(startOffset, endTextOffset));
+                    if (endTextOffset < endOffset) {
+                        // Display last three chars with possibly "..." inside
+                        int lastCharsOffset = Math.max(endTextOffset, endOffset - 3);
+                        if (lastCharsOffset != endTextOffset) {
+                            sb.append("...");
+                        }
+                        CharSequenceUtilities.debugText(sb, docText.subSequence(lastCharsOffset, endOffset));
+                    }
+                    sb.append('"');
+                }
+            } else {
+                sb.append(" NULL-doc");
+            }
         }
         // Do not getPreferredSpan() since it may be expensive (for HighlightsView calls getTextLayout())
         return sb;
@@ -504,7 +538,7 @@ public abstract class EditorView extends View {
 
     private void checkBounds(int offset) throws BadLocationException {
         Document doc = getDocument();
-        if (offset < 0 || offset > doc.getLength()) {
+        if (offset < 0 || offset > doc.getLength() + 1) {
             throw new BadLocationException("Invalid offset=" + offset + ", docLen=" + doc.getLength(), offset); // NOI18N
         }
     }
@@ -524,14 +558,6 @@ public abstract class EditorView extends View {
          */
         int getViewOffset(int rawOffset);
 
-        /**
-         * Get cached text layout for the given child view.
-         *
-         * @param textLayoutView non-null text layout view.
-         * @return cached (or created) text layout.
-         */
-        TextLayout getTextLayout(TextLayoutView textLayoutView);
-
         /**
          * Get font rendering context that for example may be used for text layout creation.
          * @return font rendering context.
