@@ -77,6 +77,7 @@ import org.openide.util.Utilities;
  */
 public final class CompositeFCS extends FontColorSettings {
 
+    // -J-Dorg.netbeans.modules.editor.settings.storage.fontscolors.CompositeFCS.level=FINE
     private static final Logger LOG = Logger.getLogger(CompositeFCS.class.getName());
     
     public static final String TEXT_ANTIALIASING_PROP = "textAntialiasing"; // NOI18N
@@ -138,6 +139,7 @@ public final class CompositeFCS extends FontColorSettings {
      * text found by the last search peration, etc. They are not bound to any
      * tokens and therefore are mime type independent.
      */
+    @Override
     public AttributeSet getFontColors(String highlightName) {
         assert highlightName != null : "The parameter highlightName must not be null."; //NOI18N
         
@@ -155,6 +157,7 @@ public final class CompositeFCS extends FontColorSettings {
         return attribs;
     }
 
+    @Override
     public AttributeSet getTokenFontColors(String tokenName) {
         assert tokenName != null : "The parameter tokenName must not be null."; //NOI18N
         
@@ -261,7 +264,7 @@ public final class CompositeFCS extends FontColorSettings {
             Object key = keys.nextElement();
             Object value = attribs.getAttribute(key);
 
-            sb.append("'" + key + "' = '" + value + "'"); //NOI18N
+            sb.append("'").append(key).append("' = '").append(value).append("'"); //NOI18N
             if (keys.hasMoreElements()) {
                 sb.append(", "); //NOI18N
             }
@@ -304,6 +307,17 @@ public final class CompositeFCS extends FontColorSettings {
         // property and refresh FontColorSettings in MimeLookup. As per JDK docs java apps
         // should pick up changes in OS AA Font Settings automatically without restart.
         Map<?, ?> desktopHints = (Map<?, ?>) Toolkit.getDefaultToolkit().getDesktopProperty("awt.font.desktophints"); //NOI18N
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.fine("System provided desktop hints:"); //NOI18N
+            for(Object key : desktopHints.keySet()) {
+                Object value = desktopHints.get(key);
+                String humanReadableKey = translateRenderingHintsConstant(key);
+                String humanReadableValue = translateRenderingHintsConstant(value);
+                LOG.fine("  " + humanReadableKey + " = " + humanReadableValue); //NOI18N
+            }
+            LOG.fine("----------------"); //NOI18N
+        }
+
         Boolean aaOn = null;
         String reason = null;
 
@@ -345,15 +359,19 @@ public final class CompositeFCS extends FontColorSettings {
         if (aaOn == null) {
             LOG.fine("Text Antialiasing setting was not determined, using defaults."); //NOI18N
             if (desktopHints != null) {
+                LOG.fine("Using system provided desktop hints"); //NOI18N
                 hints = new HashMap<Object, Object>(desktopHints);
             } else {
+                LOG.fine("No system provided desktop hints available, using hardcoded defaults"); //NOI18N
                 hints = Collections.<Object, Object>singletonMap(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_DEFAULT);
             }
         } else {
             LOG.fine("Text Antialiasing was set " + (aaOn.booleanValue() ? "ON" : "OFF") + " by " + reason + "."); //NOI18N
             if (desktopHints != null) {
+                LOG.fine("Using system provided desktop hints"); //NOI18N
                 hints = new  HashMap<Object, Object>(desktopHints);
             } else {
+                LOG.fine("No system provided desktop hints available, using hardcoded defaults"); //NOI18N
                 hints = new  HashMap<Object, Object>();
             }
             if (aaOn.booleanValue()) {
@@ -367,6 +385,15 @@ public final class CompositeFCS extends FontColorSettings {
                 hints.put(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);
             }
         }
+        
+        if (Boolean.getBoolean("org.netbeans.editor.aa.extra.hints")) {
+            // Get "bolder" Liberation Mono
+            hints.put(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+            hints.put(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
+            hints.put(RenderingHints.KEY_FRACTIONALMETRICS, RenderingHints.VALUE_FRACTIONALMETRICS_ON);
+            // Extra hints
+            hints.put(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_QUALITY);
+        }
 
         if (LOG.isLoggable(Level.FINE)) {
             LOG.fine("Editor Rendering hints:"); //NOI18N
