@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -288,6 +291,7 @@ public class NbEditorKit extends ExtKit implements Callable {
             putValue ("helpID", ToggleToolbarAction.class.getName ()); // NOI18N
         }
 
+        @Override
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
             Preferences prefs = MimeLookup.getLookup(MimePath.EMPTY).lookup(Preferences.class);
             boolean toolbarVisible = prefs.getBoolean(SimpleValueNames.TOOLBAR_VISIBLE_PROP, EditorPreferencesDefaults.defaultToolbarVisible);
@@ -303,7 +307,7 @@ public class NbEditorKit extends ExtKit implements Callable {
                 toolbarVisible);
             
             item.addItemListener( new ItemListener() {
-                public void itemStateChanged(ItemEvent e) {
+                public @Override void itemStateChanged(ItemEvent e) {
                     actionPerformed(null,null);
                 }
             });
@@ -444,9 +448,16 @@ public class NbEditorKit extends ExtKit implements Callable {
                 if (item instanceof DynamicMenuContent) {
                     Component[] cmps = ((DynamicMenuContent)item).getMenuPresenters();
                     for (int i = 0; i < cmps.length; i++) {
-                        popupMenu.add(cmps[i]);
+                        if(cmps[i] != null) {
+                            popupMenu.add(cmps[i]);
+                        } else {
+                            popupMenu.addSeparator();
+                        }
                     }
                 } else {
+                    if (Boolean.TRUE.equals(action.getValue(DynamicMenuContent.HIDE_WHEN_DISABLED)) && !action.isEnabled()) {
+                        return;
+                    }
                     item.setEnabled(action.isEnabled());
                     Object helpID = action.getValue ("helpID"); // NOI18N
                     if (helpID != null && (helpID instanceof String)) {
@@ -499,10 +510,17 @@ public class NbEditorKit extends ExtKit implements Callable {
                             if (item instanceof DynamicMenuContent) {
                                 Component[] cmps = ((DynamicMenuContent)item).getMenuPresenters();
                                 for (int i = 0; i < cmps.length; i++) {
-                                    popupMenu.add(cmps[i]);
+                                    if(cmps[i] != null) {
+                                        popupMenu.add(cmps[i]);
+                                    } else {
+                                        popupMenu.addSeparator();
+                                    }
                                 }
                             } else {
                                 if (!(item instanceof JMenu)) {
+                                    if (Boolean.TRUE.equals(action.getValue(DynamicMenuContent.HIDE_WHEN_DISABLED)) && !action.isEnabled()) {
+                                        return;
+                                    }
                                     assignAccelerator(
                                          (Keymap)Lookup.getDefault().lookup(Keymap.class),
                                          action,
@@ -602,6 +620,7 @@ public class NbEditorKit extends ExtKit implements Callable {
             putValue(BaseAction.NO_KEYBINDING, Boolean.TRUE);
         }
 
+        @Override
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
         }
 
@@ -638,6 +657,7 @@ public class NbEditorKit extends ExtKit implements Callable {
             return NbEditorKit.class;
         }
         
+        @Override
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
         }
 
@@ -787,6 +807,7 @@ public class NbEditorKit extends ExtKit implements Callable {
             return fos;
         }
         
+        @SuppressWarnings("LeakingThisInConstructor")
         private LayerSubFolderMenu(JTextComponent target, String text, List items) {
             super();
             Mnemonics.setLocalizedText(this, text);
@@ -907,6 +928,7 @@ public class NbEditorKit extends ExtKit implements Callable {
         }        
     }
 
+    @Override
     public Object call() {
         Map<SideBarPosition, List<SideBarFactory>> factoriesMap = CustomizableSideBar.getFactoriesMap(getContentType());
         //initialize all factories
