@@ -46,12 +46,15 @@ package org.netbeans.modules.editor;
 
 import java.awt.Point;
 import java.awt.Rectangle;
+import java.awt.Shape;
+import javax.swing.JComponent;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import javax.swing.text.AbstractDocument;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.StyledDocument;
 import javax.swing.text.BadLocationException;
+import org.netbeans.editor.PopupManager;
 import org.openide.filesystems.FileChangeAdapter;
 import org.openide.filesystems.FileObject;
 import org.openide.text.Annotation;
@@ -72,6 +75,7 @@ import java.util.ArrayList;
 import java.beans.PropertyChangeEvent;
 import java.lang.ref.Reference;
 import java.lang.ref.WeakReference;
+import java.util.Collection;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -83,7 +87,9 @@ import org.netbeans.spi.editor.highlighting.HighlightAttributeValue;
 import org.netbeans.spi.editor.highlighting.HighlightsContainer;
 import org.netbeans.spi.editor.highlighting.HighlightsSequence;
 import org.openide.filesystems.FileUtil;
+import org.openide.util.Lookup;
 import org.openide.util.RequestProcessor;
+import org.openide.util.lookup.Lookups;
 
 /**
 * ToolTip annotations reading and refreshing
@@ -143,73 +149,14 @@ public class NbToolTip extends FileChangeAdapter {
         }
         
         if (annos == null) {
-
             if (LOG.isLoggable(Level.FINE)) {
                 LOG.fine("Searching for tooltip annotations for mimeType = '" + mimeType + "'"); //NOI18N
             }
-
-            // XXX: should use Class2LayerFolder and InstanceProvider
-            FileObject annoFolder = FileUtil.getConfigFile("Editors/" + mimeType + "/ToolTips"); //NOI18N
-        
-            if (LOG.isLoggable(Level.FINE)) {
-                LOG.fine("tooltip annotation folder = '" + annoFolder + "'"); //NOI18N
-            }
-
-            if (annoFolder != null) {
-                ArrayList<Annotation> al = new ArrayList<Annotation>();
-                Enumeration en = annoFolder.getChildren(false);
-                while (en.hasMoreElements()) {
-                    FileObject fo = (FileObject)en.nextElement();
-                    
-                    if (LOG.isLoggable(Level.FINE)) {
-                        LOG.fine("tooltip annotation fileobject=" + fo); //NOI18N
-                    }
-
-                    try {
-                        DataObject dob = DataObject.find(fo);
-                        InstanceCookie ic = dob.getCookie(InstanceCookie.class);
-
-                        if (LOG.isLoggable(Level.FINE)) {
-                            LOG.fine("tooltip annotation instanceCookie=" + ic); //NOI18N
-                        }
-
-                        if (ic != null) {
-                            Object a = ic.instanceCreate();
-
-                            if (LOG.isLoggable(Level.FINE)) {
-                                LOG.fine("tooltip annotation instance=" + a); //NOI18N
-                            }
-
-                            if (a instanceof Annotation) {
-                                if (LOG.isLoggable(Level.FINE)) {
-                                    LOG.fine("Found tooltip annotation = " + a //NOI18N
-                                        + ", class = " + a.getClass() // NOI18N
-                                        + " for mimeType = '" + mimeType + "'"// NOI18N
-                                    );
-                                }
-                                
-                                al.add((Annotation)a);
-                            }
-                        }
-                    } catch (DataObjectNotFoundException donfe) {
-                        LOG.log(Level.FINE, null, donfe);
-                    } catch (IOException ioe) {
-                        LOG.log(Level.FINE, null, ioe);
-                    } catch (ClassNotFoundException cnfe) {
-                        LOG.log(Level.FINE, null, cnfe);
-                    }
-                }
-                
-                annos = al.toArray(new Annotation[al.size()]);
-                synchronized (NbToolTip.class) {
-                    tipAnnotations = annos;
-                }
-                
-                annoFolder.addFileChangeListener(this);
-            } else {
-                synchronized (NbToolTip.class) {
-                    tipAnnotations = new Annotation[0];
-                }
+            Lookup l = Lookups.forPath("Editors/" + mimeType + "/ToolTips");  //NOI18N
+            Collection<? extends Annotation> res = l.lookupAll(Annotation.class);
+            annos = res.toArray(new Annotation[res.size()]);
+            synchronized (NbToolTip.class) {
+                tipAnnotations = annos;
             }
         }
         
@@ -224,16 +171,40 @@ public class NbToolTip extends FileChangeAdapter {
             return; // no tooltip support, no tooltips
         }
         
-        // Calls View.getTooltipText, which usually does nothing. CollapsedView.getTooltipText
-        // however calls ToolTipSupport to show its own tooltip component and then
-        // returns an empty string.
-        String toolTipText = target.getUI().getToolTipText(target, tts.getLastMouseEvent().getPoint());
-        if (toolTipText != null){
-            return;
+        BaseDocument doc = Utilities.getDocument(target);
+        Point p = tts.getLastMouseEvent().getPoint();
+        doc.readLock();
+        try {
+            // Calls View.getTooltipText, which usually does nothing. CollapsedView.getTooltipText
+            // however calls ToolTipSupport to show its own tooltip component and then
+            // returns an empty string.
+            String toolTipText = target.getUI().getToolTipText(target, tts.getLastMouseEvent().getPoint());
+            if (toolTipText != null){
+                return;
+            }
+
+            assert (tts.getLastMouseEvent().getSource() == target);
+            org.netbeans.modules.editor.lib2.view.DocumentView docView =
+                    org.netbeans.modules.editor.lib2.view.DocumentView.get(target);
+            Shape alloc;
+            if (docView != null && (alloc = docView.getAllocation()) != null) {
+                JComponent toolTip = docView.getToolTip(p.getX(), p.getY(), alloc);
+                if (toolTip != null) {
+                    String tooltipType = (String) toolTip.getClientProperty("tooltip-type");
+                    if ("fold-preview".equals(tooltipType)) {
+                        tts.setToolTip(toolTip, PopupManager.ViewPortBounds, PopupManager.BelowPreferred, -1, 0);
+    //                    tts.setToolTip(toolTip, PopupManager.ScrollBarBounds, PopupManager.Largest, 2, 0);
+                    } else {
+                        tts.setToolTip(toolTip);
+                    }
+                    return;
+                }
+            }
+        } finally {
+            doc.readUnlock();
         }
         
         Annotation[] annos = getTipAnnotations();
-        BaseDocument doc = Utilities.getDocument(target);
         if (doc != null) {
             DataObject dob = NbEditorUtilities.getDataObject(doc);
             if (dob != null && dob.isValid()) {
@@ -247,7 +218,6 @@ public class NbToolTip extends FileChangeAdapter {
                     // partial fix of #33165 - read-locking of the document added
                     doc.readLock();
                     try {
-                        Point p = tts.getLastMouseEvent().getPoint();
                         int offset = getOffsetForPoint(p, target, doc);
                         if (offset >= 0) {
                             EditorKit kit = org.netbeans.editor.Utilities.getKit(target);
@@ -271,7 +241,7 @@ public class NbToolTip extends FileChangeAdapter {
                                 if (annos != null) {
                                     // Get the annotations stuff
                                     int line = Utilities.getLineOffset(doc, offset);
-                                    int col = offset - Utilities.getRowStart(target, offset);
+                                    int col = offset - Utilities.getRowStartFromLineOffset(doc, line);
                                     Line.Set ls = ec.getLineSet();
                                     if (ls != null) {
                                         Line l = ls.getCurrent(line);
@@ -319,7 +289,8 @@ public class NbToolTip extends FileChangeAdapter {
 
             // Check that p is on a line with text and not completely below text,
             // ie. behind EOF.
-            if (eui != null && r.y == (p.y / eui.getLineHeight()) * eui.getLineHeight()) {
+            int relY = p.y - r.y;
+            if (eui != null && relY < eui.getLineHeight()) {
                 // Check that p is on a line with text before its EOL.
                 if (offset < Utilities.getRowEnd(doc, offset)) {
                     return offset;
@@ -393,6 +364,8 @@ public class NbToolTip extends FileChangeAdapter {
                         }
                     }
                 });
+            } else { // Attempt to get tooltip from view under mouse
+
             }
         }
 
@@ -444,7 +417,11 @@ public class NbToolTip extends FileChangeAdapter {
             if (!isRequestValid()) {
                 return null;
             }
-            
+
+            return getTooltipFromHighlightingLayers();
+        }
+
+        private String getTooltipFromHighlightingLayers() {
             // Read tooltip from highlighting layers attribute
             String tooltipFromHighlightingLayers = null;
             {
@@ -506,20 +483,36 @@ public class NbToolTip extends FileChangeAdapter {
         public void propertyChange(PropertyChangeEvent evt) {
             String propName = evt.getPropertyName();
             if (Annotation.PROP_SHORT_DESCRIPTION.equals(propName) || AnnotationDesc.PROP_SHORT_DESCRIPTION.equals(propName)) {
-                if (evt.getNewValue() != null) {
-                    final String tipText = (String)evt.getNewValue();
-                    Utilities.runInEventDispatchThread( // ensure to run in AWT thread
-                        new Runnable() {
-                            public void run() {
-                                final ToolTipSupport ftts = tts;
-                                if (ftts != null) {
-                                    ftts.setToolTipText(tipText);
+                final Object newValue = evt.getNewValue();
+                toolTipRP.post(new Runnable() {
+                    @Override public void run() {
+                        final String tipText;
+                        if (newValue != null) {
+                            tipText = (String) newValue;
+                        } else {
+                            if (isRequestValid()) {
+                                tipText = getTooltipFromHighlightingLayers();
+                                if (tipText == null || tipText.isEmpty()) {
+                                    return ;
                                 }
+                            } else {
+                                return ;
                             }
                         }
-                    );
-                }
-                
+                        if (tipText != null) {
+                            Utilities.runInEventDispatchThread( // ensure to run in AWT thread
+                                new Runnable() {
+                                    public void run() {
+                                        final ToolTipSupport ftts = tts;
+                                        if (ftts != null) {
+                                            ftts.setToolTipText(tipText);
+                                        }
+                                    }
+                                }
+                            );
+                        }
+                    }
+                });
             } else if (ToolTipSupport.PROP_STATUS.equals(propName)) {
                 if (((Integer)evt.getNewValue()).intValue() == ToolTipSupport.STATUS_HIDDEN) {
                     dismiss();
