@@ -44,10 +44,12 @@
 package org.netbeans.modules.editor.impl;
 
 import java.awt.event.FocusEvent;
+import java.beans.PropertyChangeEvent;
+import java.util.Arrays;
+import java.util.logging.Level;
 import javax.swing.event.PopupMenuEvent;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
-import javax.swing.text.Position;
 import org.netbeans.editor.*;
 import javax.swing.Action;
 import org.openide.util.ImageUtilities;
@@ -66,8 +68,7 @@ import java.awt.event.ComponentEvent;
 import java.awt.event.FocusAdapter;
 import java.awt.event.InputEvent;
 import java.awt.event.KeyEvent;
-import java.awt.event.MouseEvent;
-import java.awt.event.MouseListener;
+import java.beans.PropertyChangeListener;
 import java.util.ArrayList;
 
 import java.util.HashMap;
@@ -76,14 +77,13 @@ import java.util.List;
 import java.util.Map;
 import javax.swing.Timer;
 import java.util.logging.Logger;
-import java.util.prefs.Preferences;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
 import javax.swing.AbstractAction;
 import javax.swing.AbstractButton;
+import javax.swing.ActionMap;
 import javax.swing.BoxLayout;
-import javax.swing.ImageIcon;
 import javax.swing.InputMap;
 import javax.swing.JButton;
 import javax.swing.JCheckBox;
@@ -92,6 +92,7 @@ import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
+import javax.swing.JRootPane;
 import javax.swing.JTextField;
 import javax.swing.JToolBar;
 import javax.swing.KeyStroke;
@@ -103,14 +104,12 @@ import javax.swing.event.DocumentListener;
 import javax.swing.event.PopupMenuListener;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.Keymap;
-import org.netbeans.api.editor.EditorActionRegistration;
 import org.netbeans.api.editor.EditorRegistry;
 import org.netbeans.modules.editor.lib2.search.EditorFindSupport;
 import org.openide.awt.Mnemonics;
 import org.openide.awt.StatusDisplayer;
-import org.openide.util.NbPreferences;
-import org.openide.windows.TopComponent;
-import org.openide.windows.WindowManager;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileUtil;
 
 
 /**
@@ -121,6 +120,7 @@ import org.openide.windows.WindowManager;
 public final class SearchBar extends JPanel {
     
     private static final Logger LOG = Logger.getLogger(SearchBar.class.getName());
+    private static final boolean CLOSE_ON_ENTER = Boolean.getBoolean("org.netbeans.modules.editor.search.closeOnEnter"); // NOI18N
 
     private static final Insets BUTTON_INSETS = new Insets(2, 1, 0, 1);
     private static final Color NOT_FOUND = Color.RED.darker();
@@ -136,36 +136,6 @@ public final class SearchBar extends JPanel {
     public static final String INCREMENTAL_SEARCH_FORWARD = "incremental-search-forward";
     public static final String INCREMENTAL_SEARCH_BACKWARD = "incremental-search-backward";
 
-    /** Shared mouse listener used for setting the border painting property
-     * of the toolbar buttons and for invoking the popup menu.
-     */
-    private static final MouseListener sharedMouseListener
-        = new org.openide.awt.MouseUtils.PopupMouseAdapter() {
-            public @Override void mouseEntered(MouseEvent evt) {
-                Object src = evt.getSource();
-                
-                if (src instanceof JButton) { // ignore JMenuItem and JToggleButton
-                    AbstractButton button = (AbstractButton)evt.getSource();
-                    if (button.isEnabled()) {
-                        button.setContentAreaFilled(true);
-                        button.setBorderPainted(true);
-                    }
-                }
-            }
-            
-            public @Override void mouseExited(MouseEvent evt) {
-                Object src = evt.getSource();
-                if (src instanceof JButton) { // ignore JMenuItem and JToggleButton
-                    AbstractButton button = (AbstractButton)evt.getSource();
-                    button.setContentAreaFilled(false);
-                    button.setBorderPainted(false);
-                }
-            }
-            
-            protected void showPopup(MouseEvent evt) {
-            }
-        };
-
     private JTextComponent component;
     private JButton closeButton;
     private JButton expandButton;
@@ -182,7 +152,7 @@ public final class SearchBar extends JPanel {
     private Map<Object, Object> findProps;
     private JPopupMenu expandPopup;
     private JPanel padding;
-    private boolean navigateOnFocusLost = false;
+    private boolean searched = false;
     
     /**
      * contains everything that is in Search bar and is possible to move to expand popup
@@ -200,72 +170,96 @@ public final class SearchBar extends JPanel {
     private boolean isPopupShown = false;
     
     @SuppressWarnings("unchecked")
-    public SearchBar(JTextComponent component) {
+    public SearchBar(final JTextComponent component) {
         this.component = component;
-
+        component.addFocusListener(new FocusAdapter() {
+            @Override
+            public void focusGained(FocusEvent e) {
+                if (e.getOppositeComponent() instanceof JRootPane) {
+                    // Hack for linux where invoking Find from main menu caused focus gained on editor
+                    // evein when openning quick search
+                    return;
+                }
+                looseFocus();
+            }
+        });
+        FindSupport findSupport = FindSupport.getFindSupport();
+        findProps = new HashMap<Object, Object>(findSupport.getFindProperties());
+        
         setLayout(new BoxLayout(this, BoxLayout.LINE_AXIS));
+        setFocusCycleRoot(true);
         Color bgColor = getBackground();
         bgColor = new Color( Math.max( 0, bgColor.getRed() - 20 ),
                              Math.max( 0, bgColor.getGreen() - 20 ),
                              Math.max( 0, bgColor.getBlue() - 20 ) );        
         setBackground(bgColor);
         setForeground(UIManager.getColor("textText")); //NOI18N
-        
-        //setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
-        addMouseListener(sharedMouseListener);
 
-        Keymap keymap = component.getKeymap();
-        
-        if (keymap instanceof MultiKeymap) {
-            MultiKeymap multiKeymap = (MultiKeymap) keymap;
+        PropertyChangeListener pcl = new PropertyChangeListener() {
+            @Override
+            public void propertyChange(PropertyChangeEvent evt) {
+                if (evt == null || !"keymap".equals(evt.getPropertyName())) { // NOI18N
+                    return;
+                }
 
-            Action[] actions = component.getActions();
-            for(Action action:actions) {
-                // Discover the keyStrokes for incremental-search-forward
-                String actionName = (String) action.getValue(Action.NAME);
-                if (actionName == null) {
-                    LOG.warning("SearchBar: Null Action.NAME property of action: " + action + "\n");
-                }
-                //keystroke for incremental search forward and
-                //keystroke to add standard search next navigation in search bar (by default F3 on win)
-                else if (actionName.equals(INCREMENTAL_SEARCH_FORWARD) || actionName.equals(BaseKit.findNextAction)) {
-                    Action incrementalSearchForwardAction = action;
-                    KeyStroke[] keyStrokes = multiKeymap.getKeyStrokesForAction(incrementalSearchForwardAction);
-                    if (keyStrokes != null) {
-                        InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
-                        for(KeyStroke ks : keyStrokes) {
-                            LOG.fine("found forward search action, " + ks); //NOI18N
-                            inputMap.put(ks, actionName);
+                Keymap keymap = component.getKeymap();
+
+                if (keymap instanceof MultiKeymap) {
+                    MultiKeymap multiKeymap = (MultiKeymap) keymap;
+
+                    Action[] actions = component.getActions();
+                    for(Action action:actions) {
+                        // Discover the keyStrokes for incremental-search-forward
+                        String actionName = (String) action.getValue(Action.NAME);
+                        if (actionName == null) {
+                            LOG.log(Level.WARNING, "SearchBar: Null Action.NAME property of action: {0}\n", action);
                         }
-                        getActionMap().put(actionName,
-                            new AbstractAction() {
-                                public void actionPerformed(ActionEvent e) {
-                                    findNext();
+                        //keystroke for incremental search forward and
+                        //keystroke to add standard search next navigation in search bar (by default F3 on win)
+                        else if (actionName.equals(INCREMENTAL_SEARCH_FORWARD) || actionName.equals(BaseKit.findNextAction)) {
+                            Action incrementalSearchForwardAction = action;
+                            KeyStroke[] keyStrokes = multiKeymap.getKeyStrokesForAction(incrementalSearchForwardAction);
+                            if (keyStrokes != null) {
+                                InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
+                                for(KeyStroke ks : keyStrokes) {
+                                    LOG.log(Level.FINE, "found forward search action, {0}", ks); //NOI18N
+                                    inputMap.put(ks, actionName);
                                 }
-                            });
-                    }
-                }
-                // Discover the keyStrokes for incremental-search-backward
-                // Discover the keyStrokes for search-backward
-                else if (actionName.equals(INCREMENTAL_SEARCH_BACKWARD) || actionName.equals(BaseKit.findPreviousAction)) {
-                    Action incrementalSearchBackwardAction = action;
-                    KeyStroke[] keyStrokes = multiKeymap.getKeyStrokesForAction(incrementalSearchBackwardAction);
-                    if (keyStrokes != null) {
-                        InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
-                        for(KeyStroke ks : keyStrokes) {
-                            LOG.fine("found backward search action, " + ks); //NOI18N
-                            inputMap.put(ks, actionName);
+                                getActionMap().put(actionName,
+                                    new AbstractAction() {
+                                    @Override
+                                        public void actionPerformed(ActionEvent e) {
+                                            findNext();
+                                        }
+                                    });
+                            }
                         }
-                        getActionMap().put(actionName,
-                            new AbstractAction() {
-                                public void actionPerformed(ActionEvent e) {
-                                    findPrevious();
+                        // Discover the keyStrokes for incremental-search-backward
+                        // Discover the keyStrokes for search-backward
+                        else if (actionName.equals(INCREMENTAL_SEARCH_BACKWARD) || actionName.equals(BaseKit.findPreviousAction)) {
+                            Action incrementalSearchBackwardAction = action;
+                            KeyStroke[] keyStrokes = multiKeymap.getKeyStrokesForAction(incrementalSearchBackwardAction);
+                            if (keyStrokes != null) {
+                                InputMap inputMap = getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
+                                for(KeyStroke ks : keyStrokes) {
+                                    LOG.log(Level.FINE, "found backward search action, {0}", ks); //NOI18N
+                                    inputMap.put(ks, actionName);
                                 }
-                            });
+                                getActionMap().put(actionName,
+                                    new AbstractAction() {
+                                    @Override
+                                        public void actionPerformed(ActionEvent e) {
+                                            findPrevious();
+                                        }
+                                    });
+                            }
+                        }
                     }
                 }
             }
-        }
+        };
+        component.addPropertyChangeListener(pcl);
+        pcl.propertyChange(new PropertyChangeEvent(this, "keymap", null, null));
 
         // ESCAPE to put focus back in the editor
         getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT)
@@ -273,13 +267,20 @@ public final class SearchBar extends JPanel {
             "loose-focus"); // NOI18N
         getActionMap().put("loose-focus", // NOI18N
             new AbstractAction() {
+            @Override
                 public void actionPerformed(ActionEvent e) {
+                    if (!CLOSE_ON_ENTER) {
+                        if (!searched) {
+                            findNext();
+                        }
+                    }
                     looseFocus();
                 }
             });
 
         closeButton = new JButton(ImageUtilities.loadImageIcon("org/netbeans/modules/editor/resources/find_close.png", false)); // NOI18N
         closeButton.addActionListener(new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 looseFocus();
             }
@@ -291,6 +292,7 @@ public final class SearchBar extends JPanel {
         expandButton.setMnemonic(NbBundle.getMessage(SearchBar.class, "CTL_ExpandButton_Mnemonic").charAt(0)); // NOI18N
         processButton(expandButton);
         expandButton.addActionListener(new ActionListener() {
+            @Override
                 public void actionPerformed(ActionEvent e) {
                     boolean state = !isPopupShown;
                     isPopupShown = state;
@@ -330,11 +332,13 @@ public final class SearchBar extends JPanel {
             }
         };
         
+        findLabel.setLabelFor(incrementalSearchComboBox);
         incrementalSearchComboBox.setEditable(true);
         incrementalSearchTextField = (JTextField) incrementalSearchComboBox.getEditor().getEditorComponent();
         incrementalSearchTextField.setToolTipText(NbBundle.getMessage(SearchBar.class, "TOOLTIP_IncrementalSearchText")); // NOI18N
 
         ActionListener al = new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 incrementalSearch();
             }
@@ -345,17 +349,23 @@ public final class SearchBar extends JPanel {
         
         // listen on text change
         incrementalSearchTextFieldListener = new DocumentListener() {
+            @Override
             public void changedUpdate(DocumentEvent e) {
+                searched = false;
             }
 
+            @Override
             public void insertUpdate(DocumentEvent e) {
+                searched = false;
                 // text changed - attempt incremental search
                 computeLayout();
                 if(incrementalSearchTextField.getText().length() > 3) searchDelayTimer.setInitialDelay(SEARCH_DELAY_TIME_SHORT);
                 searchDelayTimer.restart();
             }
 
+            @Override
             public void removeUpdate(DocumentEvent e) {
+                searched = false;
                 // text changed - attempt incremental search
                 computeLayout();
                 if(incrementalSearchTextField.getText().length() <= 3) searchDelayTimer.setInitialDelay(SEARCH_DELAY_TIME_LONG);
@@ -363,21 +373,31 @@ public final class SearchBar extends JPanel {
             }
         };
         incrementalSearchTextField.getDocument().addDocumentListener(incrementalSearchTextFieldListener);
-
-        incrementalSearchTextField.addFocusListener(new FocusAdapter() {
-            public @Override void focusLost(FocusEvent e) {
-                navigateOnFocusLost = false;
-                looseFocus();
-            }
-        });
         
-        // ENTER to find next
-        incrementalSearchTextField.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent e) {
-                findNext();
-            }
-        });
+        // flatten the action map for the text field to allow removal
+        ActionMap origActionMap = incrementalSearchTextField.getActionMap();
+        ActionMap newActionMap = new ActionMap();
+        for (Object key : origActionMap.allKeys()) {
+            newActionMap.put(key, origActionMap.get(key));
+        }
+        incrementalSearchTextField.setActionMap(newActionMap);
 
+        // ENTER to find next
+        incrementalSearchTextField.getInputMap().put(
+            KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0, true),
+            "incremental-find-next"); // NOI18N
+        incrementalSearchTextField.getActionMap().put("incremental-find-next", // NOI18N
+            new AbstractAction() {
+            @Override
+                public void actionPerformed(ActionEvent e) {
+                    if (!CLOSE_ON_ENTER && !searched) {
+                        findNext();
+                    }
+                    findNext();
+                    if (CLOSE_ON_ENTER) {
+                        looseFocus();
+                    }
+                }});
         // Shift+ENTER to find previous
         incrementalSearchTextField.getInputMap()
                                   .put(KeyStroke.getKeyStroke(
@@ -385,15 +405,55 @@ public final class SearchBar extends JPanel {
             "incremental-find-previous"); // NOI18N
         incrementalSearchTextField.getActionMap().put("incremental-find-previous", // NOI18N
             new AbstractAction() {
+            @Override
                 public void actionPerformed(ActionEvent e) {
                     findPrevious();
+                    if (CLOSE_ON_ENTER) {
+                        looseFocus();
+                    }
                 }});
+        incrementalSearchTextField.getActionMap().remove("toggle-componentOrientation"); // NOI18N
 
+        // Treat Emacs profile specially in order to fix #191895
+        if (getCurrentKeyMapProfile().startsWith("Emacs")) { // NOI18N
+            class JumpOutOfSearchAction extends AbstractAction {
+                private String actionName;
+                public JumpOutOfSearchAction(String n) {
+                    actionName = n;
+                }
+                @Override
+                public void actionPerformed(ActionEvent e) {
+                    looseFocus();
+                    ActionEvent ev = new ActionEvent(component, e.getID(), e.getActionCommand(), e.getModifiers());
+                    Action action = component.getActionMap().get(actionName);
+                    action.actionPerformed(ev);
+                }
+            }
+            String actionName = "caret-begin-line"; // NOI18N
+            Action a1 = new JumpOutOfSearchAction(actionName);
+            incrementalSearchTextField.getActionMap().put(actionName, a1);
+            actionName = "caret-end-line"; // NOI18N
+            Action a2 = new JumpOutOfSearchAction(actionName);
+            incrementalSearchTextField.getActionMap().put(actionName, a2);
+
+            incrementalSearchTextField.getInputMap().put(KeyStroke.getKeyStroke(
+                KeyEvent.VK_P, InputEvent.CTRL_MASK, false), "caret-up-alt"); // NOI18N
+            actionName = "caret-up"; // NOI18N
+            Action a3 = new JumpOutOfSearchAction(actionName);
+            incrementalSearchTextField.getActionMap().put("caret-up-alt", a3); // NOI18N
+
+            incrementalSearchTextField.getInputMap().put(KeyStroke.getKeyStroke(
+                KeyEvent.VK_N, InputEvent.CTRL_MASK, false), "caret-down-alt"); // NOI18N
+            actionName = "caret-down"; // NOI18N
+            Action a4 = new JumpOutOfSearchAction(actionName);
+            incrementalSearchTextField.getActionMap().put("caret-down-alt", a4); // NOI18N
+        }
         // configure find next button
         findNextButton = new JButton(
             ImageUtilities.loadImageIcon("org/netbeans/modules/editor/resources/find_next.png", false)); // NOI18N
         Mnemonics.setLocalizedText( findNextButton, NbBundle.getMessage(SearchBar.class, "CTL_FindNext")); // NOI18N
         findNextButton.addActionListener(new ActionListener() {
+            @Override
                 public void actionPerformed(ActionEvent e) {
                     findNext();
                 }});
@@ -404,6 +464,7 @@ public final class SearchBar extends JPanel {
             ImageUtilities.loadImageIcon("org/netbeans/modules/editor/resources/find_previous.png", false)); // NOI18N
         Mnemonics.setLocalizedText(findPreviousButton, NbBundle.getMessage(SearchBar.class, "CTL_FindPrevious")); // NOI18N
         findPreviousButton.addActionListener(new ActionListener() {
+            @Override
                 public void actionPerformed(ActionEvent e) {
                     findPrevious();
                 }
@@ -414,11 +475,10 @@ public final class SearchBar extends JPanel {
         matchCaseCheckBox = new JCheckBox();
         Mnemonics.setLocalizedText(matchCaseCheckBox, NbBundle.getMessage(SearchBar.class, "CTL_MatchCase")); // NOI18N
         matchCaseCheckBox.addActionListener(new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 switchMatchCase();
-                // Put focus back in the incremental search textField
                 incrementalSearch();
-                incrementalSearchTextField.requestFocusInWindow();
             }
         });
         matchCaseCheckBox.setSelected(getMatchCase());
@@ -427,11 +487,10 @@ public final class SearchBar extends JPanel {
         wholeWordsCheckBox = new JCheckBox();
         Mnemonics.setLocalizedText(wholeWordsCheckBox, NbBundle.getMessage(SearchBar.class, "CTL_WholeWords")); // NOI18N
         wholeWordsCheckBox.addActionListener(new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 switchWholeWords();
-                // Put focus back in the incremental search textField
                 incrementalSearch();
-                incrementalSearchTextField.requestFocusInWindow();
             }
         });
         wholeWordsCheckBox.setSelected(getWholeWords());
@@ -441,13 +500,12 @@ public final class SearchBar extends JPanel {
         regexpCheckBox = new JCheckBox();
         Mnemonics.setLocalizedText(regexpCheckBox, NbBundle.getMessage(SearchBar.class, "CTL_Regexp")); // NOI18N
         regexpCheckBox.addActionListener(new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 switchRegExp();
                 // Switch other checkbozes on/off
                 wholeWordsCheckBox.setEnabled(!regexpCheckBox.isSelected());
-                // Put focus back in the incremental search textField
                 incrementalSearch();
-                incrementalSearchTextField.requestFocusInWindow();
             }
         });
         regexpCheckBox.setSelected(getRegExp());
@@ -456,11 +514,10 @@ public final class SearchBar extends JPanel {
         highlightCheckBox = new JCheckBox();
         Mnemonics.setLocalizedText(highlightCheckBox, NbBundle.getMessage(SearchBar.class, "CTL_Highlight")); // NOI18N
         highlightCheckBox.addActionListener(new ActionListener() {
+            @Override
             public void actionPerformed(ActionEvent e) {
                 switchHighlightResults();
-                // Put focus back in the incremental search textField
                 incrementalSearch();
-                incrementalSearchTextField.requestFocusInWindow();
             }
         });
         highlightCheckBox.setSelected(getHighlightResults());
@@ -469,12 +526,15 @@ public final class SearchBar extends JPanel {
         expandPopup = new JPopupMenu();
         expandPopup.addPopupMenuListener(new PopupMenuListener() {
 
+            @Override
             public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
             }
 
+            @Override
             public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
             }
 
+            @Override
             public void popupMenuCanceled(PopupMenuEvent e) {
                 // check if it was canceled by click on expand button
                 if (expandButton.getMousePosition() == null) {
@@ -484,19 +544,6 @@ public final class SearchBar extends JPanel {
                 }
             }
         });
-
-        // configure find properties
-        findProps = new HashMap<Object, Object>();
-        findProps.put(EditorFindSupport.FIND_HIGHLIGHT_SEARCH, true);
-        findProps.put(EditorFindSupport.FIND_WHOLE_WORDS, false);
-        findProps.put(EditorFindSupport.FIND_WRAP_SEARCH, true);
-        findProps.put(EditorFindSupport.FIND_BLOCK_SEARCH, false);
-        findProps.put(EditorFindSupport.FIND_BLOCK_SEARCH_START, null);
-        findProps.put(EditorFindSupport.FIND_BLOCK_SEARCH_END, null);
-        // XXX take from preferences
-        findProps.put(EditorFindSupport.FIND_MATCH_CASE, false);
-        findProps.put(EditorFindSupport.FIND_REG_EXP, false);
-        findProps.put(EditorFindSupport.FIND_HIGHLIGHT_SEARCH, true);
         
         // padding at the end of the toolbar
         JPanel spacer = new JPanel();
@@ -543,16 +590,36 @@ public final class SearchBar extends JPanel {
         });
     }
     
+    // From org.netbeans.modules.editor.settings.storage.EditorSettingsImpl
+    private static final String DEFAULT_PROFILE = "NetBeans"; //NOI18N
+    private static final String FATTR_CURRENT_KEYMAP_PROFILE = "currentKeymap";      // NOI18N
+    private static final String KEYMAPS_FOLDER = "Keymaps"; // NOI18N
+    
+    /* This method is verbatim copy from class
+     * org.netbeans.modules.editor.settings.storage.EditorSettingsImpl
+     * bacause we don't want to introduce the dependency between this module
+     * and Editor Setting Storage module.
+     */
+    private String getCurrentKeyMapProfile () {
+        String currentKeyMapProfile = null;
+        FileObject fo = FileUtil.getConfigFile (KEYMAPS_FOLDER);
+        if (fo != null) {
+            Object o = fo.getAttribute (FATTR_CURRENT_KEYMAP_PROFILE);
+            if (o instanceof String) {
+                currentKeyMapProfile = (String) o;
+            }
+        }
+        if (currentKeyMapProfile == null) {
+            currentKeyMapProfile = DEFAULT_PROFILE;
+        }
+        return currentKeyMapProfile;
+    }    
     private void makeBarExpandable() {
-//        inBar.add(findPreviousButton);
-//        inBar.add(findNextButton);
         inBar.add(matchCaseCheckBox);
         inBar.add(wholeWordsCheckBox);
         inBar.add(regexpCheckBox);
         inBar.add(highlightCheckBox);
-        for (Component c : this.getComponents()) {
-            barOrder.add(c);
-        }
+        barOrder.addAll(Arrays.asList(this.getComponents()));
         remove(expandButton);
     }
     
@@ -641,6 +708,9 @@ public final class SearchBar extends JPanel {
     }
     
     private void gainFocus() {
+        FindSupport findSupport = FindSupport.getFindSupport();
+        findProps = new HashMap<Object, Object>(findSupport.getFindProperties());
+
         if (isVisible()) {
             incrementalSearchTextField.requestFocusInWindow();
             return;
@@ -662,22 +732,28 @@ public final class SearchBar extends JPanel {
             findPreviousButton.setEnabled(false);
             findNextButton.setEnabled(false);
         }
+        wholeWordsCheckBox.setSelected(getWholeWords());
+        wholeWordsCheckBox.setEnabled(!getRegExp());
+        matchCaseCheckBox.setSelected(getMatchCase());
+        regexpCheckBox.setSelected(getRegExp());
+        highlightCheckBox.setSelected(getHighlightResults());
+        searched = false;
     }
 
     private void looseFocus() {
+        if (!isVisible()) {
+            return;
+        }
         if (isPopupGoingToShow) {
             isPopupGoingToShow = false;
             return;
         }
         
-        if (navigateOnFocusLost) {
-            findNext();
-        }
-        
         org.netbeans.editor.Utilities.setStatusText(component, "");
         FindSupport.getFindSupport().setBlockSearchHighlight(0, 0);
         FindSupport.getFindSupport().incSearchReset();
         setVisible(false);
+        component.requestFocusInWindow();
     }
 
     private void incrementalSearch() {
@@ -728,13 +804,11 @@ public final class SearchBar extends JPanel {
             if (findSupport.incSearch(findProps, caretPosition) || empty) {
                 // text found - reset incremental search text field's foreground
                 incrementalSearchTextField.setForeground(UIManager.getColor("textText")); //NOI18N
-                navigateOnFocusLost = !empty;
                 org.netbeans.editor.Utilities.setStatusText(component, "", StatusDisplayer.IMPORTANCE_INCREMENTAL_FIND);
             } else {
                 // text not found - indicate error in incremental search
                 // text field with red foreground
                 incrementalSearchTextField.setForeground(NOT_FOUND);
-                navigateOnFocusLost = false;
                 org.netbeans.editor.Utilities.setStatusText(component, NbBundle.getMessage(
                     SearchBar.class, "incremental-search-not-found", incrementalSearchText),
                     StatusDisplayer.IMPORTANCE_INCREMENTAL_FIND); //NOI18N
@@ -783,22 +857,16 @@ public final class SearchBar extends JPanel {
         if (findSupport.find(findProps, !next) || empty) {
             // text found - reset incremental search text field's foreground
             incrementalSearchTextField.setForeground(UIManager.getColor("textText")); //NOI18N
+            searched = true;
         } else {
             // text not found - indicate error in incremental search text field with red foreground
             incrementalSearchTextField.setForeground(NOT_FOUND);
             Toolkit.getDefaultToolkit().beep();
         }
-        navigateOnFocusLost = false;
     }
 
     private void processButton(AbstractButton button) {
-        button.setContentAreaFilled(false);
-        button.setBorderPainted(false);
         button.setMargin(BUTTON_INSETS);
-        if (button instanceof JButton) {
-            button.addMouseListener(sharedMouseListener);
-        }
-        button.setFocusable(false);
     }
     
     @SuppressWarnings("unchecked")
@@ -868,6 +936,7 @@ public final class SearchBar extends JPanel {
      * Factory for creating the incremental search sidebar
      */
     public static final class Factory implements SideBarFactory {
+        @Override
         public JComponent createSideBar(JTextComponent target) {
             return new SearchBar(target);
         }
@@ -882,6 +951,7 @@ public final class SearchBar extends JPanel {
             putValue(SHORT_DESCRIPTION, NbBundle.getMessage(IncrementalSearchForwardAction.class, INCREMENTAL_SEARCH_FORWARD));
         }
         
+        @Override
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
             if (target != null) {
                 EditorUI eui = org.netbeans.editor.Utilities.getEditorUI(target);
@@ -909,6 +979,7 @@ public final class SearchBar extends JPanel {
             putValue(SHORT_DESCRIPTION, NbBundle.getMessage(IncrementalSearchBackwardAction.class, INCREMENTAL_SEARCH_BACKWARD));
         }
         
+        @Override
         public void actionPerformed(ActionEvent evt, JTextComponent target) {
             if (target != null) {
                 EditorUI eui = org.netbeans.editor.Utilities.getEditorUI(target);
@@ -944,46 +1015,40 @@ public final class SearchBar extends JPanel {
         }
         return null;
     }
-    
-    // preferences
-    private static final String IS_HIGHLIGHT_RESULTS = "isHighlightResults";
-    private static final String IS_REG_EXP = "isRegExp";
-    private static final String IS_MATCH_CASE = "isMatchCase";
-    private static final String IS_WHOLE_WORDS = "isWholeWords";
-    
-    private Preferences prefs() {
-        return NbPreferences.forModule(SearchBar.class);
-    }
-    
+
     private boolean getMatchCase() {
-        return prefs().getBoolean(IS_MATCH_CASE, false); // NOI18N 
+        Boolean b = (Boolean)findProps.get(EditorFindSupport.FIND_MATCH_CASE);
+        return b != null ? b.booleanValue() : false;
     }
-    
+
     private void switchMatchCase() {
-        prefs().putBoolean(IS_MATCH_CASE, !getMatchCase());
+        findProps.put(EditorFindSupport.FIND_MATCH_CASE, !getMatchCase());
     }
-    
+
     private boolean getWholeWords() {
-        return prefs().getBoolean(IS_WHOLE_WORDS, false); // NOI18N 
+        Boolean b = (Boolean)findProps.get(EditorFindSupport.FIND_WHOLE_WORDS);
+        return b != null ? b.booleanValue() : false;
     }
-    
+
     private void switchWholeWords() {
-        prefs().putBoolean(IS_WHOLE_WORDS, !getWholeWords());
+        findProps.put(EditorFindSupport.FIND_MATCH_CASE, !getWholeWords());
     }
-    
+
     private boolean getRegExp() {
-        return prefs().getBoolean(IS_REG_EXP, false); // NOI18N 
+        Boolean b = (Boolean)findProps.get(EditorFindSupport.FIND_REG_EXP);
+        return b != null ? b.booleanValue() : false;
     }
-    
+
     private void switchRegExp() {
-        prefs().putBoolean(IS_REG_EXP, !getRegExp());
+        findProps.put(EditorFindSupport.FIND_MATCH_CASE, !getRegExp());
     }
-    
+
     private boolean getHighlightResults() {
-        return prefs().getBoolean(IS_HIGHLIGHT_RESULTS, true); // NOI18N 
+        Boolean b = (Boolean)findProps.get(EditorFindSupport.FIND_HIGHLIGHT_SEARCH);
+        return b != null ? b.booleanValue() : false;
     }
-    
+
     private void switchHighlightResults() {
-        prefs().putBoolean(IS_HIGHLIGHT_RESULTS, !getHighlightResults());
-    }  
+        findProps.put(EditorFindSupport.FIND_MATCH_CASE, !getHighlightResults());
+    }
 }
