@@ -53,6 +53,7 @@ import org.netbeans.api.editor.mimelookup.MimeLookup;
 import org.netbeans.api.editor.mimelookup.MimePath;
 import org.netbeans.spi.editor.mimelookup.Class2LayerFolder;
 import org.netbeans.spi.editor.mimelookup.InstanceProvider;
+import org.netbeans.spi.editor.mimelookup.MimeLocation;
 import org.openide.filesystems.FileObject;
 import org.openide.loaders.DataObject;
 
@@ -60,12 +61,12 @@ import org.openide.loaders.DataObject;
  *
  * @author Vita Stejskal
  */
-@org.openide.util.lookup.ServiceProvider(service=org.netbeans.spi.editor.mimelookup.Class2LayerFolder.class)
-public final class ToolbarActionsProvider extends ActionsList implements Class2LayerFolder<ToolbarActionsProvider>, InstanceProvider<ToolbarActionsProvider> {
+@MimeLocation(subfolderName=ToolbarActionsProvider.TOOLBAR_ACTIONS_FOLDER_NAME, instanceProviderClass=ToolbarActionsProvider.class)
+public final class ToolbarActionsProvider extends ActionsList implements InstanceProvider<ToolbarActionsProvider> {
 
     private static final Logger LOG = Logger.getLogger(ToolbarActionsProvider.class.getName());
     
-    private static final String TOOLBAR_ACTIONS_FOLDER_NAME = "Toolbars/Default"; //NOI18N
+    static final String TOOLBAR_ACTIONS_FOLDER_NAME = "Toolbars/Default"; //NOI18N
     private static final String TEXT_BASE_PATH = "Editors/text/base/"; //NOI18N
     
     public static List getToolbarItems(String mimeType) {
@@ -87,18 +88,6 @@ public final class ToolbarActionsProvider extends ActionsList implements Class2L
         super(keys, true, false);
     }
     
-    public Class<ToolbarActionsProvider> getClazz(){
-        return ToolbarActionsProvider.class;
-    }
-
-    public String getLayerFolderName(){
-        return TOOLBAR_ACTIONS_FOLDER_NAME;
-    }
-
-    public InstanceProvider<ToolbarActionsProvider> getInstanceProvider() {
-        return new ToolbarActionsProvider();
-    }
-    
     public ToolbarActionsProvider createInstance(List<FileObject> fileObjectList) {
         return new ToolbarActionsProvider(fileObjectList);
     }
@@ -106,8 +95,8 @@ public final class ToolbarActionsProvider extends ActionsList implements Class2L
     // XXX: This is here to help NbEditorToolbar to deal with legacy code
     // that registered toolbar actions in text/base. The artificial text/base
     // mime type is deprecated and should not be used anymore.
-    @org.openide.util.lookup.ServiceProvider(service=org.netbeans.spi.editor.mimelookup.Class2LayerFolder.class)
-    public static final class LegacyToolbarActionsProvider extends ActionsList implements Class2LayerFolder<LegacyToolbarActionsProvider>, InstanceProvider<LegacyToolbarActionsProvider> {
+    @MimeLocation(subfolderName=TOOLBAR_ACTIONS_FOLDER_NAME, instanceProviderClass=LegacyToolbarActionsProvider.class)
+    public static final class LegacyToolbarActionsProvider extends ActionsList implements InstanceProvider<LegacyToolbarActionsProvider> {
 
         public LegacyToolbarActionsProvider() {
             this(null);
@@ -117,18 +106,6 @@ public final class ToolbarActionsProvider extends ActionsList implements Class2L
             super(keys, false, false);
         }
 
-        public Class<LegacyToolbarActionsProvider> getClazz(){
-            return LegacyToolbarActionsProvider.class;
-        }
-
-        public String getLayerFolderName(){
-            return TOOLBAR_ACTIONS_FOLDER_NAME;
-        }
-
-        public InstanceProvider<LegacyToolbarActionsProvider> getInstanceProvider() {
-            return new LegacyToolbarActionsProvider();
-        }
-
         public LegacyToolbarActionsProvider createInstance(List<FileObject> fileObjectList) {
             ArrayList<FileObject> textBaseFilesList = new ArrayList<FileObject>();
 
