@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -457,14 +460,20 @@ public final class ExecutionService {
      * @param inputOutput output window to configure
      */
     private void configureInputOutput(InputOutput inputOutput) {
-        try {
-            inputOutput.getOut().reset();
-        } catch (IOException exc) {
-            LOGGER.log(Level.INFO, null, exc);
+        if (inputOutput == InputOutput.NULL) {
+            return;
         }
 
-        // Note - do this AFTER the reset() call above; if not, weird bugs occur
-        inputOutput.setErrSeparated(false);
+        if (descriptor.getInputOutput() == null || !descriptor.noReset()) {
+            try {
+                inputOutput.getOut().reset();
+            } catch (IOException exc) {
+                LOGGER.log(Level.INFO, null, exc);
+            }
+
+            // Note - do this AFTER the reset() call above; if not, weird bugs occur
+            inputOutput.setErrSeparated(false);
+        }
 
         // Open I/O window now. This should probably be configurable.
         if (descriptor.isFrontWindow()) {
