@@ -44,25 +44,24 @@
 
 package org.netbeans.modules.favorites;
 
-import java.awt.Image;
-import java.awt.event.ActionEvent;
+import java.awt.EventQueue;
 import java.beans.PropertyVetoException;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import javax.swing.AbstractAction;
 import javax.swing.Action;
-import javax.swing.ImageIcon;
 import javax.swing.JFileChooser;
-import javax.swing.JMenuItem;
 import javax.swing.SwingUtilities;
-import org.netbeans.modules.favorites.api.Favorites;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
+import org.openide.awt.ActionID;
+import org.openide.awt.ActionReference;
+import org.openide.awt.ActionRegistration;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileStateInvalidException;
 import org.openide.filesystems.FileUtil;
@@ -70,12 +69,12 @@ import org.openide.filesystems.URLMapper;
 import org.openide.loaders.DataFolder;
 import org.openide.loaders.DataObject;
 import org.openide.loaders.DataObjectNotFoundException;
+import org.openide.loaders.DataShadow;
 import org.openide.nodes.Node;
+import org.openide.util.ContextAwareAction;
 import org.openide.util.HelpCtx;
-import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.actions.NodeAction;
-import org.openide.windows.TopComponent;
 import org.openide.windows.WindowManager;
 
 /** List of all actions available for Favorites module.
@@ -93,43 +92,21 @@ public final class Actions extends Object {
         // noinstances
     }
     
-    public static Action view () { return View.getDefault(); }
-    public static Action add () { return Add.getDefault(); }
-    public static Action addOnFavoritesNode () { return AddOnFavoritesNode.getDefault(); }
-    public static Action remove () { return Remove.getDefault(); }
-    public static Action select () { return Select.getDefault(); }
-    
-    /**
-     * Action which opend <code>CurrentProjectNode.ProjectsTab</code> default component.
-     *
-     * @author  Peter Zavadsky
-     */
-    private static class View extends AbstractAction implements HelpCtx.Provider {
-        
-        private static final View VIEW = new View ();
-        
-        public View() {
-            putValue(NAME, NbBundle.getMessage(Actions.class,
-                    "ACT_View"));
-            Image image = ImageUtilities.loadImage("org/netbeans/modules/favorites/resources/actionView.png"); // NOI18N
-            putValue(SMALL_ICON, image != null ? new ImageIcon(image) : null);
-        }
-        
-        public static Action getDefault () {
-            return VIEW;
-        }
-        
-        public void actionPerformed(ActionEvent evt) {
-            final TopComponent projectsTab = Tab.findDefault();
-            projectsTab.open();
-            projectsTab.requestActive();
-        }
+    @ActionID(id = "org.netbeans.modules.favorites.Add", category = "Window")
+    @ActionRegistration(displayName = "#ACT_Add")
+    @ActionReference(position = 300, path = "UI/ToolActions/Files")
+    public static ContextAwareAction add() { return Add.getDefault(); }
 
-        public HelpCtx getHelpCtx() {
-            return new HelpCtx(View.class);
-        }
-    } // end of View
-    
+    public static Action addOnFavoritesNode () { return AddOnFavoritesNode.getDefault(); }
+
+    @ActionID(id = "org.netbeans.modules.favorites.Remove", category = "Window")
+    @ActionRegistration(displayName = "#ACT_Remove")
+    public static Action remove () { return Remove.getDefault(); }
+
+    @ActionID(id = "org.netbeans.modules.favorites.Select", category = "Window/SelectDocumentNode")
+    @ActionRegistration(displayName = "#ACT_Select_Main_Menu")
+    @ActionReference(position = 2800, name = "org-netbeans-modules-favorites-SelectInFavorites", path = "Menu/GoTo")
+    public static ContextAwareAction select () { return Select.getDefault(); }
     
     /** An action which selects activated nodes in the Explorer's tab.
     * @author   Dusan Balek
@@ -137,7 +114,7 @@ public final class Actions extends Object {
     private static class Select extends NodeAction {
         private static final Select SELECT = new Select ();
         
-        public static Action getDefault () {
+        public static ContextAwareAction getDefault () {
             return SELECT;
         }
         
@@ -146,13 +123,18 @@ public final class Actions extends Object {
             putValue("noIconInMenu", Boolean.TRUE); //NOI18N
         }
         
-        protected void performAction(Node[] activatedNodes) {
-            Tab proj = Tab.findDefault();
-            proj.open();
-            proj.requestActive();
-            proj.doSelectNode(activatedNodes[0].getCookie(DataObject.class));
+        @Override
+        protected void performAction(final Node[] activatedNodes) {
+            final Tab proj = Tab.findDefault();
+            Tab.RP.post(new Runnable() {
+                @Override
+                public void run() {
+                    proj.doSelectNode(activatedNodes[0].getCookie(DataObject.class));
+                }
+            });
         }
 
+        @Override
         protected boolean enable(Node[] activatedNodes) {
             if (activatedNodes.length != 1) {
                 return false;
@@ -165,23 +147,17 @@ public final class Actions extends Object {
             /*return Tab.findDefault().containsNode(dobj);*/
           }
 
+        @Override
         public String getName() {
             return NbBundle.getMessage(Select.class, "ACT_Select_Main_Menu"); // NOI18N
         }
 
-        /** Overriden to have different title in popup menu, works but ugly a bit */
-        @Override
-        public JMenuItem getPopupPresenter() {
-            JMenuItem mi = super.getPopupPresenter();
-            mi.setText(NbBundle.getMessage(Select.class, "ACT_Select")); // NOI18N
-            return mi;
-        }
-
         @Override
         protected String iconResource() {
             return "org/netbeans/modules/favorites/resources/actionView.png"; // NOI18N
         }
 
+        @Override
         public HelpCtx getHelpCtx() {
             return null;
         }
@@ -209,6 +185,7 @@ public final class Actions extends Object {
         
         /** Enabled only if the current project is ProjectDataObject.
         */
+        @Override
         public boolean enable (Node[] arr) {
             if ((arr == null) || (arr.length == 0)) return false;
 
@@ -226,6 +203,7 @@ public final class Actions extends Object {
         * presented as an item in a menu.
         * @return the name of the action
         */
+        @Override
         public String getName() {
             return NbBundle.getMessage (
                     Actions.class, "ACT_Remove"); // NOI18N
@@ -234,6 +212,7 @@ public final class Actions extends Object {
         /** Help context where to find more about the action.
         * @return the help context for this action
         */
+        @Override
         public HelpCtx getHelpCtx() {
             return new HelpCtx(Remove.class);
         }
@@ -243,6 +222,7 @@ public final class Actions extends Object {
         *
         * @param arr gives array of actually activated nodes.
         */
+        @Override
         protected void performAction (Node[] arr) {
             for (int i = 0; i < arr.length; i++) {
                 DataObject shad = arr[i].getCookie(DataObject.class);
@@ -276,7 +256,7 @@ public final class Actions extends Object {
         //  static final long serialVersionUID = -5280204757097896304L;
         private static final Add ADD = new Add ();
         
-        public static Action getDefault () {
+        public static ContextAwareAction getDefault() {
             return ADD;
         }
         
@@ -286,6 +266,7 @@ public final class Actions extends Object {
         
         /** Enabled only if the current project is ProjectDataObject.
         */
+        @Override
         public boolean enable (Node[] arr) {
             if ((arr == null) || (arr.length == 0)) return false;
             if (arr.length == 1 && arr[0] instanceof FavoritesNode) return true;
@@ -304,6 +285,7 @@ public final class Actions extends Object {
         * presented as an item in a menu.
         * @return the name of the action
         */
+        @Override
         public String getName() {
             return NbBundle.getMessage (
                     Actions.class, "ACT_Add"); // NOI18N
@@ -312,6 +294,7 @@ public final class Actions extends Object {
         /** Help context where to find more about the action.
         * @return the help context for this action
         */
+        @Override
         public HelpCtx getHelpCtx() {
             return new HelpCtx(Add.class);
         }
@@ -321,10 +304,10 @@ public final class Actions extends Object {
         *
         * @param activatedNodes gives array of actually activated nodes.
         */
+        @Override
         protected void performAction (final Node[] activatedNodes) {
-            List<DataObject> toShadows;
-
             try {
+                final List<DataObject> toShadows;
                 if (activatedNodes.length == 1 && activatedNodes[0] instanceof FavoritesNode) {
                     // show JFileChooser
                     FileObject fo = chooseFileObject();
@@ -338,7 +321,12 @@ public final class Actions extends Object {
                             toShadows.add(obj);
                     }
                 }
-                addToFavorites(toShadows);
+                Tab.RP.post(new Runnable () {
+                    @Override
+                    public void run() {
+                        addToFavorites(toShadows);
+                    }
+                });
             } catch (DataObjectNotFoundException e) {
                 LOG.log(Level.WARNING, null, e);
             }
@@ -406,6 +394,7 @@ public final class Actions extends Object {
                 }
                 if (setSelected) {
                     SwingUtilities.invokeLater(new Runnable () {
+                        @Override
                         public void run() {
                             try {
                                 projectsTab.getExplorerManager().setExploredContextAndSelection(toSelect[0],toSelect);
@@ -422,12 +411,19 @@ public final class Actions extends Object {
             DataObject createdDO = null;
             for (DataObject obj : dos) {
                 try {
-                    if (createdDO == null) {
-                        // Select only first node in array added to favorites
-                        createdDO = obj.createShadow(favourities);
-                        listAdd.add(createdDO);
+                    DataShadow added = findShadow(favourities, obj);
+                    if (added != null) {
+                        if (createdDO == null) {
+                            createdDO = added;
+                        }
                     } else {
-                        listAdd.add(obj.createShadow(favourities));
+                        if (createdDO == null) {
+                            // Select only first node in array added to favorites
+                            createdDO = obj.createShadow(favourities);
+                            listAdd.add(createdDO);
+                        } else {
+                            listAdd.add(obj.createShadow(favourities));
+                        }
                     }
                 } catch (IOException ex) {
                     LOG.log(Level.WARNING, null, ex);
@@ -436,6 +432,22 @@ public final class Actions extends Object {
             return createdDO;
         }
 
+        private static DataShadow findShadow (DataFolder f, DataObject dobj) {
+            FileObject fo = dobj.getPrimaryFile();
+            if (fo != null) {
+                DataObject [] arr = f.getChildren();
+                for (int i = 0; i < arr.length; i++) {
+                    if (arr[i] instanceof DataShadow) {
+                        DataShadow obj = (DataShadow) arr[i];
+                        if (fo.equals(obj.getOriginal().getPrimaryFile())) {
+                            return obj;
+                        }
+                    }
+                }
+            }
+            return null;
+        }
+
         public static void reorderAfterAddition(final DataFolder favourities, final DataObject[] children, final List<? extends DataObject> listAdd) {
             List<DataObject> listDest = new ArrayList<DataObject>();
             if (listAdd.size() > 0) {
@@ -457,10 +469,7 @@ public final class Actions extends Object {
                     listDest.addAll(listAdd);
                     listDest.add(root);
                 } else {
-                    //Root not found. It should not happen because root is defined in layer
-                    for (int i = 0; i < children.length; i++) {
-                        listDest.add(children[i]);
-                    }
+                    listDest.addAll(Arrays.asList(children));
                     listDest.addAll(listAdd);
                 }
                 //Set desired order
@@ -479,13 +488,19 @@ public final class Actions extends Object {
         }
 
         static void addToFavorites(List<DataObject> toShadows) {
+            assert !EventQueue.isDispatchThread();
             final DataFolder f = FavoritesNode.getFolder();
             final DataObject[] arr = f.getChildren();
             final List<DataObject> listAdd = new ArrayList<DataObject>();
-            DataObject createdDO = createShadows(f, toShadows, listAdd);
+            final DataObject toSelect = createShadows(f, toShadows, listAdd);
             //This is done to set desired order of nodes in view
             reorderAfterAddition(f, arr, listAdd);
-            selectAfterAddition(createdDO);
+            EventQueue.invokeLater(new Runnable () {
+                @Override
+                public void run () {
+                    selectAfterAddition(toSelect);
+                }
+            });
         }
 
         static boolean isAllowed(DataObject dataObject) {
@@ -499,10 +514,6 @@ public final class Actions extends Object {
                 if (URLMapper.findURL(fo, URLMapper.EXTERNAL) == null) {
                     return false;
                 }
-                //Allow to link only once
-                if (Favorites.getDefault().isInFavorites(fo)) {
-                    return false;
-                }
                 //Check if it is root.
                 File file = FileUtil.toFile(fo);
                 if (file != null) {
@@ -534,7 +545,7 @@ public final class Actions extends Object {
         
         private static final AddOnFavoritesNode ADD_ON_FAVORITES_NODE = new AddOnFavoritesNode ();
         
-        public static Action getDefault () {
+        public static ContextAwareAction getDefault () {
             return ADD_ON_FAVORITES_NODE;
         }
         
