@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,10 +44,7 @@
 
 package org.netbeans.modules.favorites;
 
-import java.awt.Image;
-import java.awt.datatransfer.DataFlavor;
 import java.awt.datatransfer.Transferable;
-import java.awt.dnd.DnDConstants;
 import java.io.File;
 import java.io.IOException;
 import java.net.MalformedURLException;
@@ -74,7 +74,6 @@ import org.openide.nodes.Index;
 import org.openide.nodes.Node;
 import org.openide.util.ChangeSupport;
 import org.openide.util.Exceptions;
-import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.datatransfer.PasteType;
 
@@ -85,8 +84,6 @@ import org.openide.util.datatransfer.PasteType;
 public final class FavoritesNode extends FilterNode implements Index {
     /** default node */
     private static Node node;
-    /** node that represents root of filesystems */
-    private static Node root;
 
     /** Creates new ProjectRootFilterNode. */
     private FavoritesNode(Node node) {
@@ -118,6 +115,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
     
+    @Override
     public int getNodesCount() {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -127,6 +125,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
     
+    @Override
     public Node[] getNodes() {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -136,6 +135,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }        
     }
 
+    @Override
     public int indexOf(final Node node) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -152,6 +152,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }                
     }
 
+    @Override
     public void reorder() {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -159,6 +160,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void reorder(int[] perm) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -166,6 +168,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void move(int x, int y) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -173,6 +176,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void exchange(int x, int y) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -180,6 +184,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void moveUp(int x) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -187,6 +192,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void moveDown(int x) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -194,6 +200,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void addChangeListener(final ChangeListener chl) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -201,6 +208,7 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
 
+    @Override
     public void removeChangeListener(final ChangeListener chl) {
         Index ind = getOriginal().getCookie(Index.class);
         if (ind != null) {
@@ -208,16 +216,6 @@ public final class FavoritesNode extends FilterNode implements Index {
         }
     }
     
-    @Override
-    public Image getIcon (int type) {
-        return ImageUtilities.loadImage("org/netbeans/modules/favorites/resources/actionSelect.png"); // NOI18N
-    }
-    
-    @Override
-    public Image getOpenedIcon (int type) {
-        return ImageUtilities.loadImage("org/netbeans/modules/favorites/resources/actionSelect.png"); // NOI18N
-    }
-    
     @Override
     public boolean canCopy () {
         return false;
@@ -295,6 +293,7 @@ public final class FavoritesNode extends FilterNode implements Index {
 
         /** Return a node for the current project.
         */
+        @Override
         public Node getNode () {
             return FavoritesNode.getNode ();
         }
@@ -314,22 +313,27 @@ public final class FavoritesNode extends FilterNode implements Index {
             VisibilityQuery.getDefault().addChangeListener(weak);
         }
         
+        @Override
         public boolean acceptFileObject(FileObject fo) {
             return VisibilityQuery.getDefault().isVisible(fo);
         }
 
+        @Override
         public boolean acceptDataObject(DataObject obj) {
             return acceptFileObject(obj.getPrimaryFile());
         }
 
+        @Override
         public void addChangeListener(ChangeListener listener) {
             support.addChangeListener(listener);
         }
 
+        @Override
         public void removeChangeListener(ChangeListener listener) {
             support.removeChangeListener(listener);
         }
 
+        @Override
         public void stateChanged(ChangeEvent e) {
             support.fireChange();
         }
@@ -409,10 +413,20 @@ public final class FavoritesNode extends FilterNode implements Index {
             }
         }
         
-        // Must be overridden since getDisplayName is.
         @Override
         public String getHtmlDisplayName() {
-            return getOriginal().getHtmlDisplayName();
+            if (FavoritesNode.getNode().equals(this.getParentNode())) {
+                DataShadow ds = getCookie(DataShadow.class);
+                if (ds != null) {
+                    String name = ds.getName();
+                    String path = FileUtil.getFileDisplayName(ds.getOriginal().getPrimaryFile());
+                    return NbBundle.getMessage(FavoritesNode.class, "CTL_DisplayNameTemplateHtml", name, path); //NOI18N
+                } else {
+                    return super.getDisplayName();
+                }
+            } else {
+                return getOriginal().getHtmlDisplayName();
+            }
         }
         
         @Override
@@ -608,7 +622,12 @@ public final class FavoritesNode extends FilterNode implements Index {
 
         @Override
         public Transferable paste() throws IOException {
-            Actions.Add.addToFavorites(Arrays.asList(dos));
+            Tab.RP.post(new Runnable () {
+                @Override
+                public void run() {
+                    Actions.Add.addToFavorites(Arrays.asList(dos));
+                }
+            });
             return null;
         }
 
