@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -42,34 +45,41 @@
 package org.netbeans.modules.favorites;
 
 import java.awt.BorderLayout;
-import java.beans.BeanInfo;
+import java.awt.EventQueue;
+import java.awt.Rectangle;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyVetoException;
 import java.io.File;
 import java.io.ObjectStreamException;
-import java.util.ArrayList;
-import java.util.List;
+import java.util.Collections;
 import java.util.Stack;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.ActionMap;
 import javax.swing.JFileChooser;
-import javax.swing.SwingUtilities;
 import javax.swing.text.DefaultEditorKit;
+import javax.swing.tree.DefaultTreeModel;
+import javax.swing.tree.TreeModel;
+import javax.swing.tree.TreeNode;
+import javax.swing.tree.TreePath;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
+import org.openide.awt.ActionID;
+import org.openide.awt.ActionReference;
 import org.openide.awt.StatusDisplayer;
 import org.openide.explorer.ExplorerManager;
 import org.openide.explorer.ExplorerUtils;
 import org.openide.explorer.view.BeanTreeView;
 import org.openide.explorer.view.TreeView;
+import org.openide.explorer.view.Visualizer;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
-import org.openide.loaders.DataFolder;
 import org.openide.loaders.DataObject;
 import org.openide.loaders.DataObjectNotFoundException;
 import org.openide.loaders.DataShadow;
+import org.openide.nodes.AbstractNode;
+import org.openide.nodes.Children;
 import org.openide.nodes.Node;
 import org.openide.nodes.NodeEvent;
 import org.openide.nodes.NodeListener;
@@ -78,6 +88,7 @@ import org.openide.nodes.NodeOp;
 import org.openide.nodes.NodeReorderEvent;
 import org.openide.util.HelpCtx;
 import org.openide.util.NbBundle;
+import org.openide.util.RequestProcessor;
 import org.openide.util.WeakListeners;
 import org.openide.windows.TopComponent;
 import org.openide.windows.WindowManager;
@@ -85,16 +96,15 @@ import org.openide.windows.WindowManager;
 /**
  * Physical tree view showing list of favorites.
  */
+@TopComponent.Description(preferredID="favorites", persistenceType=TopComponent.PERSISTENCE_ALWAYS, iconBase="org/netbeans/modules/favorites/resources/actionView.png")
 public class Tab extends TopComponent
 implements Runnable, ExplorerManager.Provider {
     static final long serialVersionUID =-8178367548546385799L;
-
-    /** data object which should be selected in EQ; synch array when accessing */
-    private static final DataObject[] needToSelect = new DataObject[1];
+    static final RequestProcessor RP = new RequestProcessor("Favorites", 1); //NOI18N
 
     private static final Logger LOG = Logger.getLogger(Tab.class.getName());
 
-    private static transient Tab DEFAULT;
+    /* private */ static transient Tab DEFAULT; // package-private for unit tests
 
     /** composited view */
     transient protected TreeView view;
@@ -127,16 +137,11 @@ implements Runnable, ExplorerManager.Provider {
         return new HelpCtx(Tab.class);
     }
     
+    @Override
     public ExplorerManager getExplorerManager() {
         return manager;
     }
     
-    /** Return preferred ID */
-    @Override
-    protected String preferredID () {
-        return "favorites"; //NOI18N
-    }
-    
     /** Initialize visual content of component */
     @Override
     protected void componentShowing () {
@@ -161,13 +166,13 @@ implements Runnable, ExplorerManager.Provider {
     * @return Tree view that will serve as main view for this explorer.
     */
     protected TreeView initGui () {
-        TreeView view = new BeanTreeView();
-        view.setRootVisible(false);
-        view.setDragSource (true);
-        view.setUseSubstringInQuickSearch(true);
+        TreeView tView = new MyBeanTreeView();
+        tView.setRootVisible(false);
+        tView.setDragSource (true);
+        tView.setUseSubstringInQuickSearch(true);
         setLayout(new BorderLayout());
-        add (view);
-        return view;
+        add (tView);
+        return tView;
     }
 
     @Override
@@ -199,7 +204,7 @@ implements Runnable, ExplorerManager.Provider {
         }
     }
 
-    /** Sets new root context to view. Name, icon, tooltip
+    /** Sets new root context to view. Name,  tooltip
     * of this top component will be updated properly */
     public void setRootContext (Node rc) {
         Node oldRC = getExplorerManager().getRootContext();
@@ -220,8 +225,9 @@ implements Runnable, ExplorerManager.Provider {
 
     /** Implementation of DeferredPerformer.DeferredCommand
     * Performs initialization of component's attributes
-    * after deserialization (component's name, icon etc, 
+    * after deserialization (component's name, etc, 
     * according to the root context) */
+    @Override
     public void run() {
         if (!valid) {
             valid = true;
@@ -251,7 +257,6 @@ implements Runnable, ExplorerManager.Provider {
     * obtained from specified root context node */
     private void initializeWithRootContext (Node rc) {
         // update TC's attributes
-        setIcon(rc.getIcon(BeanInfo.ICON_COLOR_16x16));
         setToolTipText(rc.getDisplayName());
         setName(rc.getDisplayName());
         updateTitle();
@@ -277,8 +282,8 @@ implements Runnable, ExplorerManager.Provider {
     // deserialization, so we must wait for it
     protected final void scheduleValidation() {
         valid = false;
-//            WindowManagerImpl.deferredPerformer().putRequest(this, null);
-        SwingUtilities.invokeLater(this); // TEMP
+        // initialize
+        RP.post(this, 100);
     }
 
     /* Updated accessible name of the tree view */
@@ -300,9 +305,10 @@ implements Runnable, ExplorerManager.Provider {
     }
 
     /** Multi - purpose listener, listens to: <br>
-    * 1) Changes of name, icon, short description of root context.
+    * 1) Changes of name, short description of root context.
     * 2) Changes of IDE settings, namely delete confirmation settings */
     private final class RootContextListener implements NodeListener {
+        @Override
         public void propertyChange (PropertyChangeEvent evt) {
             String propName = evt.getPropertyName();
             Object source = evt.getSource();
@@ -312,26 +318,29 @@ implements Runnable, ExplorerManager.Provider {
             if (Node.PROP_DISPLAY_NAME.equals(propName) ||
                     Node.PROP_NAME.equals(propName)) {
                 setName(n.getDisplayName());
-            } else if (Node.PROP_ICON.equals(propName)) {
-                setIcon(n.getIcon(BeanInfo.ICON_COLOR_16x16));
             } else if (Node.PROP_SHORT_DESCRIPTION.equals(propName)) {
                 setToolTipText(n.getShortDescription());
             }
         }
 
+        @Override
         public void nodeDestroyed(NodeEvent nodeEvent) {
             //Tab.this.setCloseOperation(TopComponent.CLOSE_EACH);
             Tab.this.close();
         }            
 
+        @Override
         public void childrenRemoved(NodeMemberEvent e) {}
+        @Override
         public void childrenReordered(NodeReorderEvent e) {}
+        @Override
         public void childrenAdded(NodeMemberEvent e) {}
 
     } // end of RootContextListener inner class
 
     /** Gets default instance. Don't use directly, it reserved for deserialization routines only,
      * e.g. '.settings' file in xml layer, otherwise you can get non-deserialized instance. */
+    @Registration(mode="explorer", openAtStartup=false, position=300)
     public static synchronized Tab getDefault() {
         if (DEFAULT == null) {
             DEFAULT = new Tab();
@@ -346,6 +355,9 @@ implements Runnable, ExplorerManager.Provider {
     }
 
     /** Finds default instance. Use in client code instead of {@link #getDefault()}. */
+    @ActionID(id = "org.netbeans.modules.favorites.View", category = "Window")
+    @OpenActionRegistration(displayName="#ACT_View")
+    @ActionReference(position = 350, path = "Menu/Window")
     public static synchronized Tab findDefault() {
         if(DEFAULT == null) {
             TopComponent tc = WindowManager.getDefault().findTopComponent("favorites"); // NOI18N
@@ -362,13 +374,6 @@ implements Runnable, ExplorerManager.Provider {
         return DEFAULT;
     }
 
-    /** Overriden to explicitely set persistence type of ProjectsTab
-     * to PERSISTENCE_ALWAYS */
-    @Override
-    public int getPersistenceType() {
-        return TopComponent.PERSISTENCE_ALWAYS;
-    }
-    
     // ---- private implementation
     
     /** Finds a node for given data object.
@@ -485,8 +490,21 @@ implements Runnable, ExplorerManager.Provider {
     /** Exchanges deserialized root context to projects root context
     * to keep the uniquennes. */
     protected void validateRootContext () {
-        Node projectsRc = Favorites.getNode ();
-        setRootContext(projectsRc);
+        EventQueue.invokeLater(new Runnable() {
+            @Override
+            public void run () {
+                Node n = new AbstractNode(Children.LEAF);
+                n.setName(NbBundle.getMessage(Tab.class, "MSG_Tab.rootNode.loading")); //NOI18N
+                setRootContext(n);
+            }
+        });
+        final Node projectsRc = FavoritesNode.getNode ();
+        EventQueue.invokeLater(new Runnable() {
+            @Override
+            public void run () {
+                setRootContext(projectsRc);
+            }
+        });
     }
     
     
@@ -496,38 +514,44 @@ implements Runnable, ExplorerManager.Provider {
         return check(node, obj);
     }
 
-    protected void doSelectNode (DataObject obj) {
+    protected void doSelectNode (final DataObject obj) {
         //#142155: For some selected nodes there is no corresponding dataobject
         if (obj == null) {
             return;
         }
-        Node root = getExplorerManager ().getRootContext ();
-        if (selectNode (obj, root)) {
-            requestActive();
-            StatusDisplayer.getDefault().setStatusText(""); // NOI18N
-        } else {
-            StatusDisplayer.getDefault().setStatusText(NbBundle.getMessage(Tab.class,"MSG_NodeNotFound"));
-            FileObject file = chooseFileObject(obj.getPrimaryFile());
-            if (file == null) {
-                return;
+        Node root = getExplorerManager().getRootContext();
+        StatusDisplayer.getDefault().setStatusText(NbBundle.getMessage(Tab.class,"MSG_SearchingForNode"));
+        final boolean selected = selectNode(obj, root);
+        EventQueue.invokeLater(new Runnable() {
+            @Override
+            public void run() {
+                if (selected) {
+                    open();
+                    requestActive();
+                    scrollToSelection();
+                    StatusDisplayer.getDefault().setStatusText(""); // NOI18N
+                } else {
+                    StatusDisplayer.getDefault().setStatusText(NbBundle.getMessage(Tab.class,"MSG_NodeNotFound"));
+                    FileObject file = chooseFileObject(obj.getPrimaryFile());
+                    if (file == null) {
+                        return;
+                    }
+                    open();
+                    requestActive();
+                    try {
+                        final DataObject dobj = DataObject.find(file);
+                        RP.post(new Runnable() {
+                            @Override
+                            public void run() {
+                                Actions.Add.addToFavorites(Collections.singletonList(dobj));
+                            }
+                        });
+                    } catch (DataObjectNotFoundException e) {
+                        LOG.log(Level.WARNING, null, e);
+                    }
+                }
             }
-
-            try {
-                Node[] toShadows = new Node[] {DataObject.find(file).getNodeDelegate()};
-                final DataFolder f = Favorites.getFolder();
-                final DataObject [] arr = f.getChildren();
-                final List<DataObject> listAdd = new ArrayList<DataObject>();
-                DataObject createdDO = null;
-
-                createdDO = Actions.Add.createShadows(f, toShadows, listAdd);
-
-                //This is done to set desired order of nodes in view
-                Actions.Add.reorderAfterAddition(f, arr, listAdd);
-                Actions.Add.selectAfterAddition(createdDO);
-            } catch (DataObjectNotFoundException e) {
-                LOG.log(Level.WARNING, null, e);
-            }
-        }
+        });
     }
 
     /**
@@ -575,5 +599,40 @@ implements Runnable, ExplorerManager.Provider {
         getDefault().scheduleValidation();
         return getDefault();
     }
-    
+
+    private void scrollToSelection() {
+        final Node[] selection = getExplorerManager().getSelectedNodes();
+        if( null == selection || selection.length < 1 )
+            return;
+        if( view instanceof MyBeanTreeView ) {
+            ((MyBeanTreeView)view).scrollNodeToVisible(selection[0]);
+        }
+    }
+
+    private static class MyBeanTreeView extends BeanTreeView {
+        private void scrollNodeToVisible( final Node n ) {
+            EventQueue.invokeLater(new Runnable() {
+
+                @Override
+                public void run() {
+                    TreeNode tn = Visualizer.findVisualizer(n);
+                    if (tn == null) {
+                        return;
+                    }
+                    TreeModel model = tree.getModel();
+                    if (!(model instanceof DefaultTreeModel)) {
+                        return;
+                    }
+                    TreePath path = new TreePath(((DefaultTreeModel) model).getPathToRoot(tn));
+                    if( null == path )
+                        return;
+                    Rectangle r = tree.getPathBounds(path);
+                    if (r != null) {
+                        tree.scrollRectToVisible(r);
+                    }
+                }
+            });
+        }
+    }
+
 } // end of Tab inner class
