@@ -74,6 +74,7 @@ import org.netbeans.api.java.source.CancellableTask;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.TreeMaker;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.api.progress.aggregate.AggregateProgressFactory;
 import org.netbeans.api.project.FileOwnerQuery;
@@ -181,7 +182,7 @@ public class J2EEUtils {
             // The first persistence unit - use EclipseLink provider
             // (it is delivered as a part of NetBeans J2EE support)
             //provider = ProviderUtil.ECLIPSELINK_PROVIDER;
-            provider = ProviderUtil.TOPLINK_PROVIDER;
+            provider = ProviderUtil.TOPLINK_PROVIDER1_0;
         }
 
         unit = ProviderUtil.buildPersistenceUnit(puName, provider, connection, persistence.getVersion());
@@ -190,7 +191,7 @@ public class J2EEUtils {
         // TopLink(Eclipselink may too, TODO: verify)/Derby combination doesn't like empty username and password,
         // but we can use dummy (app/app) values in this case, see issue 121427.
         if ((nullOrEmpty(connection.getUser()) || nullOrEmpty(connection.getPassword()))
-                && (ProviderUtil.TOPLINK_PROVIDER.equals(provider) || ProviderUtil.ECLIPSELINK_PROVIDER.equals(provider))
+                && (ProviderUtil.TOPLINK_PROVIDER1_0.equals(provider) || ProviderUtil.ECLIPSELINK_PROVIDER.equals(provider))
                 && connection.getDriverClass().startsWith("org.apache.derby.jdbc.")) { // NOI18N
             String userPropName = provider.getJdbcUsername();
             String passwdPropName = provider.getJdbcPassword();
@@ -520,7 +521,7 @@ public class J2EEUtils {
         // Make sure that TopLink JAR files are on the classpath (if using TopLink)
         if(ProviderUtil.ECLIPSELINK_PROVIDER.equals(ProviderUtil.getProvider(unit)) || ProviderUtil.ECLIPSELINK_PROVIDER1_0.equals(ProviderUtil.getProvider(unit))) {//the same for eclipselink
             updateProjectForEclipseLink(fileInProject);
-        }    else    if (ProviderUtil.TOPLINK_PROVIDER.equals(ProviderUtil.getProvider(unit))) {
+        }    else    if (ProviderUtil.TOPLINK_PROVIDER1_0.equals(ProviderUtil.getProvider(unit))) {
             updateProjectForTopLink(fileInProject);
         }
 
@@ -762,7 +763,7 @@ public class J2EEUtils {
                     CompilationUnitTree cu = wc.getCompilationUnit();
                     ClassTree clazz = null;
                     for (Tree typeDecl : cu.getTypeDecls()) {
-                        if (Tree.Kind.CLASS == typeDecl.getKind()) {
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(typeDecl.getKind())) {
                             ClassTree candidate = (ClassTree) typeDecl;
                             if (candidate.getModifiers().getFlags().contains(javax.lang.model.element.Modifier.PUBLIC)) {
                                 clazz = candidate;
@@ -858,7 +859,7 @@ public class J2EEUtils {
                     CompilationUnitTree cu = wc.getCompilationUnit();
                     ClassTree clazz = null;
                     for (Tree typeDecl : cu.getTypeDecls()) {
-                        if (Tree.Kind.CLASS == typeDecl.getKind()) {
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(typeDecl.getKind())) {
                             ClassTree candidate = (ClassTree) typeDecl;
                             if (candidate.getModifiers().getFlags().contains(javax.lang.model.element.Modifier.PUBLIC)) {
                                 clazz = candidate;
@@ -903,7 +904,7 @@ public class J2EEUtils {
                     CompilationUnitTree cu = wc.getCompilationUnit();
                     ClassTree clazz = null;
                     for (Tree typeDecl : cu.getTypeDecls()) {
-                        if (Tree.Kind.CLASS == typeDecl.getKind()) {
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(typeDecl.getKind())) {
                             ClassTree candidate = (ClassTree) typeDecl;
                             if (candidate.getModifiers().getFlags().contains(javax.lang.model.element.Modifier.PUBLIC)) {
                                 clazz = candidate;
@@ -960,7 +961,7 @@ public class J2EEUtils {
                     CompilationUnitTree cu = cc.getCompilationUnit();
                     ClassTree clazz = null;
                     for (Tree typeDecl : cu.getTypeDecls()) {
-                        if (Tree.Kind.CLASS == typeDecl.getKind()) {
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(typeDecl.getKind())) {
                             ClassTree candidate = (ClassTree) typeDecl;
                             if (candidate.getModifiers().getFlags().contains(javax.lang.model.element.Modifier.PUBLIC)) {
                                 clazz = candidate;
