@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -176,6 +179,7 @@ private void connectionComboActionPerformed(java.awt.event.ActionEvent evt) {//G
      * @param formModel form to import the data into.
      * @return the component encapsulating the imported data.
      */
+    @Override
     public Future<RADComponent> importData(final FormModel formModel) {
         removeAll();
         if (FormJavaSource.isInDefaultPackage(formModel)) {
@@ -195,6 +199,7 @@ private void connectionComboActionPerformed(java.awt.event.ActionEvent evt) {//G
         dialog.setVisible(true);
         if (dd.getValue() != DialogDescriptor.OK_OPTION) return null;
         FutureTask<RADComponent> task = new FutureTask<RADComponent>(new Callable<RADComponent>() {
+            @Override
             public RADComponent call() throws Exception {
                 final RADComponent[] resultList = new RADComponent[1];
                 try {
@@ -239,6 +244,7 @@ private void connectionComboActionPerformed(java.awt.event.ActionEvent evt) {//G
                     final String puName = unit.getName();
                     final String[] info = entityInfo;
                     EventQueue.invokeAndWait(new Runnable() {
+                        @Override
                         public void run() {
                             try {
                                 RADComponent entityManager = J2EEUtils.findEntityManager(formModel, puName);
