@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -99,12 +102,15 @@ public class DetailPanel implements WizardDescriptor.Panel {
         availableList.setModel(new DefaultListModel());
         includeList.setModel(new DefaultListModel());
         ListDataListener listener = new ListDataListener() {
+            @Override
             public void intervalAdded(ListDataEvent e) {
                 contentsChanged(e);
             }
+            @Override
             public void intervalRemoved(ListDataEvent e) {
                 contentsChanged(e);
             }
+            @Override
             public void contentsChanged(ListDataEvent e) {
                 Object source = e.getSource();
                 if (source == availableList.getModel()) {
@@ -442,6 +448,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
         Object item = model.remove(index);
         model.add(index+1, item);
         includeList.setSelectedIndex(index+1);
+        includeList.ensureIndexIsVisible(index+1);
     }//GEN-LAST:event_downButtonActionPerformed
 
     private void upButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_upButtonActionPerformed
@@ -450,6 +457,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
         Object item = model.remove(index);
         model.add(index-1, item);
         includeList.setSelectedIndex(index-1);
+        includeList.ensureIndexIsVisible(index-1);
     }//GEN-LAST:event_upButtonActionPerformed
 
     private void removeAllButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_removeAllButtonActionPerformed
@@ -619,6 +627,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
      *
      * @return component that represents this wizard panel.
      */
+    @Override
     public Component getComponent() {
         if (masterPanel == null) {
             initGUI();
@@ -631,11 +640,13 @@ public class DetailPanel implements WizardDescriptor.Panel {
      *
      * @return default help.
      */
+    @Override
     public HelpCtx getHelp() {
         return new HelpCtx("org.netbeans.modules.form.j2ee.wizard.DetailPanel"); // NOI18N
     }
 
     private boolean defaultPreselect = true;
+    @Override
     public void readSettings(Object settings) {
         WizardDescriptor wizard = (WizardDescriptor) settings;
         wizardDesc = wizard;
@@ -682,6 +693,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
      *
      * @param settings wizard descriptor to store the settings in.
      */
+    @Override
     public void storeSettings(Object settings) {
         WizardDescriptor wizard = (WizardDescriptor) settings;
         ForeignKey key = getForeignKey();
@@ -699,6 +711,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
      * @return <code>true</code> if we can proceed to the next
      * panel, returns <code>false</code> otherwise.
      */
+    @Override
     public boolean isValid() {
         return valid;
     }
@@ -719,6 +732,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
      *
      * @param listener listener to add.
      */
+    @Override
     public void addChangeListener(ChangeListener listener) {
         if (listenerList == null) {
             listenerList = new EventListenerList();
@@ -731,6 +745,7 @@ public class DetailPanel implements WizardDescriptor.Panel {
      *
      * @param listener listener to remove.
      */
+    @Override
     public void removeChangeListener(ChangeListener listener) {
         if (listenerList != null) {
             listenerList.remove(ChangeListener.class, listener);
