@@ -66,6 +66,7 @@ import org.netbeans.api.java.source.ClasspathInfo;
 import org.netbeans.api.java.source.ClasspathInfo.PathKind;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.TreeMaker;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressRunnable;
@@ -419,7 +420,8 @@ public class MasterDetailWizard implements WizardDescriptor.InstantiatingIterato
         } catch (Exception ex) {
             Logger.getLogger(getClass().getName()).log(Level.INFO, ex.getMessage(), ex);
         } finally {
-            postJavaInfrastructureCleanup();
+// issue #195818 - commented out the following cleanup
+//            postJavaInfrastructureCleanup();
         }
         
         return resultSet;
@@ -703,7 +705,7 @@ public class MasterDetailWizard implements WizardDescriptor.InstantiatingIterato
                         CompilationUnitTree cu = wc.getCompilationUnit();
                         ClassTree clazz = null;
                         for (Tree typeDecl : cu.getTypeDecls()) {
-                            if (Tree.Kind.CLASS == typeDecl.getKind()) {
+                            if (TreeUtilities.CLASS_TREE_KINDS.contains(typeDecl.getKind())) {
                                 ClassTree candidate = (ClassTree) typeDecl;
                                 if (candidate.getModifiers().getFlags().contains(javax.lang.model.element.Modifier.PUBLIC)) {
                                     clazz = candidate;
@@ -847,7 +849,7 @@ public class MasterDetailWizard implements WizardDescriptor.InstantiatingIterato
                     CompilationUnitTree cu = wc.getCompilationUnit();
                     ClassTree clazz = null;
                     for (Tree typeDecl : cu.getTypeDecls()) {
-                        if (Tree.Kind.CLASS == typeDecl.getKind()) {
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(typeDecl.getKind())) {
                             ClassTree candidate = (ClassTree) typeDecl;
                             if (candidate.getModifiers().getFlags().contains(javax.lang.model.element.Modifier.PUBLIC)) {
                                 clazz = candidate;
