@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -112,10 +115,12 @@ class CopySupport {
             this.radComponent = radComponent;
         }
 
+        @Override
         public DataFlavor[] getTransferDataFlavors() {
             return flavors;
         }
 
+        @Override
         public boolean isDataFlavorSupported(DataFlavor flavor) {
             for (int i = 0; i < flavors.length; i++) {
                 if (flavors[i] == flavor) {
@@ -125,6 +130,7 @@ class CopySupport {
             return false;
         }
 
+        @Override
         public Object getTransferData(DataFlavor flavor)
             throws UnsupportedFlavorException, IOException
         {
@@ -287,6 +293,7 @@ class CopySupport {
             return FormUtils.getBundleString(fromCut ? "CTL_CutPaste" : "CTL_CopyPaste"); // NOI18N
         }
 
+        @Override
         public Transferable paste() throws IOException {
             if (java.awt.EventQueue.isDispatchThread())
                 return doPaste();
@@ -306,6 +313,7 @@ class CopySupport {
             }
         }
 
+        @Override
         public Transferable run() throws Exception {
             return doPaste();
         }
@@ -547,6 +555,7 @@ class CopySupport {
             this.targetComponent = targetComponent;
         }
 
+        @Override
         public Transferable paste() throws IOException {
             if (java.awt.EventQueue.isDispatchThread()) {
                 return doPaste();
@@ -567,6 +576,7 @@ class CopySupport {
             }
         }
 
+        @Override
         public Transferable run() throws Exception {
             return doPaste();
         }
