@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -707,12 +710,14 @@ public class FormModel
     //  probably implemented here - in FormModel - but seperately.]
     class UndoRedoManager extends UndoRedo.Manager {
         private Mutex.ExceptionAction<Object> runUndo = new Mutex.ExceptionAction<Object>() {
+            @Override
             public Object run() throws Exception {
                 superUndo();
                 return null;
             }
         };
         private Mutex.ExceptionAction<Object> runRedo = new Mutex.ExceptionAction<Object>() {
+            @Override
             public Object run() throws Exception {
                 superRedo();
                 return null;
@@ -1202,6 +1207,7 @@ public class FormModel
         if (eventList == null) {
             eventList = new ArrayList<FormModelEvent>();
             java.awt.EventQueue.invokeLater(new Runnable() {
+                @Override
                 public void run() {
                     firePendingEvents();
                 }
@@ -1280,7 +1286,7 @@ public class FormModel
     void fireEvents(FormModelEvent ... events) {
         java.util.List targets;
         synchronized(this) {
-            if (listeners == null || listeners.size() == 0) {
+            if (listeners == null || listeners.isEmpty()) {
                 return;
             }
             targets = (ArrayList) listeners.clone();
@@ -1320,6 +1326,7 @@ public class FormModel
     // ModelContainer innerclass
 
     final class ModelContainer implements ComponentContainer {
+        @Override
         public RADComponent[] getSubBeans() {
             int n = otherComponents.size();
             if (topRADComponent != null)
@@ -1331,6 +1338,7 @@ public class FormModel
             return comps;
         }
 
+        @Override
         public void initSubComponents(RADComponent[] initComponents) {
             otherComponents.clear();
             for (int i = 0; i < initComponents.length; i++)
@@ -1338,6 +1346,7 @@ public class FormModel
                     otherComponents.add(initComponents[i]);
         }
 
+        @Override
         public void reorderSubComponents(int[] perm) {
             RADComponent[] components = new RADComponent[otherComponents.size()];
             for (int i=0; i < perm.length; i++)
@@ -1347,16 +1356,19 @@ public class FormModel
             otherComponents.addAll(Arrays.asList(components));
         }
 
+        @Override
         public void add(RADComponent comp) {
             comp.setParentComponent(null);
             otherComponents.add(comp);
         }
 
+        @Override
         public void remove(RADComponent comp) {
             if (otherComponents.remove(comp))
                 comp.setParentComponent(null);
         }
 
+        @Override
         public int getIndexOf(RADComponent comp) {
             int index = otherComponents.indexOf(comp);
             if (index < 0 && comp == topRADComponent)
