@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -71,6 +74,7 @@ public class GuardedBlockHandlerFactoryImpl implements GuardedBlockHandlerFactor
     public GuardedBlockHandlerFactoryImpl() {
     }
     
+    @Override
     public GuardedBlockHandler createInstance(AbstractRefactoring refactoring) {
         RefactoringInfo refInfo = refactoring.getContext().lookup(RefactoringInfo.class);
         return new GuardedBlockHandlerImpl(refInfo);
@@ -88,6 +92,7 @@ public class GuardedBlockHandlerFactoryImpl implements GuardedBlockHandlerFactor
             this.refInfo = refInfo;
         }
 
+        @Override
         public Problem handleChange(RefactoringElementImplementation proposedChange,
                                     Collection<RefactoringElementImplementation> replacements,
                                     Collection<Transaction> transactions) {
@@ -195,6 +200,7 @@ public class GuardedBlockHandlerFactoryImpl implements GuardedBlockHandlerFactor
             }
         }
 
+        @Override
         public void commit() {
             for (GuardedBlockInfo block : guardedInfos) {
                 String newText = block.getNewSectionText();
@@ -206,6 +212,7 @@ public class GuardedBlockHandlerFactoryImpl implements GuardedBlockHandlerFactor
             }
         }
 
+        @Override
         public void rollback() {
             // rollback not needed - should be reverted by java refactoring as a whole file
 /*            for (GuardedBlockInfo block : guardedInfos) {
@@ -237,6 +244,7 @@ public class GuardedBlockHandlerFactoryImpl implements GuardedBlockHandlerFactor
                 this.newText = newText;
             }
 
+            @Override
             public int compareTo(ChangeInfo ch) {
                 return startPos - ch.startPos;
             }
