@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -56,6 +59,7 @@ public class ListSelector extends javax.swing.JPanel {
     public ListSelector() {
         initComponents();
         ListDataListener listener = new ListDataListener() {
+            @Override
             public void contentsChanged(ListDataEvent e) {
                 if (e.getSource() == availableList.getModel()) {
                     addAllButton.setEnabled(availableList.getModel().getSize() != 0);
@@ -63,9 +67,11 @@ public class ListSelector extends javax.swing.JPanel {
                     removeAllButton.setEnabled(selectedList.getModel().getSize() != 0);
                 }
             }
+            @Override
             public void intervalAdded(ListDataEvent e) {
                 contentsChanged(e);
             }
+            @Override
             public void intervalRemoved(ListDataEvent e) {
                 contentsChanged(e);
             }
@@ -262,6 +268,7 @@ public class ListSelector extends javax.swing.JPanel {
         Object item = model.remove(index);
         model.add(index+1, item);
         selectedList.setSelectedIndex(index+1);
+        selectedList.ensureIndexIsVisible(index+1);
     }//GEN-LAST:event_downButtonActionPerformed
 
     private void upButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_upButtonActionPerformed
@@ -270,6 +277,7 @@ public class ListSelector extends javax.swing.JPanel {
         Object item = model.remove(index);
         model.add(index-1, item);
         selectedList.setSelectedIndex(index-1);
+        selectedList.ensureIndexIsVisible(index-1);
     }//GEN-LAST:event_upButtonActionPerformed
 
     private void removeAllButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_removeAllButtonActionPerformed
