@@ -60,6 +60,7 @@ import javax.lang.model.element.TypeElement;
 import org.netbeans.api.java.source.CancellableTask;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.JavaSource;
+import org.netbeans.api.java.source.TreeUtilities;
 
 import org.openide.*;
 import org.openide.nodes.Node;
@@ -71,6 +72,8 @@ import org.netbeans.modules.form.layoutsupport.*;
 import org.netbeans.modules.form.layoutdesign.*;
 import org.netbeans.modules.form.layoutdesign.support.SwingLayoutBuilder;
 import org.netbeans.modules.form.editors2.BorderDesignSupport;
+import org.netbeans.modules.form.palette.BoxFillerInitializer;
+import org.netbeans.modules.form.palette.PaletteItem;
 import org.netbeans.modules.form.project.ClassSource;
 import org.netbeans.modules.form.project.ClassPathUtils;
 
@@ -107,6 +110,23 @@ public class MetaComponentCreator {
         formModel = model;
     }
 
+    /** Creates and adds a new metacomponent to FormModel. The new component
+     * is added to target component (if it is ComponentContainer).
+     * @param paletteItem {@code PaletteItem} describing the component
+     * @param constraints constraints object (for visual components only)
+     * @param targetComp component into which the new component is added
+     * @return the metacomponent if it was successfully created and added (all
+     *         errors are reported immediately)
+     */
+    public RADComponent createComponent(PaletteItem paletteItem,
+                                        RADComponent targetComp,
+                                        Object constraints) {
+        RADComponent metaComp = createComponent(paletteItem.getComponentClassSource(), targetComp, constraints);
+        String initializerId = paletteItem.getInitializerId();
+        initializeNewComponent(metaComp, initializerId);
+        return metaComp;
+    }
+
     /** Creates and adds a new metacomponent to FormModel. The new component
      * is added to target component (if it is ComponentContainer).
      * @param classSource ClassSource describing the component class
@@ -258,6 +278,23 @@ public class MetaComponentCreator {
         }
     }
 
+    public RADVisualComponent precreateVisualComponent(PaletteItem paletteItem) {
+        RADVisualComponent metaComp = precreateVisualComponent(paletteItem.getComponentClassSource());
+        String initializerId = paletteItem.getInitializerId();
+        initializeNewComponent(metaComp, initializerId);
+        return metaComp;
+    }
+
+    private void initializeNewComponent(RADComponent metaComp, String initializerId) {
+        if (initializerId == null) {
+            return;
+        }
+        // PENDING general registration of initializers
+        if (initializerId.startsWith("Box.Filler")) { // NOI18N
+            new BoxFillerInitializer(metaComp, initializerId).initialize();
+        }
+    }
+
     public RADVisualComponent getPrecreatedMetaComponent() {
         return preMetaComp;
     }
@@ -313,18 +350,24 @@ public class MetaComponentCreator {
     }
 
     public boolean addPrecreatedComponent(RADComponent targetComp,
-                                          Object constraints)
+                                          final Object constraints)
     {
         if (preMetaComp == null) {
             return false;
         }
         if (checkFormClass(preMetaComp.getBeanClass())) {
-            TargetInfo target = getTargetInfo(preMetaComp.getBeanClass(), targetComp, true, true);
+            final TargetInfo target = getTargetInfo(preMetaComp.getBeanClass(), targetComp, true, true);
             if (target != null
                 && (target.targetType == TargetType.VISUAL
                     || target.targetType == TargetType.OTHER)) {
-                addVisualComponent2(preMetaComp, target.targetComponent, constraints, true);
-                ResourceSupport.switchComponentToResources(preMetaComp);
+                // Look&Feel UI defaults remapping needed (see issue 197521)
+                FormLAF.executeWithLookAndFeel(formModel, new Runnable() {
+                    @Override
+                    public void run() {
+                        addVisualComponent2(preMetaComp, target.targetComponent, constraints, true);
+                        ResourceSupport.switchComponentToResources(preMetaComp);                        
+                    }
+                });
             }
             releasePrecreatedComponent();
             return true;
@@ -1363,7 +1406,7 @@ public class MetaComponentCreator {
                 public void run(CompilationController controller) throws Exception {
                     controller.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
                     for (Tree t: controller.getCompilationUnit().getTypeDecls()) {
-                        if (t.getKind() == Tree.Kind.CLASS &&
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(t.getKind()) &&
                                 fo.getName().equals(((ClassTree) t).getSimpleName().toString())) {
                             TreePath classTreePath = controller.getTrees().getPath(controller.getCompilationUnit(), t);
                             Element classElm = controller.getTrees().getElement(classTreePath);
@@ -1500,7 +1543,7 @@ public class MetaComponentCreator {
             if ("".equals(((TextField)comp).getText())) { // NOI18N
                 changes.put("text", varName); // NOI18N
             }
-        } else if (comp instanceof JComboBox) {
+        } else if ("javax.swing.JComboBox".equals(comp.getClass().getName())) { // NOI18N
             ComboBoxModel model = ((JComboBox)comp).getModel();
             if ((model == null) || (model.getSize() == 0)) {
                 String prefix = NbBundle.getMessage(MetaComponentCreator.class, "FMT_CreatorComboBoxItem"); // NOI18N
