@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -44,7 +47,6 @@ package org.netbeans.modules.form;
 
 import java.beans.*;
 import java.util.*;
-import java.awt.*;
 
 import org.openide.awt.Mnemonics;
 
@@ -171,6 +173,7 @@ public class MethodPicker extends javax.swing.JPanel {
 	    
             // sort the methods by name
             Arrays.sort(items, new Comparator<MethodPickerItem>() {
+                @Override
                 public int compare(MethodPickerItem o1, MethodPickerItem o2) {
                     return o1.getMethodName().compareTo(o2.getMethodName());
                 }
@@ -189,12 +192,15 @@ public class MethodPicker extends javax.swing.JPanel {
     private MethodPickerItem createItem(final MethodDescriptor desc) {
 	return new MethodPickerItem() {		
 	    private String name = FormUtils.getMethodName(desc);
+            @Override
 	    public String getMethodName() {
 		return name;
 	    }
+            @Override
 	    public Class[] getParameterTypes() {
 		return desc.getMethod().getParameterTypes();
 	    }
+            @Override
 	    public MethodDescriptor getMethodDescriptor() {
 		return desc;
 	    }
@@ -204,12 +210,15 @@ public class MethodPicker extends javax.swing.JPanel {
     private MethodPickerItem createItem(final String methodName) {
 	return new MethodPickerItem() {			
 	    private String name = FormUtils.getMethodName(methodName, NO_PARAMETERS);
+            @Override
 	    public String getMethodName() {
 		return name;
 	    }
+            @Override
 	    public Class[] getParameterTypes() {
 		return NO_PARAMETERS;
 	    }
+            @Override
 	    public MethodDescriptor getMethodDescriptor() {
 		return null;
 	    }	
