@@ -76,6 +76,11 @@ import org.openide.util.Utilities;
  */
 
 public class RADComponent {
+    /**
+     * Name of key of an aux-value holding additional information
+     * about the component class (like "RigidArea" for {@code Box.Filler}s).
+     */
+    public static final String AUX_VALUE_CLASS_DETAILS = "classDetails"; // NOI18N
 
     // -----------------------------------------------------------------------------
     // Static variables
@@ -641,7 +646,7 @@ public class RADComponent {
         return NO_NEW_TYPES;
     }
 
-    public Node.PropertySet[] getProperties() {
+    public synchronized Node.PropertySet[] getProperties() {
         if (propertySets == null) {
             List<Node.PropertySet> propSets = new ArrayList<Node.PropertySet>(5);
             createPropertySets(propSets);
@@ -651,7 +656,7 @@ public class RADComponent {
         return propertySets;
     }
 
-    public RADProperty[] getAllBeanProperties() {
+    public synchronized RADProperty[] getAllBeanProperties() {
         if (knownBeanProperties == null) {
             createBeanProperties();
         }
@@ -659,7 +664,7 @@ public class RADComponent {
         return knownBeanProperties;
     }
 
-    public RADProperty[] getKnownBeanProperties() {
+    public synchronized RADProperty[] getKnownBeanProperties() {
         return knownBeanProperties != null ? knownBeanProperties : NO_PROPERTIES;
     }
 
@@ -719,38 +724,38 @@ public class RADComponent {
     // -----------------------------------------------------------------------------
     // Access to component Properties
 
-    Node.Property[] getSyntheticProperties() {
+    synchronized Node.Property[] getSyntheticProperties() {
         if (syntheticProperties == null)
             syntheticProperties = createSyntheticProperties();
         return syntheticProperties;
     }
 
-    RADProperty[] getBeanProperties1() {
+    synchronized RADProperty[] getBeanProperties1() {
         if (beanProperties1 == null)
             createBeanProperties();
         return beanProperties1;
     }
 
-    RADProperty[] getBeanProperties2() {
+    synchronized RADProperty[] getBeanProperties2() {
         if (beanProperties2 == null)
             createBeanProperties();
         return beanProperties2;
     }
 
-    EventProperty[] getEventProperties() {
+    synchronized EventProperty[] getEventProperties() {
         if (eventProperties == null)
             createEventProperties();
         return eventProperties;
     }
     
-    List getActionProperties() {
+    synchronized List getActionProperties() {
         if (actionProperties == null) {
             createBeanProperties();
         }
         return actionProperties;
     }
 
-    protected <T> T getPropertyByName(String name, Class<? extends T> propertyType, boolean fromAll) {
+    protected synchronized <T> T getPropertyByName(String name, Class<? extends T> propertyType, boolean fromAll) {
         Node.Property prop = nameToProperty.get(name);
         if (prop == null && fromAll) {
             if (beanProperties1 == null && !name.startsWith("$")) // NOI18N
@@ -808,7 +813,7 @@ public class RADComponent {
      * @return array of properties corresponding to the names; may contain
      *         null if there is no property of given name
      */
-    public RADProperty[] getBeanProperties(String[] propNames) {
+    public synchronized RADProperty[] getBeanProperties(String[] propNames) {
         RADProperty[] properties = new RADProperty[propNames.length];        
         PropertyDescriptor[] descriptors = null;
         
@@ -901,7 +906,7 @@ public class RADComponent {
         return properties;
     }
 
-    public Event getEvent(String name) {
+    public synchronized Event getEvent(String name) {
         Object prop = nameToProperty.get(name);
         if (prop == null && eventProperties == null) {
             createEventProperties();
@@ -911,7 +916,7 @@ public class RADComponent {
                ((EventProperty)prop).getEvent() : null;
     }
 
-    public Event[] getEvents(String[] eventNames) {
+    public synchronized Event[] getEvents(String[] eventNames) {
         Event[] events = new Event[eventNames.length];
         EventSetDescriptor[] eventSets = null;
 
@@ -1022,7 +1027,7 @@ public class RADComponent {
 
     /** @return all events of the component grouped by EventSetDescriptor
      */
-    public Event[] getAllEvents() {
+    public synchronized Event[] getAllEvents() {
         if (knownEvents == null || eventProperties == null) {
             if (eventProperties == null)
                 createEventProperties();
@@ -1037,7 +1042,7 @@ public class RADComponent {
     }
 
     // Note: events must be grouped by EventSetDescriptor
-    public Event[] getKnownEvents() {
+    public synchronized Event[] getKnownEvents() {
         return knownEvents != null ? knownEvents : FormEvents.NO_EVENTS;
     }
 
@@ -1070,7 +1075,7 @@ public class RADComponent {
     // -----------------------------------------------------------------------------
     // Properties
 
-    protected void clearProperties() {
+    protected synchronized void clearProperties() {
         if (nameToProperty != null)
             nameToProperty.clear();
         else nameToProperty = new HashMap<String,Node.Property>();
@@ -1087,9 +1092,9 @@ public class RADComponent {
     }
 
     static final boolean SUPPRESS_PROPERTY_TABS = Boolean.getBoolean(
-            "nb.form.suppressTabs");
+            "nb.form.suppressTabs"); // NOI18N
 
-    protected void createPropertySets(List<Node.PropertySet> propSets) {
+    protected synchronized void createPropertySets(List<Node.PropertySet> propSets) {
         if (beanProperties1 == null)
             createBeanProperties();
 
@@ -1213,7 +1218,7 @@ public class RADComponent {
         return codeGen != null ? codeGen.getSyntheticProperties(this) : new Node.Property[0];
     }
 
-    private void createBeanProperties() {
+    private synchronized void createBeanProperties() {
         List<RADProperty> prefProps = new ArrayList<RADProperty>();
         List<RADProperty> normalProps = new ArrayList<RADProperty>();
         List<RADProperty> expertProps = new ArrayList<RADProperty>();
@@ -1381,7 +1386,7 @@ public class RADComponent {
         }       
     }
 
-    private void createEventProperties() {
+    private synchronized void createEventProperties() {
         EventSetDescriptor[] eventSets = getBeanInfo().getEventSetDescriptors();
 
         List<EventProperty> eventPropList = new ArrayList<EventProperty>(eventSets.length * 5);
@@ -1411,21 +1416,20 @@ public class RADComponent {
         eventProperties = eventProps;
     }
 
-    public FormProperty[] getAccessibilityProperties() {
+    public synchronized FormProperty[] getAccessibilityProperties() {
         if (accessibilityProperties == null)
             createAccessibilityProperties();
         return accessibilityProperties;
     }
 
-    FormProperty[] getKnownAccessibilityProperties() {
+    synchronized FormProperty[] getKnownAccessibilityProperties() {
         return accessibilityProperties != null ? accessibilityProperties : NO_PROPERTIES;
     }
 
-    private void createAccessibilityProperties() {
-        Object comp = getBeanInstance();
+    private synchronized void createAccessibilityProperties() {
+        final Object comp = getBeanInstance();
         if (comp instanceof Accessible
-            && ((Accessible)comp).getAccessibleContext() != null)
-        {
+            && (!EventQueue.isDispatchThread() || ((Accessible)comp).getAccessibleContext() != null)) {
             if (accessibilityData == null)
                 accessibilityData = new MetaAccessibleContext();
             accessibilityProperties = accessibilityData.getProperties();
@@ -1436,6 +1440,35 @@ public class RADComponent {
                 prop.setPropertyContext(new FormPropertyContext.Component(this));
                 nameToProperty.put(prop.getName(), prop);
             }
+
+            if (!EventQueue.isDispatchThread()) { // Issue 187131
+                EventQueue.invokeLater(new Runnable() {
+                    @Override
+                    public void run() {
+                        if (((Accessible)comp).getAccessibleContext() == null) {
+                            // Remove accessible properties
+                            for (int i = 0; i < accessibilityProperties.length; i++) {
+                                FormProperty prop = accessibilityProperties[i];
+                                nameToProperty.remove(prop.getName());
+                            }
+                            accessibilityData = null;
+                            accessibilityProperties = NO_PROPERTIES;
+                            if (propertySets != null) {
+                                Node.PropertySet[] newPS = new Node.PropertySet[propertySets.length-1];
+                                int idx = 0;
+                                for (Node.PropertySet ps : propertySets) {
+                                    if (!"accessibility".equals(ps.getName())) { // NOI18N
+                                        newPS[idx++] = ps;
+                                    }
+                                }
+                                Node.PropertySet[] oldPS = propertySets;
+                                propertySets = newPS;
+                                getNodeReference().firePropertyChangeHelper(Node.PROP_PROPERTY_SETS, oldPS, newPS);
+                            }
+                        }
+                    }
+                });
+            }
         }
         else {
             accessibilityData = null;
