@@ -51,7 +51,9 @@ import java.awt.datatransfer.*;
 import java.text.MessageFormat;
 import java.util.*;
 import java.beans.*;
+import java.lang.reflect.InvocationTargetException;
 import java.security.*;
+import java.util.logging.Level;
 import javax.swing.Action;
 
 import org.openide.ErrorManager;
@@ -129,12 +131,14 @@ public class RADComponentNode extends FormNode
         // try to get a special icon
         icon = BeanSupport.getBeanIcon(component.getBeanClass(), iconType);
         if (icon == null) {
+            final String className = component.getBeanClass().getName();
+            final String classDetails = (String)component.getAuxValue(RADComponent.AUX_VALUE_CLASS_DETAILS);
             if (!iconsInitialized) {
                 // getIconForClass invokes getNodes(true) which cannot be called in Mutex
                 EventQueue.invokeLater(new Runnable() {
                     @Override
                     public void run() {
-                        Image icon = PaletteUtils.getIconForClass(component.getBeanClass().getName(), iconType, true);
+                        Image icon = PaletteUtils.getIconForClass(className, classDetails, iconType, true);
 			iconsInitialized = true;
                         if (icon != null) {
                             img.put(iconType, icon);
@@ -143,7 +147,7 @@ public class RADComponentNode extends FormNode
                     }
                 });
             } else {
-                icon = PaletteUtils.getIconForClass(component.getBeanClass().getName(), iconType, false);
+                icon = PaletteUtils.getIconForClass(className, classDetails, iconType, false);
             }
 
             if (icon == null) {
@@ -175,9 +179,35 @@ public class RADComponentNode extends FormNode
 
     @Override
     public Node.PropertySet[] getPropertySets() {
-        return component.getProperties();
+        final Node.PropertySet[][] props = new Node.PropertySet[1][];
+        Runnable runnable = new Runnable() {
+            @Override
+            public void run() {
+                FormLAF.executeWithLAFLocks(new Runnable() {
+                    @Override
+                    public void run() {
+                       props[0] = component.getProperties();
+                    }
+                });
+            }
+        };
+        if (EventQueue.isDispatchThread()) {
+            runnable.run();
+        } else {
+            try {
+                // We have made some attempts to keep initialization
+                // of properties outside AWT thread, but it always
+                // deadlocked with AWT thread for various reasons.
+                EventQueue.invokeAndWait(runnable);
+            } catch (InterruptedException iex) {
+                FormUtils.LOGGER.log(Level.INFO, iex.getMessage(), iex);
+            } catch (InvocationTargetException itex) {
+                FormUtils.LOGGER.log(Level.INFO, itex.getMessage(), itex);
+            }
+        }
+        return props[0];
     }
-    
+
     /* List new types that can be created in this node.
      * @return new types
      */
