@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -64,10 +67,12 @@ public class CustomizeEmptySpaceAction extends CookieAction {
     private static String name;
     private Dialog dialog;
 
+    @Override
     protected int mode() {
         return MODE_EXACTLY_ONE;
     }
 
+    @Override
     protected Class[] cookieClasses() {
         return new Class[] { RADComponentCookie.class };
     }
@@ -82,6 +87,7 @@ public class CustomizeEmptySpaceAction extends CookieAction {
      *
      * @return the name of the action
      */
+    @Override
     public String getName() {
         if (name == null)
             name = org.openide.util.NbBundle.getBundle(CustomizeEmptySpaceAction.class)
@@ -89,6 +95,7 @@ public class CustomizeEmptySpaceAction extends CookieAction {
         return name;
     }
 
+    @Override
     public HelpCtx getHelpCtx() {
         return HelpCtx.DEFAULT_HELP;
     }
@@ -103,6 +110,7 @@ public class CustomizeEmptySpaceAction extends CookieAction {
      *
      * @param activatedNodes gives array of actually activated nodes.
      */
+    @Override
     protected void performAction(Node[] activatedNodes) {
         java.util.List comps = FormUtils.getSelectedLayoutComponents(activatedNodes);
         if ((comps == null) || (comps.size() != 1)) return;
@@ -119,6 +127,7 @@ public class CustomizeEmptySpaceAction extends CookieAction {
             DialogDescriptor.DEFAULT_ALIGN,
             HelpCtx.DEFAULT_HELP,
             new java.awt.event.ActionListener() {
+            @Override
                 public void actionPerformed(java.awt.event.ActionEvent evt) {
                     if (evt.getSource() == NotifyDescriptor.OK_OPTION) {
                         if (customizer.checkValues()) {
