@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -239,6 +242,7 @@ public class AbstractFormatterFactoryEditor extends PropertyEditorSupport
      * 
      * @param evt property change event.
      */
+    @Override
     public void propertyChange(PropertyChangeEvent evt) {
         setValue(new FormFormatter(selector.getFormat()));
     }
@@ -294,6 +298,7 @@ public class AbstractFormatterFactoryEditor extends PropertyEditorSupport
     /** Attribute describing format's pattern. */
     private static final String ATTR_FORMAT = "format"; // NOI18N
     
+    @Override
     public void readFromXML(Node element) throws IOException {
         NamedNodeMap attributes = element.getAttributes();
         String typeTxt = attributes.getNamedItem(ATTR_TYPE).getNodeValue();
@@ -308,6 +313,7 @@ public class AbstractFormatterFactoryEditor extends PropertyEditorSupport
         setValue(new FormFormatter(new FormatSelector.FormatInfo(type, subtype, format)));
     }
 
+    @Override
     public Node storeToXML(Document doc) {
         org.w3c.dom.Element el = doc.createElement(XML_FORMAT);
         Object value = getValue();
@@ -326,10 +332,12 @@ public class AbstractFormatterFactoryEditor extends PropertyEditorSupport
      * 
      * @return display name of the property editor.
      */
+    @Override
     public String getDisplayName() {
         return NbBundle.getMessage(getClass(), "CTL_AbstractFormatterFactoryEditor_DisplayName"); // NOI18N
     }
 
+    @Override
     public void setContext(FormModel formModel, FormProperty property) {
         this.property = property;
         try {
@@ -342,6 +350,7 @@ public class AbstractFormatterFactoryEditor extends PropertyEditorSupport
     /**
      * Raise form version to 6.0 - this editor is available since NB 6.0.
      */
+    @Override
     public void updateFormVersionLevel() {
         property.getPropertyContext().getFormModel()
                 .raiseVersionLevel(FormModel.FormVersion.NB60, FormModel.FormVersion.NB60);
@@ -377,6 +386,7 @@ public class AbstractFormatterFactoryEditor extends PropertyEditorSupport
          * 
          * @return design value corresponding to this formatter. 
          */
+        @Override
         public Object getDesignValue() {
             JFormattedTextField.AbstractFormatter value = null;
             int type = format.getType();
