@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -78,7 +81,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
     public String getJavaInitializationString() {
         KeyStroke key =(KeyStroke) getValue();
         int mods = key.getModifiers();
-        StringBuffer modsText = new StringBuffer();
+        StringBuilder modsText = new StringBuilder();
 
         if (0 !=(mods
                  &(InputEvent.ALT_MASK | InputEvent.SHIFT_MASK | InputEvent.CTRL_MASK | InputEvent.META_MASK))) {
@@ -194,7 +197,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
         String ctrl = i18ned ? TXT_CTRL : "Ctrl"; // NOI18N
         String meta = i18ned ? TXT_META : "Meta"; //NOI18N
 
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         int mods = key.getModifiers();
         int modMasks[] = { InputEvent.SHIFT_MASK, InputEvent.CTRL_MASK,
                            InputEvent.ALT_MASK, InputEvent.META_MASK };
@@ -220,6 +223,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
     public static final String XML_KEYSTROKE = "KeyStroke"; // NOI18N
     public static final String ATTR_KEY = "key"; // NOI18N
 
+    @Override
     public void readFromXML(org.w3c.dom.Node element) throws java.io.IOException {
         if (!XML_KEYSTROKE.equals(element.getNodeName())) {
             throw new java.io.IOException();
@@ -238,6 +242,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
         }
     }
 
+    @Override
     public org.w3c.dom.Node storeToXML(org.w3c.dom.Document doc) {
         KeyStroke key = (KeyStroke) getValue();
         String str = key != null ? keyStrokeAsString(key, false) : "null"; // NOI18N
@@ -262,6 +267,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
     }
     
     // NamedPropertyEditor implementation
+    @Override
     public String getDisplayName() {
         return NbBundle.getBundle(getClass()).getString("CTL_KeyStrokeEditor_DisplayName"); // NOI18N
     }
@@ -367,6 +373,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
             keyStrokeLabel.setLabelFor(_keyGrabber);
 
             _keyGrabber.addActionListener(new ActionListener() {
+                @Override
                 public void actionPerformed(ActionEvent ev) {
                     setAsText(_keyGrabber.getText());
                 }
@@ -408,6 +415,7 @@ public class KeyStrokeEditor extends PropertyEditorSupport
             // listeners
 
             ItemListener il = new ItemListener() {
+                @Override
                 public void itemStateChanged(ItemEvent e) {
                     virtualKeyChanged();
                 }
