@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -107,6 +110,7 @@ public class BorderDesignSupport implements FormDesignValue
 
     // --------------------------
 
+    @Override
     public FormDesignValue copy(FormProperty formProperty) {
         try {
             return new BorderDesignSupport(this, new FormPropertyContext.SubProperty(formProperty));
@@ -181,6 +185,7 @@ public class BorderDesignSupport implements FormDesignValue
 
     private void createProperties() {
         FormLAF.executeWithLookAndFeel(propertyContext.getFormModel(), new Runnable() {
+            @Override
             public void run() {
                 createPropertiesInLAFBlock();
             }
@@ -262,10 +267,12 @@ public class BorderDesignSupport implements FormDesignValue
         }
     }
     
+    @Override
     public Object getDesignValue() {
         return getBorder();
     }
 
+    @Override
     public Object getDesignValue(Object target) {
         if (FormLAF.getUsePreviewDefaults()) {
             return copy((FormProperty)propertyContext.getOwner()).getDesignValue();
@@ -274,6 +281,7 @@ public class BorderDesignSupport implements FormDesignValue
         }
     }
 
+    @Override
     public String getDescription() {
         return getDisplayName();
     }
@@ -336,6 +344,7 @@ public class BorderDesignSupport implements FormDesignValue
             }
         }
 
+        @Override
         public Object getTargetValue()
             throws IllegalAccessException, InvocationTargetException
         {
@@ -343,6 +352,7 @@ public class BorderDesignSupport implements FormDesignValue
             return readMethod.invoke(theBorder, new Object[0]);
         }
 
+        @Override
         public void setTargetValue(Object value)
             throws IllegalAccessException, IllegalArgumentException,
                    InvocationTargetException
