@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -479,7 +482,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
         while (st.hasMoreTokens()) {
             items.add(st.nextToken());
         }
-        if (items.size() == 0) {
+        if (items.isEmpty()) {
             items.add(""); // NOI18N
         }
         return items;
@@ -1658,6 +1661,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
     /** Value denoting now (date value). */
     private static final String VALUE_NOW = "now"; // NOI18N
 
+    @Override
     public void readFromXML(Node element) throws IOException {
         org.w3c.dom.NamedNodeMap attributes = element.getAttributes();
         String type = attributes.getNamedItem(ATTR_TYPE).getNodeValue();
@@ -1674,6 +1678,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
         setValue(value);
     }
 
+    @Override
     public Node storeToXML(Document doc) {
         org.w3c.dom.Element el = doc.createElement(XML_SPINNER_MODEL);
         Object value = getValue();
@@ -1868,6 +1873,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
      * 
      * @return diaplay name of this property editor.
      */
+    @Override
     public String getDisplayName() {
         return NbBundle.getMessage(getClass(), "SpinnerModelEditor"); // NOI18N
     }
@@ -1878,6 +1884,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
      * @param formModel form model.
      * @param property property being edited.
      */
+    @Override
     public void setContext(FormModel formModel, FormProperty property) {
         this.property = property;
     }
@@ -1885,6 +1892,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
     /**
      * Raise form version to 6.0 - this editor is available since NB 6.0.
      */
+    @Override
     public void updateFormVersionLevel() {
         property.getPropertyContext().getFormModel()
                 .raiseVersionLevel(FormModel.FormVersion.NB60, FormModel.FormVersion.NB60);
@@ -1999,6 +2007,7 @@ public class SpinnerModelEditor extends PropertyEditorSupport
          * 
          * @return design value.
          */
+        @Override
         public SpinnerModel getDesignValue() {
             return model;
         }
