@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -132,7 +135,7 @@ public class LayoutTestUtils implements LayoutConstants {
     
     static void dumpTestcode(List codeList, DataObject form, final int modelCounter) {
         FileWriter fw = null;
-        StringBuffer template = new StringBuffer();
+        StringBuilder template = new StringBuilder();
         
         if (form == null) return;
         try {
@@ -161,8 +164,10 @@ public class LayoutTestUtils implements LayoutConstants {
             final boolean[] resolved = new boolean[1];
             JavaSource js = JavaSource.forFileObject(primaryFile);
             js.runUserActionTask(new CancellableTask<CompilationController>() {
+                @Override
                 public void cancel() {
                 }
+                @Override
                 public void run(CompilationController controller) throws Exception {
                     controller.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
                     TypeElement clazz = controller.getElements().getTypeElement(primaryFileClassFQN);
@@ -191,8 +196,10 @@ public class LayoutTestUtils implements LayoutConstants {
             final String testClassFQN = "org.netbeans.modules.form.layoutdesign." + testFO.getName(); //NOI18N
             js = JavaSource.forFileObject(testFO);
             js.runModificationTask(new CancellableTask<WorkingCopy>() {
+                @Override
                 public void cancel() {
                 }
+                @Override
                 public void run(WorkingCopy wcopy) throws Exception {
                     wcopy.toPhase(JavaSource.Phase.RESOLVED);
                     
