@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -396,6 +399,7 @@ public class SwingLayoutCodeGenerator {
             List<String> l = linkGroupsIt.next();
             // sort so that the generated line is always the same when no changes were made
             Collections.sort(l, new Comparator<String>() {
+                @Override
                 public int compare(String id1, String id2) {
                     ComponentInfo info1 = componentIDMap.get(id1);
                     ComponentInfo info2 = componentIDMap.get(id2);                    
@@ -403,7 +407,7 @@ public class SwingLayoutCodeGenerator {
                 }
             });
             if (l.size() > 1) {
-                layout.append("\n\n" + layoutVarName + ".linkSize("); // NOI18N
+                layout.append("\n\n").append(layoutVarName).append(".linkSize("); // NOI18N
                 if (!useLayoutLibrary()) {
                     layout.append("javax.swing.SwingConstants"); // NOI18N
                     layout.append(dimension == LayoutConstants.HORIZONTAL ?
@@ -419,7 +423,7 @@ public class SwingLayoutCodeGenerator {
                         first = false;
                         layout.append(info.variableName);
                     } else {
-                        layout.append(", " + info.variableName); // NOI18N
+                        layout.append(", ").append(info.variableName); // NOI18N
                     }
                 }
                 layout.append( "}"); // NOI18N
