@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -779,10 +782,12 @@ public final class LayoutSupportManager implements LayoutSupportContext {
     // -----------
     // API for layout delegates (LayoutSupportContext implementation)
 
+    @Override
     public CodeStructure getCodeStructure() {
         return codeStructure;
     }
 
+    @Override
     public CodeExpression getContainerCodeExpression() {
         if (containerCodeExpression == null) {
             containerCodeExpression = metaContainer.getCodeExpression();
@@ -791,6 +796,7 @@ public final class LayoutSupportManager implements LayoutSupportContext {
         return containerCodeExpression;
     }
 
+    @Override
     public CodeExpression getContainerDelegateCodeExpression() {
         if (containerDelegateCodeExpression == null) {
             containerDelegateCodeExpression =
@@ -833,11 +839,13 @@ public final class LayoutSupportManager implements LayoutSupportContext {
     }
 
     // return container instance of meta container
+    @Override
     public Container getPrimaryContainer() {
         return (Container) metaContainer.getBeanInstance();
     }
 
     // return container delegate of container instance of meta container
+    @Override
     public Container getPrimaryContainerDelegate() {
         Container defCont = (Container) metaContainer.getBeanInstance();
         if (primaryContainerDelegate == null || primaryContainer != defCont) {
@@ -849,10 +857,12 @@ public final class LayoutSupportManager implements LayoutSupportContext {
     }
 
     // return component instance of meta component
+    @Override
     public Component getPrimaryComponent(int index) {
         return (Component) metaContainer.getSubComponent(index).getBeanInstance();
     }
 
+    @Override
     public void updatePrimaryContainer() {
         Container cont = getPrimaryContainer();
         Container contDel = getPrimaryContainerDelegate();
@@ -872,6 +882,7 @@ public final class LayoutSupportManager implements LayoutSupportContext {
         }
     }
 
+    @Override
     public void containerLayoutChanged(PropertyChangeEvent ev)
         throws PropertyVetoException
     {
@@ -896,6 +907,7 @@ public final class LayoutSupportManager implements LayoutSupportContext {
         }
     }
 
+    @Override
     public void componentLayoutChanged(int index, PropertyChangeEvent ev)
         throws PropertyVetoException
     {
@@ -948,6 +960,7 @@ public final class LayoutSupportManager implements LayoutSupportContext {
     private class LayoutListener implements VetoableChangeListener,
                                             PropertyChangeListener
     {
+        @Override
         public void vetoableChange(PropertyChangeEvent ev)
             throws PropertyVetoException
         {
@@ -966,6 +979,7 @@ public final class LayoutSupportManager implements LayoutSupportContext {
             }
         }
 
+        @Override
         public void propertyChange(PropertyChangeEvent ev) {
             Object source = ev.getSource();
             if (source instanceof FormProperty
