@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -66,6 +69,7 @@ class ChooseCategoryWizardPanel implements WizardDescriptor.FinishablePanel<AddT
     // ----------
     // WizardDescriptor.Panel implementation
 
+    @Override
     public java.awt.Component getComponent() {
         if (categorySelector == null) { // create the UI component for the wizard step
             categorySelector = new CategorySelector();
@@ -77,6 +81,7 @@ class ChooseCategoryWizardPanel implements WizardDescriptor.FinishablePanel<AddT
 
             categorySelector.getExplorerManager().addPropertyChangeListener(
                 new PropertyChangeListener() {
+                    @Override
                     public void propertyChange(PropertyChangeEvent ev) {
                         if (ExplorerManager.PROP_SELECTED_NODES.equals(ev.getPropertyName()))
                             cs.fireChange();
@@ -87,33 +92,40 @@ class ChooseCategoryWizardPanel implements WizardDescriptor.FinishablePanel<AddT
         return categorySelector;
     }
 
+    @Override
     public org.openide.util.HelpCtx getHelp() {
         // PENDING
         return new org.openide.util.HelpCtx("beans.adding"); // NOI18N
     }
 
+    @Override
     public boolean isValid() {
         return categorySelector != null
                && categorySelector.getSelectedCategory() != null;
     }
 
+    @Override
     public void readSettings(AddToPaletteWizard settings) {
     }
 
+    @Override
     public void storeSettings(AddToPaletteWizard settings) {
         if (categorySelector != null)
             settings.setSelectedCategory(categorySelector.getSelectedCategory());
     }
 
+    @Override
     public void addChangeListener(ChangeListener listener) {
         cs.addChangeListener(listener);
     }
 
+    @Override
     public void removeChangeListener(ChangeListener listener) {
         cs.removeChangeListener(listener);
     }
 
     // WizardDescriptor.FinishablePanel implementation
+    @Override
     public boolean isFinishPanel() {
         return true;
     }
