@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -73,6 +76,7 @@ class ChooseLibraryWizardPanel implements WizardDescriptor.Panel<AddToPaletteWiz
     // ----------
     // WizardDescriptor.Panel implementation
 
+    @Override
     public java.awt.Component getComponent() {
         if (librarySelectorComponent == null) {
             librarySelector = LibraryChooser.createPanel(null, null);
@@ -85,6 +89,7 @@ class ChooseLibraryWizardPanel implements WizardDescriptor.Panel<AddToPaletteWiz
                                               new Integer(0));
 
             librarySelector.addPropertyChangeListener(new PropertyChangeListener() {
+                @Override
                 public void propertyChange(PropertyChangeEvent evt) {
                     cs.fireChange();
                 }
@@ -94,20 +99,24 @@ class ChooseLibraryWizardPanel implements WizardDescriptor.Panel<AddToPaletteWiz
         return librarySelectorComponent;
     }
 
+    @Override
     public org.openide.util.HelpCtx getHelp() {
         // PENDING
         return new org.openide.util.HelpCtx("beans.adding"); // NOI18N
     }
 
+    @Override
     public boolean isValid() {
         return librarySelector != null
                && !librarySelector.getSelectedLibraries().isEmpty();
     }
 
+    @Override
     public void readSettings(AddToPaletteWizard settings) {
 //        wizard = settings;
     }
 
+    @Override
     public void storeSettings(AddToPaletteWizard settings) {
         if (librarySelector != null) { // create the UI component for the wizard step
             List<ClassSource.LibraryEntry> entries = new ArrayList<ClassSource.LibraryEntry>();
@@ -118,10 +127,12 @@ class ChooseLibraryWizardPanel implements WizardDescriptor.Panel<AddToPaletteWiz
         }
     }
 
+    @Override
     public void addChangeListener(ChangeListener listener) {
         cs.addChangeListener(listener);
     }
 
+    @Override
     public void removeChangeListener(ChangeListener listener) {
         cs.removeChangeListener(listener);
     }
