@@ -46,6 +46,7 @@ package org.netbeans.qa.form;
 import java.io.File;
 import java.io.IOException;
 import junit.framework.Test;
+import org.netbeans.jellytools.DocumentsDialogOperator;
 import org.netbeans.jellytools.NewFileWizardOperator;
 import org.netbeans.jellytools.ProjectsTabOperator;
 import org.netbeans.jellytools.modules.form.ComponentInspectorOperator;
@@ -56,11 +57,12 @@ import org.netbeans.jellytools.NbDialogOperator;
 import org.netbeans.jellytools.NewJavaProjectNameLocationStepOperator;
 import org.netbeans.jellytools.NewProjectWizardOperator;
 import org.netbeans.jellytools.actions.DeleteAction;
+import org.netbeans.jellytools.modules.form.FormDesignerOperator;
 import org.netbeans.jellytools.nodes.ProjectRootNode;
-//import org.netbeans.jemmy.Test;
 import org.netbeans.jemmy.operators.JCheckBoxOperator;
 import org.netbeans.jemmy.operators.JTextFieldOperator;
 import org.netbeans.junit.NbModuleSuite;
+import org.openide.util.Exceptions;
 
 /**
  * A Test based on JellyTestCase. JellyTestCase redirects Jemmy output
@@ -80,6 +82,9 @@ import org.netbeans.junit.NbModuleSuite;
  * @author Jana Maleckova
  * Created on 29 January 2007, 15:59
  * Test is only for java 1.6 for now
+ * 
+ * <b>Adam Senk</b>
+ * 20 April 2011 WORKS
  */
 public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
 
@@ -88,7 +93,6 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
     public String PROJECT_NAME = "Java";
     public String workdirpath;
     public String jdkVersion = ExtJellyTestCase.getJDKVersionCode();
-    public String pokus;
     MainWindowOperator mainWindow;
     ProjectsTabOperator pto;
     ComponentInspectorOperator cio;
@@ -103,8 +107,21 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
     public static Test suite() {
         return NbModuleSuite.create(
                 NbModuleSuite.createConfiguration(OpenTempl_defaultPackTest.class).addTest(
-                "testApplet", "testDialog", "testFrame", "testInter", "testAppl", "testMidi", "testPanel", "testBean")
-                .gui(true).enableModules(".*").clusters(".*"));
+                //SWING
+                "testApplet",
+                "testDialog",
+                "testFrame", 
+                "testInter", 
+                "testMidi", 
+                "testPanel",
+                "testBean", 
+                "testAppl",
+                "testOkCancel",
+                //AWT
+                "testAWTApplet",
+                "testAWTDialog",
+                "testAWTFrame",
+                "testAWTPanel").gui(true).enableModules(".*").clusters(".*"));
 
     }
 
@@ -114,9 +131,15 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
         openDataProjects(DATA_PROJECT_NAME);
         workdirpath = getWorkDir().getParentFile().getAbsolutePath();
         System.out.println("########  " + getName() + "  #######");
+        try {
+            Thread.sleep(15000);
+        } catch (InterruptedException ex) {
+            Exceptions.printStackTrace(ex);
+        }
     }
 
     /** Called after every test case. */
+    @Override
     public void tearDown() {
     }
 
@@ -170,19 +193,37 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
             log("File " + DATA_PROJECT_NAME + " was deleted correctly");
         }
     }
+    /*
+     * Close document given in parametr.
+     *Is HIGHLY RECOMMENDED close document, after test is finished.
+     */
+
+    public void closeDocument(String documentName) throws InterruptedException {
+        FormDesignerOperator fdo = new FormDesignerOperator(documentName);
+        fdo.editor();
+        Thread.sleep(1000);
+        DocumentsDialogOperator ddo = DocumentsDialogOperator.invoke();
+        Thread.sleep(1000);
+        ddo.selectDocument(documentName);
+        Thread.sleep(1000);
+        ddo.btCloseDocuments().doClick();
+
+
+    }
+
+    public void openTemplate(String templateName, String category) throws InterruptedException {
 
-    public void openTemplate(String templateName) throws InterruptedException {
         NewFileWizardOperator nfwo = NewFileWizardOperator.invoke();
         nfwo.selectProject(DATA_PROJECT_NAME);
         Thread.sleep(10000);
-        nfwo.selectCategory("Swing GUI Forms");
+        nfwo.selectCategory(category);
         nfwo.selectFileType(templateName);
         nfwo.next();
         JComboBoxOperator jcb_package = new JComboBoxOperator(nfwo, 1);
         jcb_package.clearText();
         Thread.sleep(5000);
 
-        if ((templateName == "Bean Form")) {
+        if (templateName.equals("Bean Form")) {
             nfwo.next();
             JTextFieldOperator class_name = new JTextFieldOperator(nfwo);
             class_name.setText("javax.swing.JButton");
@@ -195,19 +236,27 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
         }
     }
 
+    public void testTemplateMethod(String templateName, String category, String name) throws InterruptedException, IOException {
+
+        openTemplate(templateName, category);
+
+        System.out.println(getWorkDir());
+        testFormFile(name);
+        Thread.sleep(10000);
+        testJavaFile(name);
+        Thread.sleep(10000);
+        closeDocument(name + ".java");
+
+    }
+
     /** Test case 1.
      *Create new JApplet template in default package
      */
-    public void testApplet() throws InterruptedException, IOException {
+    public void testApplet() throws InterruptedException, IOException, Exception {
+
 
-        Thread.sleep(2000);
 //        begin();
-
-        openTemplate("JApplet Form");
-        Thread.sleep(10000);
-        System.out.println(getWorkDir());
-        //testFormFile("NewJApplet");
-        testJavaFile("NewJApplet");
+        testTemplateMethod("JApplet Form", "Swing GUI Forms", "NewJApplet");
 
     }
 
@@ -216,11 +265,8 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
      */
     public void testDialog() throws InterruptedException, IOException {
 
-        openTemplate("JDialog Form");
+        testTemplateMethod("JDialog Form", "Swing GUI Forms", "NewJDialog");
 
-        //check if template is generated correctly
-        //testFormFile("NewJDialog");
-        testJavaFile("NewJDialog");
 
     }
 
@@ -229,10 +275,8 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
      */
     public void testFrame() throws InterruptedException, IOException {
 
-        openTemplate("JFrame Form");
-        //check if template is generated correctly
-        //testFormFile("NewJFrame");
-        testJavaFile("NewJFrame");
+        testTemplateMethod("JFrame Form", "Swing GUI Forms", "NewJFrame");
+
     }
 
     /** Test case 4.
@@ -240,31 +284,18 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
      */
     public void testInter() throws InterruptedException, IOException {
 
-        openTemplate("JInternalFrame Form");
-
-        //check if template is generated correctly
-        //testFormFile("NewJInternalFrame");
-        testJavaFile("NewJInternalFrame");
-    }
-
-    public void testAppl() throws InterruptedException, IOException {
-
-        openTemplate("Application Sample Form");
-
-        //check if template is generated correctly
-        //testFormFile("NewApplication");
-        testJavaFile("NewApplication");
+        testTemplateMethod("JInternalFrame Form", "Swing GUI Forms", "NewJInternalFrame");
 
     }
 
-    public void testMidi() throws InterruptedException, IOException {
+    public void testAppl() throws InterruptedException, IOException, Exception {
 
-        openTemplate("MDI Application Sample Form");
+        testTemplateMethod("Application Sample Form", "Swing GUI Forms", "NewApplication");
+    }
 
-        //check if template is generated correctly
-        //testFormFile("NewMDIApplication");
-        testJavaFile("NewMDIApplication");
+    public void testMidi() throws InterruptedException, IOException, Exception {
 
+        testTemplateMethod("MDI Application Sample Form", "Swing GUI Forms", "NewMDIApplication");
     }
 
     /** Test case 5.
@@ -272,11 +303,7 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
      */
     public void testPanel() throws InterruptedException, IOException {
 
-        openTemplate("JPanel Form");
-
-        //check if template is generated correctly
-        //testFormFile("NewJPanel");
-        testJavaFile("NewJPanel");
+        testTemplateMethod("JPanel Form", "Swing GUI Forms", "NewJPanel");
 
     }
 
@@ -285,51 +312,89 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
      */
     public void testBean() throws InterruptedException, IOException {
 
-        openTemplate("Bean Form");
+        testTemplateMethod("Bean Form", "Swing GUI Forms", "NewBeanForm");
+
+    }
+
+    public void testOkCancel() throws InterruptedException, IOException {
+
+        testTemplateMethod("OK / Cancel Dialog Sample Form", "Swing GUI Forms", "NewOkCancelDialog");
+
+    }
+    
+    /**AWT Test case 1.
+     * Create new Panel template in default package
+     */
+    public void testAWTPanel() throws InterruptedException, IOException {
+
+        testTemplateMethod("Panel Form", "AWT GUI Forms", "NewPanel");
+
+    }
+    
+    /**AWT Test case 2.
+     * Create new Dialog template in default package
+     */
+    
+    public void testAWTApplet() throws InterruptedException, IOException, Exception {
+
+        testTemplateMethod("Applet Form", "AWT GUI Forms", "NewApplet");
+
+    }
+
+    /**AWT Test case 3.
+     * Create new Dialog template in default package
+     */
+    public void testAWTDialog() throws InterruptedException, IOException {
+
+        testTemplateMethod("Dialog Form", "AWT GUI Forms", "NewDialog");
 
 
-        //testFormFile("NewBeanForm");
-        //Bug in generating of new Bean Form template 95403
-        //testJavaFile("NewBeanForm");
-        Thread.sleep(1000);
-    //Timeout needed
+    }
+
+    /**AWT Test case 4.
+     * Create new Frame template in default package
+     */
+    public void testAWTFrame() throws InterruptedException, IOException {
+
+        testTemplateMethod("Frame Form", "AWT GUI Forms", "NewFrame");
+
     }
 
     public void testFormFile(String formfile) throws IOException {
         try {
+            String refFile = VisualDevelopmentUtil.readFromFile(getDataDir().getAbsolutePath()
+                    + File.separatorChar + DATA_PROJECT_NAME + File.separatorChar + "src" + File.separatorChar + formfile + ".form");
+
+            getLog(formfile + "Form.ref").print(refFile);
 
-            getRef().print(VisualDevelopmentUtil.readFromFile(
-                    getWorkDir().getParentFile().getAbsolutePath() + File.separatorChar + DATA_PROJECT_NAME + File.separatorChar + "src" + File.separatorChar + formfile + ".form"));
 
         } catch (Exception e) {
             fail("Fail during create reffile: " + e.getMessage());
         }
 
-        assertFile(new File(getWorkDir() + File.separator + this.getName() + ".ref"), getGoldenFile(formfile + "FormFile.pass"), new File(getWorkDir(), formfile + ".diff"));
-        System.out.println(formfile + " is not the same as golden file");
+        assertFile(new File(getWorkDir() + File.separator + formfile + "Form.ref"), getGoldenFile(formfile + "FormFile.pass"), new File(getWorkDir(), formfile + ".diff"));
 
-
-
-    //compareReferenceFiles("TestScenario.ref", "testFormFile.pass", null);
     }
 
     public void testJavaFile(String javafile) throws IOException {
 
         try {
-            pokus = VisualDevelopmentUtil.readFromFile(getDataDir().getAbsolutePath() +
-                    File.separatorChar + DATA_PROJECT_NAME + File.separatorChar + "src" + File.separatorChar + javafile + ".java");
+            String refFile = VisualDevelopmentUtil.readFromFile(getDataDir().getAbsolutePath()
+                    + File.separatorChar + DATA_PROJECT_NAME + File.separatorChar + "src" + File.separatorChar + javafile + ".java");
+
+            getRef().print(createRefFile(refFile));
+
+            // golden files are in ${xtest.data}/goldenfiles/${classname}/...
 
-            getRef().print(createRefFile(pokus));
             log("Java reference file was created");
 
         } catch (Exception e) {
             fail("Fail during create reffile: " + e.getMessage());
         }
-        if (jdkVersion == "jdk15") {
-            assertFile(new File(getWorkDir() + File.separator + this.getName() + ".ref"), getGoldenFile(javafile + "JavaFile15.pass"), new File(getWorkDir(), javafile + ".diff"));
-        } else {
-            assertFile(new File(getWorkDir() + File.separator + this.getName() + ".ref"), getGoldenFile(javafile + "JavaFile.pass"), new File(getWorkDir(), javafile + ".diff"));
-        }
+
+
+        assertFile(new File(getWorkDir() + File.separator + this.getName() + ".ref"), getGoldenFile(javafile + "JavaFile" + jdkVersion.replaceAll("jdk", "") + ".pass"), new File(getWorkDir(), javafile + "java.diff"));
+
 
     }
 
@@ -337,7 +402,7 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
         int start = test.indexOf("/*");
         int end = test.indexOf("*/");
         test = test.substring(0, start) + test.substring(end + 2);
-        
+
         start = test.indexOf("/*");
         end = test.indexOf("*/");
         test = test.substring(0, start) + test.substring(end + 2);
@@ -347,4 +412,4 @@ public class OpenTempl_defaultPackTest extends ExtJellyTestCase {
         test = test.substring(0, start) + test.substring(end + 2);
         return test;
     }
-}
+}
\ No newline at end of file
