@@ -43,6 +43,7 @@
  */
 package org.netbeans.qa.form.jda;
 
+import junit.framework.Test;
 import org.netbeans.jellytools.NbDialogOperator;
 import org.netbeans.jellytools.actions.ActionNoBlock;
 import org.netbeans.jellytools.modules.form.ComponentInspectorOperator;
@@ -51,13 +52,16 @@ import org.netbeans.jellytools.nodes.Node;
 import org.netbeans.jellytools.properties.Property;
 import org.netbeans.jellytools.properties.PropertySheetOperator;
 import org.netbeans.jemmy.operators.JButtonOperator;
-import org.netbeans.junit.NbTestSuite;
+import org.netbeans.junit.NbModuleSuite;
 import org.netbeans.qa.form.ExtJellyTestCase;
 
 /**
  * Testing properties of JDA FrameView node
  *
  * @author Jiri Vagner
+ * 
+ * <b>Adam Senk</b>
+ * 20 April 2011 WORKS
  */
 public class FrameViewPropertiesTest extends ExtJellyTestCase {
     private String _frameViewName;
@@ -76,18 +80,17 @@ public class FrameViewPropertiesTest extends ExtJellyTestCase {
         _frameViewFileName = _frameViewName + ".java";
     }
     
-    /* Method allowing to execute test directly from IDE. */
-    public static void main(java.lang.String[] args) {
-        junit.textui.TestRunner.run(suite());
+     @Override
+    public void setUp(){
+        
     }
     
-    /** Creates suite from particular test cases. */
-    public static NbTestSuite suite() {
-        NbTestSuite suite = new NbTestSuite();
-        suite.addTest(new FrameViewPropertiesTest("testCreation")); // NOI18N
-        suite.addTest(new FrameViewPropertiesTest("testGeneratedCode")); // NOI18N        
-        suite.addTest(new FrameViewPropertiesTest("testProperties")); // NOI18N
-        return suite;
+    public static Test suite() {
+        return NbModuleSuite.create(NbModuleSuite.createConfiguration(FrameViewPropertiesTest.class).addTest(
+                "testCreation",
+                "testGeneratedCode",
+                "testProperties" 
+                ).gui(true).clusters(".*").enableModules(".*"));
     }
 
     /** Creating JDA Basic project */
@@ -107,63 +110,65 @@ public class FrameViewPropertiesTest extends ExtJellyTestCase {
     }        
     
     //** Testing properties of FrameView node */
-    public void testProperties() {
+    public void testProperties() throws InterruptedException {
         FormDesignerOperator designer = new FormDesignerOperator(_frameViewFileName);
-        
+        Thread.sleep(500);
         // nothing about toolbar in code
         missInCode("setToolBar("+TOOLBAR_NAME+");", designer);
 
         ComponentInspectorOperator inspector = new ComponentInspectorOperator();
         Node frameNode = new Node(inspector.treeComponents(), ""); // NOI18N
-
+        Thread.sleep(500);
         // add new JToolBar component
         runPopupOverNode("Add From Palette|Swing Containers|Tool Bar", frameNode); // NOI18N
         
         Node frameView = new Node(frameNode.tree(), "[FrameView]");
+        Thread.sleep(500);
         ActionNoBlock act = new ActionNoBlock(null, "Properties");  // NOI18N
         act.perform(frameView);
 
         // get and set value of property
         NbDialogOperator dialogOp = new NbDialogOperator("[FrameView]");  // NOI18N
         Property prop = new Property(new PropertySheetOperator(dialogOp), "toolBar");  // NOI18N
-        
+        Thread.sleep(500);
         // test NONE value
         assertEquals(prop.getValue(), NONE_VALUE);
         
         // set toolbar component
         prop.setValue(TOOLBAR_NAME);
-        
+        Thread.sleep(500);
         // close property dialog
         new JButtonOperator(dialogOp,"Close").push();  // NOI18N
         
         // test generated code
         findInCode("setToolBar("+TOOLBAR_NAME+");", designer);
-        
+        Thread.sleep(500);
         // get value of property again, test it and set NONE value
         act = new ActionNoBlock(null, "Properties");  // NOI18N
         act.perform(frameView);
-
+        Thread.sleep(500);
         dialogOp = new NbDialogOperator("[FrameView]");  // NOI18N
         prop = new Property(new PropertySheetOperator(dialogOp), "toolBar");  // NOI18N
+        Thread.sleep(500);
         assertEquals(prop.getValue(), TOOLBAR_NAME);
         prop.setValue(NONE_VALUE);
         
         // close property dialog
         new JButtonOperator(dialogOp,"Close").push();  // NOI18N
-        
+        Thread.sleep(500);
         // nothing about toolbat in code?
         missInCode("setToolBar("+TOOLBAR_NAME+");", designer);
         
         // just check property value
         act = new ActionNoBlock(null, "Properties");  // NOI18N
         act.perform(frameView);
-
+        Thread.sleep(500);
         dialogOp = new NbDialogOperator("[FrameView]");  // NOI18N
         prop = new Property(new PropertySheetOperator(dialogOp), "toolBar");  // NOI18N
-
+        Thread.sleep(500);
         // is selected NONE?
         assertEquals(prop.getValue(), NONE_VALUE);
-        
+        Thread.sleep(500);
         // close property dialog
         new JButtonOperator(dialogOp,"Close").push();  // NOI18N
     }
