@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -49,7 +49,6 @@ import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.ObjectOutputStream;
 import java.net.Authenticator;
 import java.net.HttpURLConnection;
 import java.net.MalformedURLException;
@@ -76,8 +75,11 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipOutputStream;
 import java.security.cert.CertificateException;
 import java.security.cert.X509Certificate;
+import java.util.Map.Entry;
+import javax.net.ssl.HostnameVerifier;
 import javax.net.ssl.HttpsURLConnection;
 import javax.net.ssl.SSLContext;
+import javax.net.ssl.SSLSession;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.X509TrustManager;
 import org.netbeans.modules.glassfish.spi.AppDesc;
@@ -90,23 +92,24 @@ import org.netbeans.modules.glassfish.spi.ServerCommand.GetPropertyCommand;
 import org.netbeans.modules.glassfish.spi.ServerCommand.SetPropertyCommand;
 import org.netbeans.modules.glassfish.spi.CommandFactory;
 import org.netbeans.modules.glassfish.spi.Utils;
+import org.netbeans.modules.glassfish.spi.WSDesc;
 
 
-/** 
+/**
  * Implementation of management task that provides info about progress
  *
  * @author Peter Williams
  */
 public class CommandRunner extends BasicTask<OperationState> {
-    
+
     public final int HTTP_RETRY_DELAY = 3000;
-    
-    /** Executor that serializes management tasks. 
+
+    /** Executor that serializes management tasks.
      */
     private static ExecutorService executor;
 
     private static Authenticator AUTH = new AdminAuthenticator();
-    
+
     /** Returns shared executor.
      */
     private static synchronized ExecutorService executor() {
@@ -115,53 +118,137 @@ public class CommandRunner extends BasicTask<OperationState> {
         }
         return executor;
     }
-    
+
     /** Command type used for events. */
     private ServerCommand serverCmd;
-    
+
     /** Has been the last access to  manager web app authorized? */
     private boolean authorized;
     private final CommandFactory cf;
     private final boolean isReallyRunning;
-    
-    
+
+
     public CommandRunner(boolean isReallyRunning, CommandFactory cf, Map<String, String> properties, OperationStateListener... stateListener) {
         super(properties, stateListener);
         this.cf =cf;
         this.isReallyRunning = isReallyRunning;
     }
-    
+
     /**
      * Sends stop-domain command to server (asynchronous)
-     * 
+     *
      */
     public Future<OperationState> stopServer() {
         return execute(Commands.STOP, "MSG_STOP_SERVER_IN_PROGRESS"); // NOI18N
-        
+
     }
-    
+
+    /**
+     * Sends restart-domain command to server (asynchronous)
+     *
+     */
+    public Future<OperationState> restartServer(int debugPort, String query) {
+        final String restartQuery = query; // cf.getRestartQuery(debugPort);
+        if (-1 == debugPort || "".equals(restartQuery) ) {
+            return execute(new ServerCommand("restart-domain") {
+
+                @Override
+                public String getQuery() {
+                    return restartQuery;
+                }
+            }, "MSG_RESTART_SERVER_IN_PROGRESS"); // NOI18N
+        }
+        // force the options to be correct for remote debugging, then restart...
+        CommandRunner inner = new CommandRunner(isReallyRunning, cf, ip, new OperationStateListener() {
+
+            @Override
+            public void operationStateChanged(OperationState newState, String message) {
+                //throw new UnsupportedOperationException("Not supported yet.");
+            }
+
+        });
+
+        // I wish that the server folks had let me add a port number to the
+        // restart-domain --debug command... but this will have to do until then
+
+        ServerCommand.GetPropertyCommand getCmd = new ServerCommand.GetPropertyCommand("configs.config.server-config.java-config.debug-options");
+
+        OperationState state = null;
+        try {
+            state = inner.execute(getCmd).get();
+        } catch (InterruptedException ie) {
+            Logger.getLogger("glassfish").log(Level.INFO,debugPort+"",ie);
+        } catch (ExecutionException ee) {
+            Logger.getLogger("glassfish").log(Level.INFO,debugPort+"",ee);
+        }
+        String qs = null;
+        if (state == OperationState.COMPLETED) {
+            Map<String, String> data = getCmd.getData();
+            if (!data.isEmpty()) {
+                // now I can reset the debug data
+                String oldValue = data.get("configs.config.server-config.java-config.debug-options");
+                ServerCommand.SetPropertyCommand setCmd =
+                        cf.getSetPropertyCommand("configs.config.server-config.java-config.debug-options",
+                        oldValue.replace("transport=dt_shmem", "transport=dt_socket").
+                        replace("address=[^,]+", "address=" + debugPort));
+                //serverCmd = setCmd;
+                //task = executor.submit(this);
+                try {
+                    state = inner.execute(setCmd).get();
+                    qs = "debug=true";
+                } catch (InterruptedException ie) {
+                     Logger.getLogger("glassfish").log(Level.INFO,debugPort+"",ie);
+                } catch (ExecutionException ee) {
+                     Logger.getLogger("glassfish").log(Level.INFO,debugPort+"",ee);
+                }
+            }
+        }
+        if (null == qs) {
+            qs = "debug=false";
+        }
+        final String fqs = qs;
+        return execute(new ServerCommand("restart-domain") {
+
+            @Override
+            public String getQuery() {
+                return fqs;
+            }
+        }, "MSG_RESTART_SERVER_IN_PROGRESS");
+    }
+
     /**
      * Sends list-applications command to server (synchronous)
-     * 
+     *
      * @return String array of names of deployed applications.
      */
     public Map<String, List<AppDesc>> getApplications(String container) {
+        CommandRunner inner = new CommandRunner(isReallyRunning, cf, ip, new OperationStateListener() {
+
+            @Override
+            public void operationStateChanged(OperationState newState, String message) {
+                //throw new UnsupportedOperationException("Not supported yet.");
+            }
+
+        });
         Map<String, List<AppDesc>> result = Collections.emptyMap();
         try {
             Map<String, List<String>> apps = Collections.emptyMap();
             Commands.ListComponentsCommand cmd = new Commands.ListComponentsCommand(container);
-            serverCmd = cmd;
-            Future<OperationState> task = executor().submit(this);
-            OperationState state = task.get();
+            OperationState state = inner.execute(cmd).get();
             if (state == OperationState.COMPLETED) {
                 apps = cmd.getApplicationMap();
             }
+            if (null == apps || apps.isEmpty()) {
+                return result;
+            }
             ServerCommand.GetPropertyCommand getCmd = new ServerCommand.GetPropertyCommand("applications.application.*");
-            serverCmd = getCmd;
-            task = executor().submit(this);
-            state = task.get();
+            state = inner.execute(getCmd).get();
             if (state == OperationState.COMPLETED) {
-                result = processApplications(apps, getCmd.getData());
+                ServerCommand.GetPropertyCommand getRefs = new ServerCommand.GetPropertyCommand("servers.server.server.application-ref.*");
+                state = inner.execute(getRefs).get();
+                if (OperationState.COMPLETED == state) {
+                    result = processApplications(apps, getCmd.getData(),getRefs.getData());
+                }
             }
         } catch (InterruptedException ex) {
             Logger.getLogger("glassfish").log(Level.INFO, ex.getMessage(), ex);  // NOI18N
@@ -171,10 +258,11 @@ public class CommandRunner extends BasicTask<OperationState> {
         return result;
     }
 
-    private Map<String, List<AppDesc>> processApplications(Map<String, List<String>> appsList, Map<String, String> properties){
+    private Map<String, List<AppDesc>> processApplications(Map<String, List<String>> appsList, Map<String, String> properties, Map<String, String> refProperties){
         Map<String, List<AppDesc>> result = new HashMap<String, List<AppDesc>>();
         Iterator<String> appsItr = appsList.keySet().iterator();
         while (appsItr.hasNext()) {
+            boolean enabled = false;
             String engine = appsItr.next();
             List<String> apps = appsList.get(engine);
             for (int i = 0; i < apps.size(); i++) {
@@ -197,19 +285,60 @@ public class CommandRunner extends BasicTask<OperationState> {
                 }
                 if (path.startsWith("file:")) {  // NOI18N
                     path = path.substring(5);
+                    path = (new File(path)).getAbsolutePath();
                 }
 
-                List<AppDesc> appList = result.get(engine);
-                if(appList == null) {
-                    appList = new ArrayList<AppDesc>();
-                    result.put(engine, appList);
+                String enabledKey = "servers.server.server.application-ref."+name+".enabled";
+                String enabledValue = refProperties.get(enabledKey);
+                if (null != enabledValue) {
+                    enabled = Boolean.parseBoolean(enabledValue);
+
+                    List<AppDesc> appList = result.get(engine);
+                    if(appList == null) {
+                        appList = new ArrayList<AppDesc>();
+                        result.put(engine, appList);
+                    }
+                    appList.add(new AppDesc(name, path, contextRoot, enabled));
                 }
-                appList.add(new AppDesc(name, path, contextRoot));
             }
         }
         return result;
     }
-    
+
+    /**
+     * Sends list-web-services command to server (synchronous)
+     *
+     * @return String array of names of deployed applications.
+     */
+    public List<WSDesc> getWebServices() {
+        List<WSDesc> result = Collections.emptyList();
+        try {
+            List<String> wss = Collections.emptyList();
+            Commands.ListWebservicesCommand cmd = new Commands.ListWebservicesCommand();
+            serverCmd = cmd;
+            Future<OperationState> task = executor().submit(this);
+            OperationState state = task.get();
+            if (state == OperationState.COMPLETED) {
+                wss = cmd.getWebserviceList();
+
+                result = processWebServices(wss);
+            }
+        } catch (InterruptedException ex) {
+            Logger.getLogger("glassfish").log(Level.INFO, ex.getMessage(), ex);  // NOI18N
+        } catch (ExecutionException ex) {
+            Logger.getLogger("glassfish").log(Level.INFO, ex.getMessage(), ex);  // NOI18N
+        }
+        return result;
+    }
+
+    private List<WSDesc> processWebServices(List<String> wssList){
+        List<WSDesc> result = new  ArrayList<WSDesc>();
+        for (String a : wssList) {
+            result.add(new WSDesc(a, a+"?wsdl", a+"?Tester")); // NOI18N
+        }
+        return result;
+    }
+
     public List<ResourceDesc> getResources(String type) {
         List<ResourceDesc> result = Collections.emptyList();
         try {
@@ -227,7 +356,7 @@ public class CommandRunner extends BasicTask<OperationState> {
         }
         return result;
     }
-    
+
     public Map<String, String> getResourceData(String name) {
         try {
             GetPropertyCommand cmd;
@@ -256,7 +385,7 @@ public class CommandRunner extends BasicTask<OperationState> {
         }
         return new HashMap<String,String>();
     }
-    
+
     public void putResourceData(Map<String, String> data) throws PartialCompletionException {
         Set<String> keys = data.keySet();
         String itemsNotUpdated = null;
@@ -301,18 +430,21 @@ public class CommandRunner extends BasicTask<OperationState> {
     public Future<OperationState> deploy(File dir, String moduleName) {
         return deploy(dir, moduleName, null);
     }
-    
+
     public Future<OperationState> deploy(File dir, String moduleName, String contextRoot)  {
-        return deploy(dir, moduleName, contextRoot, null);
+        return deploy(dir, moduleName, contextRoot, null, new File[0]);
     }
-    
-    Future<OperationState> deploy(File dir, String moduleName, String contextRoot, Map<String,String> properties) {
+
+    public Future<OperationState> deploy(File dir, String moduleName, String contextRoot, Map<String,String> properties, File[] libraries) {
+        LogViewMgr.displayOutput(ip,null);
         return execute(new Commands.DeployCommand(dir, moduleName,
-                contextRoot, computePreserveSessions(ip), properties));
+                contextRoot, computePreserveSessions(ip), properties, libraries));
     }
-        public Future<OperationState> redeploy(String moduleName, String contextRoot)  {
-        return execute(new Commands.RedeployCommand(moduleName, contextRoot, 
-                computePreserveSessions(ip)));
+
+    public Future<OperationState> redeploy(String moduleName, String contextRoot, File[] libraries, boolean resourcesChanged)  {
+        LogViewMgr.displayOutput(ip,null);
+        return execute(new Commands.RedeployCommand(moduleName, contextRoot,
+                computePreserveSessions(ip), libraries, resourcesChanged));
     }
 
     private static Boolean computePreserveSessions(Map<String,String> ip) {
@@ -325,11 +457,20 @@ public class CommandRunner extends BasicTask<OperationState> {
         }
         return Boolean.parseBoolean(sessionPreservationFlag);
     }
-    
+
     public Future<OperationState> undeploy(String moduleName) {
+        LogViewMgr.displayOutput(ip,null);
         return execute(new Commands.UndeployCommand(moduleName));
     }
-    
+
+    public Future<OperationState> enable(String moduleName) {
+        return execute(new Commands.EnableCommand(moduleName));
+    }
+
+    public Future<OperationState> disable(String moduleName) {
+        return execute(new Commands.DisableCommand(moduleName));
+    }
+
     public Future<OperationState> unregister(String resourceName, String suffix, String cmdPropName, boolean cascade) {
         return execute(new Commands.UnregisterCommand(resourceName, suffix, cmdPropName, cascade));
     }
@@ -350,7 +491,7 @@ public class CommandRunner extends BasicTask<OperationState> {
         }
         return retVal;
     }
-    
+
     private Future<OperationState> execute(ServerCommand command, String msgResId) {
         serverCmd = command;
         if(msgResId != null) {
@@ -358,8 +499,8 @@ public class CommandRunner extends BasicTask<OperationState> {
         }
         return executor().submit(this);
     }
-    
-    /** Executes one management task. 
+
+    /** Executes one management task.
      */
     @Override
     public OperationState call() {
@@ -370,34 +511,35 @@ public class CommandRunner extends BasicTask<OperationState> {
             return fireOperationStateChanged(OperationState.FAILED, "MSG_ServerCmdFailedIncorrectInstance", // NOI18N
                     serverCmd.toString(), instanceName);
         }
-        
+
         boolean httpSucceeded = false;
         boolean commandSucceeded = false;
         URL urlToConnectTo = null;
         URLConnection conn = null;
+        HttpURLConnection hconn = null;
         String commandUrl;
-        
+
         try {
-            commandUrl = constructCommandUrl(serverCmd.getCommand(), serverCmd.getQuery());
+            commandUrl = constructCommandUrl(serverCmd.getSrc(), serverCmd.getCommand(), serverCmd.getQuery());
         } catch (URISyntaxException ex) {
             return fireOperationStateChanged(OperationState.FAILED, "MSG_ServerCmdException",  // NOI18N
                     serverCmd.toString(), instanceName, ex.getLocalizedMessage());
         }
 
         int retries = 1; // disable ("version".equals(cmd) || "__locations".equals(cmd)) ? 1 : 3;
-        Logger.getLogger("glassfish").log(Level.FINEST, "CommandRunner.call(" + commandUrl + ") called on thread \"" + Thread.currentThread().getName() + "\""); // NOI18N
-        
+        Logger.getLogger("glassfish").log(Level.FINEST, "CommandRunner.call({0}) called on thread \"{1}\"", new Object[]{commandUrl, Thread.currentThread().getName()}); // NOI18N
+
         // Create a connection for this command
         try {
             urlToConnectTo = new URL(commandUrl);
 
             while(!httpSucceeded && retries-- > 0) {
                 try {
-                    Logger.getLogger("glassfish").log(Level.FINE, "HTTP Command: " + commandUrl ); // NOI18N
+                    Logger.getLogger("glassfish").log(Level.FINE, "HTTP Command: {0}", commandUrl); // NOI18N
 
                     conn = urlToConnectTo.openConnection();
                     if(conn instanceof HttpURLConnection) {
-                        HttpURLConnection hconn = (HttpURLConnection) conn;
+                        hconn = (HttpURLConnection) conn;
 
                         if (conn instanceof HttpsURLConnection) {
                             // let's just trust any server that we connect to...
@@ -405,14 +547,17 @@ public class CommandRunner extends BasicTask<OperationState> {
                             TrustManager[] tm = new TrustManager[]{
                                 new X509TrustManager() {
 
+                                @Override
                                     public void checkClientTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                                         return;
                                     }
 
+                                @Override
                                     public void checkServerTrusted(X509Certificate[] arg0, String arg1) throws CertificateException {
                                         return;
                                     }
 
+                                @Override
                                     public X509Certificate[] getAcceptedIssuers() {
                                         return null;
                                     }
@@ -424,6 +569,14 @@ public class CommandRunner extends BasicTask<OperationState> {
                                 context = SSLContext.getInstance("SSL");
                                 context.init(null, tm, null);
                                 ((HttpsURLConnection)hconn).setSSLSocketFactory(context.getSocketFactory());
+                                ((HttpsURLConnection)hconn).setHostnameVerifier(new HostnameVerifier() {
+
+                                    @Override
+                                    public boolean verify(String string, SSLSession ssls) {
+                                        return true;
+                                    }
+
+                                });
                             } catch (Exception ex) {
                                 // if there is an issue here... there will be another exception later
                                 // which will take care of the user interaction...
@@ -441,8 +594,20 @@ public class CommandRunner extends BasicTask<OperationState> {
                         String contentType = serverCmd.getContentType();
                         if(contentType != null && contentType.length() > 0) {
                             hconn.setRequestProperty("Content-Type", contentType); // NOI18N
+                            hconn.setChunkedStreamingMode(0);
+                        } else {
+                            // work around that helps prevent tickling the
+                            // GF issue that is the root cause of 195384.
+                            //
+                            // GF doesn't expect to get image content, so it doesn't
+                            // try to handle the content... which prevents the
+                            // exception, according to Tim Quinn.
+                            hconn.setRequestProperty("Content-Type", "image/png");
                         }
                         hconn.setRequestProperty("User-Agent", "hk2-agent"); // NOI18N
+                        if (serverCmd.acceptsGzip()) {
+                            hconn.setRequestProperty("Accept-Encoding", "gzip");
+                        }
 
 //                        // Set up an authorization header with our credentials
 //                        Hk2Properties tp = tm.getHk2Properties();
@@ -458,27 +623,43 @@ public class CommandRunner extends BasicTask<OperationState> {
                         handleSend(hconn);
 
                         int respCode = hconn.getResponseCode();
-                        if(respCode == HttpURLConnection.HTTP_UNAUTHORIZED || 
+                        if(respCode == HttpURLConnection.HTTP_UNAUTHORIZED ||
                                 respCode == HttpURLConnection.HTTP_FORBIDDEN) {
                             // connection to manager has not been allowed
                             authorized = false;
-                            return fireOperationStateChanged(OperationState.FAILED, 
-                                    "MSG_AuthorizationFailed", serverCmd.toString(), instanceName); // NOI18N
+                            String messageId = "MSG_AuthorizationFailed";  // NOI18N
+                            if (ip.get(GlassfishModule.DOMAINS_FOLDER_ATTR) == null) {
+                                messageId = "MSG_AuthorizationFailedRemote"; // NOI18N
+                            }
+                            return fireOperationStateChanged(OperationState.FAILED,
+                                    messageId, serverCmd.toString(), instanceName);
                         }
 
                         // !PW FIXME log status for debugging purposes
                         if(Boolean.getBoolean("org.netbeans.modules.hk2.LogManagerCommands")) { // NOI18N
-                            Logger.getLogger("glassfish").log(Level.FINE, "  receiving response, code: " + respCode); // NOI18N
+                            Logger.getLogger("glassfish").log(Level.FINE, "  receiving response, code: {0}", respCode); // NOI18N
                         }
 
                         // Process the response message
                         if(handleReceive(hconn)) {
                             commandSucceeded = serverCmd.processResponse();
+                        } else {
+                            Logger.getLogger("glassfish").log(Level.WARNING, hconn.toString());
+                            Logger.getLogger("glassfish").log(Level.WARNING, hconn.getContentType());
+                            Logger.getLogger("glassfish").log(Level.WARNING, hconn.getContentEncoding());
+                            Map<String,List<String>> ms2ls = hconn.getHeaderFields();
+                            Logger.getLogger("glassfish").log(Level.WARNING, "Header Fields");
+                            for (Entry<String,List<String>> e : ms2ls.entrySet()) {
+                                Logger.getLogger("glassfish").log(Level.WARNING, e.getKey()+" = ");
+                                for (String v : e.getValue()) {
+                                    Logger.getLogger("glassfish").log(Level.WARNING, "     "+v);
+                                }
+                            }
                         }
-                        
+
                         httpSucceeded = true;
                     } else {
-                        Logger.getLogger("glassfish").log(Level.INFO, "Unexpected connection type: " + urlToConnectTo); // NOI18N
+                        Logger.getLogger("glassfish").log(Level.INFO, "Unexpected connection type: {0}", urlToConnectTo); // NOI18N
                     }
                 } catch(ProtocolException ex) {
                     fireOperationStateChanged(OperationState.FAILED, "MSG_Exception", // NOI18N
@@ -489,8 +670,10 @@ public class CommandRunner extends BasicTask<OperationState> {
                         fireOperationStateChanged(OperationState.FAILED, "MSG_Exception", // NOI18N
                                 ex.getLocalizedMessage());
                     }
+                } finally {
+                    if (null != hconn) hconn.disconnect();
                 }
-                
+
                 if(!httpSucceeded && retries > 0) {
                     try {
                         Thread.sleep(HTTP_RETRY_DELAY);
@@ -500,24 +683,24 @@ public class CommandRunner extends BasicTask<OperationState> {
         } catch(MalformedURLException ex) {
             Logger.getLogger("glassfish").log(Level.WARNING, ex.getLocalizedMessage(), ex); // NOI18N
         }
-        
+
         if(commandSucceeded) {
             return fireOperationStateChanged(OperationState.COMPLETED, "MSG_ServerCmdCompleted", // NOI18N
                     serverCmd.toString(), instanceName);
         } else {
             return fireOperationStateChanged(OperationState.FAILED, "MSG_ServerCmdFailed", // NOI18N
-                    serverCmd.toString(), instanceName);
+                    serverCmd.toString(), instanceName, serverCmd.getServerMessage());
         }
     }
-    
-    private String constructCommandUrl(final String cmd, final String query) throws URISyntaxException {
+
+    private String constructCommandUrl(final String cmdSrc, final String cmd, final String query) throws URISyntaxException {
         String host = ip.get(GlassfishModule.HOSTNAME_ATTR);
         boolean useAdminPort = !"false".equals(System.getProperty("glassfish.useadminport")); // NOI18N
         int port = Integer.parseInt(ip.get(useAdminPort ? GlassfishModule.ADMINPORT_ATTR : GlassfishModule.HTTPPORT_ATTR));
-        URI uri = new URI(Utils.getHttpListenerProtocol(host,port), null, host, port, "/__asadmin/" + cmd, query, null); // NOI18N
+        URI uri = new URI(Utils.getHttpListenerProtocol(host,port), null, host, port, cmdSrc + cmd, query, null); // NOI18N
         return uri.toASCIIString().replace("+", "%2b"); // these characters don't get handled by GF correctly... best I can tell.
     }
-    
+
 
     /*
      * Note: this is based on reading the code of CLIRemoteCommand.java
@@ -551,8 +734,8 @@ public class CommandRunner extends BasicTask<OperationState> {
                     Logger.getLogger("glassfish").log(Level.INFO, ex.getLocalizedMessage(), ex); // NOI18N
                 }
                 if(ostream != null) {
-                    try { 
-                        ostream.close(); 
+                    try {
+                        ostream.close();
                     } catch(IOException ex) {
                         Logger.getLogger("glassfish").log(Level.INFO, ex.getLocalizedMessage(), ex);  // NOI18N
                     }
@@ -563,40 +746,24 @@ public class CommandRunner extends BasicTask<OperationState> {
             Logger.getLogger("glassfish").log(Level.INFO, "HTTP POST request but no data stream provided"); // NOI18N
         }
     }
-    
-    private byte [] getExtraProperties() {
-        boolean success = false;
+
+    private byte[] getExtraProperties() {
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        ObjectOutputStream oos = null;
-        try {
-            Properties props = new Properties();
-            props.setProperty("data-request-type", "file-xfer"); // NOI18N
-            props.setProperty("data-request-name", serverCmd.getInputName()); // NOI18N
-            props.setProperty("last-modified", serverCmd.getLastModified()); // NOI18N
-            oos = new ObjectOutputStream(baos);
-            oos.writeObject(props);
-        } catch(IOException ex) {
-            Logger.getLogger("glassfish").log(Level.WARNING, // NOI18N
-                    "Error writing zip properties for archive deployment of " + serverCmd.getInputName(), ex); // NOI18N
-        } finally {
-            if(oos != null) {
-                try {
-                    oos.close();
-                    success = true;
-                } catch(IOException ex) {
-                    Logger.getLogger("glassfish").log(Level.WARNING, // NOI18N
-                            "Error writing zip properties for archive deployment of " + serverCmd.getInputName(), ex); // NOI18N
-                }
-            }
-        }
-        return success ? baos.toByteArray() : new byte [0];
+        Properties props = new Properties();
+        props.setProperty("data-request-type", "file-xfer"); // NOI18N
+        props.setProperty("last-modified", serverCmd.getLastModified()); // NOI18N
+        props.put("data-request-name", "DEFAULT");
+        props.put("data-request-is-recursive", "true");
+        props.put("Content-Type", "application/octet-stream");
+        props.list(new java.io.PrintStream(baos));
+        return baos.toByteArray();
     }
 
     private boolean handleReceive(HttpURLConnection hconn) throws IOException {
         boolean result = false;
         InputStream httpInputStream = hconn.getInputStream();
         try {
-            result = serverCmd.readResponse(httpInputStream);
+            result = serverCmd.readResponse(httpInputStream, hconn);
         } finally {
             try {
                 httpInputStream.close();
