@@ -46,10 +46,13 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.StringWriter;
+import java.net.HttpURLConnection;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -58,10 +61,11 @@ import java.util.jar.Attributes;
 import java.util.jar.Manifest;
 import java.util.logging.Level;
 import java.util.logging.Logger;
-import org.netbeans.modules.glassfish.spi.AppDesc;
+import java.util.zip.GZIPInputStream;
 import org.netbeans.modules.glassfish.spi.ResourceDesc;
 import org.netbeans.modules.glassfish.spi.ServerCommand;
 import org.netbeans.modules.glassfish.spi.Utils;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 
 /**
@@ -85,147 +89,7 @@ public class Commands {
     public static final ServerCommand STOP = new ServerCommand("stop-domain") { // NOI18N
     };
 
-    /**
-     * Command to list applications current deployed on the server.
-     */
-    public static final class ListAppsCommand extends ServerCommand {
-
-        private final String container;
-        private Manifest list;
-        private Map<String, List<AppDesc>> appMap;
-
-        public ListAppsCommand() {
-            this(null);
-        }
-
-        public ListAppsCommand(final String container) {
-            super("list-applications"); // NOI18N
-            this.container = container;
-        }
-
-        public String[] getContainers() {
-            String[] result = null;
-            if(appMap != null && appMap.size() > 0) {
-                Set<String> containers = appMap.keySet();
-                result = containers.toArray(new String[containers.size()]);
-            }
-            return result != null ? result : new String[0];
-        }
-
-        public Map<String, List<AppDesc>> getApplicationMap() {
-            // !PW Can still modify sublist... is there a better structure?
-            if(appMap != null) {
-                return Collections.unmodifiableMap(appMap);
-            } else {
-                return Collections.emptyMap();
-            }
-        }
-
-        @Override
-        public void readManifest(Manifest manifest) throws IOException {
-            list = manifest;
-        }
-
-        @Override
-        public boolean processResponse() {
-            if(list == null) {
-                return false;
-            }
-
-            String appsList = list.getMainAttributes().getValue("children"); // NOI18N
-            if(appsList == null || appsList.length() == 0) {
-                // no applications deployed...
-                return true;
-            }
-
-            String[] apps = appsList.split(";"); // NOI18N
-            for(String appKey : apps) {
-                if("null".equals(appKey)) { // NOI18N
-                    Logger.getLogger("glassfish").log(Level.WARNING, "list-applications contains an invalid result.  " + "Check server log for possible exceptions."); // NOI18N
-                    continue;
-                }
-
-                Attributes appAttrs = list.getAttributes(appKey);
-                if(appAttrs == null) {
-                    continue;
-                }
-
-                String engine = getPreferredEngine(appAttrs.getValue("nb-engine_value")); // NOI18N
-
-                String name = appAttrs.getValue("nb-name_value");  // NOI18N
-                if(name == null || name.length() == 0) {
-                    Logger.getLogger("glassfish").log(Level.FINE, "Skipping application with no name..."); // NOI18N  FIXME better log message.
-                    continue;
-                }
-
-                String path = appAttrs.getValue("nb-location_value");  // NOI18N
-                if(path.startsWith("file:")) {  // NOI18N
-                    path = path.substring(5);
-                }
-
-                String contextRoot = appAttrs.getValue("nb-context-root_value"); // NOI18N
-                if(contextRoot == null) {
-                    contextRoot = name;
-                }
-                if(contextRoot.startsWith("/")) {  // NOI18N
-                    contextRoot = contextRoot.substring(1);
-                }
-
-                // Add app to proper list in result map
-                if(appMap == null) {
-                    appMap = new HashMap<String, List<AppDesc>>();
-                }
-                List<AppDesc> appList = appMap.get(engine);
-                if(appList == null) {
-                    appList = new ArrayList<AppDesc>();
-                    appMap.put(engine, appList);
-                }
-
-                appList.add(new AppDesc(name, path, contextRoot));
-            }
-
-            return true;
-        }
-        // XXX temporary patch to handle engine descriptions like <web, ejb>
-        // until we have better display semantics for such things.
-        // XXX bias order of list for JavaONE demos.
-        private static final List<String> engineBias =
-                Arrays.asList(new String[]{"jruby", "web", "ejb"}); // NOI18N
-
-        private String getPreferredEngine(String engineList) {
-            String[] engines = engineList.split(",");  // NOI18N
-            String engine = null;
-            int bias = -1;
-            for(int i = 0; i < engines.length; i++) {
-                if(!skipContainer(engines[i])) {
-                    engines[i] = engines[i].trim();
-                    int newBias = engineBias.indexOf(engines[i]);
-                    if(newBias >= 0 && (bias == -1 || newBias < bias)) {
-                        bias = newBias;
-                    }
-                    if(engine == null) {
-                        engine = engines[i];
-                    }
-                }
-            }
-            if(bias != -1) {
-                engine = engineBias.get(bias);
-            } else if(engine == null) {
-                engine = "unknown"; // NOI18N
-            }
-            return engine;
-        }
-
-        /**
-         * For skipping containers we don't care about.
-         * 
-         * @param container
-         * @return
-         */
-        private boolean skipContainer(String currentContainer) {
-            return container != null ? !container.equals(currentContainer) :
-                    "security_ContractProvider".equals(currentContainer); // NOI18N
-        }
+    public static final ServerCommand RESTART = new ServerCommand("restart-domain") { // NOI18N
     };
 
     /**
@@ -416,7 +280,7 @@ public class Commands {
                         resList.add(new ResourceDesc(name, cmdSuffix));
                     }
                 } else {
-                    Logger.getLogger("glassfish").log(Level.FINE, "No resource attributes returned for " + r); // NOI18N
+                    Logger.getLogger("glassfish").log(Level.FINE, "No resource attributes returned for {0}", r); // NOI18N
                 }
             }
 
@@ -428,6 +292,18 @@ public class Commands {
         }
     };
 
+    private static void appendLibraries(StringBuilder cmd, File[] libraries) {
+        cmd.append(ServerCommand.PARAM_SEPARATOR).append("libraries="); // NOI18N
+        boolean firstOne = true;
+        for (File f : libraries) {
+            if (!firstOne) {
+                cmd.append(",");
+            }
+            cmd.append(f.getPath()); // NOI18N
+            firstOne = false;
+        }
+    }
+
     /**
      * Command to deploy a directory
      */
@@ -436,24 +312,27 @@ public class Commands {
         private final boolean isDirDeploy;
         private final File path;
 
-        public DeployCommand(final File path, final String name, final String contextRoot, final Boolean preserveSessions, final Map<String,String> properties) {
+        public DeployCommand(final File path, final String name, final String contextRoot, final Boolean preserveSessions, final Map<String,String> properties, File[] libraries) {
             super("deploy"); // NOI18N
 
             this.isDirDeploy = path.isDirectory();
             this.path = path;
             
             StringBuilder cmd = new StringBuilder(128);
-            cmd.append("path="); // NOI18N
+            cmd.append("DEFAULT="); // NOI18N
             cmd.append(path.getAbsolutePath());
             if(name != null && name.length() > 0) {
-                cmd.append(PARAM_SEPARATOR + "name="); // NOI18N
+                cmd.append(PARAM_SEPARATOR).append("name="); // NOI18N
                 cmd.append(Utils.sanitizeName(name));
             }
             if(contextRoot != null && contextRoot.length() > 0) {
-                cmd.append(PARAM_SEPARATOR + "contextroot="); // NOI18N
+                cmd.append(PARAM_SEPARATOR).append("contextroot="); // NOI18N
                 cmd.append(contextRoot);
             }
-            cmd.append(PARAM_SEPARATOR + "force=true"); // NOI18N
+            if (libraries.length > 0) {
+                appendLibraries(cmd, libraries);
+            }
+            cmd.append(PARAM_SEPARATOR).append("force=true"); // NOI18N
             addProperties(cmd,properties);
             query = cmd.toString();
         }
@@ -470,10 +349,15 @@ public class Commands {
 
         @Override
         public InputStream getInputStream() {
-            try {
-                return isDirDeploy ? null : new FileInputStream(path);
-            } catch(FileNotFoundException ex) {
-                return null;
+                if (isDirDeploy) {
+                    return null;
+                } else {
+                    try {
+                        return new FileInputStream(path);
+                    } catch (FileNotFoundException fnfe) {
+                        Logger.getLogger("glassfish").log(Level.INFO, path.getPath(), fnfe); // NOI18N
+                        return null;
+                    }
             }
         }
 
@@ -494,7 +378,7 @@ public class Commands {
 
         private void addProperties(StringBuilder cmd, Map<String,String> properties) {
             if (null != properties && properties.size() > 0) {
-                cmd.append(ServerCommand.PARAM_SEPARATOR + "properties="); // NOI18N
+                cmd.append(ServerCommand.PARAM_SEPARATOR).append("properties="); // NOI18N
                 int i = 0;
                 for (Entry<String,String> e : properties.entrySet()) {
                     String k = e.getKey();
@@ -502,7 +386,7 @@ public class Commands {
                     if (i > 0) {
                         cmd.append(":"); // NOI18N
                     }
-                    cmd.append(k+"="+v);
+                    cmd.append(k).append("=").append(v);
                 }
             }
         }
@@ -513,25 +397,37 @@ public class Commands {
      */
     public static final class RedeployCommand extends ServerCommand {
 
-        public RedeployCommand(final String name, final String contextRoot, final Boolean preserveSessions) {
+        public RedeployCommand(final String name, final String contextRoot, final Boolean preserveSessions, 
+                final File[] libraries, final boolean resourcesChanged) {
             super("redeploy"); // NOI18N
 
             StringBuilder cmd = new StringBuilder(128);
             cmd.append("name="); // NOI18N
             cmd.append(Utils.sanitizeName(name));
             if(contextRoot != null && contextRoot.length() > 0) {
-                cmd.append(PARAM_SEPARATOR + "contextroot="); // NOI18N
+                cmd.append(PARAM_SEPARATOR).append("contextroot="); // NOI18N
                 cmd.append(contextRoot);
             }
-            addKeepSessions(cmd, preserveSessions);
+            if (libraries.length > 0) {
+                appendLibraries(cmd, libraries);
+            }
+            addProperties(cmd, preserveSessions, resourcesChanged);
             query = cmd.toString();
         }
     }
 
-    private static void addKeepSessions(StringBuilder cmd, Boolean preserveSessions) {
+    private static void addProperties(StringBuilder cmd, Boolean preserveSessions, boolean resourcesChanged) {
+        if(Boolean.TRUE.equals(preserveSessions) || !resourcesChanged) {
+            cmd.append(ServerCommand.PARAM_SEPARATOR).append("properties="); // NOI18N
+        }
         if(Boolean.TRUE.equals(preserveSessions)) {
-            cmd.append(ServerCommand.PARAM_SEPARATOR + "properties="); // NOI18N
             cmd.append("keepSessions=true");  // NOI18N
+            if (!resourcesChanged) {
+                cmd.append(":"); // NOI18N
+            }
+        }
+        if (!resourcesChanged) {
+            cmd.append("preserveAppScopedResources=true"); // NOI18N
         }
     }
 
@@ -546,6 +442,27 @@ public class Commands {
         }
     }
 
+    /**
+     * Command to enable a deployed application.
+     */
+    public static final class EnableCommand extends ServerCommand {
+
+        public EnableCommand(final String name) {
+            super("enable"); // NOI18N
+            query = "DEFAULT=" + Utils.sanitizeName(name); // NOI18N
+        }
+    }
+
+    /**
+     * Command to disable a deployed application.
+     */
+    public static final class DisableCommand extends ServerCommand {
+
+        public DisableCommand(final String name) {
+            super("disable"); // NOI18N
+            query = "DEFAULT=" + Utils.sanitizeName(name); // NOI18N
+        }
+    }
     /**
      * Command to unregister a resource.
      */
@@ -630,5 +547,123 @@ public class Commands {
             return true;
         }
     }
+    
+    /*
+     * Command to get log data from the server
+     */
+    public static final class FetchLogData extends ServerCommand {
+        private String lines = "";
+        private String nextURL = "";
+        
+        public FetchLogData(String query) {
+            super("view-log");
+            this.query = query;
+        }
+        
+        public String getLines() {
+            return lines;
+        }
+
+        public String getNextQuery() {
+            return nextURL;
+        }
+
+        @Override
+        public boolean acceptsGzip() {
+            return true;
+        }
+        
+        @Override
+        public boolean readResponse(InputStream in, HttpURLConnection hconn) {
+            StringWriter sw = new StringWriter();
+            try {
+                InputStream cooked = in;
+                String ce = hconn.getContentEncoding();
+                if (null != ce && ce.contains("gzip")) {
+                    cooked = new GZIPInputStream(in);
+                }
+                java.io.InputStreamReader isr = new java.io.InputStreamReader(cooked);
+                java.io.BufferedReader br = new java.io.BufferedReader(isr);
+                while (br.ready()) {
+                    sw.write(br.readLine());
+                    sw.write("\n");
+                }
+            } catch (IOException ex) {
+                Exceptions.printStackTrace(ex);
+            } finally {
+                try {
+                    sw.close();
+                } catch (IOException ex) {
+                    Exceptions.printStackTrace(ex);
+                }
+            }
+            lines = sw.toString();
+            nextURL = hconn.getHeaderField("X-Text-Append-Next");
+            int delim = nextURL.lastIndexOf("?");
+            if (-1 != delim) {
+                nextURL = nextURL.substring(delim+1);
+            }
+            return -1 == delim ? false : true;
+        }
+        
+        @Override
+        public String getSrc() {
+            return "/management/domain/";
+        }
+    }
+
+    static class ListWebservicesCommand extends ServerCommand {
+
+        private Manifest manifest;
+        private List<String> wsList;
+
+        public ListWebservicesCommand() {
+            super("__list-webservices"); // NOI18N
+        }
+
+        public List<String> getWebserviceList() {
+            // !PW Can still modify sublist... is there a better structure?
+            if(wsList != null) {
+                return Collections.unmodifiableList(wsList);
+            } else {
+                return Collections.emptyList();
+            }
+        }
+
+        @Override
+        public void readManifest(Manifest manifest) throws IOException {
+            this.manifest = manifest;
+        }
+
+        @Override
+        public boolean processResponse() {
+            if(manifest == null) {
+                return false;
+            }
+            
+            Map <String, String> filter = new HashMap<String, String>();
+
+            Iterator<String> keyIterator = manifest.getEntries().keySet().iterator();
+            while (keyIterator.hasNext()) {
+                String k = keyIterator.next();
+                if (!k.contains("address:/")) // NOI18N
+                    continue;
+                if (k.contains("address:/wsat-wsat")) // NOI18N
+                    continue;
+                if (k.contains("address:/__wstx-services")) // NOI18N
+                    continue;
+                String a = k.replaceFirst(".* address:/", "").replaceFirst("\\. .*", ""); // NOI18N
+                if (filter.containsKey(a))
+                    continue;
+                filter.put(a,a);
+                if(wsList == null) {
+                    wsList = new ArrayList<String>();
+                }
+                wsList.add(a);
+            }
+
+            return true;
+        }
+    }
 }
 
