@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -75,6 +75,7 @@ import org.netbeans.modules.glassfish.spi.ResourceDesc;
 import org.netbeans.modules.glassfish.spi.ServerCommand;
 import org.netbeans.modules.glassfish.spi.ServerCommand.GetPropertyCommand;
 import org.netbeans.modules.glassfish.spi.CommandFactory;
+import org.netbeans.modules.glassfish.spi.GlassfishModule2;
 import org.netbeans.modules.glassfish.spi.Utils;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
@@ -83,6 +84,7 @@ import org.openide.filesystems.FileUtil;
 import org.openide.util.ChangeSupport;
 import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
+import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 
 
@@ -90,7 +92,7 @@ import org.openide.util.RequestProcessor;
  *
  * @author Peter Williams
  */
-public class CommonServerSupport implements GlassfishModule, RefreshModulesCookie {
+public class CommonServerSupport implements GlassfishModule2, RefreshModulesCookie {
 
     private final transient Lookup lookup;
     private final Map<String, String> properties =
@@ -124,13 +126,12 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         updateString(ip,GlassfishModule.START_DERBY_FLAG, isRemote ? "false" : "true"); // NOI18N
         updateString(ip,GlassfishModule.USE_IDE_PROXY_FLAG, "true");  // NOI18N
         updateString(ip,GlassfishModule.DRIVER_DEPLOY_FLAG, "true");  // NOI18N
+        String deployerUri = ip.get(GlassfishModule.URL_ATTR);
 
-        if(ip.get(GlassfishModule.URL_ATTR) == null) {
-            String deployerUrl = instanceProvider.formatUri(glassfishRoot, hostName, adminPort);
-            ip.put(URL_ATTR, deployerUrl);
-        }
-
-        ip.put(JVM_MODE, isRemote ? DEBUG_MODE : NORMAL_MODE);
+        // Asume a local instance is in NORMAL_MODE
+        // Assume remote Prelude and 3.0 instances are in DEBUG (we cannot change them)
+        // Assume a remote 3.1 instance is in NORMAL_MODE... we can restart it into debug mode
+        ip.put(JVM_MODE, isRemote && !deployerUri.contains("deployer:gfv3ee6wc") ? DEBUG_MODE : NORMAL_MODE);
         properties.putAll(ip);
         
         // XXX username/password handling at some point.
@@ -323,23 +324,25 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         return isRemote;
     }
 
+    private static final RequestProcessor RP = new RequestProcessor("CommonServerSupport - start/stop/refresh",5); // NOI18N
+
     @Override
     public Future<OperationState> startServer(final OperationStateListener stateListener) {
-        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.startServer called on thread \"" + Thread.currentThread().getName() + "\""); // NOI18N
+        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.startServer called on thread \"{0}\"", Thread.currentThread().getName()); // NOI18N
         OperationStateListener startServerListener = new StartOperationStateListener(GlassfishModule.ServerState.RUNNING);
         FutureTask<OperationState> task = new FutureTask<OperationState>(
                 new StartTask(this, getRecognizers(), startServerListener, stateListener));
-        RequestProcessor.getDefault().post(task);
+        RP.post(task);
         return task;
     }
 
     @Override
     public Future<OperationState> startServer(final OperationStateListener stateListener, FileObject jdkRoot, String[] jvmArgs) {
-        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.startServer called on thread \"" + Thread.currentThread().getName() + "\""); // NOI18N
+        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.startServer called on thread \"{0}\"", Thread.currentThread().getName()); // NOI18N
         OperationStateListener startServerListener = new StartOperationStateListener(GlassfishModule.ServerState.STOPPED_JVM_PROFILER);
         FutureTask<OperationState> task = new FutureTask<OperationState>(
                 new StartTask(this, getRecognizers(), jdkRoot, jvmArgs, startServerListener, stateListener));
-        RequestProcessor.getDefault().post(task);
+        RP.post(task);
         return task;
     }
     
@@ -358,11 +361,10 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         return recognizers;
     }
     
-    private static final RequestProcessor RP = new RequestProcessor("CommonServerSupport - stop/refresh",5); // NOI18N
 
     @Override
     public Future<OperationState> stopServer(final OperationStateListener stateListener) {
-        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.stopServer called on thread \"" + Thread.currentThread().getName() + "\""); // NOI18N
+        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.stopServer called on thread \"{0}\"", Thread.currentThread().getName()); // NOI18N
         OperationStateListener stopServerListener = new OperationStateListener() {
             @Override
             public void operationStateChanged(OperationState newState, String message) {
@@ -375,9 +377,14 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
                 }
             }
         };
-        FutureTask<OperationState> task = new FutureTask<OperationState>(
+        FutureTask<OperationState> task = null;
+        if (!isRemote()) {
+            task = new FutureTask<OperationState>(
                 new StopTask(this, stopServerListener, stateListener));
         // prevent j2eeserver from stopping a server it did not start.
+        } else {
+            task = new FutureTask<OperationState>(new NoopTask(this,stopServerListener,stateListener));
+        }
         if (stopDisabled) {
             stopServerListener.operationStateChanged(OperationState.COMPLETED, "");
             if (null != stateListener) {
@@ -391,10 +398,10 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
 
     @Override
     public Future<OperationState> restartServer(OperationStateListener stateListener) {
-        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.restartServer called on thread \"" + Thread.currentThread().getName() + "\""); // NOI18N
+        Logger.getLogger("glassfish").log(Level.FINEST, "CSS.restartServer called on thread \"{0}\"", Thread.currentThread().getName()); // NOI18N
         FutureTask<OperationState> task = new FutureTask<OperationState>(
                 new RestartTask(this, stateListener));
-        RequestProcessor.getDefault().post(task);
+        RP.post(task);
         return task;
     }
     
@@ -413,22 +420,32 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
     @Override
     public Future<OperationState> deploy(final OperationStateListener stateListener,
             final File application, final String name, final String contextRoot, Map<String,String> properties) {
-        CommandRunner mgr = new CommandRunner(isReallyRunning(), getCommandFactory(), getInstanceProperties(), stateListener);
-        
-        return mgr.deploy(application, name, contextRoot, properties);
+        return deploy(stateListener, application, name, contextRoot, null, new File[0]);
     }
     
+    @Override
+    public Future<OperationState> deploy(OperationStateListener stateListener, File application, String name, String contextRoot, Map<String, String> properties, File[] libraries) {
+        CommandRunner mgr = new CommandRunner(isReallyRunning(), getCommandFactory(), getInstanceProperties(), stateListener);
+
+        return mgr.deploy(application, name, contextRoot, properties, libraries);
+    }
+
     @Override
     public Future<OperationState> redeploy(final OperationStateListener stateListener, 
-            final String name) {
-        return redeploy(stateListener, name, null);
+            final String name, boolean resourcesChanged) {
+        return redeploy(stateListener, name, null, resourcesChanged);
     }
         
     @Override
     public Future<OperationState> redeploy(final OperationStateListener stateListener, 
-            final String name, final String contextRoot) {
+            final String name, final String contextRoot, boolean resourcesChanged) {
+        return redeploy(stateListener, name, contextRoot, new File[0], resourcesChanged);
+    }
+
+    @Override
+    public Future<OperationState> redeploy(OperationStateListener stateListener, String name, String contextRoot, File[] libraries, boolean resourcesChanged) {
         CommandRunner mgr = new CommandRunner(isReallyRunning(), getCommandFactory(), getInstanceProperties(), stateListener);
-        return mgr.redeploy(name, contextRoot);
+        return mgr.redeploy(name, contextRoot, libraries, resourcesChanged);
     }
 
     @Override
@@ -437,6 +454,17 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         return mgr.undeploy(name);
     }
     
+    @Override
+    public Future<OperationState> enable(final OperationStateListener stateListener, final String name) {
+        CommandRunner mgr = new CommandRunner(isReallyRunning(), getCommandFactory(), getInstanceProperties(), stateListener);
+        return mgr.enable(name);
+    }
+    @Override
+    public Future<OperationState> disable(final OperationStateListener stateListener, final String name) {
+        CommandRunner mgr = new CommandRunner(isReallyRunning(), getCommandFactory(), getInstanceProperties(), stateListener);
+        return mgr.disable(name);
+    }
+
     @Override
     public Future<OperationState> execute(ServerCommand command) {
         CommandRunner mgr = new CommandRunner(isReallyRunning(), getCommandFactory(), getInstanceProperties());
@@ -447,6 +475,11 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         CommandRunner mgr = new CommandRunner(irr, getCommandFactory(), getInstanceProperties());
         return mgr.execute(command);
     }
+    private Future<OperationState> execute(boolean irr, ServerCommand command, OperationStateListener... osl) {
+        CommandRunner mgr = new CommandRunner(irr, getCommandFactory(), getInstanceProperties(), osl);
+        return mgr.execute(command);
+    }
+
     @Override
     public AppDesc [] getModuleList(String container) {
         CommandRunner mgr = new CommandRunner(isReallyRunning(),getCommandFactory(), getInstanceProperties());
@@ -520,42 +553,81 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         properties.get(key);
     }
     
-    void setInstanceAttr(String name, String value) {
+    boolean setInstanceAttr(String name, String value) {
+        boolean retVal = false;
         if(instanceFO == null || !instanceFO.isValid()) {
             instanceFO = getInstanceFileObject();
         }
-        if(instanceFO != null) {
+        if(instanceFO != null && instanceFO.canWrite()) {
             try {
-                instanceFO.setAttribute(name, value);
+                Object currentValue = instanceFO.getAttribute(name);
+                if (null != currentValue && currentValue.equals(value)) {
+                    // do nothing
+                } else {
+                    instanceFO.setAttribute(name, value);
+                }
+                retVal = true;
             } catch(IOException ex) {
-                Logger.getLogger("glassfish").log(Level.WARNING, "Unable to save attribute " + name + " for " + getDeployerUri(), ex); // NOI18N
+                Logger.getLogger("glassfish").log(Level.WARNING, 
+                        "Unable to save attribute " + name + " in " + instanceFO.getPath() + " for " + getDeployerUri(), ex); // NOI18N
             }
         } else {
-            Logger.getLogger("glassfish").log(Level.WARNING, "Unable to save attribute " + name + " for " + getDeployerUri()); // NOI18N
+            if (null == instanceFO)
+                Logger.getLogger("glassfish").log(Level.WARNING,
+                        "Unable to save attribute {0} for {1} in {3}. Instance file is writable? {2}",
+                        new Object[]{name, getDeployerUri(), false, "null"}); // NOI18N
+            else
+                Logger.getLogger("glassfish").log(Level.WARNING,
+                        "Unable to save attribute {0} for {1} in {3}. Instance file is writable? {2}",
+                        new Object[]{name, getDeployerUri(), instanceFO.canWrite(), instanceFO.getPath()}); // NOI18N
         }
+        return retVal;
     }
     
     void setFileObject(FileObject fo) {
         instanceFO = fo;
     }
 
-    public static boolean isRunning(final String host, final int port) {
+    public static boolean isRunning(final String host, final int port, String name) {
         if(null == host)
             return false;
         
         try {
             InetSocketAddress isa = new InetSocketAddress(host, port);
             Socket socket = new Socket();
-            socket.connect(isa, 100);
-            socket.close();
+            int timeout = 2000;
+            if ("localhost".equals(host) || "127.0.0.1".equals(host)) {
+                timeout = 2000;
+            }
+            socket.connect(isa, timeout);
+            socket.setSoTimeout(timeout);
+            try { socket.close(); } catch (IOException ioe) {
+                Logger.getLogger("glassfish").log(Level.INFO, "closing after test", ioe);
+            }
             return true;
-        } catch(IOException ex) {
+        } catch (java.net.ConnectException ex) {
+            return false;
+        } catch (java.net.SocketTimeoutException ste) {
+            return false;
+        } catch (IOException ioe) {
+            String message = null;
+            if (name == null || "".equals(name.trim())) {
+                message = NbBundle.getMessage(CommonServerSupport.class, 
+                        "MSG_FLAKEY_NETWORK", host, ""+port, ioe.getLocalizedMessage()); // NOI18N
+            } else {
+                message = NbBundle.getMessage(CommonServerSupport.class, 
+                        "MSG_FLAKEY_NETWORK2", host, ""+port, ioe.getLocalizedMessage(), name); // NOI18N
+            }
+            NotifyDescriptor nd = new NotifyDescriptor.Message(message);
+            DialogDisplayer.getDefault().notifyLater(nd);
+            Logger.getLogger("glassfish").log(Level.INFO, "evidence of network flakiness", ioe); // NOI18N
             return false;
         }
     }
     
     public boolean isReallyRunning() {
-        return isRunning(getHostName(), getAdminPortNumber()) && isReady(false,30,TimeUnit.SECONDS);
+        return isRunning(getHostName(), getAdminPortNumber(), properties.get(DISPLAY_NAME_ATTR))
+                && isReady(false,30,TimeUnit.SECONDS);
     }
 
     public boolean isReady(boolean retry, int timeout, TimeUnit units) {
@@ -574,10 +646,26 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
             long start = System.nanoTime();
             Commands.LocationCommand command = new Commands.LocationCommand();
             try {
-                Future<OperationState> result = execute(true,command);
+                Future<OperationState> result = null;
+
+                if (isRemote) {
+                    result = execute(true, command, new OperationStateListener() {
+
+                        @Override
+                        public void operationStateChanged(OperationState newState, String message) {
+                            if (OperationState.FAILED == newState) {
+                                NotifyDescriptor nd = new NotifyDescriptor.Message(message);
+                                DialogDisplayer.getDefault().notifyLater(nd);
+                                Logger.getLogger("glassfish").log(Level.INFO, message);
+                            }
+                        }
+                    });
+                } else {
+                    result = execute(true, command);
+                }
                 if(result.get(timeout, units) == OperationState.COMPLETED) {
                     long end = System.nanoTime();
-                    Logger.getLogger("glassfish").log(Level.FINE, command.getCommand() + " responded in " + (end - start)/1000000 + "ms");  // NOI18N
+                    Logger.getLogger("glassfish").log(Level.FINE, "{0} responded in {1}ms", new Object[]{command.getCommand(), (end - start) / 1000000});  // NOI18N
                     String domainRoot = getDomainsRoot() + File.separator + getDomainName();
                     String targetDomainRoot = command.getDomainRoot();
                     if(getDomainsRoot() != null && targetDomainRoot != null) {
@@ -589,10 +677,10 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
                         // to trust that it is the 'right one'
                         // TODO -- better edge case detection/protection
                         isReady = null != targetDomainRoot;
-                        if (isReady) {
-                            // make sure the http port info is corrected
-                            updateHttpPort();
-                        }
+                    }
+                    if (isReady) {
+                        // make sure the http port info is corrected
+                        updateHttpPort();
                     }
                     break;
                 } else if(!command.retry()) {
@@ -603,11 +691,18 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
                     isReady = result.get(timeout, units) == OperationState.COMPLETED;
                     break;
                 } else {
+                    // keep trying for 10 minutes if the server is stuck between 
+                    // httpLive and server ready state. We have to give up sometime, though.
+                    if (maxtries < 20)
+                        maxtries++;
                     long end = System.nanoTime();
-                    Logger.getLogger("glassfish").log(Level.FINE, command.getCommand() + " timed out inside server after " + (end - start)/1000000 + "ms"); // NOI18N
+                    Logger.getLogger("glassfish").log(Level.INFO, "{0} returned from server after {1}ms. The server is still getting ready", new Object[]{command.getCommand(), (end - start) / 1000000}); // NOI18N
                 }
-            } catch(Exception ex) {
-                Logger.getLogger("glassfish").log(Level.INFO, command.getCommand() + " timed out.", ex); // NOI18N
+            } catch(TimeoutException ex) {
+                Logger.getLogger("glassfish").log(Level.INFO, command.getCommand() + " timed out. "+tries+" of "+maxtries, ex); // NOI18N
+                isReady = false;
+            } catch (Exception ex) {
+                Logger.getLogger("glassfish").log(Level.INFO, command.getCommand() + " failed at  "+tries+" of "+maxtries, ex); // NOI18N
                 isReady = false;
                 break;
             }
@@ -662,6 +757,27 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         return instanceProvider.getCommandFactory();
     }
 
+    @Override
+    public String getResourcesXmlName() {
+        return getDeployerUri().contains(GlassfishInstanceProvider.EE6WC_DEPLOYER_FRAGMENT) ?
+                "glassfish-resources" : "sun-resources"; // NOI18N
+    }
+
+    @Override
+    public boolean supportsRestartInDebug() {
+        return getDeployerUri().contains(GlassfishInstanceProvider.EE6WC_DEPLOYER_FRAGMENT);
+    }
+
+    @Override
+    public boolean isRestfulLogAccessSupported() {
+        return getDeployerUri().contains(GlassfishInstanceProvider.EE6WC_DEPLOYER_FRAGMENT);
+    }
+
+    @Override
+    public boolean isWritable() {
+        return (null == instanceFO) ? false : instanceFO.canWrite();
+    }
+
     class StartOperationStateListener implements OperationStateListener {
         private ServerState endState;
 
@@ -674,7 +790,7 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
             if(newState == OperationState.RUNNING) {
                 setServerState(ServerState.STARTING);
             } else if(newState == OperationState.COMPLETED) {
-                startedByIde = isReady(false,300,TimeUnit.MILLISECONDS);
+                startedByIde = isRemote ? false : isReady(false,300,TimeUnit.MILLISECONDS);
                 setServerState(endState);
             } else if(newState == OperationState.FAILED) {
                 setServerState(ServerState.STOPPED);
@@ -686,15 +802,20 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
     }
 
     private void updateHttpPort() {
-        GetPropertyCommand gpc = new GetPropertyCommand("*.http-listener-1.port"); // NOI18N
+        GetPropertyCommand gpc = new GetPropertyCommand("*.server-config.*.http-listener-1.port"); // NOI18N
         Future<OperationState> result2 = execute(true, gpc);
         try {
             if (result2.get(10, TimeUnit.SECONDS) == OperationState.COMPLETED) {
                 Map<String, String> retVal = gpc.getData();
                 for (Entry<String, String> entry : retVal.entrySet()) {
                     String val = entry.getValue();
-                    if (null != val && val.trim().length() > 0) {
-                        setEnvironmentProperty(GlassfishModule.HTTPPORT_ATTR, val, true);
+                    try {
+                        if (null != val && val.trim().length() > 0) {
+                            Integer.parseInt(val);
+                            setEnvironmentProperty(GlassfishModule.HTTPPORT_ATTR, val, true);
+                        }
+                    } catch (NumberFormatException nfe) {
+                        // skip it quietly..
                     }
                 }
             }
@@ -703,7 +824,7 @@ public class CommonServerSupport implements GlassfishModule, RefreshModulesCooki
         } catch (ExecutionException ex) {
             Logger.getLogger("glassfish").log(Level.INFO, null, ex); // NOI18N
         } catch (TimeoutException ex) {
-            Logger.getLogger("glassfish").log(Level.INFO, null, ex); // NOI18N
+            Logger.getLogger("glassfish").log(Level.INFO, "could not get http port value in 10 seconds from the server", ex); // NOI18N
         }
 
     }
