@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -92,11 +92,6 @@ import org.openide.windows.InputOutput;
  */
 public class GlassfishInstance implements ServerInstanceImplementation, LookupListener {
 
-    // !PW FIXME Can we extract the server name from the install?  That way,
-    // perhaps we can distinguish between GF V3 and Sun AS 10.0
-    private static final String GLASSFISH_PRELUDE_SERVER_NAME = "GlassFish v3 Prelude"; // NOI18N
-    private static final String GLASSFISH_SERVER_NAME = "GlassFish Server 3"; // NOI18N
-
     // Reasonable default values for various server parameters.  Note, don't use
     // these unless the server's actual setting cannot be determined in any way.
     public static final String DEFAULT_HOST_NAME = "localhost"; // NOI18N
@@ -129,22 +124,33 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
             ic = new InstanceContent();
             lookup = new AbstractLookup(ic);
             this.instanceProvider = instanceProvider;
+            String domainDirPath = ip.get(GlassfishModule.DOMAINS_FOLDER_ATTR);
+            String domainName = ip.get(GlassfishModule.DOMAIN_NAME_ATTR);
+            if (null != domainDirPath && null != domainName) {
+                File domainDir = new File(domainDirPath,domainName);
+                PortCollection pc = new PortCollection();
+                if (Util.readServerConfiguration(domainDir, pc)) {
+                    ip.put(GlassfishModule.ADMINPORT_ATTR, Integer.toString(pc.getAdminPort()));
+                    ip.put(GlassfishModule.HTTPPORT_ATTR, Integer.toString(pc.getHttpPort()));
+                }
+            }
             commonSupport = new CommonServerSupport(lookup, ip, instanceProvider);
-            ic.add(this); // Server instance in lookup (to find instance from node lookup)
-
-            ic.add(commonSupport); // Common action support, e.g start/stop, etc.
 
             // Flag this server URI as under construction
             deployerUri = commonSupport.getDeployerUri();
             GlassfishInstanceProvider.activeRegistrationSet.add(deployerUri);
+            if (null == instanceProvider.getInstance(deployerUri)) {
+                ic.add(this); // Server instance in lookup (to find instance from node lookup)
 
-            commonInstance = ServerInstanceFactory.createServerInstance(this);
-            if (updateNow) {
-                updateModuleSupport();
+                ic.add(commonSupport); // Common action support, e.g start/stop, etc.
+                commonInstance = ServerInstanceFactory.createServerInstance(this);
+                if (updateNow) {
+                    updateModuleSupport();
+                }
+
+                // make this instance publicly accessible
+                instanceProvider.addServerInstance(this);
             }
-            
-            // make this instance publicly accessible
-            instanceProvider.addServerInstance(this);
         } finally {
             if(deployerUri != null) {
                 GlassfishInstanceProvider.activeRegistrationSet.remove(deployerUri);
@@ -173,7 +179,7 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
                 }
             }
         } else {
-            Logger.getLogger("glassfish").log(Level.WARNING, asenvConf.getAbsolutePath() + " does not exist"); // NOI18N
+            Logger.getLogger("glassfish").log(Level.WARNING, "{0} does not exist", asenvConf.getAbsolutePath()); // NOI18N
         }
         Set<GlassfishModuleFactory> added = new HashSet<GlassfishModuleFactory>();
         //Set<GlassfishModuleFactory> removed = new HashSet<GlassfishModuleFactory>();
@@ -182,12 +188,12 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
             added.addAll(factories);
             added.removeAll(currentFactories);
             currentFactories = factories;
-        
+
             for (GlassfishModuleFactory moduleFactory : added) {
                 if(moduleFactory.isModuleSupported(homeFolder, asenvProps)) {
                     Object t = moduleFactory.createModule(lookup);
                     if (null == t) {
-                        Logger.getLogger("glassfish").log(Level.WARNING, moduleFactory+" created a null module"); // NOI18N
+                        Logger.getLogger("glassfish").log(Level.WARNING, "{0} created a null module", moduleFactory); // NOI18N
                     } else {
                         ic.add(t);
                     }
@@ -302,7 +308,7 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
                         }
                     }
                 } catch(TimeoutException ex) {
-                    Logger.getLogger("glassfish").fine("Server " + getDeployerUri() + " timed out sending stop-domain command."); // NOI18N
+                    Logger.getLogger("glassfish").log(Level.FINE, "Server {0} timed out sending stop-domain command.", getDeployerUri()); // NOI18N
                 } catch(Exception ex) {
                     Logger.getLogger("glassfish").log(Level.INFO, ex.getLocalizedMessage(), ex); // NOI18N
                 }
@@ -325,12 +331,7 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
     // TODO -- this should be done differently
     @Override
     public String getServerDisplayName() {
-        File f = new File(commonSupport.getGlassfishRoot(), "lib"+File.separator+"schemas"+File.separator+"web-app_3_0.xsd"); // NOI18N
-        if (f.exists()) {
-            return GLASSFISH_SERVER_NAME;
-        } else {
-            return GLASSFISH_PRELUDE_SERVER_NAME;
-        }
+        return commonSupport.getInstanceProvider().getDisplayName(commonSupport.getDeployerUri());
     }
 
     @Override
@@ -400,6 +401,7 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
         }
 
         instanceProvider.removeServerInstance(this);
+        ic.remove(this);
     }
 
     //
@@ -411,6 +413,24 @@ public class GlassfishInstance implements ServerInstanceImplementation, LookupLi
             return false;
         }
         GlassfishInstance other = (GlassfishInstance) obj;
+        if (null == getDeployerUri()) {
+            return false;
+        }
+        if (null == other.getDeployerUri()) {
+            return false;
+        }
+        if (null == commonSupport) {
+            return false;
+        }
+        if (null == commonSupport.getDomainName()) {
+            return false;
+        }
+        if (null == other.getCommonSupport()) {
+            return false;
+        }
+        if (null == other.getCommonSupport().getDomainName()) {
+            return false;
+        }
         return getDeployerUri().replace("127.0.0.1", "localhost").equals(other.getDeployerUri().replace("127.0.0.1", "localhost")) &&
                 commonSupport.getDomainName().equals(other.getCommonSupport().getDomainName()) &&
                 commonSupport.getDomainsRoot().equals(other.getCommonSupport().getDomainsRoot()) &&
