@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -39,6 +39,7 @@
  * 
  * Portions Copyrighted 2007 Sun Microsystems, Inc.
  */
+
 package org.netbeans.modules.glassfish.common;
 
 import java.io.File;
@@ -55,6 +56,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.prefs.BackingStoreException;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.server.ServerInstance;
 import org.netbeans.modules.glassfish.spi.GlassfishModule;
@@ -69,6 +71,7 @@ import org.openide.filesystems.FileUtil;
 import org.openide.util.ChangeSupport;
 import org.openide.util.Lookup;
 import org.openide.util.NbBundle;
+import org.openide.util.NbPreferences;
 
 /**
  *
@@ -76,21 +79,21 @@ import org.openide.util.NbBundle;
  * @author vince kraemer
  */
 public final class GlassfishInstanceProvider implements ServerInstanceProvider {
+    public static final String GLASSFISH_AUTOREGISTERED_INSTANCE = "glassfish_autoregistered_instance";
 
     static final String INSTANCE_FO_ATTR = "InstanceFOPath"; // NOI18N
+    private static final String AUTOINSTANCECOPIED = "autoinstance-copied"; // NOI18N
     private volatile static GlassfishInstanceProvider preludeProvider;
     private volatile static GlassfishInstanceProvider ee6Provider;
-
-    static private String EE6_PROP_ROOT = "org.glassfish.v3ee6."; // NOI18N
-    static private String INSTALL_ROOT_SUFFIX = "installRoot"; // NOI18N
-    static private String EE6_INSTALL_ROOT_PROP = EE6_PROP_ROOT + INSTALL_ROOT_SUFFIX;
-    static private String PRELUDE_PROP_ROOT = "org.glassfish.v3."; // NOI18N
-    static private String EE6_DEPLOYER_FRAGMENT = "deployer:gfv3ee6"; // NOI18N
-    static private String PRELUDE_DEPLOYER_FRAGMENT = "deployer:gfv3"; // NOI18N
+    public static final String EE6_DEPLOYER_FRAGMENT = "deployer:gfv3ee6"; // NOI18N
+    public static final String EE6WC_DEPLOYER_FRAGMENT = "deployer:gfv3ee6wc"; // NOI18N
+    public static final String PRELUDE_DEPLOYER_FRAGMENT = "deployer:gfv3"; // NOI18N
     static private String EE6_INSTANCES_PATH = "/GlassFishEE6/Instances"; // NOI18N
+    static private String EE6WC_INSTANCES_PATH = "/GlassFishEE6WC/Instances"; // NOI18N
     static private String PRELUDE_INSTANCES_PATH = "/GlassFish/Instances"; // NOI18N
 
     static public String PRELUDE_DEFAULT_NAME = "GlassFish_v3_Prelude"; //NOI18N
+    static public String EE6WC_DEFAULT_NAME = "GlassFish_Server_3.1"; // NOI18N
     
     public static List<GlassfishInstanceProvider> getProviders(boolean initialize) {
         List<GlassfishInstanceProvider> providerList = new ArrayList<GlassfishInstanceProvider>();
@@ -106,29 +109,24 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
         }
         return providerList;
     }
-
+    
     public static synchronized GlassfishInstanceProvider getEe6() {
         if (ee6Provider == null) {
-            ee6Provider = new GlassfishInstanceProvider(new String[]{EE6_DEPLOYER_FRAGMENT},
-                    new String[]{EE6_INSTANCES_PATH},
-                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class, "STR_V3_SERVER_NAME", new Object[]{}), // NOI18N
-                    EE6_INSTALL_ROOT_PROP,
-                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class, "STR_V3_AUTO_REGISTERED_NAME", new Object[]{}),  // NOI18N
-                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class, "STR_V3_AUTO_CREATED_NAME", new Object[]{}),  // NOI18N
-                    "GlassFish_Server_3", // NOI18N
-                    "http://java.net/download/glassfish/v3/release/glassfish-v3.zip", // NOI18N
-                    "http://serverplugins.netbeans.org/glassfishv3/post68v3.txt", // NOI18N
-                    "last-v3ee6-install-root", // NOI18N
-                    new String[]{"lib" + File.separator + "schemas" + File.separator + "web-app_3_0.xsd"}, // NOI18N
-                    new String[0],
-                    true, new String[]{"docs/javaee6-doc-api.zip"}, // NOI18N
+            ee6Provider = new GlassfishInstanceProvider(
+                    new String[]{EE6_DEPLOYER_FRAGMENT, EE6WC_DEPLOYER_FRAGMENT},
+                    new String[]{EE6_INSTANCES_PATH, EE6WC_INSTANCES_PATH},
+                    null,
+                    true, 
+                    new String[]{"docs/javaee6-doc-api.zip"}, // NOI18N
                     new String[]{"--nopassword"}, // NOI18N
-                    new CommandFactory() {
+                    new CommandFactory()  {
 
                 @Override
                 public SetPropertyCommand getSetPropertyCommand(String name, String value) {
-                    return new ServerCommand.SetPropertyCommand(name, value, "DEFAULT={0}={1}"); // NOI18N
+                    return new ServerCommand.SetPropertyCommand(name, value,
+                            "DEFAULT={0}={1}"); // NOI18N
                 }
+
             });
             ee6Provider.init();
         }
@@ -141,26 +139,22 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
         uriFragments = new String[]{PRELUDE_DEPLOYER_FRAGMENT};
         instanceDirs = new String[]{PRELUDE_INSTANCES_PATH};
         if (preludeProvider == null) {
-            preludeProvider = new GlassfishInstanceProvider(uriFragments, instanceDirs,
-                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class, "STR_PRELUDE_SERVER_NAME", new Object[]{}), // NOI18N
-                    PRELUDE_PROP_ROOT + INSTALL_ROOT_SUFFIX,
-                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class, "STR_PRELUDE_AUTO_REGISTERED_NAME", new Object[]{}),  // NOI18N
-                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class, "STR_PRELUDE_AUTO_CREATED_NAME", new Object[]{}),  // NOI18N
-                    PRELUDE_DEFAULT_NAME, 
-                    "http://java.net/download/glassfish/v3-prelude/release/glassfish-v3-prelude-ml.zip", // NOI18N
-                    "http://serverplugins.netbeans.org/glassfishv3/post68prelude.txt", // NOI18N
-                    "last-install-root", // NOI18N
-                    new String[0],
-                    new String[]{"lib" + File.separator + "schemas" + File.separator + "web-app_3_0.xsd"}, // NOI18N
+            preludeProvider = new GlassfishInstanceProvider(
+                    uriFragments,
+                    instanceDirs,
+                    org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class,
+                        "STR_PRELUDE_SERVER_NAME", new Object[]{}), // NOI18N
                     false,
                     new String[]{"docs/javaee6-doc-api.zip"}, // NOI18N
                     null,
-                    new CommandFactory() {
+                    new CommandFactory()  {
 
-                @Override
+                        @Override
                         public SetPropertyCommand getSetPropertyCommand(String name, String value) {
-                            return new ServerCommand.SetPropertyCommand(name, value, "target={0}&value={1}"); // NOI18N
+                            return new ServerCommand.SetPropertyCommand(name, value,
+                                    "target={0}&value={1}"); // NOI18N
                         }
+
                     });
             preludeProvider.init();
         }
@@ -174,41 +168,26 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
     private static final Set<String> activeDisplayNames = Collections.synchronizedSet(new HashSet<String>());
     private final ChangeSupport support = new ChangeSupport(this);
 
-    private String[] instancesDirNames;
-    private String displayName;
-    private String[] uriFragments;
-    private String installRootPropName;
-    private String defaultDomainName;
-    private String defaultPersonalDomainName;
-    private String defaultInstallName;
-    private String directDownloadUrl;
-    private String indirectDownloadUrl;
-    private String installRootKey;
-    private String[] requiredFiles;
-    private String[] excludedFiles;
-    private boolean needsJdk6;
-    private String[] javadocFilenames;
-    private List<String> noPasswordOptions;
-    private CommandFactory cf;
+    final private String[] instancesDirNames;
+    final private String displayName;
+    final private String[] uriFragments;
+    final private boolean needsJdk6;
+    final private String[] javadocFilenames;
+    final private List<String> noPasswordOptions;
+    final private CommandFactory cf;
 
-    private GlassfishInstanceProvider(String[] uriFragments, String[] instancesDirNames,
-            String displayName, String propName, String defaultName, String personalName,
-            String installName, String direct, String indirect, String prefKey,
-            String[] requiredFiles, String[] excludedFiles, boolean needsJdk6,
+    private GlassfishInstanceProvider(
+            String[] uriFragments, 
+            String[] instancesDirNames,
+            String displayName, 
+            boolean needsJdk6,
             String[] javadocFilenames,
-            String[] noPasswordOptionsArray, CommandFactory cf) {
+            String[] noPasswordOptionsArray, 
+            CommandFactory cf 
+            ) {
         this.instancesDirNames = instancesDirNames;
         this.displayName = displayName;
         this.uriFragments = uriFragments;
-        this.installRootPropName = propName;
-        this.defaultDomainName = defaultName;
-        this.defaultPersonalDomainName = personalName;
-        this.defaultInstallName = installName;
-        this.directDownloadUrl = direct;
-        this.indirectDownloadUrl = indirect;
-        this.installRootKey = prefKey;
-        this.requiredFiles = requiredFiles;
-        this.excludedFiles = excludedFiles;
         this.needsJdk6 = needsJdk6;
         this.javadocFilenames = javadocFilenames;
         this.noPasswordOptions = new ArrayList<String>();
@@ -259,7 +238,7 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
                         catalog.refreshRunTimeDDCatalog(this, si.getGlassfishRoot());
                     }
                 }
-                writeInstanceToFile(si);
+                writeInstanceToFile(si,true);
             } catch(IOException ex) {
                 getLogger().log(Level.INFO, null, ex);
             }
@@ -268,46 +247,6 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
         support.fireChange();
     }
 
-    public String getDefaultInstallName() {
-        return defaultInstallName;
-    }
-
-    public String getDirectDownloadUrl() {
-        return directDownloadUrl;
-    }
-
-    public String getDisplayName() {
-        return displayName;
-    }
-
-    public String getIndirectDownloadUrl() {
-        return indirectDownloadUrl;
-    }
-
-    public String getInstallRootKey() {
-        return installRootKey;
-    }
-
-    public String getInstallRootProperty() {
-        return installRootPropName;
-    }
-
-    public String[] getRequiredFiles() {
-        return requiredFiles.clone();
-    }
-
-    public String[] getExcludedFiles() {
-        return excludedFiles.clone();
-    }
-    
-    public String getNameOfBits() {
-        return displayName;
-    }
-
-    public String getUriFragment() {
-        return uriFragments[0];
-    }
-
     public boolean removeServerInstance(GlassfishInstance si) {
         boolean result = false;
         synchronized(instanceMap) {
@@ -317,7 +256,7 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
                 activeDisplayNames.remove(si.getDisplayName());
                 // If this was the last of its type, need to remove the
                 // resolver catalog contents
-                if (instanceMap.size() == 0) {
+                if (instanceMap.isEmpty()) {
                     RegisteredDDCatalog catalog = getDDCatalog();
                     if (null != catalog) {
                         catalog.refreshRunTimeDDCatalog(this, null);
@@ -383,7 +322,15 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
         //init();
         synchronized (instanceMap) {
             for (GlassfishInstance instance : instanceMap.values()) {
-                result.add(instance.getCommonInstance());
+                ServerInstance si = instance.getCommonInstance();
+                if (null != si) {
+                    result.add(si);
+                } else {
+                    String message = "invalid commonInstance for " + instance.getDeployerUri(); // NOI18N
+                    Logger.getLogger("glassfish").log(Level.WARNING, message);   // NOI18N
+                    if (null != instance.getDeployerUri())
+                        instanceMap.remove(instance.getDeployerUri());
+                }
             }
         }
         return result;
@@ -407,12 +354,18 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
     public ServerInstance getInstance(String uri) {
 //        return instanceMap.get(uri);
         //init();
+        ServerInstance rv = null;
         GlassfishInstance instance = instanceMap.get(uri);
-        return instance == null ? null : instance.getCommonInstance();
-    }
-
-    public String formatUri(String glassfishRoot, String hostName, int httpPort) {
-        return "[" + glassfishRoot + "]"+uriFragments[0]+":" + hostName + ":" + httpPort; // NOI18N
+        if (null != instance) {
+            rv = instance.getCommonInstance();
+            if (null == rv) {
+                String message = "invalid commonInstance for " + instance.getDeployerUri(); // NOI18N
+                Logger.getLogger("glassfish").log(Level.WARNING, message);
+                if (null != instance.getDeployerUri())
+                    instanceMap.remove(instance.getDeployerUri());
+            }
+        }
+        return rv;
     }
 
     String getInstancesDirName() {
@@ -456,6 +409,8 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
     // Persistence for server instances.
     // ------------------------------------------------------------------------
     private void loadServerInstances() {
+        FileObject installedInstance = null;
+        int savedj = -1;
         for (int j = 0; j < instancesDirNames.length ; j++ ) {
             FileObject dir = getRepositoryDir(instancesDirNames[j], false);
             if(dir != null) {
@@ -463,12 +418,17 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
                 if(instanceFOs != null && instanceFOs.length > 0) {
                     for(int i = 0; i < instanceFOs.length; i++) {
                         try {
+                            if (GLASSFISH_AUTOREGISTERED_INSTANCE.equals(instanceFOs[i].getName())) {
+                                installedInstance = instanceFOs[i];
+                                savedj = j;
+                                continue;
+                            }
                             GlassfishInstance si = readInstanceFromFile(instanceFOs[i],uriFragments[j]);
                             if(si != null) {
-                                instanceMap.put(si.getDeployerUri(), si);
                                 activeDisplayNames.add(si.getDisplayName());
                             } else {
-                                getLogger().finer("Unable to create glassfish instance for " + instanceFOs[i].getPath()); // NOI18N
+                                getLogger().log(Level.FINER, "Unable to create glassfish instance for {0}", // NOI18N
+                                        instanceFOs[i].getPath()); 
                             }
                         } catch(IOException ex) {
                             getLogger().log(Level.INFO, null, ex);
@@ -477,6 +437,20 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
                 }
             }
         }
+        if (null != installedInstance && null == NbPreferences.forModule(this.getClass()).get(AUTOINSTANCECOPIED,null)) {
+            try {
+                GlassfishInstance igi = readInstanceFromFile(installedInstance, uriFragments[savedj]);
+                try {
+                    NbPreferences.forModule(this.getClass()).put(AUTOINSTANCECOPIED, "true"); // NOI18N
+                    NbPreferences.forModule(this.getClass()).flush();
+                } catch (BackingStoreException ex) {
+                    Logger.getLogger("glassfish").log(Level.INFO, "auto-registered instance may reappear", ex); // NOI18N
+                }
+                activeDisplayNames.add(igi.getDisplayName());
+            } catch (IOException ex) {
+                getLogger().log(Level.INFO, null, ex);
+            }
+        }
         for (GlassfishInstance gi : instanceMap.values()) {
             gi.updateModuleSupport();
         }
@@ -506,14 +480,14 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
             ip.put(INSTANCE_FO_ATTR, instanceFO.getName());
             instance = GlassfishInstance.create(ip,this,false);
         } else {
-            getLogger().finer("GlassFish folder " + instanceFO.getPath() + " is not a valid install."); // NOI18N
+            getLogger().log(Level.FINER, "GlassFish folder {0} is not a valid install.", instanceFO.getPath()); // NOI18N
             instanceFO.delete();
         }
 
         return instance;
     }
 
-    private void writeInstanceToFile(GlassfishInstance instance) throws IOException {
+    private void writeInstanceToFile(GlassfishInstance instance,boolean search) throws IOException {
         String glassfishRoot = instance.getGlassfishRoot();
         if(glassfishRoot == null) {
             getLogger().log(Level.SEVERE, NbBundle.getMessage(GlassfishInstanceProvider.class, "MSG_NullServerFolder")); // NOI18N
@@ -528,7 +502,7 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
             FileObject[] instanceFOs = dir.getChildren();
             FileObject instanceFO = null;
 
-            for(int i = 0; i < instanceFOs.length; i++) {
+            for(int i = 0; search && i < instanceFOs.length; i++) {
                 if(url.equals(instanceFOs[i].getAttribute(GlassfishModule.URL_ATTR))) {
                     instanceFO = instanceFOs[i];
                 }
@@ -544,7 +518,12 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
             for(Map.Entry<String, String> entry: attrMap.entrySet()) {
                 String key = entry.getKey();
                 if(!filterKey(key)) {
-                    instanceFO.setAttribute(key, entry.getValue());
+                    Object currentValue = instanceFO.getAttribute(key);
+                    if (null != currentValue && currentValue.equals(entry.getValue())) {
+                        // do nothing
+                    } else {
+                        instanceFO.setAttribute(key, entry.getValue());
+                    }
                 }
             }
             
@@ -575,7 +554,8 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
                 FileObject[] installedServers = dir.getChildren();
                 for(int i = 0; i < installedServers.length; i++) {
                     String val = getStringAttribute(installedServers[i], GlassfishModule.URL_ATTR);
-                    if(val != null && val.equals(url)) {
+                    if(val != null && val.equals(url) &&
+                            !GLASSFISH_AUTOREGISTERED_INSTANCE.equals(installedServers[i].getName())) {
                         return installedServers[i];
                     }
                 }
@@ -633,8 +613,9 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
         return result;
     }
         
-    String[] getNoPasswordCreatDomainCommand(String startScript, String jarLocation, String domainDir, String portBase, String uname, String domain) {
-        List<String> retVal = new ArrayList<String>();
+    String[] getNoPasswordCreatDomainCommand(String startScript, String jarLocation, 
+            String domainDir, String portBase, String uname, String domain) {
+            List<String> retVal = new ArrayList<String>();
         retVal.addAll(Arrays.asList(new String[] {startScript,
                     "-client",  // NOI18N
                     "-jar",  // NOI18N
@@ -643,9 +624,11 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
                     "--user", //NOI18N
                     uname,
                     "--domaindir", //NOI18N
-                    domainDir,
-                    "--portbase", //NOI18N
-                    portBase,}));
+                    domainDir}));
+        if (null != portBase) {
+            retVal.add("--portbase"); //NOI18N
+            retVal.add(portBase);
+        }
         if (noPasswordOptions.size() > 0) {
             retVal.addAll(noPasswordOptions);
         }
@@ -656,4 +639,17 @@ public final class GlassfishInstanceProvider implements ServerInstanceProvider {
     CommandFactory getCommandFactory() {
        return cf;
     }
+
+    String getDisplayName(String deployerUri) {
+        if (null == displayName) {
+            return deployerUri.contains(EE6WC_DEPLOYER_FRAGMENT) ?
+                org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class,
+                    "STR_V31_SERVER_NAME", new Object[]{}) : // NOI18N
+                org.openide.util.NbBundle.getMessage(GlassfishInstanceProvider.class,
+                    "STR_V3_SERVER_NAME", new Object[]{}); // NOI18N
+                    
+        } else {
+            return displayName;
+        }
+    }
 }
