@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -41,6 +41,7 @@
  * Version 2 license, then the option applies only if the new code is
  * made subject to such option by the copyright holder.
  */
+
 package org.netbeans.modules.glassfish.common;
 
 import java.awt.Color;
@@ -51,17 +52,24 @@ import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.io.OutputStream;
+import java.io.PipedInputStream;
+import java.io.PipedOutputStream;
 import java.lang.ref.WeakReference;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.ResourceBundle;
 import java.util.WeakHashMap;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -75,10 +83,16 @@ import org.netbeans.modules.glassfish.common.actions.RestartAction;
 import org.netbeans.modules.glassfish.common.actions.StartServerAction;
 import org.netbeans.modules.glassfish.common.actions.StopServerAction;
 import org.netbeans.modules.glassfish.spi.GlassfishModule;
+import org.netbeans.modules.glassfish.spi.GlassfishModule.OperationState;
+import org.netbeans.modules.glassfish.spi.OperationStateListener;
 import org.netbeans.modules.glassfish.spi.Recognizer;
+import org.netbeans.modules.glassfish.spi.RecognizerCookie;
 import org.openide.nodes.Node;
+import org.openide.util.Lookup;
 import org.openide.util.Mutex;
+import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
+import org.openide.util.Utilities;
 import org.openide.windows.IOColorLines;
 import org.openide.windows.IOProvider;
 import org.openide.windows.InputOutput;
@@ -105,13 +119,13 @@ public class LogViewMgr {
 
     private static final Logger LOGGER = Logger.getLogger("glassfish"); //  NOI18N
 
-    private static final boolean strictFilter = Boolean.getBoolean("glassfish.logger.strictfilter");
+    private static final boolean strictFilter = Boolean.getBoolean("glassfish.logger.strictfilter"); // NOI18N
 
     /**
      * Amount of time in milliseconds to wait between checks of the input
      * stream
      */
-    private static final int DELAY = 1000;
+    private static final int DELAY = Utilities.isWindows() ? 1 : 100;
     
     /**
      * Singleton model pattern
@@ -184,7 +198,7 @@ public class LogViewMgr {
         return logViewMgr;
     }
     
-    public void ensureActiveReader(List<Recognizer> recognizers, File serverLog) {
+    public void ensureActiveReader(List<Recognizer> recognizers, InputStream serverLog, Map<String,String> properties) {
         synchronized (readers) {
             boolean activeReader = false;
             for(WeakReference<LoggerRunnable> ref: readers) {
@@ -196,53 +210,33 @@ public class LogViewMgr {
             }
 
             if(!activeReader && serverLog != null) {
-                readFiles(recognizers, serverLog);
+                readInputStreams(recognizers, serverLog instanceof FileInputStream, properties, serverLog);
             }
         }
     }
 
-    private static final RequestProcessor RP = new RequestProcessor("LogViewMgr",100); // NOI18N
+    //private static final RequestProcessor RP = new RequestProcessor("LogViewMgr",100); // NOI18N
 
     /**
      * Reads a newly included InputSreams
      *
      * @param inputStreams InputStreams to read
      */
-    public void readInputStreams(List<Recognizer> recognizers, InputStream... inputStreams) {
+    public void readInputStreams(List<Recognizer> recognizers, boolean fromFile,
+            Map<String,String> properties, InputStream... inputStreams) {
         synchronized (readers) {
             stopReaders();
 
             for(InputStream inputStream : inputStreams){
                 // LoggerRunnable will close the stream if necessary.
-                LoggerRunnable logger = new LoggerRunnable(recognizers, inputStream, false);
+                LoggerRunnable logger = new LoggerRunnable(recognizers, inputStream, fromFile, properties);
                 readers.add(new WeakReference<LoggerRunnable>(logger));
-                RP.post(logger);
+                Thread t = new Thread(logger);
+                t.start();
             }
         }
     }
-    
-    /**     
-     * Reads a newly included Files
-     * 
-     * @param files Files to read
-     */
-    public void readFiles(List<Recognizer> recognizers, File... files) {
-        synchronized (readers) {
-            stopReaders();
-            
-            for(File file : files) {
-                try {
-                    // LoggerRunnable will close the stream.
-                    LoggerRunnable logger = new LoggerRunnable(recognizers, new FileInputStream(file), true);
-                    readers.add(new WeakReference<LoggerRunnable>(logger));
-                    RP.post(logger);
-                } catch (FileNotFoundException ex) {
-                    LOGGER.log(Level.FINE, ex.getLocalizedMessage());
-                }
-            }
-        }
-    }
-    
+        
     public void stopReaders() {
         synchronized (readers) {
             for(WeakReference<LoggerRunnable> ref: readers) {
@@ -303,13 +297,13 @@ public class LogViewMgr {
         }
         OutputWriter writer = error ? io.getErr() : io.getOut();
         if(LOGGER.isLoggable(Level.FINEST)) {
-            LOGGER.log(Level.FINEST, "getIOWriter: closed = " + io.isClosed() + " [ " + (error ? "STDERR" : "STDOUT") + " ]" + ", output error flag = " + writer.checkError()); // NOI18N
+            LOGGER.log(Level.FINEST, "getIOWriter: closed = {0} [ {1}" + " ]" + ", output error flag = " + "{2}", new Object[]{io.isClosed(), error ? "STDERR" : "STDOUT", writer.checkError()}); // NOI18N
         }
         if(writer.checkError() == true) {
             InputOutput newIO = getServerIO(uri);
             if(newIO == null) {
                 if(LOGGER.isLoggable(Level.INFO)) {
-                    LOGGER.log(Level.INFO, "Unable to recreate I/O for " + uri + ", still in error state"); // NOI18N
+                    LOGGER.log(Level.INFO, "Unable to recreate I/O for {0}, still in error state", uri); // NOI18N
                 }
                 writer = null;
             } else {
@@ -363,21 +357,30 @@ public class LogViewMgr {
     /**
      * Selects output panel
      */
-    public synchronized void selectIO() {
+    public synchronized void selectIO(boolean force) {
         if(LOGGER.isLoggable(Level.FINEST)) {
-            LOGGER.log(Level.FINEST, "selectIO: closed = " + io.isClosed() + ", output error flag = " + io.getOut().checkError()); // NOI18N
+            LOGGER.log(Level.FINEST, "selectIO: closed = {0}, output error flag = {1}", new Object[]{io.isClosed(), io.getOut().checkError()}); // NOI18N
         }
 
         // Only select the output window if it's closed.  This makes sure it's
         // created properly and displayed.  However, if the user minimizes the
         // output window or switches to another one, we don't switch back.
         if(io.isClosed()) {
+            try {
+                io.getOut().reset();
+            } catch (IOException ex) {
+                LOGGER.log(Level.FINE, "ignorable problem", ex);
+            }
             io.select();
 
             // Horrible hack.  closed flag is never reset, so reset it after reopening.
             invokeSetClosed(io, false);
         }
 
+        if (force) {
+            lastVisibleCheck = 0;
+        }
+
         // If the user happened to close the OutputWindow TopComponent, reopen it.
         // Don't this check too often, but often enough.
         if(System.currentTimeMillis() > lastVisibleCheck + VISIBILITY_CHECK_DELAY) {
@@ -449,15 +452,18 @@ public class LogViewMgr {
     private class LoggerRunnable implements Runnable {
 
         private final List<Recognizer> recognizers;
-        private final InputStream inputStream;
+        private InputStream inputStream;
         private final boolean ignoreEof;
         private volatile boolean shutdown;
+        private final Map<String, String> properties;
         
-        public LoggerRunnable(List<Recognizer> recognizers, InputStream inputStream, boolean ignoreEof) {
+        public LoggerRunnable(List<Recognizer> recognizers, InputStream inputStream, 
+                boolean ignoreEof, Map<String,String> properties) {
             this.recognizers = recognizers;
             this.inputStream = inputStream;
             this.ignoreEof = ignoreEof;
             this.shutdown = false;
+            this.properties = properties;
         }
 
         public void stop() {
@@ -481,7 +487,7 @@ public class LogViewMgr {
                 // ignoreEof is true for log files and false for process streams.
                 // FIXME Should differentiate filter types more cleanly.
                 Filter filter = ignoreEof ? new LogFileFilter(localizedLevels) : 
-                    (uri.contains("]deployer:gfv3ee6:") ? new LogFileFilter(localizedLevels) :new StreamFilter());
+                    (uri.contains("]deployer:gfv3ee6") ? new LogFileFilter(localizedLevels) :new StreamFilter());
                 
                 // read from the input stream and put all the changes to the I/O window
                 char [] chars = new char[1024];
@@ -489,6 +495,7 @@ public class LogViewMgr {
 
                 while(!shutdown && len != -1) {
                     if(ignoreEof) {
+                        reader = followLogRotation(reader);
                         // For file streams, only read if there is something there.
                         while(!shutdown && reader.ready()) {
                             String text = filter.process((char) reader.read());
@@ -526,19 +533,19 @@ public class LogViewMgr {
                     }
                 }
             } catch (IOException ex) {
-                LOGGER.log(Level.SEVERE, "I/O exception reading server log", ex); // NOI18N
+                LOGGER.log(Level.INFO, "I/O exception reading server log", ex); // NOI18N
             } finally {
                 try {
                     inputStream.close();
                 } catch (IOException ex) {
-                    LOGGER.log(Level.SEVERE, "I/O exception closing server log", ex); // NOI18N
+                    LOGGER.log(Level.INFO, "I/O exception closing server log", ex); // NOI18N
                 }
                 
                 if(reader != null) {
                     try {
                         reader.close();
                     } catch (IOException ex) {
-                        LOGGER.log(Level.WARNING, "I/O exception closing stream buffer", ex); // NOI18N
+                        LOGGER.log(Level.INFO, "I/O exception closing stream buffer", ex); // NOI18N
                     }
                 }
                 
@@ -552,7 +559,7 @@ public class LogViewMgr {
 
         private void processLine(String line) {
             if(LOGGER.isLoggable(Level.FINEST)) {
-                LOGGER.log(Level.FINEST, "processing text: '" + line + "'"); // NOI18N
+                LOGGER.log(Level.FINEST, "processing text: ''{0}''", line); // NOI18N
             }
             // XXX sort of a hack to eliminate specific glassfish messages that
             // ought not to be printed at their current level (INFO vs FINE+).
@@ -563,7 +570,7 @@ public class LogViewMgr {
             Message message = new Message(line);
             message.process(recognizers);
                 message.print();
-                selectIO();
+                selectIO(false);
             if (shutdown) {
                 // some messages get processed after the server has 'stopped'
                 //    prevent new stars on the output caption.
@@ -571,6 +578,42 @@ public class LogViewMgr {
                 io.getOut().close();
             }
         }
+
+        private synchronized BufferedReader followLogRotation(BufferedReader reader) {
+            BufferedReader retVal = reader;
+            if (null != properties) {
+                InputStream is = null;
+                String dir = properties.get(GlassfishModule.DOMAINS_FOLDER_ATTR);
+                if (null == dir) {
+                    // this log cannot rotate... it isn't based on a file
+                    return retVal;
+                }
+                try {
+                  is  = getServerLogStream(properties);
+                  if (inputStream instanceof FileInputStream && is instanceof FileInputStream) {
+                      FileInputStream fis = (FileInputStream) is;
+                      long newSize = fis.getChannel().size();
+                      long oldSize = ((FileInputStream) inputStream).getChannel().size();
+                      if (oldSize != newSize) {
+                          retVal = new BufferedReader(new InputStreamReader(is));
+                          try {inputStream.close();} catch (IOException ioe) {
+                            Logger.getLogger("glassfish").log(Level.INFO, "closing the old inputstream", ioe); // NOI18N
+                          }
+                          inputStream = is;
+                      }
+                  }
+                } catch (IOException ioe) {
+                    Logger.getLogger("glassfish").log(Level.WARNING, null, ioe); // NOI18N
+                } finally {
+                    if (null != is && !(is == inputStream)) {
+                        try {is.close();} catch (IOException ioe) {
+                            Logger.getLogger("glassfish").log(Level.INFO, "closing the duplicate inputstream", ioe); // NOI18N
+                        }
+                    }
+                }
+            }
+            return retVal;
+        }
     }
 
     private static Pattern colorPattern = Pattern.compile(
@@ -694,7 +737,7 @@ public class LogViewMgr {
                 ;
     }
 
-    private static final String stripNewline(String s) {
+    private static String stripNewline(String s) {
         int len = s.length();
         if(len > 0 && '\n' == s.charAt(len-1)) {
             s = s.substring(0, len-1);
@@ -1004,18 +1047,18 @@ public class LogViewMgr {
                 boolean valid = true;
                 if(serverIO.isClosed()) {
                     if(LOGGER.isLoggable(Level.FINE)) {
-                        LOGGER.fine("Output window for " + uri + " is closed."); // NOI18N
+                        LOGGER.log(Level.FINE, "Output window for {0} is closed.", uri); // NOI18N
                     }
                 }
                 if(serverIO.getOut().checkError()) {
                     if(LOGGER.isLoggable(Level.FINE)) {
-                        LOGGER.fine("Standard out for " + uri + " is in error state."); // NOI18N
+                        LOGGER.log(Level.FINE, "Standard out for {0} is in error state.", uri); // NOI18N
                     }
                     valid = false;
                 }
                 if(serverIO.getErr().checkError()) {
                     if(LOGGER.isLoggable(Level.FINE)) {
-                        LOGGER.fine("Standard error for " + uri + " is in error state."); // NOI18N
+                        LOGGER.log(Level.FINE, "Standard error for {0} is in error state.", uri); // NOI18N
                     }
                     valid = false;
                 }
@@ -1063,4 +1106,136 @@ public class LogViewMgr {
         }
         return newIO;
     }
+
+    static public void displayOutput(Map<String,String> properties, Lookup lookup) {
+        String uri = properties.get(GlassfishModule.URL_ATTR);
+        if (null != uri && (uri.contains("gfv3ee6wc") || uri.contains("localhost"))) {
+            try {
+                InputStream is = getServerLogStream(properties);
+                LogViewMgr mgr = LogViewMgr.getInstance(uri);
+                List<Recognizer> recognizers = new ArrayList<Recognizer>();
+                if (null != lookup) {
+                    recognizers = getRecognizers(lookup.lookupAll(RecognizerCookie.class));
+                }
+                mgr.ensureActiveReader(recognizers, is,properties);
+                mgr.selectIO(true);
+            } catch (IOException ioe) {
+                LOGGER.log(Level.WARNING, NbBundle.getMessage(LogViewMgr.class,
+                        "WARN_UNREADABLE_LOG_STREAM", uri),ioe);
+            }
+        }
+    }
+
+    static private List<Recognizer> getRecognizers(Collection<? extends RecognizerCookie> cookies) {
+        List<Recognizer> recognizers;
+        if(!cookies.isEmpty()) {
+            recognizers = new LinkedList<Recognizer>();
+            for(RecognizerCookie cookie: cookies) {
+                recognizers.addAll(cookie.getRecognizers());
+            }
+            recognizers = Collections.unmodifiableList(recognizers);
+        } else {
+            recognizers = Collections.emptyList();
+        }
+        return recognizers;
+    }
+
+    private static final Map<String,PipedInputStream> remoteInputStreams = new HashMap<String,PipedInputStream>();
+
+    static private InputStream getServerLogStream(Map<String, String> ip) throws IOException {
+        InputStream result = null;
+        String domainsFolder = ip.get(GlassfishModule.DOMAINS_FOLDER_ATTR);
+        String domainName = ip.get(GlassfishModule.DOMAIN_NAME_ATTR);
+        if (null != domainsFolder && null != domainName) {
+            File domainFolder = new File(domainsFolder, domainName);
+
+            // domain folder must exist.
+            if(domainFolder.exists()) {
+                    try {
+                        // however, logs folder or server.log does not have to exist yet.
+                        result = new FileInputStream(new File(domainFolder, "logs" + File.separatorChar + "server.log"));
+                    } catch (FileNotFoundException ex) {
+                    }
+            } else {
+                Logger.getLogger("glassfish").log(Level.WARNING, NbBundle.getMessage(
+                        LogViewMgr.class, "MSG_DomainFolderNotFound", domainFolder.getAbsolutePath()));
+            }
+            return result;
+        } else {
+            PipedInputStream pis = null;
+            synchronized (remoteInputStreams) {
+                String key = ip.get(GlassfishModule.HOSTNAME_ATTR)+":"+ip.get(GlassfishModule.ADMINPORT_ATTR);
+                pis = remoteInputStreams.get(key);
+                if (null == pis) {
+                    final PipedOutputStream pos = new PipedOutputStream();
+                    try {
+                        pis = new PipedInputStream(pos);
+                        remoteInputStreams.put(key, pis);
+                        RequestProcessor RLRRP = new RequestProcessor("Remote log reader for "+ key);
+                        RLRRP.post(new FetchLogEntries(pos,ip));
+                    } catch (IOException ioe) {
+                        // close the output stream, since the is did not create
+                        try { pos.close(); } catch (IOException ex) {}
+                        throw ioe;
+                    }
+                }
+            }
+            return pis;
+        }
+    }
+
+    static private class FetchLogEntries implements Runnable {
+
+        final OutputStream os;
+        final Map<String, String> ip;
+
+        FetchLogEntries(OutputStream os, Map<String, String> ip) {
+            this.os = os;
+            this.ip = ip;
+        }
+
+        @Override
+        public void run() {
+            CommandRunner cmd = new CommandRunner(true, null, ip, new OperationStateListener() {
+
+                @Override
+                public void operationStateChanged(OperationState newState, String message) {
+                }
+            });
+
+            Commands.FetchLogData fld = new Commands.FetchLogData(null);
+            Future<OperationState> result = cmd.execute(fld);
+            OperationState state = null;
+            try {
+                state = result.get();
+
+                if (state == OperationState.COMPLETED) {
+                    // now we start to actually put data into the pipe
+                    while (true) {
+                        String newQuery = fld.getNextQuery();
+                        fld = new Commands.FetchLogData(newQuery);
+                        result = cmd.execute(fld);
+                        state = result.get();
+                        if (state == OperationState.COMPLETED) {
+                            String s = fld.getLines();
+                            if (null != s && !"null\n".equals(s)) {
+                                os.write(s.getBytes());
+                                os.flush();
+                            }
+                        } else {
+                            break;
+                        }
+                        Thread.sleep(1000);
+                    }
+                }
+            } catch (IOException ex) {
+                LOGGER.log(Level.INFO, "possible problem", ex);
+            } catch (InterruptedException ex) {
+                LOGGER.log(Level.INFO, "possible problem", ex);
+            } catch (ExecutionException ex) {
+                LOGGER.log(Level.INFO, "possible problem", ex);
+            } finally {
+            }
+        }
+    }
 }
