@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -44,6 +44,7 @@
 
 package org.netbeans.modules.glassfish.common;
 
+import java.awt.Dialog;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -62,11 +63,13 @@ import javax.swing.SwingUtilities;
 import org.netbeans.modules.glassfish.spi.RegisteredDerbyServer;
 import org.netbeans.modules.glassfish.spi.GlassfishModule;
 import org.netbeans.modules.glassfish.spi.GlassfishModule.OperationState;
+import org.netbeans.modules.glassfish.spi.GlassfishModule.ServerState;
 import org.netbeans.modules.glassfish.spi.OperationStateListener;
 import org.netbeans.modules.glassfish.spi.Recognizer;
 import org.netbeans.modules.glassfish.spi.ServerUtilities;
 import org.netbeans.modules.glassfish.spi.TreeParser;
 import org.netbeans.modules.glassfish.spi.Utils;
+import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.execution.NbProcessDescriptor;
@@ -90,9 +93,10 @@ public class StartTask extends BasicTask<OperationState> {
     private List<Recognizer> recognizers;
     private FileObject jdkHome = null;
     private List<String> jvmArgs = null;
+    static final private int LOWEST_USER_PORT = org.openide.util.Utilities.isWindows() ? 1 : 1025;
 
     /**
-     * 
+     *
      * @param support common support object for the server instance being started
      * @param recognizers output recognizers to pass to log processors, if any
      * @param stateListener state monitor to track start progress
@@ -101,7 +105,7 @@ public class StartTask extends BasicTask<OperationState> {
             OperationStateListener... stateListener) {
         this(support, recognizers, null, null, stateListener);
     }
-    
+
     /**
      *
      * @param support common support object for the server instance being started
@@ -131,7 +135,7 @@ public class StartTask extends BasicTask<OperationState> {
         this.jdkHome = jdkRoot;
         this.jvmArgs = (jvmArgs != null) ? Arrays.asList(removeEscapes(jvmArgs)) : null;
     }
-    
+
     private static String [] removeEscapes(String [] args) {
         for(int i = 0; i < args.length; i++) {
             args[i] = args[i].replace("\\\"", ""); // NOI18N
@@ -140,32 +144,118 @@ public class StartTask extends BasicTask<OperationState> {
     }
 
     /**
-     * 
+     *
      */
     @Override
     public OperationState call() {
         // Save the current time so that we can deduct that the startup
         // Failed due to timeout
-        Logger.getLogger("glassfish").log(Level.FINEST, "StartTask.call() called on thread \"" + Thread.currentThread().getName() + "\""); // NOI18N
-        long start = System.currentTimeMillis();
+        Logger.getLogger("glassfish").log(Level.FINEST, "StartTask.call() called on thread \"{0}\"", Thread.currentThread().getName()); // NOI18N
+        final long start = System.currentTimeMillis();
+
+        final String host;
+        final int port;
 
-        String host;
-        int port = 0;
-        
         host = ip.get(GlassfishModule.HOSTNAME_ATTR);
         if(host == null || host.length() == 0) {
-            return fireOperationStateChanged(OperationState.FAILED, 
+            return fireOperationStateChanged(OperationState.FAILED,
                     "MSG_START_SERVER_FAILED_NOHOST", instanceName); //NOI18N
         }
-               
+
         Process serverProcess;
         try {
             port = Integer.valueOf(ip.get(GlassfishModule.ADMINPORT_ATTR));
             if(port < 0 || port > 65535) {
-                return fireOperationStateChanged(OperationState.FAILED, 
+                return fireOperationStateChanged(OperationState.FAILED,
                         "MSG_START_SERVER_FAILED_BADPORT", instanceName); //NOI18N
             }
 
+            if (support.isRemote()) {
+                // deal with the remote case here...
+                CommandRunner mgr = new CommandRunner(true, support.getCommandFactory(), ip, new OperationStateListener() {
+                    // if the http command is successful, we are not done yet...
+                    // The server still has to stop. If we signal success to the 'stateListener'
+                    // for the task, it may be premature.
+
+                    @Override
+                    public void operationStateChanged(OperationState newState, String message) {
+                        if (newState == OperationState.RUNNING) {
+                            support.setServerState(ServerState.STARTING);
+                        }
+                        if (newState == OperationState.FAILED) {
+                            fireOperationStateChanged(newState, message, instanceName);
+                            support.setServerState(ServerState.STOPPED);
+                            //support.refresh();
+                        } else if (newState == OperationState.COMPLETED) {
+                            if (message.matches("[sg]et\\?.*\\=configs\\..*")) {
+                                return;
+                            }
+                            long startTime = System.currentTimeMillis();
+                            OperationState state = OperationState.RUNNING;
+                            try {
+                                Thread.sleep(2000);
+                            } catch (InterruptedException e) {
+                                // no op
+                            }
+                            while (OperationState.RUNNING == state && System.currentTimeMillis() - start < START_TIMEOUT) {
+                                // Send the 'completed' event and return when the server is running
+                                boolean httpLive = CommonServerSupport.isRunning(host, port,
+                                        ip.get(GlassfishModule.DISPLAY_NAME_ATTR));
+
+                                // Sleep for a little so that we do not make our checks too often
+                                //
+                                // Doing this before we check httpAlive also prevents us from
+                                // pinging the server too quickly after the ports go live.
+                                //
+                                try {
+                                    Thread.sleep(1000);
+                                } catch (InterruptedException e) {
+                                    // no op
+                                }
+
+                                if (httpLive) {
+                                    try {
+                                        Thread.sleep(2000);
+                                    } catch (InterruptedException e) {
+                                        // no op
+                                    }
+                                    state = OperationState.COMPLETED;
+                                }
+                            }
+                            if (state == OperationState.COMPLETED) { //support.isReady(false, 120, TimeUnit.SECONDS)) {
+                                support.setServerState(ServerState.RUNNING);
+                            } else {
+                                support.setServerState(ServerState.STOPPED);
+                            }
+                        }
+                    }
+                });
+                int debugPort = -1;
+                if (GlassfishModule.DEBUG_MODE.equals(ip.get(GlassfishModule.JVM_MODE))) {
+                    try {
+                        debugPort = Integer.parseInt(ip.get(GlassfishModule.DEBUG_PORT));
+                        if (debugPort < LOWEST_USER_PORT || debugPort > 65535) {
+                            support.setEnvironmentProperty(GlassfishModule.DEBUG_PORT, "9009", true);
+                            debugPort = 9009;
+                            Logger.getLogger("glassfish").log(Level.INFO, "converted debug port to 9009 for {0}", instanceName);
+                        }
+                    } catch (NumberFormatException nfe) {
+                        support.setEnvironmentProperty(GlassfishModule.DEBUG_PORT, "9009", true);
+                        support.setEnvironmentProperty(GlassfishModule.USE_SHARED_MEM_ATTR, "false", true);
+                        debugPort = 9009;
+                        Logger.getLogger("glassfish").log(Level.INFO, "converted debug type to socket and port to 9009 for {0}", instanceName);
+                    }
+                }
+                String restartQ = "";
+                if (support.supportsRestartInDebug()) {
+                    restartQ = -1 == debugPort ? "debug=false" : "debug=true";
+                }
+                mgr.restartServer(debugPort,restartQ);
+                return fireOperationStateChanged(OperationState.RUNNING,
+                        "MSG_START_SERVER_IN_PROGRESS", instanceName); // NOI18N
+
+            }
+
             jdkHome = getJavaPlatformRoot(support);
             // lookup the javadb start service and use it here.
             RegisteredDerbyServer db = Lookup.getDefault().lookup(RegisteredDerbyServer.class);
@@ -175,7 +265,7 @@ public class StartTask extends BasicTask<OperationState> {
             // this may be an autheticated server... so we will say it is started.
             // other operations will fail if the process on the port is not a
             // GF v3 server.
-            if (CommonServerSupport.isRunning(host,port)) {
+            if (CommonServerSupport.isRunning(host,port,ip.get(GlassfishModule.DISPLAY_NAME_ATTR))) {
                 OperationState result = OperationState.COMPLETED;
                 if (GlassfishModule.PROFILE_MODE.equals(ip.get(GlassfishModule.JVM_MODE))) {
                     result = OperationState.FAILED;
@@ -183,7 +273,10 @@ public class StartTask extends BasicTask<OperationState> {
                 return fireOperationStateChanged(result,
                         "MSG_START_SERVER_OCCUPIED_PORT", instanceName); //NOI18N
             }
-
+            if (upgradeFailed()) {
+                return fireOperationStateChanged(OperationState.FAILED,
+                        "MSG_DOMAIN_UPGRADE_FAILED", instanceName); //NOI18N
+            }
             serverProcess = createProcess();
         } catch (NumberFormatException nfe) {
             Logger.getLogger("glassfish").log(Level.INFO, ip.get(GlassfishModule.HTTPPORT_ATTR), nfe); // NOI18N
@@ -199,18 +292,19 @@ public class StartTask extends BasicTask<OperationState> {
                     ex.getLocalizedMessage());
         }
 
-        fireOperationStateChanged(OperationState.RUNNING, 
+        fireOperationStateChanged(OperationState.RUNNING,
                 "MSG_START_SERVER_IN_PROGRESS", instanceName); // NOI18N
-        
+
         // create a logger to the server's output stream so that a user
         // can observe the progress
         LogViewMgr logger = LogViewMgr.getInstance(ip.get(GlassfishModule.URL_ATTR));
-        logger.readInputStreams(recognizers, serverProcess.getInputStream(), serverProcess.getErrorStream());
+        logger.readInputStreams(recognizers, false, null, serverProcess.getInputStream(), serverProcess.getErrorStream());
 
         // Waiting for server to start
         while(System.currentTimeMillis() - start < START_TIMEOUT) {
             // Send the 'completed' event and return when the server is running
-            boolean httpLive = CommonServerSupport.isRunning(host, port);
+            boolean httpLive = CommonServerSupport.isRunning(host, port,
+                    ip.get(GlassfishModule.DISPLAY_NAME_ATTR));
 
             // Sleep for a little so that we do not make our checks too often
             //
@@ -230,11 +324,12 @@ public class StartTask extends BasicTask<OperationState> {
                 if (!support.isReady(true,30,TimeUnit.SECONDS)) {
                     state = OperationState.FAILED;
                     messageKey = "MSG_START_SERVER_FAILED"; // NOI18N
+                    serverProcess.destroy();
                     logger.stopReaders();
                 }
                 return fireOperationStateChanged(state, messageKey, instanceName);
             }
-            
+
             // if we are profiling, we need to lie about the status?
             if (null != jvmArgs) {
                 // try to sync the states after the profiler attaches
@@ -242,7 +337,8 @@ public class StartTask extends BasicTask<OperationState> {
 
                     @Override
                     public void run() {
-                        while (!CommonServerSupport.isRunning(support.getHostName(), support.getAdminPortNumber())) {
+                        while (!CommonServerSupport.isRunning(support.getHostName(), support.getAdminPortNumber(),
+                                ip.get(GlassfishModule.DISPLAY_NAME_ATTR))) {
                             try {
                                 Thread.sleep(200);
                             } catch (InterruptedException ex) {
@@ -253,7 +349,7 @@ public class StartTask extends BasicTask<OperationState> {
                             @Override
                             public void run() {
                                     support.refresh();
-                                                    
+
                             }
 
                         });
@@ -263,15 +359,14 @@ public class StartTask extends BasicTask<OperationState> {
                         "MSG_SERVER_STARTED", instanceName); // NOI18N
             }
         }
-        
+
         // If the server did not start in the designated time limits
         // We consider the startup as failed and warn the user
-        Logger.getLogger("glassfish").log(Level.INFO, "V3 Failed to start, killing process: " + serverProcess+" after "+  // NOI18N
-                (System.currentTimeMillis() - start));
+        Logger.getLogger("glassfish").log(Level.INFO, "V3 Failed to start, killing process: {0} after {1}", new Object[]{serverProcess, System.currentTimeMillis() - start});
         serverProcess.destroy();
         logger.stopReaders();
         return fireOperationStateChanged(OperationState.FAILED,
-                "MSG_START_SERVER_FAILED2", instanceName); // NOI18N
+                "MSG_START_SERVER_FAILED2", instanceName,host,port+""); // NOI18N
     }
 
     private String[] createEnvironment() {
@@ -306,7 +401,7 @@ public class StartTask extends BasicTask<OperationState> {
         }
         return envp.toArray(new String[envp.size()]);
     }
-    
+
     private void appendSystemEnvVar(List<String> envp, String key) {
         String value = ip.get(key);
         if(value != null && value.length() > 0) {
@@ -332,7 +427,7 @@ public class StartTask extends BasicTask<OperationState> {
         }
         return retVal;
     }
-    
+
     private String getJdkHome() {
         String result;
         if (null != jdkHome) {
@@ -345,8 +440,8 @@ public class StartTask extends BasicTask<OperationState> {
         }
         return result;
     }
-    
-    private NbProcessDescriptor createProcessDescriptor() throws ProcessCreationException { 
+
+    private NbProcessDescriptor createProcessDescriptor() throws ProcessCreationException {
         String startScript = FileUtil.toFile(jdkHome).getAbsolutePath() +
                 File.separatorChar + "bin" + File.separatorChar + "java"; // NOI18N
         if (Utilities.isWindows()) {
@@ -372,7 +467,7 @@ public class StartTask extends BasicTask<OperationState> {
         if (!readJvmArgs(domainDir, optList, argMap, propMap)) {
             throw new ProcessCreationException(null, "MSG_START_SERVER_FAILED_DOMAIN_FNF"); // NOI18N
         }
-        
+
         if (null != jvmArgs) {
             optList.addAll(jvmArgs);
         }
@@ -393,11 +488,11 @@ public class StartTask extends BasicTask<OperationState> {
             argumentBuf.append(" -jar "); // NOI18N
             argumentBuf.append(Util.quote(bootstrapJar.getAbsolutePath()));
         }
-        argumentBuf.append(" --domain " + getDomainName()); // NOI18N
-        argumentBuf.append(" --domaindir " + Util.quote(domainDir.getAbsolutePath())); // NOI18N
-        
+        argumentBuf.append(" --domain ").append(getDomainName()); // NOI18N
+        argumentBuf.append(" --domaindir ").append(Util.quote(domainDir.getAbsolutePath())); // NOI18N
+
         String arguments = argumentBuf.toString();
-        Logger.getLogger("glassfish").log(Level.FINE, "V3 JVM Command: " + startScript + " " + arguments); // NOI18N
+        Logger.getLogger("glassfish").log(Level.FINE, "V3 JVM Command: {0} {1}", new Object[]{startScript, arguments}); // NOI18N
         return new NbProcessDescriptor(startScript, arguments);
     }
 
@@ -459,7 +554,7 @@ public class StartTask extends BasicTask<OperationState> {
                     int t = 0;
                     if (null != debugPortString && debugPortString.trim().length() > 0) {
                         t = Integer.parseInt(debugPortString);
-                        if(t < 0 || t > 65535) {
+                        if(t < LOWEST_USER_PORT || t > 65535) {
                             throw new NumberFormatException();
                         }
                     }
@@ -469,23 +564,24 @@ public class StartTask extends BasicTask<OperationState> {
                     if ("true".equals(ip.get(GlassfishModule.USE_SHARED_MEM_ATTR))) { // NOI18N
                         debugPortString = Integer.toString(
                                 Math.abs((ip.get(GlassfishModule.GLASSFISH_FOLDER_ATTR) +
-                                support.getDomainsRoot() + 
+                                support.getDomainsRoot() +
                                 ip.get(GlassfishModule.DOMAIN_NAME_ATTR)).hashCode() + 1));
                     } else {
-                        int debugPort = 9009;
-                        // calculate the port and save it.
-                        ServerSocket t = null;
-                        try {
-                            t = new ServerSocket(0);
-                            debugPort = t.getLocalPort();
-                            debugPortString = Integer.toString(debugPort);
-                        } finally {
-                            if (null != t) {
-                                t.close();
-                            }
-                        }
+                        debugPortString = selectDebugPort();
                     }
-                } 
+                    DialogDescriptor note =
+                            new DialogDescriptor(
+                            NbBundle.getMessage(StartTask.class,"MSG_SELECTED_PORT", debugPortString),
+                            NbBundle.getMessage(StartTask.class,"TITLE_MESSAGE"),
+                            false,
+                            new Object[] { DialogDescriptor.OK_OPTION },
+                            DialogDescriptor.OK_OPTION,
+                            DialogDescriptor.DEFAULT_ALIGN,
+                            null,
+                            null);
+                    Dialog d = DialogDisplayer.getDefault().createDialog(note);
+                    d.setVisible(true);
+                }
                 support.setEnvironmentProperty(GlassfishModule.DEBUG_PORT, debugPortString, true);
                 argumentBuf.append(" -Xdebug -Xrunjdwp:transport="); // NOI18N
                 argumentBuf.append(debugTransport);
@@ -493,16 +589,37 @@ public class StartTask extends BasicTask<OperationState> {
                 argumentBuf.append(debugPortString);
                 argumentBuf.append(",server=y,suspend=n"); // NOI18N
             }
-        } catch (NumberFormatException nfe) {
-            throw new ProcessCreationException(nfe,
-                    "MSG_START_SERVER_FAILED_INVALIDPORT", instanceName, debugPortString); //NOI18N
         } catch (IOException ioe) {
             throw new ProcessCreationException(ioe,
                     "MSG_START_SERVER_FAILED_INVALIDPORT", instanceName, debugPortString); //NOI18N
         }
         return argumentBuf;
     }
-    
+
+    private String selectDebugPort() throws IOException {
+        int debugPort = 9009;
+        ServerSocket t = null;
+        try {
+            // try to use the 'standard port'
+            t = new ServerSocket(debugPort);
+            return Integer.toString(debugPort);
+        } catch (IOException ex) {
+            // log this... but don't panic
+            Logger.getLogger("glassfish").fine("9009 is in use... going random");
+        } finally {
+            if (null != t) try { t.close(); } catch (IOException ioe) {}
+        }
+        try {
+            // try to find a different port... if this fails,
+            //    it is a great time to panic.
+            t = new ServerSocket(0);
+            debugPort = t.getLocalPort();
+            return Integer.toString(debugPort);
+        } finally {
+            if (null != t) try { t.close(); } catch (IOException ioe) {}
+        }
+    }
+
     private StringBuilder appendSystemVars(Map<String, String> argMap, StringBuilder argumentBuf) {
         appendSystemVar(argumentBuf, GlassfishModule.JRUBY_HOME, ip.get(GlassfishModule.JRUBY_HOME));
         appendSystemVar(argumentBuf, GlassfishModule.COMET_FLAG, ip.get(GlassfishModule.COMET_FLAG));
@@ -532,14 +649,14 @@ public class StartTask extends BasicTask<OperationState> {
 
         argMap.remove(GlassfishModule.JRUBY_HOME);
         argMap.remove(GlassfishModule.COMET_FLAG);
-        
+
         for(Map.Entry<String, String> entry: argMap.entrySet()) {
             appendSystemVar(argumentBuf, entry.getKey(), entry.getValue());
         }
-        
+
         return argumentBuf;
-    }    
-    
+    }
+
     private StringBuilder appendSystemVar(StringBuilder argumentBuf, String key, String value) {
         if(value != null && value.length() > 0) {
             argumentBuf.append(" -D"); // NOI18N
@@ -549,7 +666,7 @@ public class StartTask extends BasicTask<OperationState> {
         }
         return argumentBuf;
     }
-    
+
     private Process createProcess() throws ProcessCreationException {
         Process process = null;
         NbProcessDescriptor pd = createProcessDescriptor();
@@ -562,15 +679,15 @@ public class StartTask extends BasicTask<OperationState> {
         }
         return process;
     }
-    
+
     private File getDomainFolder() {
         return new File(support.getDomainsRoot()+ File.separatorChar + getDomainName());
     }
-    
-    private final String getDomainName() {
+
+    private String getDomainName() {
         return ip.get(GlassfishModule.DOMAIN_NAME_ATTR);
     }
-    
+
     private boolean readJvmArgs(File domainRoot, List<String> optList,
             Map<String, String> argMap, Map<String, String> propMap) {
         Map<String, String> varMap = new HashMap<String, String>();
@@ -597,6 +714,14 @@ public class StartTask extends BasicTask<OperationState> {
             }
             try {
                 TreeParser.readXml(domainXml, pathList);
+                if (Utilities.isMac() &&
+                    System.getProperty("java.vm.vendor").equals("Apple Inc.")) {
+                    // on Mac OS, unless the property is specified in the domain.xml, we add
+                    // the -d32 flag to start the JVM in 32 bits mode
+                    if (!optList.contains("-d64") && !optList.contains("-d32")) {
+                        optList.add("-d32");
+                    }
+                }
                 return true;
             } catch(IllegalStateException ex) {
                 Logger.getLogger("glassfish").log(Level.INFO, ex.getLocalizedMessage(), ex); // NOI18N
@@ -617,4 +742,70 @@ public class StartTask extends BasicTask<OperationState> {
         return javadb;
     }
 
+    private boolean upgradeFailed() {
+        // get server install version
+        File glassfishDir = new File(support.getGlassfishRoot());
+        int installVersion = ServerDetails.getVersionFromInstallDirectory(glassfishDir);
+
+        if (installVersion < 0) return false;  // no upgrade attempted, so it DID NOT fail.
+
+        // get domain.xml 'version'
+        File domainXmlFile = new File(getDomainFolder(), "config" + File.separator + "domain.xml"); // NOI18N
+        int domainVersion = ServerDetails.getVersionFromDomainXml(domainXmlFile);
+
+        if (domainVersion < 0) return false;  // no upgrade attempted, so it DID NOT fail.
+
+        if (domainVersion < installVersion) {
+            return executeUpgradeProcess() != 0;
+        }
+        return false;
+    }
+
+    private int executeUpgradeProcess() {
+        int retVal = -1;
+        File asadmin = findFirstExecutableFile(new File(support.getGlassfishRoot()), "asadmin", "bin");
+        if (null == asadmin)
+            return retVal;
+        NbProcessDescriptor upgrader = new NbProcessDescriptor(asadmin.getAbsolutePath(),
+                    "start-domain --upgrade --domaindir "+Util.quote(support.getDomainsRoot())+" "+  // NOI18N
+                    support.getDomainName());
+        try {
+            Process p = upgrader.exec();
+            p.waitFor();
+            retVal = p.exitValue();
+        } catch (InterruptedException ex) {
+            Logger.getLogger("glassfish").log(Level.INFO, upgrader.toString(), ex); // NOI18N
+        } catch (IOException ex) {
+            Logger.getLogger("glassfish").log(Level.INFO, upgrader.toString(), ex); // NOI18N
+        }
+        return retVal;
+    }
+
+    // TODO : refactor and remove 'similar' methods post 7.0
+    private File findFirstExecutableFile(File installRoot, String executableName, String... directories) {
+        File result = null;
+        if (installRoot != null && installRoot.exists()) {
+            for (String dir : directories) {
+                File updateCenterBin = new File(installRoot, dir); // NOI18N
+                if (updateCenterBin.exists()) {
+                    if (Utilities.isWindows()) {
+                        File launcherPath = new File(updateCenterBin, executableName + ".exe"); // NOI18N
+                        if (launcherPath.exists()) {
+                            result = launcherPath;
+                        } else {
+                            launcherPath = new File(updateCenterBin, executableName + ".bat"); // NOI18N
+                            result = (launcherPath.exists()) ? launcherPath : null;
+                        }
+                    } else {
+                        File launcherPath = new File(updateCenterBin, executableName); // NOI18N
+                        result = (launcherPath.exists()) ? launcherPath : null;
+                    }
+                    if (null != result) {
+                        break;
+                    }
+                }
+            }
+        }
+        return result;
+    }
 }
