@@ -72,6 +72,7 @@ public class StopTask extends BasicTask<OperationState> {
     /**
      * 
      */
+    @Override
     public OperationState call() {
         // save the current time so that we can deduct that the startup
         // failed due to timeout
@@ -105,6 +106,7 @@ public class StopTask extends BasicTask<OperationState> {
             // if the http command is successful, we are not done yet...
             // The server still has to stop. If we signal success to the 'stateListener'
             // for the task, it may be premature.
+            @Override
             public void operationStateChanged(OperationState newState, String message) {
                 if (newState == OperationState.FAILED) {
                     fireOperationStateChanged(newState, message, instanceName);
@@ -119,7 +121,8 @@ public class StopTask extends BasicTask<OperationState> {
         // Waiting for server to stop
         while(System.currentTimeMillis() - start < STOP_TIMEOUT) {
             // Send the 'completed' event and return when the server is stopped
-            if(!CommonServerSupport.isRunning(host, port)) {
+            if(!CommonServerSupport.isRunning(host, port,
+                    ip.get(GlassfishModule.DISPLAY_NAME_ATTR))) {
                 try {
                     Thread.sleep(1000); // flush the process
                 } catch (InterruptedException e) {
