@@ -78,6 +78,7 @@ public class Hk2InstanceChildren extends Children.Keys<Node> implements Refresha
         serverInstance.addChangeListener(WeakListeners.change(this, serverInstance));
     }
 
+    @Override
     public void updateKeys(){
         Vector<Node> keys = new Vector<Node>();
         serverInstance.getCommonSupport().refresh();
@@ -90,6 +91,13 @@ public class Hk2InstanceChildren extends Children.Keys<Node> implements Refresha
                     new Hk2ResourceContainers(serverInstance.getLookup()),
                     NbBundle.getMessage(Hk2InstanceNode.class, "LBL_Resources"),
                     Hk2ItemNode.RESOURCES_FOLDER));
+            String iid = serverInstance.getDeployerUri();
+            if (null != iid && iid.contains("gfv3ee6wc")) {
+                keys.add(new Hk2ItemNode(serverInstance.getLookup(),
+                        new Hk2WSChildren(serverInstance.getLookup()),
+                        NbBundle.getMessage(Hk2InstanceNode.class, "LBL_WS"),
+                        Hk2ItemNode.WS_FOLDER));
+            }
             List<Node> pluggableNodes = getExtensionNodes();
             for (Iterator itr = pluggableNodes.iterator(); itr.hasNext();) {
                 keys.add((Node)itr.next());
@@ -109,12 +117,15 @@ public class Hk2InstanceChildren extends Children.Keys<Node> implements Refresha
         setKeys(noKeys);
     }
     
+    @Override
     protected org.openide.nodes.Node[] createNodes(Node key) {
         return new Node [] { key };
     }
 
+    @Override
     public void stateChanged(ChangeEvent e) {
         Mutex.EVENT.readAccess(new Runnable() {
+            @Override
             public void run() {
                 updateKeys();
             }
