@@ -57,7 +57,12 @@ import javax.swing.Action;
 import javax.swing.JFileChooser;
 import org.netbeans.modules.glassfish.common.CommandRunner;
 import org.netbeans.modules.glassfish.common.nodes.actions.DeployDirectoryCookie;
+import org.netbeans.modules.glassfish.common.nodes.actions.DisableModulesAction;
+import org.netbeans.modules.glassfish.common.nodes.actions.DisableModulesCookie;
 import org.netbeans.modules.glassfish.common.nodes.actions.EditDetailsAction;
+import org.netbeans.modules.glassfish.common.nodes.actions.EnableModulesAction;
+import org.netbeans.modules.glassfish.common.nodes.actions.EnableModulesCookie;
+import org.netbeans.modules.glassfish.common.nodes.actions.OpenTestURLAction;
 import org.netbeans.modules.glassfish.common.nodes.actions.OpenURLAction;
 import org.netbeans.modules.glassfish.common.nodes.actions.RefreshModulesAction;
 import org.netbeans.modules.glassfish.common.nodes.actions.RefreshModulesCookie;
@@ -68,6 +73,7 @@ import org.netbeans.modules.glassfish.spi.Decorator;
 import org.netbeans.modules.glassfish.spi.GlassfishModule;
 import org.netbeans.modules.glassfish.spi.GlassfishModule.OperationState;
 import org.netbeans.modules.glassfish.spi.ResourceDecorator;
+import org.openide.actions.CopyAction;
 import org.openide.filesystems.FileUtil;
 import org.openide.loaders.DataFolder;
 import org.openide.nodes.AbstractNode;
@@ -96,10 +102,12 @@ public class Hk2ItemNode extends AbstractNode {
         
         if(decorator.isRefreshable()) {
             getCookieSet().add(new RefreshModulesCookie() {
+                @Override
                 public void refresh() {
                     refresh(null, null);
                 }
 
+                @Override
                 public void refresh(String expected, String unexpected) {
                     Children children = getChildren();
                     if(children instanceof Refreshable) {
@@ -125,6 +133,7 @@ public class Hk2ItemNode extends AbstractNode {
         
         if(decorator.canDeployTo()) {
             getCookieSet().add(new DeployDirectoryCookie() {
+                @Override
                 public void deployDirectory() {
                     JFileChooser chooser = new JFileChooser();
                     chooser.setDialogTitle(NbBundle.getMessage(Hk2ItemNode.class, "LBL_ChooseButton")); // NOI18N
@@ -154,6 +163,7 @@ public class Hk2ItemNode extends AbstractNode {
                 
                 private volatile WeakReference<Future<OperationState>> status;
 
+                @Override
                 public Future<OperationState> undeploy() {
                     Future<OperationState> result = null;
                     GlassfishModule commonModule = lookup.lookup(GlassfishModule.class);
@@ -165,6 +175,7 @@ public class Hk2ItemNode extends AbstractNode {
                     return result;
                 }
 
+                @Override
                 public boolean isRunning() {
                     WeakReference<Future<OperationState>> localref = status;
                     if(localref == null) {
@@ -180,7 +191,73 @@ public class Hk2ItemNode extends AbstractNode {
             });
         }
 
-//        if(decorator.canUnregister()) {
+        if(decorator.canEnable()) {
+            getCookieSet().add(new EnableModulesCookie() {
+
+                private volatile WeakReference<Future<OperationState>> status;
+
+                @Override
+                public Future<OperationState> enableModule() {
+                    Future<OperationState> result = null;
+                    GlassfishModule commonModule = lookup.lookup(GlassfishModule.class);
+                    if(commonModule != null) {
+                        CommandRunner mgr = new CommandRunner(true, commonModule.getCommandFactory(), commonModule.getInstanceProperties());
+                        result = mgr.enable(name);
+                        status = new WeakReference<Future<OperationState>>(result);
+                    }
+                    return result;
+                }
+
+                @Override
+                public boolean isRunning() {
+                    WeakReference<Future<OperationState>> localref = status;
+                    if(localref == null) {
+                        return false;
+                    }
+                    Future<OperationState> cmd = localref.get();
+                    if(cmd == null || cmd.isDone()) {
+                        return false;
+                    }
+                    return true;
+                }
+
+            });
+        }
+
+        if(decorator.canDisable()) {
+            getCookieSet().add(new DisableModulesCookie() {
+
+                private volatile WeakReference<Future<OperationState>> status;
+
+                @Override
+                public Future<OperationState> disableModule() {
+                    Future<OperationState> result = null;
+                    GlassfishModule commonModule = lookup.lookup(GlassfishModule.class);
+                    if(commonModule != null) {
+                        CommandRunner mgr = new CommandRunner(true, commonModule.getCommandFactory(), commonModule.getInstanceProperties());
+                        result = mgr.disable(name);
+                        status = new WeakReference<Future<OperationState>>(result);
+                    }
+                    return result;
+                }
+
+                @Override
+                public boolean isRunning() {
+                    WeakReference<Future<OperationState>> localref = status;
+                    if(localref == null) {
+                        return false;
+                    }
+                    Future<OperationState> cmd = localref.get();
+                    if(cmd == null || cmd.isDone()) {
+                        return false;
+                    }
+                    return true;
+                }
+
+            });
+        }
+
+        //        if(decorator.canUnregister()) {
 //            getCookieSet().add(new UnregisterResourceCookie() {
 //
 //                private volatile WeakReference<Future<OperationState>> status;
@@ -251,7 +328,11 @@ public class Hk2ItemNode extends AbstractNode {
         Image image = null;
         Image badge = decorator.getIconBadge();
         if(badge != null) {
-            image = badgeFolder(badge, false);
+            if (null == decorator.getIcon(type)) {
+                image = badgeFolder(badge, false);
+            } else {
+                image = badgeIcon(badge,decorator.getIcon(type));
+            }
         } else {
             image = decorator.getIcon(type);
         }
@@ -286,6 +367,14 @@ public class Hk2ItemNode extends AbstractNode {
             actions.add(SystemAction.get(UndeployModuleAction.class));
         }
     
+        if(decorator.canEnable()) {
+            actions.add(SystemAction.get(EnableModulesAction.class));
+        }
+
+        if(decorator.canDisable()) {
+            actions.add(SystemAction.get(DisableModulesAction.class));
+        }
+
         if(decorator.canUnregister()) {
             actions.add(SystemAction.get(UnregisterResourceAction.class));
         }
@@ -293,6 +382,12 @@ public class Hk2ItemNode extends AbstractNode {
         if(decorator.canShowBrowser()) {
             actions.add(SystemAction.get(OpenURLAction.class));
         }
+        if(decorator.canTest()) {
+            actions.add(SystemAction.get(OpenTestURLAction.class));
+        }
+        if(decorator.canCopy()) {
+            actions.add(SystemAction.get(CopyAction.class));
+        }
         if (decorator.canEditDetails()) {
             actions.add(SystemAction.get(EditDetailsAction.class));
         }
@@ -326,6 +421,17 @@ public class Hk2ItemNode extends AbstractNode {
         return ImageUtilities.mergeImages(folder, badge, 7, 7);
     }
     
+    /**
+     * Applies a badge to an icon.
+     *
+     * @param badge badge image for folder
+     * @param icon the image to be badged
+     * @return an image of the badged folder
+     */
+    public static Image badgeIcon(Image badge, Image icon) {
+        return ImageUtilities.mergeImages(icon, badge, 7, 7);
+    }
+
     /**
      * Retrieves the IDE's standard folder node, so we can access the default
      * open/closed folder icons.
@@ -338,6 +444,8 @@ public class Hk2ItemNode extends AbstractNode {
     
     private static final String RESOURCES_ICON = 
             "org/netbeans/modules/glassfish/common/resources/resources.gif"; // NOI18N
+    private static final String WS_ICON =
+            "org/netbeans/modules/glassfish/common/resources/webservice.png"; // NOI18N
         
     public static final Decorator J2EE_APPLICATION_FOLDER = new Decorator() {
         @Override public boolean isRefreshable() { return true; }
@@ -350,8 +458,22 @@ public class Hk2ItemNode extends AbstractNode {
         @Override public Image getOpenedIcon(int type) { return getIcon(type); }
     };
     
+    public static final Decorator WS_FOLDER = new Decorator() {
+        @Override public boolean isRefreshable() { return true; }
+    };
+
+    public static final Decorator WS_ENDPOINT = new Decorator() {
+        @Override public boolean canTest() { return true; }
+        @Override public boolean canCopy() { return true; }
+        @Override public Image getIcon(int type) { return ImageUtilities.loadImage(WS_ICON); }
+        @Override public Image getOpenedIcon(int type) { return getIcon(type); }
+        //@Override public boolean canSave() { return true; }
+    };
+
     public static final Decorator J2EE_APPLICATION = new Decorator() {
         @Override public boolean canUndeploy() { return true; }
+        @Override public boolean canEnable() { return true; }
+        @Override public boolean canDisable() { return true; }
         @Override public boolean canShowBrowser() { return true; }
     };
     
