@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -86,6 +86,7 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
      * 
      * @return 
      */
+    @Override
     public boolean isValid() {
         if (isValidating.compareAndSet(false, true)) {
             try {
@@ -106,14 +107,17 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
      * 
      * @param ev 
      */
+    @Override
     public void stateChanged(ChangeEvent ev) {
         fireChangeEvent(ev);
     }
 
+    @Override
     public void addChangeListener(ChangeListener l) {
         listeners.add(l);
     }
 
+    @Override
     public void removeChangeListener(ChangeListener l) {
         listeners.remove(l);
     }
@@ -128,6 +132,7 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
      * 
      * @return 
      */
+    @Override
     public Component getComponent() {
         if (component == null) {
             component = new AddDomainLocationVisualPanel();
@@ -140,6 +145,7 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
      * 
      * @return 
      */
+    @Override
     public HelpCtx getHelp() {
         // !PW FIXME correct help context
         return new HelpCtx("registering_app_server_hk2_domain"); //NOI18N
@@ -149,6 +155,7 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
      * 
      * @param settings 
      */
+    @Override
     public void readSettings(Object settings) {
         if (wizard == null) {
             wizard = (WizardDescriptor) settings;
@@ -161,6 +168,7 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
      * 
      * @param settings 
      */
+    @Override
     public void storeSettings(Object settings) {
     }
 
@@ -180,8 +188,8 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
         }
         int dex = domainField.indexOf(File.separator);
         if (AddServerLocationPanel.isRegisterableDomain(domainDirCandidate)) {
-            AddServerLocationPanel.readServerConfiguration(domainDirCandidate, wizardIterator);
-            String uri = wizardIterator.formatUri(gfRoot, GlassfishInstance.DEFAULT_HOST_NAME, wizardIterator.getAdminPort());
+            org.netbeans.modules.glassfish.common.Util.readServerConfiguration(domainDirCandidate, wizardIterator);
+            String uri = wizardIterator.formatUri(GlassfishInstance.DEFAULT_HOST_NAME, wizardIterator.getAdminPort());
             if (-1 == wizardIterator.getHttpPort()) {
                 wizard.putProperty(PROP_ERROR_MESSAGE, NbBundle.getMessage(this.getClass(), "ERR_InvalidDomainData", domainField)); // NOI18N
                 return false;
@@ -205,6 +213,7 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
                 !domainDirCandidate.exists()) {
             wizardIterator.setDomainLocation(domainDirCandidate.getAbsolutePath());
             wizardIterator.setHostName("localhost");
+            wizardIterator.setUseDefaultPorts(panel.getUseDefaultPorts());
             wizard.putProperty(PROP_INFO_MESSAGE, NbBundle.getMessage(this.getClass(), "MSG_CreateEmbedded", domainField)); // NOI18N
             return true;
         }
@@ -216,12 +225,13 @@ public class AddDomainLocationPanel implements WizardDescriptor.Panel, ChangeLis
             wizardIterator.setDomainLocation(domainLoc);
             wizardIterator.setHostName("localhost");
             wizard.putProperty(PROP_INFO_MESSAGE, NbBundle.getMessage(this.getClass(), "MSG_RegisterExisting", domainField)); // NOI18N
-            AddServerLocationPanel.readServerConfiguration(domainDirCandidate, wizardIterator);
+            org.netbeans.modules.glassfish.common.Util.readServerConfiguration(domainDirCandidate, wizardIterator);
             return true;
         }
         if (AddServerLocationPanel.canCreate(domainDirCandidate) && !ServerUtilities.isTP2(gfRoot)) {
             wizardIterator.setDomainLocation(domainLoc);
             wizard.putProperty(PROP_INFO_MESSAGE, NbBundle.getMessage(this.getClass(), "MSG_CreateDomain", domainField)); // NOI18N
+            wizardIterator.setUseDefaultPorts(panel.getUseDefaultPorts());
             wizardIterator.setHostName("localhost");
             return true;
         }
