@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -52,10 +52,12 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.prefs.Preferences;
 import javax.swing.JFileChooser;
+import javax.swing.JOptionPane;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
+import org.netbeans.modules.glassfish.common.ServerDetails;
 import org.netbeans.modules.glassfish.spi.Utils;
 import org.openide.awt.HtmlBrowser.URLDisplayer;
 import org.openide.util.Mutex;
@@ -67,12 +69,11 @@ import org.openide.util.NbPreferences;
  * @author Peter Williams
  */
 public class AddServerLocationVisualPanel extends javax.swing.JPanel implements Retriever.Updater {
-    private String nameOfBits;
 
     public static enum DownloadState { AVAILABLE, DOWNLOADING, COMPLETED };
 
     // expose for qa-functional tests
-    public static final String V3_DOWNLOAD_PREFIX = "http://java.net/download/"; // NOI18N
+    public static final String V3_DOWNLOAD_PREFIX = "http://download.java.net/"; // NOI18N
     
     private final List<ChangeListener> listeners = new CopyOnWriteArrayList<ChangeListener>();
     private Retriever retriever;
@@ -93,12 +94,15 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
         
         hk2HomeTextField.setText(getPreviousValue());            
         hk2HomeTextField.getDocument().addDocumentListener(new DocumentListener() {
+            @Override
             public void changedUpdate(DocumentEvent e) {
                 homeFolderChanged();
             }
+            @Override
             public void insertUpdate(DocumentEvent e) {
                 homeFolderChanged();
             }
+            @Override
             public void removeUpdate(DocumentEvent e) {
                 homeFolderChanged();
             }                    
@@ -111,15 +115,14 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
         Preferences prefs = NbPreferences.forModule(wizardIterator.getClass());
         String prevValue = null;
         if (null != prefs) {
-            prevValue = prefs.get(wizardIterator.getInstallRootKey(), null);
+            prevValue = prefs.get("INSTALL_ROOT_KEY", null); // NOI18N
         }
         if (null == prevValue) {
-            String installDir = System.getProperty(wizardIterator.getInstallRootProperty());
+            String installDir = System.getProperty("INSTALL_ROOT_PROPERTY"); // NOI18N
             if (null != installDir && !(installDir.trim().length() == 0)) {
                  return installDir;
             } else {
-                return System.getProperty("user.home") + File.separatorChar + 
-                        wizardIterator.getDefaultInstallDirectoryName(); //"GlassFish_v3_Prelude";
+                return System.getProperty("user.home") + File.separatorChar + "GlassFish_Server"; // NOI18N
             }
         } else {
             return prevValue;            
@@ -169,9 +172,9 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
         }
     }
     
-    private String browseHomeLocation(String nameOfBits) {
+    private String browseHomeLocation() {
         String hk2Location = null;
-        JFileChooser chooser = getJFileChooser(nameOfBits);
+        JFileChooser chooser = getJFileChooser();
         int returnValue = chooser.showDialog(this, NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_ChooseButton")); //NOI18N
         if(returnValue == JFileChooser.APPROVE_OPTION) {
             hk2Location = chooser.getSelectedFile().getAbsolutePath();
@@ -179,15 +182,15 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
         return hk2Location;
     }
     
-    private JFileChooser getJFileChooser(String nameOfBits) {
+    private JFileChooser getJFileChooser() {
         JFileChooser chooser = new JFileChooser();
-        String t = NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_ChooserName", nameOfBits);
+        String t = NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_ChooserName");
         chooser.setDialogTitle(t); //NOI18N
         chooser.setDialogType(JFileChooser.CUSTOM_DIALOG);
         chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
         chooser.setApproveButtonMnemonic("Choose_Button_Mnemonic".charAt(0)); //NOI18N
         chooser.setMultiSelectionEnabled(false);
-        chooser.addChoosableFileFilter(new DirFilter(nameOfBits));
+        chooser.addChoosableFileFilter(new DirFilter());
         chooser.setAcceptAllFileFilterUsed(false);
         chooser.setApproveButtonToolTipText(t); //NOI18N
         chooser.getAccessibleContext().setAccessibleName(t); //NOI18N
@@ -220,8 +223,10 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
     // ------------------------------------------------------------------------
     // Updater implementation
     // ------------------------------------------------------------------------
+    @Override
     public void updateMessageText(final String msg) {
         Mutex.EVENT.readAccess(new Runnable() {
+            @Override
             public void run() {
                 if (msg.trim().startsWith("<html>")) {
                     downloadStatusLabel.setText(msg);
@@ -233,11 +238,13 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
         });
     }
     
+    @Override
     public void updateStatusText(final String status) {
         statusText = status;
         fireChangeEvent();
     }
 
+    @Override
     public void clearCancelState() {
         setDownloadState(retriever.getDownloadState() == Retriever.STATUS_COMPLETE ? 
             DownloadState.COMPLETED : DownloadState.AVAILABLE);
@@ -247,6 +254,7 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
     // ------------------------------------------------------------------------
     private void updateButton() {
         Mutex.EVENT.readAccess(new Runnable() {
+            @Override
             public void run() {
                 DownloadState state = AddServerLocationVisualPanel.this.downloadState;
                 boolean licenseAccepted = agreeCheckBox.isSelected();
@@ -277,12 +285,10 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
     }
        
     private static class DirFilter extends javax.swing.filechooser.FileFilter {
-        private String nameOfBits;
-
-        DirFilter(String nameOfBits) {
-            this.nameOfBits = nameOfBits;
+        DirFilter() {
         }
         
+        @Override
         public boolean accept(File f) {
             if(!f.exists() || !f.canRead() || !f.isDirectory()) {
                 return false;
@@ -291,8 +297,9 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
             }
         }
         
+        @Override
         public String getDescription() {
-            return NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_DirType", nameOfBits);
+            return NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_DirType");
         }
         
     }
@@ -353,44 +360,48 @@ public class AddServerLocationVisualPanel extends javax.swing.JPanel implements
         downloadStatusLabel.setVerticalAlignment(javax.swing.SwingConstants.TOP);
         downloadStatusLabel.setHorizontalTextPosition(javax.swing.SwingConstants.LEADING);
 
-        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
+        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(layout.createSequentialGroup()
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-                    .add(hk2HomeLabel)
-                    .add(layout.createSequentialGroup()
-                        .add(downloadButton)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
-                        .add(agreeCheckBox)
-                        .add(2, 2, 2)
-                        .add(readlicenseButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
-
-                    .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
-                        .add(hk2HomeTextField, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 387, Short.MAX_VALUE)
-                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                        .add(browseButton))
-                    .add(downloadStatusLabel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 480, Short.MAX_VALUE))
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(layout.createSequentialGroup()
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+                    .addComponent(hk2HomeLabel)
+                    .addGroup(layout.createSequentialGroup()
+                        .addComponent(downloadButton)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
+                        .addComponent(agreeCheckBox)
+                        .addGap(2, 2, 2)
+                        .addComponent(readlicenseButton))
+                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
+                        .addComponent(hk2HomeTextField, javax.swing.GroupLayout.DEFAULT_SIZE, 443, Short.MAX_VALUE)
+                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                        .addComponent(browseButton))
+                    .addComponent(downloadStatusLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 552, Short.MAX_VALUE))
                 .addContainerGap())
         );
         layout.setVerticalGroup(
-            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(layout.createSequentialGroup()
-                .add(hk2HomeLabel)
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
-                    .add(hk2HomeTextField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
-                    .add(browseButton))
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
-                    .add(downloadButton)
-                    .add(agreeCheckBox)
-                    .add(readlicenseButton))
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(downloadStatusLabel)
-                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
+            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
+            .addGroup(layout.createSequentialGroup()
+                .addComponent(hk2HomeLabel)
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
+                    .addComponent(hk2HomeTextField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
+                    .addComponent(browseButton))
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
+                    .addComponent(downloadButton)
+                    .addComponent(agreeCheckBox)
+                    .addComponent(readlicenseButton, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
+                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
+                .addComponent(downloadStatusLabel)
+                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
         );
+
+        hk2HomeTextField.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(AddServerLocationVisualPanel.class, "AddServerLocationVisualPanel.hk2HomeTextField.AccessibleContext.accessibleDescription")); // NOI18N
+        browseButton.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(AddServerLocationVisualPanel.class, "AddServerLocationVisualPanel.browseButton.AccessibleContext.accessibleDescription")); // NOI18N
+        agreeCheckBox.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(AddServerLocationVisualPanel.class, "AddServerLocationVisualPanel.agreeCheckBox.AccessibleContext.accessibleDescription")); // NOI18N
+        readlicenseButton.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(AddServerLocationVisualPanel.class, "AddServerLocationVisualPanel.readlicenseButton.AccessibleContext.accessibleDescription")); // NOI18N
     }// </editor-fold>//GEN-END:initComponents
 
 private void readlicenseButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_readlicenseButtonActionPerformed
@@ -404,13 +415,23 @@ private void readlicenseButtonActionPerformed(java.awt.event.ActionEvent evt) {/
 
 private void downloadButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_downloadButtonActionPerformed
         if(retriever == null) {
+            ServerDetails selectedValue = wizardIterator.possibleValues[0];
+            if (wizardIterator.possibleValues.length > 1) {
+                selectedValue = (ServerDetails) JOptionPane.showInputDialog(null,
+                    NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_ChooseOne"), // NOI18N
+                    NbBundle.getMessage(AddServerLocationVisualPanel.class, "LBL_SELECT_BITS"), // NOI18N
+                    JOptionPane.INFORMATION_MESSAGE, null,
+                    wizardIterator.possibleValues, wizardIterator.possibleValues[0]);
+            }
+            if (null != selectedValue) {
             updateStatusText("");  // NOI18N
             retriever = new Retriever(new File(hk2HomeTextField.getText()), 
-                    wizardIterator.getIndirect(), V3_DOWNLOAD_PREFIX,
-                    wizardIterator.getDirect(),
+                    selectedValue.getIndirectUrl(), V3_DOWNLOAD_PREFIX,
+                    selectedValue.getDirectUrl(),
                     this, "glassfish"); // NOI18N
             new Thread(retriever).start();
             setDownloadState(DownloadState.DOWNLOADING);
+            }
         } else {
             retriever.stopRetrieval();
             setDownloadState(DownloadState.AVAILABLE);
@@ -418,7 +439,7 @@ private void downloadButtonActionPerformed(java.awt.event.ActionEvent evt) {//GE
 }//GEN-LAST:event_downloadButtonActionPerformed
 
 private void browseButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_browseButtonActionPerformed
-        String newLoc = browseHomeLocation(wizardIterator.getNameOfBits());
+        String newLoc = browseHomeLocation();
         if(newLoc != null && newLoc.length() > 0) {
             hk2HomeTextField.setText(newLoc);
         }
