@@ -43,6 +43,7 @@
 package org.netbeans.modules.glassfish.spi;
 
 import java.awt.Image;
+import org.openide.util.ImageUtilities;
 
 /**
  *
@@ -50,6 +51,10 @@ import java.awt.Image;
  */
 public abstract class Decorator {
 
+    public static final String DISABLED = "disabled ";
+
+    public static final Image DISABLED_BADGE =
+            ImageUtilities.loadImage("org/netbeans/modules/glassfish/common/resources/disabled-badge.gif"); // NOI18N
     /**
      * Returns the badge to be used to decorate the default icon for this node.
      * 
@@ -133,4 +138,40 @@ public abstract class Decorator {
         return false;
     }
 
+    /**
+     * Can this node be enabled?
+     *
+     * @return true if enable is supported.
+     */
+    public boolean canEnable() {
+        return false;
+    }
+
+    /**
+     * Can this node be disabled?
+     *
+     * @return true if disable is supported.
+     */
+    public boolean canDisable() {
+        return false;
+    }
+
+    /**
+     * Can this node be tested?
+     *
+     * @return true if test is supported.
+     */
+    public boolean canTest() {
+        return false;
+    }
+
+    /**
+     * Can this node be copied?
+     *
+     * @return true if copy is supported.
+     */
+    public boolean canCopy() {
+        return false;
+    }
+
 }
