@@ -112,6 +112,11 @@ public interface GlassfishModule {
     public static final String JAVAMAIL_RESOURCE = "javamail-resource"; // NOI18N
 
     public CommandFactory getCommandFactory();
+
+    public String getResourcesXmlName();
+
+    public boolean isWritable();
+
     /**
      * Enum for the current state of the server (stopped, running, etc.)
      */
@@ -278,7 +283,7 @@ public interface GlassfishModule {
      *   completed.
      */
     public Future<OperationState> redeploy(final OperationStateListener stateListener, 
-            final String name);
+            final String name, final boolean resourcesChanged);
        
     /**
      * Redeploy the named application onto the server with a new context root
@@ -295,7 +300,7 @@ public interface GlassfishModule {
      *   completed.
      */
     public Future<OperationState> redeploy(final OperationStateListener stateListener, 
-            final String name, final String contextRoot);
+            final String name, final String contextRoot, final boolean resourcesChanged);
     
     /**
      * Undeploy the named application.
@@ -310,6 +315,30 @@ public interface GlassfishModule {
     public Future<OperationState> undeploy(OperationStateListener stateListener, 
             String name);
     
+    /**
+     * Enable the named application.
+     *
+     * @param stateListener listener to listen message describing the enable
+     *   process as it progresses.  Can be null.
+     * @param name name of application to enable.
+     *
+     * @return Future instance that finishes when the deploy command has been
+     *   completed.
+     */
+    public Future<OperationState> enable(OperationStateListener stateListener,
+            String name);
+    /**
+     * Disable the named application.
+     *
+     * @param stateListener listener to listen message describing the disable
+     *   process as it progresses.  Can be null.
+     * @param name name of application to disable.
+     *
+     * @return Future instance that finishes when the deploy command has been
+     *   completed.
+     */
+    public Future<OperationState> disable(OperationStateListener stateListener,
+            String name);
     /**
      * Execute the specified server command.
      * 
@@ -363,4 +392,9 @@ public interface GlassfishModule {
      * get the password for this server
      */
     public String getPassword();
+
+    public boolean supportsRestartInDebug();
+
+    public boolean isRestfulLogAccessSupported();
+
 }
