@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -45,9 +45,11 @@ package org.netbeans.modules.glassfish.spi;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.net.HttpURLConnection;
 import java.net.URLDecoder;
 import java.text.MessageFormat;
 import java.util.HashMap;
+import java.util.Locale;
 import java.util.Map;
 import java.util.jar.Manifest;
 import java.util.logging.Level;
@@ -67,6 +69,11 @@ public abstract class ServerCommand {
     protected final String command;
     protected String query = null;
     protected boolean retry = false;
+    private String serverMessage = "";
+
+    public String getServerMessage() {
+        return serverMessage;
+    }
 
     public ServerCommand(String command) {
         this.command = command;
@@ -191,13 +198,13 @@ public abstract class ServerCommand {
      * @return true if response was read correctly.
      * @throws java.io.IOException in case of stream error.
      */
-    public boolean readResponse(InputStream in) throws IOException {
+    public boolean readResponse(InputStream in, HttpURLConnection hconn) throws IOException {
         boolean result = false;
 
         Manifest m = new Manifest();
         m.read(in);
         String outputCode = m.getMainAttributes().getValue("exit-code"); // NOI18N
-        if(outputCode.equalsIgnoreCase("Success")) { // NOI18N
+        if(null == outputCode || !"FAILURE".equals(outputCode.toUpperCase(Locale.ENGLISH))) { // NOI18N
             readManifest(m);
             result = true;
         } else {
@@ -208,6 +215,8 @@ public abstract class ServerCommand {
             // set the retry flag.
             if(message != null && message.contains("please wait")) {
                 retry = true;
+            } else {
+                serverMessage = null != message ? message.replaceAll("%%%EOL%%%", "\n") : "";
             }
             Logger.getLogger("glassfish").log(Level.WARNING, message);
         }
@@ -248,6 +257,14 @@ public abstract class ServerCommand {
         return (query == null) ? command : command + QUERY_SEPARATOR + query;
     }
 
+    public String getSrc() {
+        return "/__asadmin/";
+    }
+
+    public boolean acceptsGzip() {
+        return false;
+    }
+
     /**
      * Command to get property information for a dotted name.
      */
@@ -271,18 +288,43 @@ public abstract class ServerCommand {
         @Override
         public boolean processResponse() {
             if(info == null) {
+                Logger.getLogger("glassfish").log(Level.WARNING,
+                        "info is null for GetProperty command with \"{0}\"",query); // NOI18N
                 return false;
             }
 
             for (String key : info.getEntries().keySet()) {
                 int equalsIndex = key.indexOf('=');
                 if(equalsIndex >= 0) {
+                    String keyPart = key.substring(0, equalsIndex);
+                    String valuePart = key.substring(equalsIndex + 1);
+                    Level logLevel = Level.WARNING;
                     try {
-                        propertyMap.put(key.substring(0, equalsIndex), URLDecoder.decode(URLDecoder.decode(key.substring(equalsIndex + 1), "UTF-8"),"UTF-8"));
+                        // around Sept. 2008... 3.x servers were double encoding their
+                        // responces.  It appears that has stopped (See http://netbeans.org/bugzilla/show_bug.cgi?id=195015)
+                        // The open question is, "When did 3.x stop doing the double encode?"
+                        // since we don't know... this strategy will work for us
+                        //   Belt and suspenders, like
+                        propertyMap.put(keyPart,valuePart); // raw form
+                        propertyMap.put(keyPart, URLDecoder.decode(valuePart, "UTF-8")); // single decode
+                        //
+                        // If this next application of decoding generates an exception,
+                        // don't make a big deal of it.
+                        //
+                        logLevel = Level.FINE;
+                        propertyMap.put(keyPart, URLDecoder.decode(propertyMap.get(keyPart),"UTF-8"));
                     } catch (UnsupportedEncodingException ex) {
-                        ///Exceptions.printStackTrace(ex);
+                        Logger.getLogger("glassfish").log(Level.WARNING,  // NOI18N
+                                "UnsupportedEncodingException for value \"{0}\"",  // NOI18N
+                                propertyMap.get(keyPart));
+                    } catch (IllegalArgumentException iae) {
+                        Logger.getLogger("glassfish").log(logLevel,  // NOI18N
+                                "IllegalArgumentException for value \"{0}\" : inserted into propertyMap as \"{1}\"",  // NOI18N
+                                new Object[] { valuePart, propertyMap.get(keyPart) });
                     }
                 } else {
+                        Logger.getLogger("glassfish").log(Level.WARNING,  // NOI18N
+                                "Inserting empty string as value for key=\"{0}\"",key); // NOI18N
                     propertyMap.put(key, "");
                 }
             }
