@@ -52,9 +52,12 @@ import java.beans.PropertyChangeListener;
 import java.beans.PropertyVetoException;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import javax.accessibility.AccessibleContext;
 import javax.swing.ActionMap;
+import javax.swing.BorderFactory;
 import javax.swing.JPanel;
 import javax.swing.JToolBar;
 import javax.swing.event.ChangeEvent;
@@ -84,7 +87,7 @@ final class ResultPanelTree extends JPanel
     /** */
     private final ResultTreeView treeView;
     /** should the results be filtered (only failures and errors displayed)? */
-    private boolean filtered = false;
+    private int filterMask = 0;
     /** */
     private ChangeListener changeListener;
     /** */
@@ -93,27 +96,31 @@ final class ResultPanelTree extends JPanel
     private final ResultDisplayHandler displayHandler;
 
     private final ResultBar resultBar = new ResultBar();
+    private StatisticsPanel statPanel;
 
-    ResultPanelTree(ResultDisplayHandler displayHandler) {
+    ResultPanelTree(ResultDisplayHandler displayHandler, StatisticsPanel statPanel) {
         super(new BorderLayout());
         treeView = new ResultTreeView();
         treeView.getAccessibleContext().setAccessibleName(bundle.getString("ACSN_TestResults"));
         treeView.getAccessibleContext().setAccessibleDescription(bundle.getString("ACSD_TestResults"));
+        treeView.setBorder(BorderFactory.createEtchedBorder());
 //        resultBar.setPassedPercentage(0.0f);
         JToolBar toolBar = new JToolBar();
         toolBar.setFloatable(false);
-        toolBar.addSeparator(new Dimension(1, 0));
         toolBar.add(resultBar);
+        toolBar.setBorder(BorderFactory.createEtchedBorder());
+
         add(toolBar, BorderLayout.NORTH);
         add(treeView, BorderLayout.CENTER);
 
         explorerManager = new ExplorerManager();
-        explorerManager.setRootContext(rootNode = new RootNode(displayHandler.getSession(), filtered));
+        explorerManager.setRootContext(rootNode = new RootNode(displayHandler.getSession(), filterMask));
         explorerManager.addPropertyChangeListener(this);
 
         initAccessibility();
 
         this.displayHandler = displayHandler;
+        this.statPanel = statPanel;
         displayHandler.setLookup(ExplorerUtils.createLookup(explorerManager, new ActionMap()));
     }
 
@@ -159,6 +166,7 @@ final class ResultPanelTree extends JPanel
 
         rootNode.displayMessageSessionFinished(msg);
         resultBar.stop();
+        statPanel.updateButtons();
     }
 
     /**
@@ -214,6 +222,7 @@ final class ResultPanelTree extends JPanel
             }
         }
         resultBar.setPassedPercentage(rootNode.getPassedPercentage());
+        statPanel.updateButtons();
     }
 
     /**
@@ -230,6 +239,7 @@ final class ResultPanelTree extends JPanel
             rootNode.displayReports(reports);
         }
         resultBar.setPassedPercentage(rootNode.getPassedPercentage());
+        statPanel.updateButtons();
    }
 
     /**
@@ -249,14 +259,13 @@ final class ResultPanelTree extends JPanel
 
     /**
      */
-    void setFiltered(final boolean filtered) {
-        if (filtered == this.filtered) {
+    void setFilterMask(final int filterMask) {
+        if (filterMask == this.filterMask) {
             return;
         }
 
-        this.filtered = filtered;
-
-        rootNode.setFiltered(filtered);
+        this.filterMask = filterMask;
+        rootNode.setFilterMask(filterMask);
     }
 
     /**
@@ -311,6 +320,16 @@ final class ResultPanelTree extends JPanel
         return explorerManager.getSelectedNodes();
     }
 
+    Set<Testcase> getFailedTests(){
+        Set<Testcase> failedTests = new HashSet();
+        for(Testcase tc:displayHandler.getSession().getAllTestCases()){
+            if (Status.isFailureOrError(tc.getStatus())){
+                failedTests.add(tc);
+            }
+        }
+        return failedTests;
+    }
+
     /**
      * Selects and activates a given node.
      * Selects a given node in the tree.
