@@ -43,46 +43,58 @@ package org.netbeans.modules.html.editor.api.gsf;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import org.netbeans.editor.ext.html.dtd.DTD;
-import org.netbeans.editor.ext.html.parser.AstNode;
-import org.netbeans.editor.ext.html.parser.AstNode.Description;
-import org.netbeans.editor.ext.html.parser.AstNodeUtils;
-import org.netbeans.editor.ext.html.parser.AstNodeVisitor;
-import org.netbeans.editor.ext.html.parser.SyntaxElement;
-import org.netbeans.editor.ext.html.parser.SyntaxParserResult;
+import java.util.logging.Level;
+import java.util.logging.Logger;
+import org.netbeans.editor.ext.html.parser.api.AstNode;
+import org.netbeans.editor.ext.html.parser.api.HtmlParsingResult;
+import org.netbeans.editor.ext.html.parser.api.ParseException;
+import org.netbeans.editor.ext.html.parser.api.ProblemDescription;
+import org.netbeans.editor.ext.html.parser.api.AstNodeUtils;
+import org.netbeans.editor.ext.html.parser.api.SyntaxAnalyzerResult;
+import org.netbeans.editor.ext.html.parser.spi.ParseResult;
+import org.netbeans.html.api.validation.ValidationException;
+import org.netbeans.html.api.validation.Validator;
 import org.netbeans.modules.csl.api.Error;
 import org.netbeans.modules.csl.api.Severity;
 import org.netbeans.modules.csl.spi.DefaultError;
 import org.netbeans.modules.csl.spi.ParserResult;
-import org.netbeans.modules.html.editor.HtmlVersion;
+import org.netbeans.editor.ext.html.parser.api.HtmlVersion;
+import org.netbeans.html.api.validation.ValidationContext;
+import org.netbeans.html.api.validation.ValidationResult;
+import org.netbeans.html.api.validation.ValidatorService;
 import org.netbeans.modules.html.editor.gsf.HtmlParserResultAccessor;
-import org.netbeans.modules.parsing.api.Snapshot;
 import org.openide.filesystems.FileObject;
+import org.openide.util.Exceptions;
 
 /**
  * HTML parser result
  *
  * @author mfukala@netbeans.org
  */
-public class HtmlParserResult extends ParserResult {
+public class HtmlParserResult extends ParserResult implements HtmlParsingResult {
 
     /**
      * Used as a key of a swing document to find a default fallback dtd.
      */
     public static final String FALLBACK_DTD_PROPERTY_NAME = "fallbackDTD";
-
-    private SyntaxParserResult result;
+    private SyntaxAnalyzerResult result;
     private List<Error> errors;
     private boolean isValid = true;
 
-    private HtmlParserResult(Snapshot snapshot, SyntaxParserResult result) {
-        super(snapshot);
+    private HtmlParserResult(SyntaxAnalyzerResult result) {
+        super(result.getSource().getSnapshot());
         this.result = result;
     }
 
+    @Override
+    public SyntaxAnalyzerResult getSyntaxAnalyzerResult() {
+        return result;
+    }
+
     /** The parser result may be invalidated by the parsing infrastructure.
      * In such case the method returns false.
      * @return true for valid result, false otherwise.
@@ -99,31 +111,14 @@ public class HtmlParserResult extends ParserResult {
      * 3) if not xhtml extension, present of default XHTML namespace declaration
      *
      */
+    @Override
     public HtmlVersion getHtmlVersion() {
-        String publicId = result.getPublicID();
-        if(publicId == null) {
-            FileObject fo = getSnapshot().getSource().getFileObject();
-            if(fo != null) {
-                if("text/xhtml".equals(fo.getMIMEType())) { //NOI18N
-                    //TODO resolve the xhtml version once we support more than 1.0
-                    return HtmlVersion.XHTML10;
-                } else {
-                    //is there an xhtml namespace declared in the file?
-                    if(result.getDeclaredNamespaces().containsKey(HtmlVersion.XHTML10.getDefaultNamespace())) {
-                        return HtmlVersion.XHTML10;
-                    }
-                }
-            }
-            return HtmlVersion.UNKNOWN;
-        } else {
-            return HtmlVersion.findHtmlVersion(publicId);
-        }
-
+        return result.getHtmlVersion();
     }
 
-    /** @return an instance of DTD for the parser input. */
-    public DTD dtd() {
-        return result.getDTD();
+    @Override
+    public HtmlVersion getDetectedHtmlVersion() {
+        return result.getDetectedHtmlVersion();
     }
 
     /** @return a root node of the hierarchical parse tree of the document.
@@ -132,38 +127,49 @@ public class HtmlParserResult extends ParserResult {
      * Use the flat parse tree results if you do not need the tree structure since
      * the postprocessing takes some time and is done lazily.
      */
+    @Override
     public AstNode root() {
-        return root(getHtmlVersion().getDefaultNamespace());
+        try {
+            return result.parseHtml().root();
+        } catch (ParseException ex) {
+            Exceptions.printStackTrace(ex);
+        }
+        return null;
+    }
+
+    @Override
+    public AstNode rootOfUndeclaredTagsParseTree() {
+        try {
+            return result.parseUndeclaredEmbeddedCode().root();
+        } catch (ParseException ex) {
+            Exceptions.printStackTrace(ex);
+        }
+        return null;
     }
 
     /** returns a parse tree for non-html content */
+    @Override
     public AstNode root(String namespace) {
-        DTD dtd = null;
-        if(namespace == null || namespace != null && namespace.equals(getHtmlVersion().getDefaultNamespace())) {
-            //html content, use fallback dtd
-            dtd = getFallbackDTD(getHtmlVersion());
+        try {
+            ParseResult pr = result.parseEmbeddedCode(namespace);
+            assert pr != null : "Cannot get ParseResult for " + namespace; //NOI18N
+            return pr.root();
+        } catch (ParseException ex) {
+            Exceptions.printStackTrace(ex);
         }
-
-        return result.getASTRoot(namespace, dtd);
-    }
-
-    private DTD getFallbackDTD(HtmlVersion version) {
-        String fallbackPublicID = version == HtmlVersion.UNKNOWN ?
-            HtmlVersion.HTML41.getFallbackPublicId() :
-            version.getFallbackPublicId();
-
-        return org.netbeans.editor.ext.html.dtd.Registry.getDTD(fallbackPublicID, null);
+        return null;
     }
 
     /** returns a map of all namespaces to astnode roots.*/
+    @Override
     public Map<String, AstNode> roots() {
         Map<String, AstNode> roots = new HashMap<String, AstNode>();
-        for(String uri : getNamespaces().keySet()) {
+        for (String uri : getNamespaces().keySet()) {
             roots.put(uri, root(uri));
         }
 
         //non xhtml workaround, add the default namespaces if missing
-        if(!roots.containsValue(root())) {
+        if (!roots.containsValue(root())) {
             roots.put(null, root());
         }
 
@@ -172,58 +178,31 @@ public class HtmlParserResult extends ParserResult {
     }
 
     /**declared uri to prefix map */
+    @Override
     public Map<String, String> getNamespaces() {
         return result.getDeclaredNamespaces();
     }
 
-    /** Returns a leaf most AstNode from the parse tree to which range the given
-     * offset belongs. Uses logical node ranges.
-     *
-     * @param offset of the searched node
-     */
-    public AstNode findLeaf(int offset) {
-        return findLeaf(offset, false);
-    }
-
-    public AstNode findLeaf(int offset, boolean exclusiveStartOffset) {
-        //first try to find the leaf in html content
-        AstNode mostLeaf = AstNodeUtils.findDescendant(root(), offset, exclusiveStartOffset);
-        //now search the non html trees
-        for(String uri : getNamespaces().keySet()) {
-            AstNode root = root(uri);
-            AstNode leaf = AstNodeUtils.findDescendant(root, offset, exclusiveStartOffset);
-            if(mostLeaf == null) {
-                mostLeaf = leaf;
-            } else {
-                //they cannot overlap, just be nested, at least I think
-                if(leaf.logicalStartOffset() > mostLeaf.logicalStartOffset() ) {
-                    mostLeaf = leaf;
-                }
-            }
-        }
-        return mostLeaf;
-    }
-
     /** Returns a leaf most AstNode from the parse tree to which range the given
      * offset belongs.
      *
      * @param offset of the searched node
      */
-    public AstNode findLeafTag(int offset, boolean useLogicalRanges, boolean forward) {
+    public AstNode findLeafTag(int offset, boolean forward, boolean physicalNodesOnly ) {
         //first try to find the leaf in html content
-        AstNode mostLeaf = AstNodeUtils.findDescendantTag(root(), offset, useLogicalRanges, forward);
+        AstNode mostLeaf = AstNodeUtils.findNode(root(), offset, forward, physicalNodesOnly);
         //now search the non html trees
-        for(String uri : getNamespaces().keySet()) {
+        for (String uri : getNamespaces().keySet()) {
             AstNode root = root(uri);
-            AstNode leaf = AstNodeUtils.findDescendantTag(root, offset, useLogicalRanges, forward);
-            if(leaf == null) {
+            AstNode leaf = AstNodeUtils.findNode(root, offset, forward, physicalNodesOnly);
+            if (leaf == null) {
                 continue;
             }
-            if(mostLeaf == null) {
+            if (mostLeaf == null) {
                 mostLeaf = leaf;
             } else {
                 //they cannot overlap, just be nested, at least I think
-                if(leaf.logicalStartOffset() > mostLeaf.logicalStartOffset() ) {
+                if (leaf.logicalStartOffset() > mostLeaf.logicalStartOffset()) {
                     mostLeaf = leaf;
                 }
             }
@@ -231,15 +210,11 @@ public class HtmlParserResult extends ParserResult {
         return mostLeaf;
     }
 
-    /** @return a list of SyntaxElement-s representing parse elements of the html source. */
-    public List<SyntaxElement> elementsList() {
-        return result.getElements();
-    }
-
     @Override
     public synchronized List<? extends Error> getDiagnostics() {
         if (errors == null) {
-            errors = new ArrayList<Error>(findErrors());
+            errors = new ArrayList<Error>();
+            errors.addAll(getValidationResults());
         }
         return errors;
     }
@@ -249,56 +224,71 @@ public class HtmlParserResult extends ParserResult {
         this.isValid = false;
     }
 
-    private List<Error> findErrors() {
-        final List<Error> _errors = new ArrayList<Error>();
-
-        AstNodeVisitor errorsCollector = new AstNodeVisitor() {
-
-            @Override
-            public void visit(AstNode node) {
-                if (node.type() == AstNode.NodeType.OPEN_TAG
-                        || node.type() == AstNode.NodeType.ENDTAG
-                        || node.type() == AstNode.NodeType.UNKNOWN_TAG) {
-
-                    for (Description desc : node.getDescriptions()) {
-                        if (desc.getType() < Description.WARNING) {
-                            continue;
-                        }
-                        //some error in the node, report
-                        DefaultError error =
-                                new DefaultError(desc.getKey(), //NOI18N
-                                desc.getText(),
-                                desc.getText(),
-                                getSnapshot().getSource().getFileObject(),
-                                desc.getFrom(),
-                                desc.getTo(),
-                                false /* not line error */,
-                                desc.getType() == Description.WARNING ? Severity.WARNING : Severity.ERROR); //NOI18N
-
-                        error.setParameters(new Object[]{node});
-
-                        _errors.add(error);
-
-                    }
-                }
+    private Collection<Error> getValidationResults() {
+        FileObject file = getSnapshot().getSource().getFileObject();
+        try {
+            //use the filtered snapshot or use the namespaces filtering facility in the nu.validator
+            Validator validator = ValidatorService.getValidator(getHtmlVersion());
+            if(validator == null) {
+                return Collections.emptyList();
             }
-        };
+            ValidationContext context = new ValidationContext(getSnapshot().getText().toString(), getHtmlVersion(), file, result);
 
-        Collection<AstNode> roots = new ArrayList<AstNode>();
-        roots.addAll(roots().values());
-        roots.add(root(SyntaxParserResult.UNDECLARED_TAGS_NAMESPACE));
-        for(AstNode root : roots) {
-            AstNodeUtils.visitChildren(root, errorsCollector);
+            //XXX possibly make it configurable via hints
+            context.enableFeature("filter.foreign.namespaces", true); //NOI18N
+            
+            ValidationResult res = validator.validate(context);
+
+            Collection<Error> errs = new ArrayList<Error>();
+            for (ProblemDescription pd : res.getProblems()) {
+                DefaultError error = new DefaultError(pd.getKey(),
+                        pd.getText(), //NOI18N
+                        pd.getText(),
+                        res.getContext().getFile(),
+                        pd.getFrom(),
+                        pd.getTo(),
+                        false,
+                        forProblemType(pd.getType()));
+
+                errs.add(error);
+            }
+            return errs;
+
+        } catch (ValidationException ex) {
+            Logger.getAnonymousLogger().log(Level.INFO, "An error occured during html code validation", ex);
+
+            DefaultError error = new DefaultError("validator.error",
+                    "validator.error",
+                    "An internal error occured during validating the code: " + ex.getLocalizedMessage(),
+                    file, 0,0, true, Severity.ERROR);
+
+            return Collections.<Error>singletonList(error);
         }
 
-        return _errors;
+    }
+
+    private static Severity forProblemType(int problemtype) {
+        switch (problemtype) {
+            case ProblemDescription.INFORMATION:
+                return Severity.INFO;
+            case ProblemDescription.WARNING:
+                return Severity.WARNING;
+            case ProblemDescription.ERROR:
+                return Severity.ERROR;
+            case ProblemDescription.FATAL:
+                return Severity.FATAL;
+            case ProblemDescription.INTERNAL_ERROR:
+                return Severity.INFO;
+            default:
+                throw new IllegalArgumentException("Invalid ProblemDescription type: " + problemtype); //NOI18N
+        }
 
     }
 
     public static AstNode getBoundAstNode(Error e) {
-        if(e instanceof DefaultError) {
-            if(e.getParameters() != null && e.getParameters().length > 0 && e.getParameters()[0] instanceof AstNode) {
-                return (AstNode)e.getParameters()[0];
+        if (e instanceof DefaultError) {
+            if (e.getParameters() != null && e.getParameters().length > 0 && e.getParameters()[0] instanceof AstNode) {
+                return (AstNode) e.getParameters()[0];
             }
         }
 
@@ -312,8 +302,8 @@ public class HtmlParserResult extends ParserResult {
     private static class Accessor extends HtmlParserResultAccessor {
 
         @Override
-        public HtmlParserResult createInstance(Snapshot snapshot, SyntaxParserResult result) {
-            return new HtmlParserResult(snapshot, result);
+        public HtmlParserResult createInstance(SyntaxAnalyzerResult result) {
+            return new HtmlParserResult(result);
         }
     }
 }
