@@ -62,17 +62,66 @@ public abstract class AttrValuesCompletion {
     private static final Map<String, Map<String, ValueCompletion<HtmlCompletionItem>>> SUPPORTS =
             new HashMap<String, Map<String, ValueCompletion<HtmlCompletionItem>>>();
 
+    private static final Map<String, ValueCompletion<HtmlCompletionItem>> ALL_TAG_SUPPORTS =
+            new HashMap<String, ValueCompletion<HtmlCompletionItem>>();
+
     public static final ValueCompletion<HtmlCompletionItem> FILE_NAME_SUPPORT = new FilenameSupport();
-    private static final ValueCompletion<HtmlCompletionItem> CONTENT_TYPE_SUPPORT = new ContentTypeSupport();
+    
+    private static final ValueCompletion<HtmlCompletionItem> CONTENT_TYPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"text/css", "text/javascript"});
+    
+    private static final ValueCompletion<HtmlCompletionItem> TRUE_FALSE_SUPPORT =
+            new ValuesSetSupport(new String[]{"true", "false"});
+    
+    private static final ValueCompletion<HtmlCompletionItem> SCOPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"row", "col", "rowgroup", "colgroup" });
+
+    private static final ValueCompletion<HtmlCompletionItem> SHAPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"circle", "default", "poly", "rect"  });
+
+    private static final ValueCompletion<HtmlCompletionItem> ON_OFF_SUPPORT =
+            new ValuesSetSupport(new String[]{"on", "off"});
+
+    private static final ValueCompletion<HtmlCompletionItem> FORMENCTYPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"application/x-www-form-urlencoded", "multipart/form-data", "text/plain"});
+
+    private static final ValueCompletion<HtmlCompletionItem> FORMMETHOD_SUPPORT =
+            new ValuesSetSupport(new String[]{"GET", "POST", "PUT", "DELETE"});
+
+    private static final ValueCompletion<HtmlCompletionItem> PRELOAD_SUPPORT =
+            new ValuesSetSupport(new String[]{"none", "metadata", "auto"});
+
+    private static final ValueCompletion<HtmlCompletionItem> BUTTON_TYPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"submit", "reset", "button" });
+
+    private static final ValueCompletion<HtmlCompletionItem> COMMAND_TYPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"command", "checkbox", "radio" });
+
+    private static final ValueCompletion<HtmlCompletionItem> MENU_TYPE_SUPPORT =
+            new ValuesSetSupport(new String[]{"context", "toolbar" });
+
+    private static final ValueCompletion<HtmlCompletionItem> WRAP_SUPPORT =
+            new ValuesSetSupport(new String[]{"soft", "hard" });
+    
 
     static {
         //TODO uff, such long list ... redo it so it resolves according to the DTD attribute automatically
+        //mixed with html5 content...
         putSupport("a", "href", FILE_NAME_SUPPORT); //NOI18N
         putSupport("area", "href", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("a", "ping", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("area", "ping", FILE_NAME_SUPPORT); //NOI18N
         putSupport("link", "href", FILE_NAME_SUPPORT); //NOI18N
         putSupport("base", "href", FILE_NAME_SUPPORT); //NOI18N
         putSupport("script", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("audio", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("embed", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("iframe", "src", FILE_NAME_SUPPORT); //NOI18N
         putSupport("img", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("input", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("source", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("track", "src", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("video", "src", FILE_NAME_SUPPORT); //NOI18N        
         putSupport("img", "longdesc", FILE_NAME_SUPPORT); //NOI18N
         putSupport("img", "usemap", FILE_NAME_SUPPORT); //NOI18N
         putSupport("input", "src", FILE_NAME_SUPPORT); //NOI18N
@@ -90,19 +139,57 @@ public abstract class AttrValuesCompletion {
         putSupport("ins", "cite", FILE_NAME_SUPPORT); //NOI18N
         putSupport("del", "cite", FILE_NAME_SUPPORT); //NOI18N
         putSupport("form", "action", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("button", "formaction", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("input", "formaction", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("command", "icon", FILE_NAME_SUPPORT); //NOI18N
+        putSupport(null, "itemprop", FILE_NAME_SUPPORT); //NOI18N
+        putSupport(null, "itemtype", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("html", "manifest", FILE_NAME_SUPPORT); //NOI18N
+        putSupport("video", "poster", FILE_NAME_SUPPORT); //NOI18N
 
         putSupport("script", "type", CONTENT_TYPE_SUPPORT); //NOI18N
         putSupport("style", "type", CONTENT_TYPE_SUPPORT); //NOI18N
         putSupport("link", "type", CONTENT_TYPE_SUPPORT); //NOI18N
+
+        putSupport("form", "autocomplete", ON_OFF_SUPPORT); //NOI18N
+        putSupport("input", "autocomplete", ON_OFF_SUPPORT); //NOI18N
+
+        putSupport(null, "contenteditable", TRUE_FALSE_SUPPORT); //NOI18N
+
+        putSupport("button", "formenctype", FORMENCTYPE_SUPPORT); //NOI18N
+        putSupport("input", "formenctype", FORMENCTYPE_SUPPORT); //NOI18N
+
+        putSupport("button", "formmethod", FORMMETHOD_SUPPORT); //NOI18N
+        putSupport("input", "formmethod", FORMMETHOD_SUPPORT); //NOI18N
+
+        putSupport("audio", "preload", PRELOAD_SUPPORT); //NOI18N
+        putSupport("video", "preload", PRELOAD_SUPPORT); //NOI18N
+
+        putSupport(null, "spellcheck", TRUE_FALSE_SUPPORT); //NOI18N
+
+        putSupport("th", "scope", SCOPE_SUPPORT); //NOI18N
+
+        putSupport("area", "shape", SHAPE_SUPPORT); //NOI18N
+
+        putSupport("button", "type", BUTTON_TYPE_SUPPORT); //NOI18N
+        putSupport("command", "type", COMMAND_TYPE_SUPPORT); //NOI18N
+        putSupport("menu", "type", MENU_TYPE_SUPPORT); //NOI18N
+
+        putSupport("textarea", "wrap", WRAP_SUPPORT); //NOI18N
+
     }
 
     private static void putSupport(String tag, String attr, ValueCompletion<HtmlCompletionItem> support) {
-        Map<String, ValueCompletion<HtmlCompletionItem>> map = SUPPORTS.get(tag);
-        if (map == null) {
-            map = new HashMap<String, ValueCompletion<HtmlCompletionItem>>();
-            SUPPORTS.put(tag, map);
+        if(tag == null) {
+            ALL_TAG_SUPPORTS.put(attr, support);
+        } else {
+            Map<String, ValueCompletion<HtmlCompletionItem>> map = SUPPORTS.get(tag);
+            if (map == null) {
+                map = new HashMap<String, ValueCompletion<HtmlCompletionItem>>();
+                SUPPORTS.put(tag, map);
+            }
+            map.put(attr, support);
         }
-        map.put(attr, support);
     }
 
     public static Map<String, ValueCompletion<HtmlCompletionItem>> getSupportsForTag(String tag) {
@@ -112,23 +199,27 @@ public abstract class AttrValuesCompletion {
     public static ValueCompletion<HtmlCompletionItem> getSupport(String tag, String attr) {
         Map<String, ValueCompletion<HtmlCompletionItem>> map = getSupportsForTag(tag);
         if(map == null) {
-            return null;
+            return ALL_TAG_SUPPORTS.get(attr);
         } else {
             return map.get(attr.toLowerCase(Locale.ENGLISH));
         }
     }
 
-    public static class ContentTypeSupport implements ValueCompletion {
+    public static class ValuesSetSupport implements ValueCompletion {
 
-        public static String[] TYPICAL_CONTENT_TYPES = new String[]{"text/css", "text/javascript"}; //NOI18N
+        private String[] values;
+
+        public ValuesSetSupport(String[] values) {
+            this.values = values;
+        }
 
         @Override
         public List<HtmlCompletionItem> getItems(FileObject file, int offset, String valuePart) {
             //linear search, too little items, no problem
             List<HtmlCompletionItem> items = new ArrayList<HtmlCompletionItem>();
-            for(int i = 0; i < TYPICAL_CONTENT_TYPES.length; i++) {
-                if(TYPICAL_CONTENT_TYPES[i].startsWith(valuePart)) {
-                    items.add(HtmlCompletionItem.createAttributeValue(TYPICAL_CONTENT_TYPES[i], offset));
+            for(int i = 0; i < values.length; i++) {
+                if(values[i].startsWith(valuePart)) {
+                    items.add(HtmlCompletionItem.createAttributeValue(values[i], offset));
                 }
             }
             return items;
