@@ -46,6 +46,8 @@ package org.netbeans.modules.html.editor.completion;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Locale;
+import org.netbeans.editor.ext.html.parser.spi.HelpItem;
+import org.netbeans.editor.ext.html.parser.spi.HelpResolver;
 import org.netbeans.modules.html.editor.api.Utils;
 import org.netbeans.modules.html.editor.api.completion.HtmlCompletionItem;
 import java.net.URL;
@@ -61,6 +63,7 @@ import org.netbeans.api.lexer.TokenHierarchy;
 import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
+import org.netbeans.modules.html.editor.HtmlPreferences;
 import org.netbeans.modules.parsing.spi.ParseException;
 import org.netbeans.spi.editor.completion.CompletionDocumentation;
 import org.netbeans.spi.editor.completion.CompletionItem;
@@ -83,8 +86,9 @@ public class HtmlCompletionProvider implements CompletionProvider {
     public int getAutoQueryTypes(JTextComponent component, String typedText) {
         Document doc = component.getDocument();
         int dotPos = component.getCaret().getDot();
-        boolean openCC = checkOpenCompletion(doc, dotPos, typedText);
-        return openCC ? COMPLETION_QUERY_TYPE + DOCUMENTATION_QUERY_TYPE : 0;
+        return HtmlPreferences.autoPopupCompletionWindow() && checkOpenCompletion(doc, dotPos, typedText)
+                ? COMPLETION_QUERY_TYPE + DOCUMENTATION_QUERY_TYPE
+                : 0;
     }
 
     @Override
@@ -212,8 +216,8 @@ public class HtmlCompletionProvider implements CompletionProvider {
                 }
             }
             HtmlCompletionItem htmlItem = (HtmlCompletionItem) item;
-            if (htmlItem != null && htmlItem.getHelp() != null) {
-                resultSet.setDocumentation(new DocItem(htmlItem));
+            if (htmlItem != null && htmlItem.hasHelp()) {
+                resultSet.setDocumentation(createCompletionDocumentation(htmlItem));
             }
         }
     }
@@ -339,11 +343,11 @@ public class HtmlCompletionProvider implements CompletionProvider {
         Completion.get().hideDocumentation();
     }
 
-    private static class LinkDocItem implements CompletionDocumentation {
+    private static class LegacyLinkDocItem implements CompletionDocumentation {
 
         private URL url;
 
-        public LinkDocItem(URL url) {
+        public LegacyLinkDocItem(URL url) {
             this.url = url;
         }
 
@@ -366,7 +370,42 @@ public class HtmlCompletionProvider implements CompletionProvider {
 
         @Override
         public CompletionDocumentation resolveLink(String link) {
-            return new LinkDocItem(HelpManager.getDefault().getRelativeURL(url, link));
+            return new LegacyLinkDocItem(HelpManager.getDefault().getRelativeURL(url, link));
+        }
+
+        @Override
+        public Action getGotoSourceAction() {
+            return null;
+        }
+    }
+    private static class LinkDocItem implements CompletionDocumentation {
+
+        private URL url;
+        private HelpResolver resolver;
+
+        public LinkDocItem(HelpResolver resolver, URL url) {
+            this.url = url;
+            this.resolver = resolver;
+        }
+
+        @Override
+        public String getText() {
+            //normally it should be enough to return null here
+            //and the documentation would be loaded from the URL.
+            //However it seems that the html5 anchor navigation doesn't
+            //properly work in the embedded swing browser so I need to
+            //strip the begginning of the file to the anchor manually
+            return resolver.getHelpContent(getURL());
+        }
+
+        @Override
+        public URL getURL() {
+            return url;
+        }
+
+        @Override
+        public CompletionDocumentation resolveLink(String link) {
+            return new LinkDocItem(resolver, resolver.resolveLink(getURL(), link));
         }
 
         @Override
@@ -398,6 +437,76 @@ public class HtmlCompletionProvider implements CompletionProvider {
         }
     }
 
+    private static CompletionDocumentation createCompletionDocumentation(HtmlCompletionItem item) {
+        //fork for the new and old help approach, legacy html4 not migrated yet
+        HelpItem helpItem  = item.getHelpItem();
+        if(helpItem != null) {
+            return new HtmlTagDocumetationItem(item);
+        }
+
+        //else legacy approach
+        return new DocItem(item);
+    }
+
+
+
+    private static class HtmlTagDocumetationItem implements CompletionDocumentation {
+
+        HtmlCompletionItem item;
+
+        public HtmlTagDocumetationItem(HtmlCompletionItem ri) {
+            this.item = ri;
+        }
+
+        private HelpItem getHelpItem() {
+            return item.getHelpItem();
+        }
+
+        @Override
+        public String getText() {
+            //normally it should be enough to return null here
+            //and the documentation would be loaded from the URL.
+            //However it seems that the html5 anchor navigation doesn't
+            //properly work in the embedded swing browser so I need to
+            //strip the begginning of the file to the anchor manually
+
+            //now the statement above is not fully true since I need to add
+            //the header before the URL content
+            StringBuilder sb = new StringBuilder();
+            String header = getHelpItem().getHelpHeader();
+            if(header != null) {
+                sb.append(header);
+            }
+
+            String helpContent = getHelpItem().getHelpContent() != null
+                    ? getHelpItem().getHelpContent()
+                    : getHelpItem().getHelpResolver().getHelpContent(getURL());
+
+            sb.append(helpContent);
+
+            return sb.toString();
+        }
+
+        @Override
+        public URL getURL() {
+            return getHelpItem().getHelpURL();
+        }
+
+        @Override
+        public CompletionDocumentation resolveLink(String link) {
+            URL itemUrl = getHelpItem().getHelpResolver().resolveLink(getURL(), link);
+            return itemUrl != null ?
+                new LinkDocItem(getHelpItem().getHelpResolver(), itemUrl) :
+                new NoDocItem();
+        }
+
+        @Override
+        public Action getGotoSourceAction() {
+            return null;
+        }
+    }
+
+
     private static class DocItem implements CompletionDocumentation {
 
         HtmlCompletionItem item;
@@ -420,7 +529,7 @@ public class HtmlCompletionProvider implements CompletionProvider {
         public CompletionDocumentation resolveLink(String link) {
             URL itemUrl = HelpManager.getDefault().getHelpURL(item.getHelpId());
             return itemUrl != null ?
-                new LinkDocItem(HelpManager.getDefault().getRelativeURL(itemUrl, link)) :
+                new LegacyLinkDocItem(HelpManager.getDefault().getRelativeURL(itemUrl, link)) :
                 new NoDocItem();
         }
 
