@@ -44,21 +44,27 @@
 package org.netbeans.modules.html.editor.completion;
 
 import java.util.logging.Logger;
+import javax.swing.text.BadLocationException;
+import org.netbeans.editor.ext.html.parser.api.HtmlVersion;
+import org.netbeans.editor.ext.html.parser.spi.HtmlModel;
+import org.netbeans.editor.ext.html.parser.spi.HtmlParseResult;
+import org.netbeans.editor.ext.html.parser.spi.HtmlTag;
 import org.netbeans.modules.html.editor.api.Utils;
 import org.netbeans.modules.html.editor.api.completion.HtmlCompletionItem;
 import java.util.*;
 import java.util.Collections;
-import java.util.concurrent.atomic.AtomicReference;
 import javax.swing.text.Document;
-import org.netbeans.editor.ext.html.dtd.*;
 import org.netbeans.api.html.lexer.HTMLTokenId;
 import org.netbeans.api.lexer.Token;
 import org.netbeans.api.lexer.TokenHierarchy;
 import org.netbeans.api.lexer.TokenId;
 import org.netbeans.api.lexer.TokenSequence;
-import org.netbeans.editor.ext.html.parser.AstNode;
-import org.netbeans.editor.ext.html.parser.AstNodeUtils;
-import org.netbeans.editor.ext.html.parser.SyntaxParserResult;
+import org.netbeans.editor.ext.html.parser.XmlSyntaxTreeBuilder;
+import org.netbeans.editor.ext.html.parser.api.AstNode;
+import org.netbeans.editor.ext.html.parser.api.AstNodeUtils;
+import org.netbeans.editor.ext.html.parser.api.ProblemDescription;
+import org.netbeans.editor.ext.html.parser.spi.HtmlTagAttribute;
+import org.netbeans.editor.ext.html.parser.spi.NamedCharRef;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
 import org.netbeans.modules.csl.api.DataLoadersBridge;
 import org.netbeans.modules.html.editor.HtmlPreferences;
@@ -74,6 +80,7 @@ import org.netbeans.modules.parsing.spi.Parser;
 import org.netbeans.modules.web.common.api.ValueCompletion;
 import org.netbeans.spi.editor.completion.CompletionItem;
 import org.openide.filesystems.FileObject;
+import org.openide.util.Exceptions;
 
 /**
  * Html completion results finder
@@ -109,56 +116,57 @@ public class HtmlCompletionQuery extends UserTask {
 
     @Override
     public void run(ResultIterator resultIterator) throws Exception {
-        Parser.Result parserResult = resultIterator.getParserResult(offset);
+        final Parser.Result parserResult = resultIterator.getParserResult(offset);
         if (parserResult == null) {
             return;
         }
-        Snapshot snapshot = parserResult.getSnapshot();
-        int embeddedOffset = snapshot.getEmbeddedOffset(offset);
-        String resultMimeType = parserResult.getSnapshot().getMimeType();
-        if (resultMimeType.equals("text/html")) {
-            //proceed only on html content
-            this.completionResult = query((HtmlParserResult) parserResult);
-        } else if(resultMimeType.equals("text/javascript")) {
-            //complete the </script> end tag
-            this.completionResult = queryHtmlEndTagInEmbeddedCode(snapshot, embeddedOffset, SCRIPT_TAG_NAME);
-        } else if(resultMimeType.equals("text/x-css")) {
-            //complete the </style> end tag
-            this.completionResult = queryHtmlEndTagInEmbeddedCode(snapshot, embeddedOffset, STYLE_TAG_NAME);
+        final Snapshot snapshot = parserResult.getSnapshot();
+        final Document doc = snapshot.getSource().getDocument(true);
+        if(doc == null) {
+            return ; //this still may happen under some circumstances (deleted file, UserQuestionException etc.)
         }
+        
+        doc.render(new Runnable() {
+
+            @Override
+            public void run() {
+                int embeddedOffset = snapshot.getEmbeddedOffset(offset);
+                String resultMimeType = parserResult.getSnapshot().getMimeType();
+                if (resultMimeType.equals("text/html")) {
+                    //proceed only on html content
+                    completionResult = query((HtmlParserResult) parserResult);
+                } else if(resultMimeType.equals("text/javascript")) {
+                    //complete the </script> end tag
+                    completionResult = queryHtmlEndTagInEmbeddedCode(snapshot, doc, embeddedOffset, SCRIPT_TAG_NAME);
+                } else if(resultMimeType.equals("text/x-css")) {
+                    //complete the </style> end tag
+                    completionResult = queryHtmlEndTagInEmbeddedCode(snapshot, doc, embeddedOffset, STYLE_TAG_NAME);
+                }
+            }
+
+        });
+
     }
 
-    private CompletionResult queryHtmlEndTagInEmbeddedCode(final Snapshot snapshot, final int embeddedOffset, final String endTagName) {
+    private CompletionResult queryHtmlEndTagInEmbeddedCode(Snapshot snapshot, Document doc, final int embeddedOffset, final String endTagName) {
         // End tag autocompletion support
         // We want the end tag autocompletion to appear just after <style> and <script> tags.
         // Since there is css language as leaf languge, this needs to be treated separately.
-        final Document doc = snapshot.getSource().getDocument(false);
-        if(doc != null) {
-            final AtomicReference<CompletionResult> result = new AtomicReference<CompletionResult>();
-            doc.render(new Runnable() {
-                @Override
-                public void run() {
-                    int documentItemOffset = snapshot.getOriginalOffset(embeddedOffset);
-                    TokenSequence ts = Utils.getJoinedHtmlSequence(doc, documentItemOffset - 1);
-                    if(ts != null)  {
-                        if(ts.token().id() == HTMLTokenId.TAG_CLOSE_SYMBOL && CharSequenceUtilities.equals(ts.token().text(), ">")) {
-                            Token openTagToken = Utils.findTagOpenToken(ts);
-                            if (openTagToken != null && CharSequenceUtilities.equals(openTagToken.text(), endTagName)) {
+        int documentItemOffset = snapshot.getOriginalOffset(embeddedOffset);
+        TokenSequence ts = Utils.getJoinedHtmlSequence(doc, documentItemOffset - 1);
+        if(ts != null)  {
+            if(ts.token().id() == HTMLTokenId.TAG_CLOSE_SYMBOL && CharSequenceUtilities.equals(ts.token().text(), ">")) {
+                Token openTagToken = Utils.findTagOpenToken(ts);
+                if (openTagToken != null && CharSequenceUtilities.equals(openTagToken.text(), endTagName)) {
 
-                                List<? extends CompletionItem> items = Collections.singletonList(
-                                        HtmlCompletionItem.createAutocompleteEndTag(endTagName, documentItemOffset));
-                                result.set(new CompletionResult(items, offset));
-                            }
-                        }
-                    }
+                    List<? extends CompletionItem> items = Collections.singletonList(
+                            HtmlCompletionItem.createAutocompleteEndTag(endTagName, documentItemOffset));
+                    return new CompletionResult(items, offset);
                 }
-            });
-            if(result.get() != null) {
-                return result.get();
             }
-
         }
 
+
         String expectedCode = "</" + endTagName;
         // Common end tag completion
 
@@ -187,7 +195,7 @@ public class HtmlCompletionQuery extends UserTask {
             int itemOffset = embeddedOffset - patternSize + ltIndex;
 
             //convert back to document offsets
-            int documentItemOffset = snapshot.getOriginalOffset(itemOffset);
+            documentItemOffset = snapshot.getOriginalOffset(itemOffset);
 
             List<? extends CompletionItem> items = Collections.singletonList(HtmlCompletionItem.createEndTag(endTagName, documentItemOffset, null, -1, HtmlCompletionItem.EndTag.Type.DEFAULT));
             return new CompletionResult(items, offset);
@@ -196,18 +204,30 @@ public class HtmlCompletionQuery extends UserTask {
         return null;
     }
 
-    private CompletionResult query(HtmlParserResult result) {
-        return query(result, result.dtd());
-    }
 
-    //for unit tests, allows to use different DTD than specified in the parser result
-    CompletionResult query(HtmlParserResult parserResult, DTD dtd) {
+    CompletionResult query(HtmlParserResult parserResult) {
+        HtmlParseResult htmlResult;
+        try {
+            htmlResult = parserResult.getSyntaxAnalyzerResult().parseHtml();
+        } catch (org.netbeans.editor.ext.html.parser.api.ParseException ex) {
+            Exceptions.printStackTrace(ex);
+            return null;
+        }
 
+        HtmlModel model = htmlResult.model();
+        
         Snapshot snapshot = parserResult.getSnapshot();
         String sourceMimetype = snapshot.getSource().getMimeType();
         int astOffset = snapshot.getEmbeddedOffset(offset);
+        
+        //in some cases the embedded offset cannot be mapped, then we can do very less
+        if(astOffset == -1) {
+            return null;
+        }
+
         lowerCase = usesLowerCase(parserResult, astOffset);
-        isXHtml = parserResult.getHtmlVersion().isXhtml();
+        HtmlVersion version = parserResult.getHtmlVersion();
+        isXHtml = version.isXhtml();
 
         TokenHierarchy<?> hi = snapshot.getTokenHierarchy();
         TokenSequence<HTMLTokenId> ts = hi.tokenSequence(HTMLTokenId.language());
@@ -227,6 +247,7 @@ public class HtmlCompletionQuery extends UserTask {
                 }
             }
         } else {
+            backward = true;
             if (!ts.movePrevious()) {
                 //can't get previous token
                 return null;
@@ -244,14 +265,29 @@ public class HtmlCompletionQuery extends UserTask {
 
         // Bug 182267 -  StringIndexOutOfBoundsException: String index out of range: -1
         // debug>>>
-        if((astOffset - itemOffset) < 0) {
+        if((astOffset - itemOffset) < 0 || preText.length() < (astOffset - itemOffset)) {
             StringBuilder b = new StringBuilder();
-            b.append("just happened Bug 182267 -  StringIndexOutOfBoundsException: String index out of range: -1\n"); //NOI18N
-            b.append("current's snapshot token sequence:\n"); //NOI18N
-            b.append(ts.toString()); //dump token seuquence
-            b.append(String.format("astOffset = %1$s, itemOffset = %2$s\n", astOffset, itemOffset)); //NOI18N
+            b.append("Inconsistency in the snapshot! Detailed info:"); //NOI18N
+            b.append("\n------------------------------------------------");
+            b.append("\ndocument.getText():");
+            try {
+                b.append(document.getText(0, document.getLength()));
+            } catch (BadLocationException ex) {
+                b.append(ex.getMessage());
+            }
+            b.append("\n------------------------------------------------");
+            b.append("\ntoken hierarchy:\n").append(hi.toString());
+            b.append("\n------------------------------------------------");
+            b.append("\ntoken sequence:\n").append(ts.toString());
+            b.append("\n------------------------------------------------");
+            b.append("\nsnapshot.getText():").append(snapshot.getText().toString());
+            b.append("\n------------------------------------------------");
+            b.append("\nsnapshot.toString():").append(snapshot).toString();
+            b.append("\nsource:").append(snapshot.getSource()).toString();
+            b.append(String.format("\nastOffset = %1$s, itemOffset = %2$s", astOffset, itemOffset)); //NOI18N
+            b.append(String.format("\npreText=%s; len=%s", preText, preText.length()));
+            
             Logger.getAnonymousLogger().warning(b.toString());
-
             //and let the original exception to be thrown so the item is properly bound to the original report
         }
         //<<<debug
@@ -269,37 +305,93 @@ public class HtmlCompletionQuery extends UserTask {
         int searchAstOffset = astOffset == snapshot.getText().length() ? astOffset - 1 : astOffset;
 
         //finds a leaf node for all the declared namespaces content including the default html content
-        AstNode node = parserResult.findLeaf(searchAstOffset, backward);
-        if (node == null) {
-            return null;
+        AstNode node = null;
+        AstNode root = null;
+        //html5 parse tree broken workaround:
+        //In most cases when user edits the file the resulting parse tree
+        //from the html5 parser is broken to such extent, that it is not possible
+        //to resolve the real context node for given completion offset.
+        //So if the edited source is html5 && there is a parser error, use
+        //different approach - simply build a nesting tree of tag from the
+        //actual position to the root by using the lexical syntax elements
+        boolean useHtmlParseResult = true;
+        if(version == HtmlVersion.HTML5 
+                || version == HtmlVersion.XHTML5
+                || version == HtmlVersion.XHTML10_FRAMESET
+                || version == HtmlVersion.XHTML10_STICT
+                || version == HtmlVersion.XHTML10_TRANSATIONAL
+                || version == HtmlVersion.HTML41_FRAMESET
+                || version == HtmlVersion.HTML41_STRICT
+                || version == HtmlVersion.HTML41_TRANSATIONAL) {
+            for(ProblemDescription pd : htmlResult.getProblems()) {
+                if(pd.getType() > ProblemDescription.WARNING) {
+                    useHtmlParseResult = false;
+                    break;
+                }
+            }
         }
+        if(useHtmlParseResult) {
+            //use the standart mechanism
+            node = parserResult.findLeafTag(searchAstOffset, !backward, false);
+            if(node == null || node.equals(parserResult.root())) {
+                //fallback to the default simple xml parse tree (mlSyntaxTreeBuilder.makeUncheckedTree() )
+                //if no leaf node found or just the root seems to be the leaf. This situation is likely
+                //caused by an erroneous parse tree
+                useHtmlParseResult = false; 
+            } else {
+                root = node.getRootNode();
+            }
+        } 
+        
+        if(!useHtmlParseResult) {
+            //html5 && errors in the source => likely broken parse tree
+            //force use the legacy tree builder, even if the tree is quite inaccurate,
+            //it is not broken to such extent as the html5 parser one.
+//            System.err.println("Broken HTML5 parse tree, using the legacy SyntaxTreeBuilder!");
+//            root = SyntaxTreeBuilder.makeTree(htmlResult.source(), HtmlVersion.HTML40_TRANSATIONAL, parserResult.getSyntaxAnalyzerResult().getElements().items());
+            root = XmlSyntaxTreeBuilder.makeUncheckedTree(htmlResult.source(), parserResult.getSyntaxAnalyzerResult().getElements().items());
+            node = AstNodeUtils.findNode(root, searchAstOffset, !backward, false);
+            if(node == null) {
+                node = root;
+            }            
+        }
+        
+        assert node != null;
+        assert root != null;
 
         //find a leaf node for undeclared tags
-        AstNode undeclaredTagsParseTreeRoot = parserResult.root(SyntaxParserResult.UNDECLARED_TAGS_NAMESPACE);
+        AstNode undeclaredTagsParseTreeRoot = parserResult.rootOfUndeclaredTagsParseTree();
         assert undeclaredTagsParseTreeRoot != null;
-        AstNode undeclaredTagsLeafNode = AstNodeUtils.findDescendant(undeclaredTagsParseTreeRoot, searchAstOffset, backward);
+        AstNode undeclaredTagsLeafNode = AstNodeUtils.findNode(undeclaredTagsParseTreeRoot, searchAstOffset, !backward, false);
 
-        AstNode root = node.getRootNode();
 
         //namespace is null for html content
         String namespace = (String) root.getProperty(AstNode.NAMESPACE_PROPERTY);
         boolean queryHtmlContent = namespace == null || namespace.equals(parserResult.getHtmlVersion().getDefaultNamespace());
 
+
         /* Character reference finder */
         int ampIndex = preText.lastIndexOf('&'); //NOI18N
         if ((id == HTMLTokenId.TEXT || id == HTMLTokenId.VALUE) && ampIndex > -1) {
             //complete character references
-            String refNamePrefix = preText.substring(ampIndex + 1);
             anchor = offset;
-            result = translateCharRefs(offset - len, dtd.getCharRefList(refNamePrefix));
+            result = translateCharRefs(offset - len, model.getNamedCharacterReferences(), preText.substring(ampIndex + 1));
 
         } else if (id == HTMLTokenId.CHARACTER) {
             //complete character references
             if (inside || !preText.endsWith(";")) { // NOI18N
                 anchor = documentItemOffset + 1; //plus "&" length
-                result = translateCharRefs(documentItemOffset, dtd.getCharRefList(preText.length() > 0 ? preText.substring(1) : ""));
+                result = translateCharRefs(documentItemOffset, model.getNamedCharacterReferences(), preText.length() > 0 ? preText.substring(1) : "");
             }
         } else if (id == HTMLTokenId.TAG_OPEN) { // NOI18N
+
+            //an element being typed is parsed as normal element end then
+            //returned as a leaf node for the position, which is clearly wrong
+            //since we need its parent to be able to complete the typed element
+            if(node.getNameWithoutPrefix().equals(preText)) {
+                node = node.parent();
+            }
+
             //complete open tags with prefix
             anchor = documentItemOffset;
             //we are inside a tagname, the real content is the position before the tag
@@ -308,12 +400,10 @@ public class HtmlCompletionQuery extends UserTask {
             result = new ArrayList<CompletionItem>();
 
             if (queryHtmlContent) {
-                Collection<DTD.Element> openTags = AstNodeUtils.getPossibleOpenTagElements(root, astOffset);
-
-                result.addAll(translateTags(documentItemOffset - 1,
-                        filterElements(openTags, preText),
-                        filterElements(dtd.getElementList(null),
-                        preText)));
+                Collection<HtmlTag> possibleOpenTags = htmlResult.getPossibleTagsInContext(node, true);
+                Collection<HtmlTag> allTags = filterHtmlElements(model.getAllTags(), preText);
+                Collection<HtmlTag> filteredByPrefix = filterHtmlElements(possibleOpenTags, preText);
+                result.addAll(translateHtmlTags(documentItemOffset - 1, filteredByPrefix, allTags));
             }
 
             //extensions
@@ -325,15 +415,25 @@ public class HtmlCompletionQuery extends UserTask {
 
         } else if ((id != HTMLTokenId.BLOCK_COMMENT && preText.endsWith("<")) || 
                 (id == HTMLTokenId.TAG_OPEN_SYMBOL && "<".equals(item.text().toString()))) { // NOI18N
+
+            //an element being typed is parsed as normal element end then
+            //returned as a leaf node for the position, which is clearly wrong
+            //since we need its parent to be able to complete the typed element
+            if(node.getNameWithoutPrefix().equals(preText)) {
+                node = node.parent();
+            }
+
             //complete open tags with no prefix
             anchor = offset;
             result = new ArrayList<CompletionItem>();
 
             if (queryHtmlContent) {
-                Collection<DTD.Element> openTags = AstNodeUtils.getPossibleOpenTagElements(root, astOffset);
-                result.addAll(translateTags(offset - 1, openTags, dtd.getElementList(null)));
+                Collection<HtmlTag> possibleOpenTags = htmlResult.getPossibleTagsInContext(node, true);
+                Collection<HtmlTag> allTags = model.getAllTags();
+                result.addAll(translateHtmlTags(offset - 1, possibleOpenTags, allTags));
+
                 if(HtmlPreferences.completionOffersEndTagAfterLt()) {
-                    result.addAll(getPossibleEndTags(node, undeclaredTagsLeafNode, offset, ""));
+                    result.addAll(getPossibleEndTags(htmlResult, node, undeclaredTagsLeafNode, offset, ""));
                 }
             }
 
@@ -349,12 +449,12 @@ public class HtmlCompletionQuery extends UserTask {
                 (id == HTMLTokenId.TAG_OPEN_SYMBOL && preText.endsWith("</"))) { // NOI18N
             //complete end tags without prefix
             anchor = offset;
-            result = getPossibleEndTags(node, undeclaredTagsLeafNode, offset, "");
+            result = getPossibleEndTags(htmlResult, node, undeclaredTagsLeafNode, offset, "");
 
         } else if (id == HTMLTokenId.TAG_CLOSE) { // NOI18N
             //complete end tags with prefix
             anchor = documentItemOffset;
-            result = getPossibleEndTags(node, undeclaredTagsLeafNode, offset, preText);
+            result = getPossibleEndTags(htmlResult, node, undeclaredTagsLeafNode, offset, preText);
 
         } else if (id == HTMLTokenId.TAG_CLOSE_SYMBOL) {
             anchor = offset;
@@ -382,34 +482,34 @@ public class HtmlCompletionQuery extends UserTask {
                 }
                 //should be open tag if not unknown or root in case of the text being broken
                 //that the parser cannot recognize the tag node
-                assert node.type() == AstNode.NodeType.OPEN_TAG : "Unexpecet node type " + node.type();
-
-                
-
-                DTD.Element tag = node.getDTDElement();
-                List possible = tag.getAttributeList(prefix); // All attribs of given tag
-                Collection<String> existingAttrsNames = node.getAttributeKeys();
-
-                String wordAtCursor = (item == null) ? null : item.text().toString();
-                // #BUGFIX 25261 because of being at the end of document the
-                // wordAtCursor must be checked for null to prevent NPE
-                // below
-                if (wordAtCursor == null) {
-                    wordAtCursor = "";
-                }
-
-                List<DTD.Attribute> attribs = new ArrayList<DTD.Attribute>();
-                for (Iterator i = possible.iterator(); i.hasNext();) {
-                    DTD.Attribute attr = (DTD.Attribute) i.next();
-                    String aName = attr.getName();
-                    if (aName.equals(prefix) ||
-                            (!existingAttrsNames.contains(isXHtml ? aName : aName.toUpperCase(Locale.ENGLISH)) &&
-                            !existingAttrsNames.contains(isXHtml ? aName : aName.toLowerCase(Locale.ENGLISH))) || (wordAtCursor.equals(aName) && prefix.length() > 0)) {
-                        attribs.add(attr);
+                assert node.type() == AstNode.NodeType.OPEN_TAG : "Unexpected node type " + node.type(); //NOI18N
+                    HtmlTag tag = model.getTag(node.name());
+                    if(tag == null) {
+                        return null;
                     }
-                }
+                    Collection<HtmlTagAttribute> possible = filterAttributes(tag.getAttributes(), prefix);
+                    Collection<String> existingAttrsNames = node.getAttributeKeys();
+
+                    String wordAtCursor = (item == null) ? null : item.text().toString();
+                    // #BUGFIX 25261 because of being at the end of document the
+                    // wordAtCursor must be checked for null to prevent NPE
+                    // below
+                    if (wordAtCursor == null) {
+                        wordAtCursor = "";
+                    }
+
+                    Collection<HtmlTagAttribute> complete = new ArrayList<HtmlTagAttribute>();
+                    for (HtmlTagAttribute attr : possible) {
+                        String aName = attr.getName();
+                        if (aName.equals(prefix) ||
+                                (!existingAttrsNames.contains(isXHtml ? aName : aName.toUpperCase(Locale.ENGLISH)) &&
+                                !existingAttrsNames.contains(isXHtml ? aName : aName.toLowerCase(Locale.ENGLISH))) || (wordAtCursor.equals(aName) && prefix.length() > 0)) {
+                            complete.add(attr);
+                        }
+                    }
+
+                    result = translateAttribs(anchor, complete, tag);
 
-                result = translateAttribs(anchor, attribs, tag);
             }
 
 
@@ -442,18 +542,20 @@ public class HtmlCompletionQuery extends UserTask {
                     argName = argName.toLowerCase(Locale.ENGLISH);
                 }
 
-                DTD.Element tag = node.getDTDElement();
-                DTD.Attribute arg = tag == null ? null : tag.getAttribute(argName);
-
+                HtmlTag tag = model.getTag(node.name());
+                if(tag == null) {
+                    return null;
+                }
+                HtmlTagAttribute attribute = tag.getAttribute(argName);
                 result = new ArrayList<CompletionItem>();
 
                 if (id != HTMLTokenId.VALUE) {
                     anchor = offset;
-                    if (arg != null) {
-                        result.addAll(translateValues(anchor, arg.getValueList("")));
+                    if (attribute != null) {
+                        result.addAll(translateValues(anchor, attribute.getPossibleValues()));
                         ValueCompletion<HtmlCompletionItem> valuesCompletion = AttrValuesCompletion.getSupport(node.name(), argName);
                         if (valuesCompletion != null) {
-                            result.addAll(valuesCompletion.getItems(file, offset, ""));
+                            result.addAll(valuesCompletion.getItems(file, anchor, ""));
                         }
                     }
 
@@ -476,11 +578,11 @@ public class HtmlCompletionQuery extends UserTask {
 
                     anchor = documentItemOffset + (quotationChar != null ? 1 : 0);
 
-                    if (arg != null) {
-                        result.addAll(translateValues(documentItemOffset, arg.getValueList(prefix), quotationChar));
+                    if (attribute != null) {
+                        result.addAll(translateValues(documentItemOffset, filter(attribute.getPossibleValues(), prefix), quotationChar));
                         ValueCompletion<HtmlCompletionItem> valuesCompletion = AttrValuesCompletion.getSupport(node.name(), argName);
                         if (valuesCompletion != null) {
-                            result.addAll(valuesCompletion.getItems(file, offset, prefix));
+                            result.addAll(valuesCompletion.getItems(file, anchor, prefix));
                         }
                     }
 
@@ -530,37 +632,52 @@ public class HtmlCompletionQuery extends UserTask {
         return null;
     }
 
-    private List<CompletionItem> translateCharRefs(int offset, List refs) {
+    private List<CompletionItem> translateCharRefs(int offset, Collection<? extends NamedCharRef> refs, String prefix) {
         List<CompletionItem> result = new ArrayList<CompletionItem>(refs.size());
-        String name;
-        for (Iterator i = refs.iterator(); i.hasNext();) {
-            DTD.CharRef chr = (DTD.CharRef) i.next();
-            name = chr.getName();
-            result.add(HtmlCompletionItem.createCharacterReference(name, chr.getValue(), offset, name));
+        for (NamedCharRef ref : refs) {
+            String name = ref.getName();
+            if(name.startsWith(prefix)) {
+                result.add(HtmlCompletionItem.createCharacterReference(name, ref.getValue(), offset, name));
+            }
         }
         return result;
     }
 
-    private List<CompletionItem> getPossibleEndTags(AstNode leaf, AstNode undeclaredTagsLeafNode, int offset, String prefix) {
+    private List<CompletionItem> getPossibleEndTags(HtmlParseResult htmlResult, AstNode leaf, AstNode undeclaredTagsLeafNode, int offset, String prefix) {
         List<CompletionItem> items = new ArrayList<CompletionItem>();
-        items.addAll(getPossibleHtmlEndTags(leaf, offset, prefix));
-        items.addAll(getPossibleHtmlEndTags(undeclaredTagsLeafNode, offset, prefix));
+        items.addAll(getPossibleEndTags(htmlResult, leaf, offset, prefix));
+        items.addAll(getPossibleHtmlEndTagsForUndeclaredComponents(undeclaredTagsLeafNode, offset, prefix));
 
         return items;
     }
 
-    private List<CompletionItem> getPossibleHtmlEndTags(AstNode leaf, int offset, String prefix) {
+    private Collection<CompletionItem> getPossibleEndTags(HtmlParseResult htmlResult, AstNode leaf, int offset, String prefix) {
+        Collection<HtmlTag> possible = htmlResult.getPossibleTagsInContext(leaf, false);
+        Collection<CompletionItem> items = new ArrayList<CompletionItem>();
+        int order = 0;
+        for(HtmlTag tag : possible) {
+            //XXX this wont' work now since the API exposes only the tags desceriptions, not the physical nodes
+
+//            //distance from the caret position - lower number, higher precedence
+//            //this will ensure the two end tags list from html and undeclared content being properly ordered
+//            int order = offset - leaf.startOffset();
+//
+            String tagName = isXHtml ? tag.getName() : (lowerCase ? tag.getName().toLowerCase(Locale.ENGLISH) : tag.getName().toUpperCase(Locale.ENGLISH));
+            items.add(HtmlCompletionItem.createEndTag(tagName, offset - 2 - prefix.length(), tagName, order++, getEndTagType(leaf)));
+        }
+        return items;
+    }
+
+    private List<CompletionItem> getPossibleHtmlEndTagsForUndeclaredComponents(AstNode leaf, int offset, String prefix) {
         List<CompletionItem> items = new ArrayList<CompletionItem>();
 
         for (;;) {
             if (leaf.type() == AstNode.NodeType.ROOT) {
                 break;
             }
-            //if dtd element and doesn't have forbidden end tag
-            if ((leaf.getDTDElement() == null || !AstNodeUtils.hasForbiddenEndTag(leaf)) &&
-                    leaf.type() == AstNode.NodeType.OPEN_TAG) {
 
-                String tagName = leaf.name();
+            if (leaf.type() == AstNode.NodeType.OPEN_TAG) {
+                String tagName = isXHtml ? leaf.name() : (lowerCase ? leaf.name().toLowerCase(Locale.ENGLISH) : leaf.name().toUpperCase(Locale.ENGLISH));
                 if (tagName.startsWith(prefix.toLowerCase(Locale.ENGLISH))) {
                     //TODO - distinguish unmatched and matched tags in the completion!!!
                     //TODO - mark required and optional end tags somehow
@@ -577,15 +694,10 @@ public class HtmlCompletionQuery extends UserTask {
                     break;
                 }
             }
-
-
+            
             leaf = leaf.parent();
-
             assert leaf != null;
-
-
         }
-
         return items;
     }
 
@@ -600,10 +712,31 @@ public class HtmlCompletionQuery extends UserTask {
 
     }
 
-    private Collection<DTD.Element> filterElements(Collection<DTD.Element> elements, String elementNamePrefix) {
-        List<DTD.Element> filtered = new ArrayList<DTD.Element>();
+    private Collection<String> filter(Collection<?> col, String prefix) {
+        Collection<String> filtered = new ArrayList<String>();
+        for(Object o : col) {
+            String s = o.toString();
+            if(s.startsWith(prefix)) {
+                filtered.add(s);
+            }
+        }
+        return filtered;
+    }
+
+    private Collection<HtmlTagAttribute> filterAttributes(Collection<HtmlTagAttribute> attrs, String prefix) {
+        Collection<HtmlTagAttribute> filtered = new ArrayList<HtmlTagAttribute>();
+        for(HtmlTagAttribute ta : attrs) {
+            if(ta.getName().startsWith(prefix)) {
+                filtered.add(ta);
+            }
+        }
+        return filtered;
+    }
+
+    private Collection<HtmlTag> filterHtmlElements(Collection<HtmlTag> elements, String elementNamePrefix) {
+        List<HtmlTag> filtered = new ArrayList<HtmlTag>();
         elementNamePrefix = elementNamePrefix.toLowerCase(Locale.ENGLISH);
-        for (DTD.Element e : elements) {
+        for (HtmlTag e : elements) {
             if (e.getName().toLowerCase(Locale.ENGLISH).startsWith(elementNamePrefix)) {
                 filtered.add(e);
             }
@@ -611,47 +744,47 @@ public class HtmlCompletionQuery extends UserTask {
         return filtered;
     }
 
-    List<CompletionItem> translateTags(int offset, Collection<DTD.Element> possible, Collection<DTD.Element> all) {
-        List<CompletionItem> result = new ArrayList<CompletionItem>(all.size());
-        all.removeAll(possible); //remove possible elements
-        for (DTD.Element e : possible) {
-            result.add(item4Element(e, offset, true));
+    List<CompletionItem> translateHtmlTags(int offset, Collection<HtmlTag> possible, Collection<HtmlTag> all) {
+        List<CompletionItem> result = new ArrayList<CompletionItem>(possible.size());
+        Set<HtmlTag> allmodifiable = new HashSet<HtmlTag>(all);
+        allmodifiable.removeAll(possible); //remove possible elements
+        for (HtmlTag e : possible) {
+            result.add(item4HtmlTag(e, offset, true));
         }
-        for (DTD.Element e : all) {
-            result.add(item4Element(e, offset, false));
+        for (HtmlTag e : allmodifiable) {
+            result.add(item4HtmlTag(e, offset, false));
         }
         return result;
     }
 
-    private HtmlCompletionItem item4Element(DTD.Element e, int offset, boolean possible) {
+    private HtmlCompletionItem item4HtmlTag(HtmlTag e, int offset, boolean possible) {
         String name = e.getName();
         name = isXHtml ? name : (lowerCase ? name.toLowerCase(Locale.ENGLISH) : name.toUpperCase(Locale.ENGLISH));
-        return HtmlCompletionItem.createTag(name, offset, name, possible);
+        return HtmlCompletionItem.createTag(e, name, offset, name, possible);
     }
 
-    List<CompletionItem> translateAttribs(int offset, List<DTD.Attribute> attribs, DTD.Element tag) {
+    Collection<CompletionItem> translateAttribs(int offset, Collection<HtmlTagAttribute> attribs, HtmlTag tag) {
         List<CompletionItem> result = new ArrayList<CompletionItem>(attribs.size());
         String tagName = tag.getName() + "#"; // NOI18N
-        for (DTD.Attribute attrib : attribs) {
+        for (HtmlTagAttribute attrib : attribs) {
             String name = attrib.getName();
             switch (attrib.getType()) {
-                case DTD.Attribute.TYPE_BOOLEAN:
+                case BOOLEAN:
                     result.add(HtmlCompletionItem.createBooleanAttribute(name, offset, attrib.isRequired(), tagName + name));
                     break;
-                case DTD.Attribute.TYPE_SET:
-                case DTD.Attribute.TYPE_BASE:
-                    result.add(HtmlCompletionItem.createAttribute(name, offset, attrib.isRequired(), tagName + name));
+                default:
+                    result.add(HtmlCompletionItem.createAttribute(attrib, name, offset, attrib.isRequired(), tagName + name));
                     break;
             }
         }
         return result;
     }
 
-    List<HtmlCompletionItem> translateValues(int offset, List values) {
+    Collection<HtmlCompletionItem> translateValues(int offset, Collection<String> values) {
         return translateValues(offset, values, null);
     }
 
-    List<HtmlCompletionItem> translateValues(int offset, List values, String quotationChar) {
+    Collection<HtmlCompletionItem> translateValues(int offset, Collection<String> values, String quotationChar) {
         if (values == null) {
             return Collections.emptyList();
         }
@@ -659,8 +792,8 @@ public class HtmlCompletionQuery extends UserTask {
         if (quotationChar != null) {
             offset++; //shift the offset after the quotation
         }
-        for (Iterator i = values.iterator(); i.hasNext();) {
-            result.add(HtmlCompletionItem.createAttributeValue(((DTD.Value) i.next()).getName(), offset));
+        for (String value : values) {
+            result.add(HtmlCompletionItem.createAttributeValue(value, offset));
         }
         return result;
     }
