@@ -44,14 +44,19 @@ package org.netbeans.modules.html.editor.gsf;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Set;
 import javax.swing.SwingUtilities;
 import javax.swing.text.Document;
 import javax.swing.text.JTextComponent;
 import org.netbeans.api.editor.EditorRegistry;
-import org.netbeans.editor.ext.html.parser.AstNode;
-import org.netbeans.editor.ext.html.parser.SyntaxTree;
+import org.netbeans.api.project.FileOwnerQuery;
+import org.netbeans.api.project.Project;
+import org.netbeans.editor.ext.html.parser.SyntaxTreeBuilder;
+import org.netbeans.editor.ext.html.parser.api.AstNode;
+import org.netbeans.editor.ext.html.parser.api.HtmlVersion;
+import org.netbeans.editor.ext.html.parser.api.SyntaxAnalyzerResult;
 import org.netbeans.lib.editor.codetemplates.api.CodeTemplate;
 import org.netbeans.lib.editor.codetemplates.api.CodeTemplateManager;
 import org.netbeans.modules.csl.api.Error;
@@ -65,12 +70,16 @@ import org.netbeans.modules.csl.api.Rule.ErrorRule;
 import org.netbeans.modules.csl.api.RuleContext;
 import org.netbeans.modules.csl.api.Severity;
 import org.netbeans.modules.editor.NbEditorDocument;
+import org.netbeans.modules.html.editor.HtmlErrorFilter;
+import org.netbeans.modules.html.editor.ProjectDefaultHtmlSourceVersionController;
+import org.netbeans.modules.html.editor.HtmlPreferences;
 import org.netbeans.modules.html.editor.api.gsf.HtmlExtension;
 import org.netbeans.modules.html.editor.api.gsf.HtmlParserResult;
 import org.netbeans.modules.parsing.api.Snapshot;
 import org.netbeans.spi.lexer.MutableTextInput;
 import org.openide.filesystems.FileObject;
 import org.openide.util.NbBundle;
+import static org.netbeans.modules.html.editor.HtmlErrorFilter.*;
 
 /**
  *
@@ -83,6 +92,58 @@ public class HtmlHintsProvider implements HintsProvider {
      */
     @Override
     public void computeHints(HintsManager manager, RuleContext context, List<Hint> hints) {
+        HtmlParserResult result = (HtmlParserResult) context.parserResult;
+        HtmlVersion version = result.getDetectedHtmlVersion();
+        FileObject file = result.getSnapshot().getSource().getFileObject();
+        if(file == null) {
+            //the Hint doesn't allow the fileObject argument to be null
+            return ;
+        }
+        Project project = FileOwnerQuery.getOwner(file);
+        boolean xhtml = result.getSyntaxAnalyzerResult().mayBeXhtml();
+        if (version == null) {
+            //the version can be determined
+            
+            if (project == null) {
+                //we cannot set the default anywhere, just show a warning message
+
+                hints.add(new Hint(getRule(Severity.INFO),
+                        NbBundle.getMessage(HtmlHintsProvider.class, "MSG_CANNOT_DETERMINE_HTML_VERSION_NO_PROJECT"),
+                        file,
+                        new OffsetRange(0, 0),
+                        Collections.<HintFix>emptyList(),
+                        100) {
+                });
+            } else {
+                //no doctype declaration found, generate the set default project html version hint
+                HtmlVersion defaulted = ProjectDefaultHtmlSourceVersionController.getDefaultHtmlVersion(project, xhtml);
+                String msg =  defaulted == null ?
+                    NbBundle.getMessage(HtmlHintsProvider.class, xhtml ? "MSG_CANNOT_DETERMINE_XHTML_VERSION" : "MSG_CANNOT_DETERMINE_HTML_VERSION") :
+                    NbBundle.getMessage(HtmlHintsProvider.class, xhtml ? "MSG_CANNOT_DETERMINE_XHTML_VERSION_DEFAULTED_ALREADY" : "MSG_CANNOT_DETERMINE_HTML_VERSION_DEFAULTED_ALREADY", defaulted.getDisplayName());
+
+                hints.add(new Hint(getRule(Severity.INFO),
+                        msg,
+                        file,
+                        new OffsetRange(0, 0),
+                        generateSetDefaultHtmlVersionHints(project, result.getSnapshot().getSource().getDocument(false), xhtml),
+                        100) {
+                });
+            }
+        }
+
+    }
+
+    private static List<HintFix> generateSetDefaultHtmlVersionHints(Project project, Document doc, boolean xhtml) {
+        List<HintFix> fixes = new LinkedList<HintFix>();
+        if(project != null) {
+            for(HtmlVersion v : HtmlVersion.values()) {
+                if(xhtml == v.isXhtml()) {
+                    fixes.add(new SetDefaultHtmlVersionHintFix(v, project, doc, xhtml));
+                }
+            }
+        }
+
+        return fixes;
     }
 
     /**
@@ -113,11 +174,26 @@ public class HtmlHintsProvider implements HintsProvider {
     @Override
     public void computeErrors(HintsManager manager, RuleContext context, List<Hint> hints, List<Error> unhandled) {
         Snapshot snapshot = context.parserResult.getSnapshot();
+        HtmlParserResult result = (HtmlParserResult) context.parserResult;
+        SyntaxAnalyzerResult saresult = result.getSyntaxAnalyzerResult();
+
         FileObject fo = snapshot.getSource().getFileObject();
-        if (isErrorCheckingEnabled(fo)) {
+        if(fo == null) {
+            //the Hint doesn't allow the fileObject argument to be null
+            return ;
+        }
+        if (isErrorCheckingEnabled(saresult)) {
             for (Error e : context.parserResult.getDiagnostics()) {
                     assert e.getDescription() != null;
-                    HintFix disableChecksFix = new DisableErrorChecksFix(snapshot);
+                    List<HintFix> fixes = new ArrayList<HintFix>(3);
+
+                    if(!isErrorCheckingDisabledForFile(saresult)) {
+                        fixes.add(new DisableErrorChecksFix(snapshot));
+                    }
+
+                    if(isErrorCheckingEnabledForMimetype(saresult)) {
+                        fixes.add(new DisableErrorChecksForMimetypeFix(saresult));
+                    }
 
                     //tweak the error position if close to embedding boundary
                     int astFrom = e.getStartPosition();
@@ -135,13 +211,9 @@ public class HtmlHintsProvider implements HintsProvider {
                         to = from;
                     }
 
-                    List<HintFix> fixes = new ArrayList<HintFix>(3);
                     //add custom hint fixes
-                    fixes.addAll(getCustomHintFixesForError(context, e));
+//                    fixes.addAll(getCustomHintFixesForError(context, e));
                     
-                    //add default disable hints fix
-                    fixes.add(disableChecksFix);
-
                     Hint h = new Hint(getRule(e.getSeverity()),
                             e.getDescription(),
                             e.getFile(),
@@ -153,12 +225,19 @@ public class HtmlHintsProvider implements HintsProvider {
             }
         } else {
             //add a special hint for reenabling disabled error checks
-            HintFix fix = new EnableErrorChecksFix(snapshot);
-            Hint h = new Hint(new HtmlRule(HintSeverity.WARNING, false),
+            List<HintFix> fixes = new ArrayList<HintFix>(3);
+            if(isErrorCheckingDisabledForFile(saresult)) {
+                fixes.add(new EnableErrorChecksFix(snapshot));
+            }
+            if(!isErrorCheckingEnabledForMimetype(saresult)) {
+                fixes.add(new EnableErrorChecksForMimetypeFix(saresult));
+            }
+
+            Hint h = new Hint(new HtmlRule(HintSeverity.INFO, false),
                     NbBundle.getMessage(HtmlHintsProvider.class, "MSG_HINT_ENABLE_ERROR_CHECKS_FILE_DESCR"), //NOI18N
                     fo,
                     new OffsetRange(0, 0),
-                    Collections.singletonList(fix),
+                    fixes,
                     50);
 
             hints.add(h);
@@ -171,9 +250,10 @@ public class HtmlHintsProvider implements HintsProvider {
 
     }
 
+    //possibly reenable later once hint fixes are implementd for validator.nu errors
     private static Collection<HintFix> getCustomHintFixesForError(final RuleContext context, final Error e) {
         List<HintFix> fixes = new ArrayList<HintFix>();
-        if(e.getKey().equals(SyntaxTree.MISSING_REQUIRED_ATTRIBUTES)) {
+        if(e.getKey().equals(SyntaxTreeBuilder.MISSING_REQUIRED_ATTRIBUTES)) {
             fixes.add(new HintFix() {
                 
                 @Override
@@ -184,14 +264,14 @@ public class HtmlHintsProvider implements HintsProvider {
                 @Override
                 public void implement() throws Exception {
                     AstNode node = HtmlParserResult.getBoundAstNode(e);
-                    Collection<String> missingAttrs = (Collection<String>)node.getProperty(SyntaxTree.MISSING_REQUIRED_ATTRIBUTES);
+                    Collection<String> missingAttrs = (Collection<String>)node.getProperty(SyntaxTreeBuilder.MISSING_REQUIRED_ATTRIBUTES);
                     assert missingAttrs != null;
                     int astOffset = node.startOffset() + 1 + node.name().length();
                     int insertOffset = context.parserResult.getSnapshot().getOriginalOffset(astOffset);
                     if(insertOffset == -1) {
                         return ;
                     }
-                    StringBuffer templateText = new StringBuffer();
+                    StringBuilder templateText = new StringBuilder();
                     templateText.append(' ');
 
                     for(String attr : missingAttrs) {
@@ -275,9 +355,12 @@ public class HtmlHintsProvider implements HintsProvider {
     }
     private static final HtmlRule ERROR_RULE = new HtmlRule(HintSeverity.ERROR, true);
     private static final HtmlRule WARNING_RULE = new HtmlRule(HintSeverity.WARNING, true);
+    private static final HtmlRule INFO_RULE = new HtmlRule(HintSeverity.INFO, true);
 
     private static HtmlRule getRule(Severity s) {
         switch (s) {
+            case INFO:
+                return INFO_RULE;
             case WARNING:
                 return WARNING_RULE;
             case ERROR:
@@ -322,15 +405,9 @@ public class HtmlHintsProvider implements HintsProvider {
             return severity;
         }
     }
-    static final String DISABLE_ERROR_CHECKS_KEY = "disable_error_checking"; //NOI18N
-
-    public static boolean isErrorCheckingEnabled(FileObject fo) {
-        return fo.getAttribute(DISABLE_ERROR_CHECKS_KEY) == null;
-    }
-
+   
     private static final class DisableErrorChecksFix implements HintFix {
 
-        private static String VALUE = "true"; //NOI18N
         private Snapshot snapshot;
 
         public DisableErrorChecksFix(Snapshot snapshot) {
@@ -346,7 +423,7 @@ public class HtmlHintsProvider implements HintsProvider {
         public void implement() throws Exception {
             FileObject fo = snapshot.getSource().getFileObject();
             if (fo != null) {
-                fo.setAttribute(DISABLE_ERROR_CHECKS_KEY, VALUE);
+                fo.setAttribute(DISABLE_ERROR_CHECKS_KEY, Boolean.TRUE);
             }
 
             //force reparse => hints update
@@ -405,6 +482,116 @@ public class HtmlHintsProvider implements HintsProvider {
         }
     }
 
+    private static abstract class AbstractErrorChecksForMimetypeFix implements HintFix {
+
+        protected Document doc;
+        protected String mimeType;
+
+        public AbstractErrorChecksForMimetypeFix(SyntaxAnalyzerResult result) {
+            this.doc =  result.getSource().getSnapshot().getSource().getDocument(false);
+            this.mimeType = HtmlErrorFilter.getWebPageMimeType(result);
+        }
+
+        @Override
+        public boolean isSafe() {
+            return true;
+        }
+
+        @Override
+        public boolean isInteractive() {
+            return false;
+        }
+
+    }
+
+    
+
+    private static final class DisableErrorChecksForMimetypeFix extends AbstractErrorChecksForMimetypeFix {
+
+        public DisableErrorChecksForMimetypeFix(SyntaxAnalyzerResult result) {
+            super(result);
+        }
+
+        @Override
+        public String getDescription() {
+            return NbBundle.getMessage(HtmlHintsProvider.class, "MSG_HINT_DISABLE_ERROR_CHECKS_MIMETYPE", mimeType); //NOI18N
+        }
+
+        @Override
+        public void implement() throws Exception {
+            HtmlPreferences.setHtmlErrorChecking(mimeType, false);
+
+            //force reparse of *THIS document only* => hints update
+            if (doc != null) {
+                forceReparse(doc);
+            }
+        }
+
+       
+    }
+
+    private static final class EnableErrorChecksForMimetypeFix extends AbstractErrorChecksForMimetypeFix {
+
+        public EnableErrorChecksForMimetypeFix(SyntaxAnalyzerResult result) {
+            super(result);
+        }
+
+        @Override
+        public String getDescription() {
+            return NbBundle.getMessage(HtmlHintsProvider.class, "MSG_HINT_ENABLE_ERROR_CHECKS_MIMETYPE", mimeType); //NOI18N
+        }
+
+        @Override
+        public void implement() throws Exception {
+            HtmlPreferences.setHtmlErrorChecking(mimeType, true);
+
+            //force reparse of *THIS document only* => hints update
+            if (doc != null) {
+                forceReparse(doc);
+            }
+        }
+
+    }
+
+
+    private static class SetDefaultHtmlVersionHintFix implements HintFix {
+
+        private HtmlVersion version;
+        private Document doc;
+        private Project project;
+        private boolean xhtml;
+
+        public SetDefaultHtmlVersionHintFix(HtmlVersion version, Project project, Document doc, boolean xhtml) {
+            this.version = version;
+            this.project = project;
+            this.doc = doc; //to be able to force reparse the hinted document
+            this.xhtml = xhtml;
+        }
+
+        @Override
+        public String getDescription() {
+            return NbBundle.getMessage(HtmlHintsProvider.class, "MSG_SET_DEFAULT_HTML_VERSION", version.getDisplayName());
+        }
+
+        @Override
+        public void implement() throws Exception {
+            ProjectDefaultHtmlSourceVersionController.setDefaultHtmlVersion(project, version, xhtml);
+            forceReparse(doc);
+        }
+
+        @Override
+        public boolean isSafe() {
+            return true;
+        }
+
+        @Override
+        public boolean isInteractive() {
+            return false;
+        }
+
+    }
+
+
     private static void forceReparse(final Document doc) {
         SwingUtilities.invokeLater(new Runnable() {
 
