@@ -55,9 +55,9 @@ import javax.swing.text.Document;
 import javax.swing.text.Position.Bias;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.editor.Utilities;
-import org.netbeans.editor.ext.html.parser.AstNode;
-import org.netbeans.editor.ext.html.parser.AstNodeUtils;
-import org.netbeans.editor.ext.html.parser.AstNodeVisitor;
+import org.netbeans.editor.ext.html.parser.api.AstNode;
+import org.netbeans.editor.ext.html.parser.api.AstNodeUtils;
+import org.netbeans.editor.ext.html.parser.spi.AstNodeVisitor;
 import org.netbeans.modules.csl.api.OffsetRange;
 import org.netbeans.modules.csl.spi.GsfUtilities;
 import org.netbeans.modules.csl.spi.support.ModificationResult;
@@ -238,7 +238,7 @@ public class ExtractInlinedStyleRefactoringPlugin implements RefactoringPlugin {
             String linkRelativePath = WebUtils.getRelativePath(context.getFile(), refactoring.getExternalSheet());
             String linkText = new StringBuilder().append('\n').
                     append(baseIndentString).
-                    append("<link href=\"").
+                    append("<link rel=\"stylesheet\" href=\"").
                     append(linkRelativePath).
                     append("\" type=\"text/css\"").
                     append(isLinkTagEmpty.get() ? "" : "/").
