@@ -42,6 +42,7 @@
 package org.netbeans.modules.html.editor.xhtml;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
@@ -53,6 +54,7 @@ import org.netbeans.modules.parsing.api.Snapshot;
 import org.netbeans.modules.parsing.spi.EmbeddingProvider;
 import org.netbeans.modules.parsing.spi.SchedulerTask;
 import org.netbeans.modules.parsing.spi.TaskFactory;
+import org.netbeans.modules.web.common.api.Constants;
 
 /**
  * Provides model for html code
@@ -61,8 +63,6 @@ import org.netbeans.modules.parsing.spi.TaskFactory;
  */
 public class XhtmlElEmbeddingProvider extends EmbeddingProvider {
 
-    public static final String GENERATED_CODE = "@@@"; //NOI18N
-
     @Override
     public List<Embedding> getEmbeddings(Snapshot snapshot) {
         TokenHierarchy<?> th = snapshot.getTokenHierarchy();
@@ -79,7 +79,7 @@ public class XhtmlElEmbeddingProvider extends EmbeddingProvider {
             } else {
                 //replace templating tokens by generated code marker
                 if (!lastEmbeddingIsVirtual) {
-                    embeddings.add(snapshot.create(GENERATED_CODE, "text/html"));
+                    embeddings.add(snapshot.create(Constants.LANGUAGE_SNIPPET_SEPARATOR, "text/html"));
                     lastEmbeddingIsVirtual = true;
                 }
             }
@@ -105,7 +105,7 @@ public class XhtmlElEmbeddingProvider extends EmbeddingProvider {
 
         @Override
         public Collection<SchedulerTask> create(final Snapshot snapshot) {
-            return Collections.<SchedulerTask>singletonList(new XhtmlElEmbeddingProvider());
+            return Arrays.<SchedulerTask>asList(new XhtmlElEmbeddingProvider(), new ELEmbeddingProvider());
         }
     }
 }
