@@ -83,11 +83,12 @@ public class XhtmlElLexer implements Lexer<XhtmlElTokenId> {
         } else {
             lexerState = ((Integer) info.state()).intValue();
         }
-        if (inputAttributes != null) {
-            EL_ENABLED = inputAttributes.getValue(LanguagePath.get(XhtmlElTokenId.language()), "el_enabled") != null; //NOI18N 
-        } else {
-            EL_ENABLED = false;
-        }
+        // let EL be always enabled, needed EL infrastructure
+//        if (inputAttributes != null) {
+//            EL_ENABLED = inputAttributes.getValue(LanguagePath.get(XhtmlElTokenId.language()), "el_enabled") != null; //NOI18N
+//        } else {
+            EL_ENABLED = true;
+//        }
     }
 
     public Token<XhtmlElTokenId> nextToken() {
@@ -124,9 +125,22 @@ public class XhtmlElLexer implements Lexer<XhtmlElTokenId> {
                     switch (actChar) {
                         case '{':
                             if (input.readLength() > 2) {
-                                //we have something read except the '${' or '#{' => it's content language
-                                input.backup(2); //backup the '$/#{'
-                                return token(XhtmlElTokenId.HTML);
+                                input.backup(3); //backup the '$/#{' and possible '\'
+                                // check whether we've read literal EL ('\#{' or '\${')
+                                boolean escaped = '\\' == input.read();
+                                if (escaped && input.readLength() > 3) {
+                                    input.backup(1); // backup the escape char
+                                    //we have something read except the '\${' or '\#{' => it's content language
+                                    return token(XhtmlElTokenId.HTML);
+                                } else if (!escaped) {
+                                    //we have something read except the '${' or '#{' => it's content language
+                                    return token(XhtmlElTokenId.HTML);
+                                } else {
+                                    // we're in EL - read back the remaining 
+                                    // backed up characters ('${' or '#{') and continue
+                                    input.read();
+                                    input.read();
+                                }
                             }
                             lexerState = ISI_EL;
                             break;
