@@ -49,6 +49,7 @@ import javax.swing.text.Document;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import org.netbeans.api.editor.mimelookup.test.MockMimeLookup;
+import org.netbeans.editor.ext.html.parser.api.HtmlVersion;
 import org.netbeans.junit.MockServices;
 import org.netbeans.modules.parsing.spi.ParseException;
 
@@ -63,15 +64,21 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
         super(name);
     }
 
+    @Override
+    protected HtmlVersion getExpectedVersion() {
+        return HtmlVersion.HTML41_TRANSATIONAL;
+    }
+    
     @Override
     protected void setUp() throws Exception {
         super.setUp();
+        HtmlVersion.DEFAULT_VERSION_UNIT_TESTS_OVERRIDE = HtmlVersion.HTML41_TRANSATIONAL;
         MockServices.setServices(MockMimeLookup.class);
     }
 
     public static Test xsuite() throws IOException, BadLocationException {
 	TestSuite suite = new TestSuite();
-        suite.addTest(new HtmlCompletionQueryTest("testIssue177347"));
+//        suite.addTest(new HtmlCompletionQueryTest("testSimpleEndTag"));
         return suite;
     }
 
@@ -117,7 +124,9 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
         assertItems("<|", arr("div"), Match.CONTAINS, 1);
         assertItems("<|", arr("jindra"), Match.DOES_NOT_CONTAIN);
         assertItems("<d|", arr("div"), Match.CONTAINS, 1);
-        assertItems("<div|", arr("div"), Match.EXACT, 1);
+        assertItems("<d|", arr("html"), Match.DOES_NOT_CONTAIN, 1);
+        assertItems("<div|", arr("div"), Match.CONTAINS, 1);
+        assertItems("<div|", arr("body"), Match.DOES_NOT_CONTAIN, 1);
 
         //           01234567
         assertItems("<div></|", arr("div"), Match.CONTAINS, 7);
@@ -149,7 +158,7 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
         assertItems("<| ", arr("div"), Match.CONTAINS, 1);
         assertItems("<| ", arr("jindra"), Match.DOES_NOT_CONTAIN);
         assertItems("<d| ", arr("div"), Match.CONTAINS, 1);
-        assertItems("<div| ", arr("div"), Match.EXACT, 1);
+        assertItems("<div| ", arr("div"), Match.CONTAINS, 1);
 
         //           01234567
         assertItems("<div></| ", arr("div"), Match.CONTAINS, 7);
@@ -160,14 +169,14 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
 
     public void testTagAttributes() throws BadLocationException, ParseException {
         //           012345
-        assertItems("<col |", arr("align"), Match.CONTAINS, 5);
-        assertItems("<col |", arr("jindra"), Match.DOES_NOT_CONTAIN);
-        assertItems("<col a|", arr("align"), Match.CONTAINS, 5);
+        assertItems("<div |", arr("class"), Match.CONTAINS, 5);
+        assertItems("<div |", arr("jindra"), Match.DOES_NOT_CONTAIN);
+        assertItems("<div c|", arr("class"), Match.CONTAINS, 5);
     }
 
     public void testCompleteTagAttributes() throws BadLocationException, ParseException {
-        assertCompletedText("<col |", "align", "<col align=\"|\"");
-        assertCompletedText("<col a|", "align", "<col align=\"|\"");
+        assertCompletedText("<div |", "class", "<div class=\"|\"");
+        assertCompletedText("<div c|", "class", "<div class=\"|\"");
     }
 
     public void testTagAttributeValues() throws BadLocationException, ParseException {
@@ -260,11 +269,20 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
 
         //complete in folder
         code = "<a href='folder1/|'";
-        //             01234567890
+        //      012345678901234567
         //we need a fileobject backed document here
         doc = createDocuments("test.html", "folder1/another.html", "images/image.png")[0]; //use test.html
         doc.insertString(0, code, null);
-        assertItems(doc, arr("another.html"), Match.CONTAINS, 9);
+        assertItems(doc, arr("../", "another.html"), Match.CONTAINS, 9);
+
+        //complete go up in nested folders
+        code = "<a href='folder1/folder2/|'";
+        //      01234567890123456789023456
+        //we need a fileobject backed document here
+        doc = createDocuments("test.html", "folder1/folder2/another.html")[0]; //use test.html
+        doc.insertString(0, code, null);
+        assertItems(doc, arr("../", "another.html"), Match.CONTAINS, 9);
+        
     }
 
     public void testFileAttrValueWithPrefix() throws BadLocationException, ParseException {
@@ -282,6 +300,22 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
         doc = createDocuments("test.html", "another.html", "image.png")[0]; //use test.html
         doc.insertString(0, code, null);
         assertItems(doc, arr("image.png"), Match.CONTAINS, 8);
+
+        //complete go up in nested folders
+        code = "<a href='folder1/folder2/.|'";
+        //      01234567890123456789023456
+        //we need a fileobject backed document here
+        doc = createDocuments("test.html", "folder1/folder2/another.html")[0]; //use test.html
+        doc.insertString(0, code, null);
+        assertItems(doc, arr("../"), Match.CONTAINS, 9);
+
+        //complete go up in nested folders
+        code = "<a href='folder1/folder2/..|'";
+        //      01234567890123456789023456
+        //we need a fileobject backed document here
+        doc = createDocuments("test.html", "folder1/folder2/another.html")[0]; //use test.html
+        doc.insertString(0, code, null);
+        assertItems(doc, arr("../"), Match.CONTAINS, 9);
     }
 
     public void testFileAttrValueUppercase() throws BadLocationException, ParseException {
@@ -301,8 +335,11 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
 
     public void testEndTagAutocompletion() throws BadLocationException, ParseException {
         assertItems("<div>|", arr("div"), Match.EXACT, 5);
+    }
+    
+    public void testNoEndTagAutocompletion() throws BadLocationException, ParseException {
         //test end tag ac for unknown tags
-        assertItems("<div><bla>|", arr(), Match.EMPTY, 0);
+        assertItems("<div><bla>|", arr(), Match.EMPTY);
     }
 
     public void testJustBeforeTag() throws BadLocationException, ParseException {
@@ -311,7 +348,7 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
     }
 
     public void testNoCompletionInDoctype() throws BadLocationException, ParseException {
-        assertItems("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" |  \"http://www.w3.org/TR/html40/strict.dtd\">", arr(), Match.EMPTY);
+        assertItems("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" |  \"http://www.w3.org/TR/html40/strict.dtd\">", arr(), Match.EMPTY);
     }
 
     public void testEndTagsAutoCompletionOfUndeclaredTags() throws BadLocationException, ParseException {
@@ -362,7 +399,7 @@ public class HtmlCompletionQueryTest extends HtmlCompletionTestBase {
 //        assertItems("<td><a h|</td>  ", arr("href"), Match.CONTAINS);
     }
 
-
+    
     //helper methods ------------
 
     @Override
