@@ -42,6 +42,7 @@
 package org.netbeans.modules.html.editor.completion;
 
 import junit.framework.AssertionFailedError;
+import org.netbeans.editor.Finder;
 import org.netbeans.editor.ext.html.dtd.DTD;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -56,6 +57,7 @@ import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
 import org.netbeans.editor.BaseDocument;
 import org.netbeans.editor.ext.html.dtd.Registry;
+import org.netbeans.editor.ext.html.parser.api.HtmlVersion;
 import org.netbeans.modules.html.editor.api.completion.HtmlCompletionItem;
 import org.netbeans.modules.html.editor.api.gsf.HtmlParserResult;
 import org.netbeans.modules.parsing.api.ParserManager;
@@ -71,7 +73,7 @@ import org.netbeans.modules.html.editor.test.TestBase;
  *
  * @author marekfukala
  */
-public class HtmlCompletionTestBase extends TestBase {
+public abstract class HtmlCompletionTestBase extends TestBase {
 
     private static final String DATA_DIR_BASE = "testfiles/completion/";
 
@@ -84,6 +86,8 @@ public class HtmlCompletionTestBase extends TestBase {
         super(name);
     }
 
+    protected abstract HtmlVersion getExpectedVersion();
+
     protected String getPublicID() {
         return null;
     }
@@ -109,11 +113,11 @@ public class HtmlCompletionTestBase extends TestBase {
         JEditorPane component = new JEditorPane();
         component.setDocument(doc);
 
-        DTD dtd = Registry.getDTD(getPublicID(), null);
-        assertNotNull(dtd);
-        if (getPublicID() != null) {
-            assertEquals(getPublicID(), dtd.getIdentifier());
-        }
+//        DTD dtd = Registry.getDTD(getPublicID(), null);
+//        assertNotNull(dtd);
+//        if (getPublicID() != null) {
+//            assertEquals(getPublicID(), dtd.getIdentifier());
+//        }
 
         final HtmlParserResult[] result = new HtmlParserResult[1];
         Source source = Source.create(doc);
@@ -127,7 +131,14 @@ public class HtmlCompletionTestBase extends TestBase {
 
         assertNotNull(result[0]);
 
-        HtmlCompletionQuery.CompletionResult completionResult = query.query(result[0], dtd);
+        assertSame(getExpectedVersion(), result[0].getSyntaxAnalyzerResult().getHtmlVersion());
+
+        HtmlCompletionQuery.CompletionResult completionResult = query.query(result[0]);
+        
+        if(type != Match.EMPTY) {
+            assertNotNull("null completion query result", completionResult);
+        }
+        
         if (expectedItemsNames.length == 0 && completionResult == null) {
             //result may be null if we do not expect any result, nothing to test then
             return;
@@ -171,11 +182,11 @@ public class HtmlCompletionTestBase extends TestBase {
         component.setDocument(doc);
         component.getCaret().setDot(pipeOffset);
 
-        DTD dtd = Registry.getDTD(getPublicID(), null);
-        assertNotNull(dtd);
-        if (getPublicID() != null) {
-            assertEquals(getPublicID(), dtd.getIdentifier());
-        }
+//        DTD dtd = Registry.getDTD(getPublicID(), null);
+//        assertNotNull(dtd);
+//        if (getPublicID() != null) {
+//            assertEquals(getPublicID(), dtd.getIdentifier());
+//        }
 
         final HtmlParserResult[] result = new HtmlParserResult[1];
         Source source = Source.create(doc);
@@ -189,9 +200,9 @@ public class HtmlCompletionTestBase extends TestBase {
 
         assertNotNull(result[0]);
 
-        HtmlCompletionQuery.CompletionResult completionResult = query.query(result[0], dtd);
+        HtmlCompletionQuery.CompletionResult completionResult = query.query(result[0]);
 
-        assertNotNull(result);
+        assertNotNull(completionResult);
         Collection<? extends CompletionItem> items = completionResult.getItems();
         assertNotNull(items);
 
@@ -246,6 +257,21 @@ public class HtmlCompletionTestBase extends TestBase {
         return args;
     }
 
+    protected TestSource getTestSource(String testFilePath, boolean removePipe) throws BadLocationException {
+        FileObject source = getTestFile(DATA_DIR_BASE + testFilePath);
+        BaseDocument doc = getDocument(source);
+        StringBuilder sb = new StringBuilder(doc.getText(0, doc.getLength()));
+        int pipeIndex = sb.indexOf("|");
+        assertTrue(String.format("Errorneous test file %s, there is no pipe char specifying the completion offset!", testFilePath),
+                pipeIndex != -1);
+
+        if(removePipe) {
+            sb.deleteCharAt(pipeIndex);
+        }
+
+        return new TestSource(sb.toString(), pipeIndex);
+    }
+
     private void testCompletionResults(String testFile) throws IOException, BadLocationException, ParseException {
         FileObject source = getTestFile(DATA_DIR_BASE + testFile);
         BaseDocument doc = getDocument(source);
@@ -284,4 +310,25 @@ public class HtmlCompletionTestBase extends TestBase {
         assertDescriptionMatches(source, output.toString(), false, ".pass", true);
 
     }
+
+
+    protected static class TestSource {
+        private String code;
+        private int position;
+
+        private TestSource(String code, int position) {
+            this.code = code;
+            this.position = position;
+        }
+
+        public String getCode() {
+            return code;
+        }
+
+        public int getPosition() {
+            return position;
+        }
+        
+    }
+
 }
