@@ -239,6 +239,8 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
 
     private static final int ISI_VAL_QUOT_ESC = 42;
     private static final int ISI_VAL_DQUOT_ESC = 43;
+    
+    private static final int ISA_ARG_UNDERSCORE = 44; //after _ in attribute name
 
     static final Set<String> EVENT_HANDLER_NAMES = new HashSet<String>();
     static {
@@ -598,6 +600,10 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
                             lexerState = INIT;
                             input.backup(1);
                             break;
+                        //issue 192803 - the attribute may start with underscore
+                        case '_':
+                            lexerState = ISA_ARG_UNDERSCORE;
+                            break;
                         default:
                             tag = null;
                             lexerState = ISI_ERROR;
@@ -686,6 +692,16 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
                     lexerState = ISI_STYLE_CONTENT;
                     break;
 
+                case ISA_ARG_UNDERSCORE:
+                    if( isName(actChar)) {
+                        lexerState = ISI_ARG;
+                        //fallthrough to ISI_ARG
+                    } else {
+                        lexerState = ISI_ERROR;
+                        input.backup(1); //the char will be read again and put to the error token
+                        break;
+                    }
+
                 case ISI_ARG:           // DONE
                     if( isName( actChar ) ) break; // eat next char
                     lexerState = ISP_ARG_X;
@@ -1089,6 +1105,7 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
             case ISI_ENDTAG:
                 return token(HTMLTokenId.TAG_CLOSE);
 
+            case ISA_ARG_UNDERSCORE:
             case ISI_ARG:
                 return token(HTMLTokenId.ARGUMENT);
 
@@ -1168,7 +1185,7 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
                 Collection attrs = cssClassTagAttrMap.get(tag);
                 if (attrs != null && attrs.contains(attribute)) {
                     //yup the attribute's value should have css "class" selector embedding
-                    return token(HTMLTokenId.VALUE_CSS, HTMLTokenId.VALUE_CSS_TOKEN_TYPE_PROPERTY, HTMLTokenId.VALUE_CSS_TOKEN_TYPE_CLASS);
+                    return token(HTMLTokenId.VALUE_CSS, CLASS_TOKEN_PP);
                 }
             }
         } finally {
@@ -1178,31 +1195,31 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
     }
 
     private Token<HTMLTokenId> createCssValueToken() {
-        String cssTokenType;
+        TokenPropertyProvider provider;
         if(equals(CLASS_ATTR_NAME, attribute, true, true)) {
-            cssTokenType = HTMLTokenId.VALUE_CSS_TOKEN_TYPE_CLASS;
+            provider = CLASS_TOKEN_PP;
         } else if(equals(ID_ATTR_NAME, attribute, true, true)) {
-            cssTokenType = HTMLTokenId.VALUE_CSS_TOKEN_TYPE_ID;
+            provider = ID_TOKEN_PP;
         } else {
-            cssTokenType = null;
+            provider = null;
         }
 
-        return token(HTMLTokenId.VALUE_CSS, HTMLTokenId.VALUE_CSS_TOKEN_TYPE_PROPERTY, cssTokenType);
+        return token(HTMLTokenId.VALUE_CSS, provider);
     }
 
     private Token<HTMLTokenId> token(HTMLTokenId tokenId) {
-        return token(tokenId, null, null);
+        return token(tokenId, null);
     }
 
-    private Token<HTMLTokenId> token(HTMLTokenId tokenId, String propertyKey, String propertyValue) {
+    private Token<HTMLTokenId> token(HTMLTokenId tokenId, TokenPropertyProvider tokenPropertyProvider) {
         if(LOG) {
             if(input.readLength() == 0) {
                 LOGGER.log(Level.INFO, "Found zero length token: "); //NOI18N
             }
             LOGGER.log(Level.INFO, "[" + this.getClass().getSimpleName() + "] token ('" + input.readText().toString() + "'; id=" + tokenId + "; state=" + state() + ")\n"); //NOI18N
         }
-         if(propertyKey != null && propertyValue != null) {
-            return tokenFactory.createPropertyToken(tokenId, input.readLength(), new HtmlTokenPropertyProvider(propertyKey, propertyValue));
+         if(tokenPropertyProvider != null) {
+            return tokenFactory.createPropertyToken(tokenId, input.readLength(), tokenPropertyProvider);
         } else {
             CharSequence image = input.readText();
             switch(tokenId) {
@@ -1299,4 +1316,9 @@ public final class HtmlLexer implements Lexer<HTMLTokenId> {
         }
 
     }
+    
+    private static final TokenPropertyProvider CLASS_TOKEN_PP = new HtmlTokenPropertyProvider(HTMLTokenId.VALUE_CSS_TOKEN_TYPE_PROPERTY, HTMLTokenId.VALUE_CSS_TOKEN_TYPE_CLASS);
+    private static final TokenPropertyProvider ID_TOKEN_PP = new HtmlTokenPropertyProvider(HTMLTokenId.VALUE_CSS_TOKEN_TYPE_PROPERTY, HTMLTokenId.VALUE_CSS_TOKEN_TYPE_ID);
+    
+    
 }
