@@ -79,7 +79,8 @@ import org.openide.filesystems.FileSystem;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Cancellable;
 import org.openide.util.Exceptions;
-import org.openide.util.NbBundle;
+import org.openide.util.NbBundle.Messages;
+import static org.netbeans.modules.hudson.impl.Bundle.*;
 import org.openide.util.RequestProcessor;
 import org.openide.util.RequestProcessor.Task;
 
@@ -107,6 +108,7 @@ public class HudsonInstanceImpl implements HudsonInstance, OpenableInBrowser {
     
     private Collection<HudsonJob> jobs = new ArrayList<HudsonJob>();
     private Collection<HudsonView> views = new ArrayList<HudsonView>();
+    private HudsonView primaryView;
     private final Collection<HudsonChangeListener> listeners = new ArrayList<HudsonChangeListener>();
     private ProblemNotificationController problemNotificationController;
     /**
@@ -227,6 +229,7 @@ public class HudsonInstanceImpl implements HudsonInstance, OpenableInBrowser {
         version = null;
         jobs.clear();
         views.clear();
+        primaryView = null;
         
         // Fire changes
         fireStateChanges();
@@ -285,20 +288,29 @@ public class HudsonInstanceImpl implements HudsonInstance, OpenableInBrowser {
         props.put(INSTANCE_SUPPRESSED_JOBS, HudsonInstanceProperties.join(suppressed));
     }
     
-    public synchronized Collection<HudsonView> getViews() {
+    public @Override synchronized Collection<HudsonView> getViews() {
         return views;
     }
     
-    public synchronized void setViews(Collection<HudsonView> views) {
-        this.views = views;
+    public @Override synchronized HudsonView getPrimaryView() {
+        if (primaryView == null) {
+            primaryView = new HudsonViewImpl(this, "All", getUrl()); // NOI18N
+        }
+        return primaryView;
     }
     
+    synchronized void setViews(Collection<HudsonView> views, HudsonView primaryView) {
+        this.views = views;
+        this.primaryView = primaryView;
+    }
+
+    @Messages("MSG_Synchronizing=Synchronizing {0}")
     public synchronized void synchronize() {
         if (semaphore.tryAcquire()) {
             final AtomicReference<Thread> synchThread = new AtomicReference<Thread>();
             final AtomicReference<ProgressHandle> handle = new AtomicReference<ProgressHandle>();
             handle.set(ProgressHandleFactory.createHandle(
-                    NbBundle.getMessage(HudsonInstanceImpl.class, "MSG_Synchronizing", getName()),
+                    MSG_Synchronizing(getName()),
                     new Cancellable() {
                 public boolean cancel() {
                     Thread t = synchThread.get();
