@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -69,6 +72,8 @@ import org.openide.util.RequestProcessor;
  * @author Michal Mocnak
  */
 public class HudsonManagerImpl {
+
+    private static final RequestProcessor RP = new RequestProcessor(HudsonManagerImpl.class);
     
     /** The only instance of the hudson manager implementation in the system */
     private static HudsonManagerImpl defaultInstance;
@@ -77,16 +82,17 @@ public class HudsonManagerImpl {
     private final List<HudsonChangeListener> listeners = new ArrayList<HudsonChangeListener>();
     private PropertyChangeListener projectsListener;
     private Map<Project, HudsonInstanceImpl> projectInstances = new HashMap<Project, HudsonInstanceImpl>();
+    private final RequestProcessor.Task checkOpenProjects = RP.create(new Runnable() {
+        public @Override void run() {
+            checkOpenProjects();
+        }
+    });
     
     private HudsonManagerImpl() {
         projectsListener = new PropertyChangeListener() {
             public void propertyChange(PropertyChangeEvent evt) {
                 if (OpenProjects.PROPERTY_OPEN_PROJECTS.equals(evt.getPropertyName())) {
-                    RequestProcessor.getDefault().post(new Runnable() {
-                        public void run() {
-                            checkOpenProjects();
-                        }
-                    });
+                    checkOpenProjects.schedule(0);
                 }
             }
         };
@@ -221,7 +227,7 @@ public class HudsonManagerImpl {
     }
 
     private void init() {
-        RequestProcessor.getDefault().post(new Runnable() {
+        RP.post(new Runnable() {
             public void run() {
                 try {
                     try {
