@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -43,6 +46,7 @@ package org.netbeans.modules.hudson.ui.nodes;
 
 import java.io.CharConversionException;
 import java.util.ArrayList;
+import java.util.LinkedList;
 import java.util.List;
 import javax.swing.Action;
 import org.netbeans.modules.hudson.api.HudsonJob;
@@ -81,11 +85,24 @@ public class HudsonJobNode extends AbstractNode {
     private static Children makeChildren(final HudsonJob job) {
         return Children.create(new ChildFactory<Object>() {
             final Object WORKSPACE = new Object();
-            protected boolean createKeys(List<Object> toPopulate) {
-                // XXX would be nicer to avoid adding this in case there is no remote workspace...
-                toPopulate.add(WORKSPACE);
-                toPopulate.addAll(job.getBuilds());
-                return true;
+            LinkedList<HudsonJobBuild> builds;
+            protected @Override boolean createKeys(List<Object> toPopulate) {
+                if (Thread.interrupted()) {
+                    return true;
+                } else if (builds == null) {
+                    // XXX would be nicer to avoid adding this in case there is no remote workspace...
+                    toPopulate.add(WORKSPACE);
+                    builds = new LinkedList<HudsonJobBuild>(job.getBuilds());
+                    return false;
+                } else if (builds.isEmpty()) {
+                    return true;
+                } else {
+                    // Processing one build at a time, make sure its result is known (blocking call).
+                    HudsonJobBuild b = builds.removeFirst();
+                    b.getResult();
+                    toPopulate.add(b);
+                    return false;
+                }
             }
             protected @Override Node createNodeForKey(Object key) {
                 if (key == WORKSPACE) {
