@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -728,7 +731,7 @@ public class FormI18nSupport extends JavaI18nSupport {
                                     found = true;
                                 }
                             }
-                        } else {
+                        } else if(value instanceof String) { // #179872
                             // Has to be plain String, there is other Property Editor for String RAD Property.
                             // It's converted via toAscii method cause for this value is used org.netbeans.core.editors.StringEditor 
                             // which does the same thing.
@@ -737,6 +740,9 @@ public class FormI18nSupport extends JavaI18nSupport {
                             if ((validProp.getSkip() == 0) && string.equals(toAscii(hardString))) {
                                 found = true;
                             }
+                        } else {
+                            // TODO: now, do nothing, but see #179872 :
+                            // org.netbeans.modules.swingapp.ResourceValueImpl
                         }
                     } else {
                         // Node.Property, the value should be plain String.
