@@ -64,6 +64,7 @@ import org.netbeans.api.java.source.CancellableTask;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.JavaSource;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.project.FileOwnerQuery;
 import org.netbeans.api.project.Project;
 import org.netbeans.modules.j2ee.jpa.model.JPAAnnotations;
@@ -138,7 +139,7 @@ public abstract class JPAProblemFinder {
                             break;
                         }
                         
-                        if (tree.getKind() == Tree.Kind.CLASS){
+                        if (TreeUtilities.CLASS_TREE_KINDS.contains(tree.getKind())){
                             
                             TreePath path = info.getTrees().getPath(info.getCompilationUnit(), tree);
                             TypeElement javaClass = (TypeElement) info.getTrees().getElement(path);
@@ -316,11 +317,13 @@ public abstract class JPAProblemFinder {
                 
                 for (PersistenceScope scope : scopes.getPersistenceScopes()){
                     FileObject persistenceXML = scope.getPersistenceXml();
-                    PersistenceXMLListener pxmlListener = new PersistenceXMLListener(file);
-                    FileChangeListener weakPXMLListener = WeakListeners.create(FileChangeListener.class, pxmlListener, null);
-                    persistenceXML.addFileChangeListener(weakPXMLListener);
-                    pxmlListeners.add(pxmlListener);
-                    LOG.fine("Added PersistenceXMLListener to " + persistenceXML.getName());
+                    if(persistenceXML!=null){//persistence xml may be deleted/renamed
+                        PersistenceXMLListener pxmlListener = new PersistenceXMLListener(file);
+                        FileChangeListener weakPXMLListener = WeakListeners.create(FileChangeListener.class, pxmlListener, null);
+                        persistenceXML.addFileChangeListener(weakPXMLListener);
+                        pxmlListeners.add(pxmlListener);
+                        LOG.fine("Added PersistenceXMLListener to " + persistenceXML.getName());
+                    }
                 }
                 
                 // persistence.xml listeners should live as long as the scopes listener
