@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -46,13 +49,13 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
-import junit.framework.Test;
-import junit.framework.TestSuite;
-import junit.textui.TestRunner;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import org.netbeans.api.project.Project;
+import org.netbeans.jellytools.Bundle;
 import org.netbeans.jellytools.JellyTestCase;
 import org.netbeans.jellytools.NbDialogOperator;
-import org.netbeans.jellytools.NewFileNameLocationStepOperator;
+import org.netbeans.jellytools.NewJavaFileNameLocationStepOperator;
 import org.netbeans.jellytools.NewFileWizardOperator;
 import org.netbeans.jellytools.ProjectsTabOperator;
 import org.netbeans.jellytools.actions.SaveAllAction;
@@ -63,13 +66,14 @@ import org.netbeans.jemmy.operators.JComboBoxOperator;
 import org.netbeans.jemmy.operators.JRadioButtonOperator;
 import org.netbeans.jemmy.operators.JTextFieldOperator;
 import org.netbeans.junit.NbTestCase;
-import org.netbeans.junit.NbTestSuite;
+import org.netbeans.modules.java.j2seproject.J2SEProjectGenerator;
 import org.netbeans.test.j2ee.lib.ContentComparator;
 import org.netbeans.test.j2ee.lib.FilteringLineDiff;
 import org.netbeans.test.j2ee.lib.J2eeProjectSupport;
 import org.netbeans.test.j2ee.lib.Reporter;
 import org.netbeans.test.j2ee.lib.Ejb;
 import org.netbeans.test.j2ee.lib.Utils;
+import org.openide.filesystems.FileUtil;
 
 /**
  * Test New File wizards in J2EE area. These tests are
@@ -77,46 +81,38 @@ import org.netbeans.test.j2ee.lib.Utils;
  * In each test is checked if all classes are created
  * and if deployment descriptors are changed accordingly.
  *
- * @author jungi
+ * @author jungi, Jiri Skrivanek
  * @see <a href="http://qa.netbeans.org/modules/j2ee/promo-f/testspec/j2ee-wizards-testspec.html">J2EE Wizards Test Specification</a>
  */
 public class NewFileWizardsTest extends JellyTestCase {
 
-    private static boolean CREATE_GOLDEN_FILES = Boolean.getBoolean("org.netbeans.test.j2ee.wizard.golden");
-//    private static boolean CREATE_GOLDEN_FILES = true;
-
+//    private static boolean CREATE_GOLDEN_FILES = Boolean.getBoolean("org.netbeans.test.j2ee.wizard.golden");
+    private static boolean CREATE_GOLDEN_FILES = false;
     private static final String DEF_EJB_MOD = "def EJB Mod";
     private static final String DEF_WEB_MOD = "def Web app";
-    private static final String BAD_EJB_MOD = "BadModule";
-
+    private static final String REMOTE_JAVA_PROJECT_NAME = "JavaProject";
     private Reporter reporter;
     private String version;
-
-    public NewFileWizardsTest(String testName) {
-        this(testName, "1.4");
-    }
+    private static String projectLocation = null;
 
     public NewFileWizardsTest(String testName, String version) {
         super(testName);
         this.version = version;
     }
 
-    public static void main(String[] args) {
-        TestRunner.run(suite());
-    }
-
-    public static Test suite() {
-        TestSuite suite = new NbTestSuite(NewFileWizardsTest.class);
-        return suite;
-    }
-
     @Override
     public void setUp() throws Exception {
+        super.setUp();
+        if (projectLocation == null) {
+            projectLocation = getWorkDir().getParentFile().getParentFile().getCanonicalPath();
+        }
         reporter = Reporter.getReporter((NbTestCase) this);
+        System.out.println("########  " + getName() + "  #######");
     }
 
     @Override
     public void tearDown() throws Exception {
+        super.tearDown();
         reporter.close();
     }
 
@@ -208,7 +204,7 @@ public class NewFileWizardsTest extends JellyTestCase {
      * and <code>String</code> as primary key class.
      */
     public void testLocalBeanEntityBean() throws Exception {
-        ejbTest("Entity Bean", BAD_EJB_MOD + version, "LocalBeanEntity",
+        ejbTest("Entity Bean", DEF_EJB_MOD + version, "LocalBeanEntity",
                 "ejbs.entity.bean.local", true, false, false, null);
     }
 
@@ -217,7 +213,7 @@ public class NewFileWizardsTest extends JellyTestCase {
      * and <code>String</code> as primary key class.
      */
     public void testRemoteBeanEntityBean() throws Exception {
-        ejbTest("Entity Bean", BAD_EJB_MOD + version, "RemoteBeanEntity",
+        ejbTest("Entity Bean", DEF_EJB_MOD + version, "RemoteBeanEntity",
                 "ejbs.entity.bean.remote", false, true, false, null);
     }
 
@@ -226,7 +222,7 @@ public class NewFileWizardsTest extends JellyTestCase {
      * and <code>String</code> as primary key class.
      */
     public void testLocalRemoteBeanEntityBean() throws Exception {
-        ejbTest("Entity Bean", BAD_EJB_MOD + version, "LRBE",
+        ejbTest("Entity Bean", DEF_EJB_MOD + version, "LRBE",
                 "ejbs.entity.bean", true, true, false, null);
     }
 
@@ -332,9 +328,10 @@ public class NewFileWizardsTest extends JellyTestCase {
         Project p = J2eeProjectSupport.getProject(new File(prjRoot), ".");
         NewFileWizardOperator nfwo = WizardUtils.createNewFile(p,
                 "Web", "Servlet");
-        NewFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
+        NewJavaFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
                 servletName, servletPkg, null);
-        nop.finish();    }
+        nop.finish();
+    }
 
     /**
      * Go through New Session/Entity/Message-Driven Bean wizard.
@@ -347,11 +344,17 @@ public class NewFileWizardsTest extends JellyTestCase {
             boolean local, boolean remote, boolean stateless, String srcRoot) throws Exception {
         boolean hasMoreSrcRoots = (srcRoot != null);
         Project p = (hasMoreSrcRoots)
-        ? J2eeProjectSupport.getProject(new File(prjRoot), ".")
-        : J2eeProjectSupport.getProject(new File(System.getProperty("xtest.sketchpad")), prjRoot);
-        NewFileWizardOperator nfwo = WizardUtils.createNewFile(p,
-                "Enterprise", type);
-        NewFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
+                ? J2eeProjectSupport.getProject(new File(prjRoot), ".")
+                : J2eeProjectSupport.getProject(new File(projectLocation), prjRoot);
+        File remoteJavaProjectDir = new File(FileUtil.toFile(p.getProjectDirectory().getParent()), REMOTE_JAVA_PROJECT_NAME + version);
+        if (!remoteJavaProjectDir.exists()) {
+            // create java project needed for remote beans
+            J2SEProjectGenerator.createProject(remoteJavaProjectDir, REMOTE_JAVA_PROJECT_NAME + version, null, null, null, true);
+            J2eeProjectSupport.openProject(remoteJavaProjectDir);
+        }
+        String category = Bundle.getStringTrimmed("org.netbeans.modules.j2ee.ejbcore.resources.Bundle", "Templates/J2EE");
+        NewFileWizardOperator nfwo = WizardUtils.createNewFile(p, category, type);
+        NewJavaFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
                 ejbName, ejbPkg, srcRoot);
         if (type.equals("Message-Driven Bean")) {
             new JButtonOperator(nop, "Add").pushNoBlock();
@@ -363,6 +366,8 @@ public class NewFileWizardsTest extends JellyTestCase {
                 new JRadioButtonOperator(addMessageDestinationOper, "Queue").push();
             }
             addMessageDestinationOper.ok();
+            // need to wait until wizard is refreshed after the add dialog is closed
+            new EventTool().waitNoEvent(1000);
         } else {
             if (!stateless) {
                 if (type.equals("Session Bean")) {
@@ -371,33 +376,36 @@ public class NewFileWizardsTest extends JellyTestCase {
                     new JRadioButtonOperator(nop, "Bean").setSelected(true);
                 }
             }
-            new JCheckBoxOperator(nop, "Local").setSelected(local);
-            new JCheckBoxOperator(nop, "Remote").setSelected(remote);
+            new JCheckBoxOperator(nop, "Local").changeSelection(local);
+            new JCheckBoxOperator(nop, "Remote").changeSelection(remote);
         }
         nop.finish();
         Ejb ejb = (hasMoreSrcRoots)
-        ? new Ejb(ejbPkg + "." + ejbName, p, local, remote, srcRoot)
-        : new Ejb(ejbPkg + "." + ejbName, p, local, remote);
+                ? new Ejb(ejbPkg + "." + ejbName, p, remoteJavaProjectDir, local, remote, srcRoot)
+                : new Ejb(ejbPkg + "." + ejbName, p, remoteJavaProjectDir, local, remote);
         if ("1.4".equals(version)) {
             String[] err = ejb.checkExistingFiles();
-            assertTrue(Arrays.asList(err).toString(),  err.length == 0);
+            assertTrue(Arrays.asList(err).toString(), err.length == 0);
         }
         List<File> files = new ArrayList<File>();
         File prjDir = (hasMoreSrcRoots)
-        ? new File(prjRoot).getCanonicalFile()
-        : new File(new File(System.getProperty("xtest.sketchpad")), prjRoot).getCanonicalFile();
+                ? new File(prjRoot).getCanonicalFile()
+                : new File(new File(projectLocation), prjRoot).getCanonicalFile();
         if ("1.4".equals(version)) {
             files.add(new File(prjDir, "src/conf/ejb-jar.xml"));
-            files.add(new File(prjDir, "src/conf/sun-ejb-jar.xml"));
+            files.add(new File(prjDir, "src/conf/glassfish-ejb-jar.xml"));
         }
         if (!hasMoreSrcRoots) {
             files.addAll(Arrays.asList(
-                    new File(prjDir, "src/java/" + ejbPkg.replace('.', '/') + "/")
-                    .listFiles(new Filter(ejbName))));
+                    new File(prjDir, "src/java/" + ejbPkg.replace('.', '/') + "/").listFiles(new Filter(ejbName))));
         } else {
             files.addAll(Arrays.asList(
-                    new File(prjDir, srcRoot + "/" + ejbPkg.replace('.', '/') + "/")
-                    .listFiles(new Filter(ejbName))));
+                    new File(prjDir, srcRoot + "/" + ejbPkg.replace('.', '/') + "/").listFiles(new Filter(ejbName))));
+        }
+        // check files in remote java project
+        File[] fileList = new File(remoteJavaProjectDir, "src/" + ejbPkg.replace('.', '/') + "/").listFiles(new Filter(ejbName));
+        if (fileList != null) {
+            files.addAll(Arrays.asList(fileList));
         }
         checkFiles(files);
     }
@@ -409,21 +417,21 @@ public class NewFileWizardsTest extends JellyTestCase {
             boolean caching, String srcRoot) throws Exception {
         boolean hasMoreSrcRoots = (srcRoot != null);
         Project p = (hasMoreSrcRoots)
-        ? J2eeProjectSupport.getProject(new File(prjRoot), ".")
-        : J2eeProjectSupport.getProject(new File(System.getProperty("xtest.sketchpad")), prjRoot);
+                ? J2eeProjectSupport.getProject(new File(prjRoot), ".")
+                : J2eeProjectSupport.getProject(new File(projectLocation), prjRoot);
         String type = (caching) ? "Caching Service Locator" : "Service Locator";
-        String category = "Enterprise";
-        if(prjRoot.startsWith(DEF_WEB_MOD) || prjRoot.startsWith(getMultiWebPath())) {
+        String category = Bundle.getStringTrimmed("org.netbeans.modules.j2ee.ejbcore.resources.Bundle", "Templates/J2EE");
+        if (prjRoot.startsWith(DEF_WEB_MOD) || prjRoot.startsWith(getMultiWebPath())) {
             category = "Web";
         }
         NewFileWizardOperator nfwo = WizardUtils.createNewFile(p, category, type);
-        NewFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
+        NewJavaFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
                 name, pkg, srcRoot);
         nop.finish();
         List<File> files = new ArrayList<File>(1);
         File prjDir = (hasMoreSrcRoots)
-        ? new File(prjRoot).getCanonicalFile()
-        : new File(new File(System.getProperty("xtest.sketchpad")), prjRoot).getCanonicalFile();
+                ? new File(prjRoot).getCanonicalFile()
+                : new File(new File(projectLocation), prjRoot).getCanonicalFile();
         if (!hasMoreSrcRoots) {
             files.add(new File(prjDir, "src/java/" + pkg.replace('.', '/') + "/" + name + ".java"));
         } else {
@@ -433,17 +441,17 @@ public class NewFileWizardsTest extends JellyTestCase {
     }
 
     private void puTest(String prjRoot, String name) throws Exception {
-        Project p = J2eeProjectSupport.getProject(new File(System.getProperty("xtest.sketchpad")), prjRoot);
+        Project p = J2eeProjectSupport.getProject(new File(projectLocation), prjRoot);
         NewFileWizardOperator nfwo = WizardUtils.createNewFile(p,
                 "Persistence", "Persistence Unit");
         JTextFieldOperator jtfo = new JTextFieldOperator(nfwo, 0);
         jtfo.clearText();
         jtfo.typeText(name);
         JComboBoxOperator jcbo = new JComboBoxOperator(nfwo, 1);
-        jcbo.selectItem("sample");
+        jcbo.selectItem("jdbc/sample");
         nfwo.finish();
         List<File> files = new ArrayList<File>();
-        File prjDir = new File(new File(System.getProperty("xtest.sketchpad")), prjRoot).getCanonicalFile();
+        File prjDir = new File(new File(projectLocation), prjRoot).getCanonicalFile();
         files.add(new File(prjDir, "src/conf/persistence.xml"));
         checkFiles(files);
     }
@@ -452,30 +460,27 @@ public class NewFileWizardsTest extends JellyTestCase {
             throws Exception {
         boolean hasMoreSrcRoots = (srcRoot != null);
         Project p = (hasMoreSrcRoots)
-        ? J2eeProjectSupport.getProject(new File(prjRoot), ".")
-        : J2eeProjectSupport.getProject(new File(System.getProperty("xtest.sketchpad")), prjRoot);
+                ? J2eeProjectSupport.getProject(new File(prjRoot), ".")
+                : J2eeProjectSupport.getProject(new File(projectLocation), prjRoot);
         NewFileWizardOperator nfwo = WizardUtils.createNewFile(p,
                 "Persistence", "Entity Class");
-        NewFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
+        NewJavaFileNameLocationStepOperator nop = WizardUtils.setFileNameLocation(
                 name, pkg, srcRoot);
         nop.finish();
         List<File> files = new ArrayList<File>();
         File prjDir = (hasMoreSrcRoots)
-        ? new File(prjRoot).getCanonicalFile()
-        : new File(new File(System.getProperty("xtest.sketchpad")), prjRoot).getCanonicalFile();
+                ? new File(prjRoot).getCanonicalFile()
+                : new File(new File(projectLocation), prjRoot).getCanonicalFile();
         if (!hasMoreSrcRoots) {
             files.addAll(Arrays.asList(
-                    new File(prjDir, "src/java/" + pkg.replace('.', '/') + "/")
-                    .listFiles(new Filter(name))));
+                    new File(prjDir, "src/java/" + pkg.replace('.', '/') + "/").listFiles(new Filter(name))));
         } else {
             files.addAll(Arrays.asList(
-                    new File(prjDir, srcRoot + "/" + pkg.replace('.', '/') + "/")
-                    .listFiles(new Filter(name))));
+                    new File(prjDir, srcRoot + "/" + pkg.replace('.', '/') + "/").listFiles(new Filter(name))));
         }
         checkFiles(files);
     }
 
-
     /**
      * Check files against golden files.
      *
@@ -485,14 +490,18 @@ public class NewFileWizardsTest extends JellyTestCase {
         new EventTool().waitNoEvent(1000);
         // save all instead of timeout
         new SaveAllAction().performAPI();
+        new EventTool().waitNoEvent(1000);
         if (!CREATE_GOLDEN_FILES) {
             List<String> l = new ArrayList<String>(newFiles.size() / 2);
             for (Iterator<File> i = newFiles.iterator(); i.hasNext();) {
                 File newFile = i.next();
                 File goldenFile = null;
                 try {
+                    Logger lo = Logger.getLogger(NewFileWizardsTest.class.getName());
                     goldenFile = getGoldenFile(getName() + "_" + version + "/" + newFile.getName() + ".pass");
-                    if (newFile.getName().endsWith(".xml") && !newFile.getName().startsWith("sun-") && !newFile.getName().startsWith("webservices.xml")) {
+                    lo.log(Level.FINE, "comparing: {0}", goldenFile.getAbsolutePath());
+                    lo.log(Level.FINE, "with: {0}", newFile.getAbsolutePath());
+                    if (newFile.getName().endsWith(".xml") && !newFile.getName().startsWith("glassfish-") && !newFile.getName().startsWith("webservices.xml")) {
                         assertTrue(ContentComparator.equalsXML(goldenFile, newFile));
                     } else {
                         assertFile(newFile, goldenFile,
@@ -518,12 +527,12 @@ public class NewFileWizardsTest extends JellyTestCase {
         List<String> names = new ArrayList<String>();
         names.add("goldenfiles");
         while (!f.getName().equals("test")) {
-            if (!f.getName().equals("sys") && !f.getName().equals("work") &&!f.getName().equals("tests")) {
+            if (!f.getName().equals("sys") && !f.getName().equals("work") && !f.getName().equals("tests")) {
                 names.add(f.getName());
             }
-            f=f.getParentFile();
+            f = f.getParentFile();
         }
-        for (int i = names.size()-1;i > -1;i--) {
+        for (int i = names.size() - 1; i > -1; i--) {
             f = new File(f, names.get(i));
         }
         f = new File(f, getClass().getName().replace('.', File.separatorChar));
@@ -539,15 +548,13 @@ public class NewFileWizardsTest extends JellyTestCase {
     /**
      * Build project.
      * @paramprjName project to build
-     * @param projectNameInStatus true if project name is displayed in IDE's status bar
      */
     private void tearDownProject(String prjName) {
+        ProjectsTabOperator.invoke().getProjectRootNode(prjName).collapse();
         Utils.buildProject(prjName);
     }
 
-
 //----------------------------------------------------- multi src roots projects
-
     /**
      * Open EJB Module project with multiple source roots.
      */
@@ -735,8 +742,10 @@ public class NewFileWizardsTest extends JellyTestCase {
             start = name;
         }
 
+        @Override
         public boolean accept(File dir, String name) {
-            return name.startsWith(start);
+            // include files with specified prefix and exclude local history temporary files
+            return name.startsWith(start) && !name.endsWith(".nblh~");
         }
     }
 }
