@@ -78,8 +78,10 @@ public class DbSchemaEjbGenerator {
     private List relations = new ArrayList();
     private SchemaElement schemaElement;
     private Set<String> tablesReferecedByOtherTables;
+    private Set<String> primaryKeyIsForeignKeyTables;
     private final CollectionType colectionType;
     private final static Logger LOGGER = Logger.getLogger(DbSchemaEjbGenerator.class.getName());
+    private boolean useColumNamesInRelations = false;
     //private ArrayList<String> warningMessages;
    
     /**
@@ -89,7 +91,7 @@ public class DbSchemaEjbGenerator {
      * @param schemaElement the dbschema containing the tables to generate beans for.
      */
     public DbSchemaEjbGenerator(GeneratedTables genTables, SchemaElement schemaElement) {
-        this(genTables, schemaElement, CollectionType.COLLECTION);
+        this(genTables, schemaElement, CollectionType.COLLECTION, false);
     }
 
     /**
@@ -99,13 +101,15 @@ public class DbSchemaEjbGenerator {
      * @param schemaElement the dbschema containing the tables to generate beans for.
      * @param collectionType collection type is used in some names generation
      */
-    public DbSchemaEjbGenerator(GeneratedTables genTables, SchemaElement schemaElement, CollectionType collectionType) {
+    public DbSchemaEjbGenerator(GeneratedTables genTables, SchemaElement schemaElement, CollectionType collectionType, boolean useColumnNamesInRelationships) {
         this.schemaElement = schemaElement;
         this.genTables = genTables;
         this.colectionType = collectionType;
+        this.useColumNamesInRelations = useColumnNamesInRelationships;
         //warningMessages = new ArrayList<String>();
 
         tablesReferecedByOtherTables = getTablesReferecedByOtherTables(schemaElement);
+        primaryKeyIsForeignKeyTables = getTablesReferencesOtherTablesWithPrimaryKeyMatch(schemaElement);
         buildCMPSet();
     }
     /**
@@ -125,6 +129,36 @@ public class DbSchemaEjbGenerator {
         
         return tableNames;
     }
+    /**
+     *
+     * @param schemaElement The schema
+     * @return A set of tables that reference another tables with primary key to promary key reference
+     */
+    public static Set<String> getTablesReferencesOtherTablesWithPrimaryKeyMatch(SchemaElement schemaElement) {
+        Set<String> tableNames = new HashSet<String>();
+        TableElement[] allTables = schemaElement.getTables();
+        for(int i = 0; i < allTables.length; i ++ ) {
+            TableElement table0 = allTables[i];
+            UniqueKeyElement pk0 = table0.getPrimaryKey();
+            if(pk0 != null){//it may be join table or other without pk
+                ForeignKeyElement[] fkElements = table0.getForeignKeys();
+                for(int fkix = 0; fkix < fkElements.length; fkix ++ ) {
+                    ForeignKeyElement fk = fkElements[fkix];
+                    TableElement table = fk.getReferencedTable();
+                    UniqueKeyElement pk = table.getPrimaryKey();
+                    //at first step support 1-1 keys (no composite yet).
+                    if(pk != null && 1 == pk0.getColumns().length && fk.getLocalColumns().length == 1 && pk.getColumns().length==1){
+                        if(fk.getLocalColumns()[0].equals(pk0.getColumns()[0])){
+                            tableNames.add(table0.getName().getName());
+                            continue;
+                        }
+                    }
+                }
+            }
+        }
+
+        return tableNames;
+    }
     
     /**
      * Returns true if the table is a join table. A table is considered
@@ -438,6 +472,10 @@ public class DbSchemaEjbGenerator {
         EntityMember m = EntityMember.create(column);
         m.setPrimaryKey(inPk, pkField);
         EntityClass bean = getBean(column.getDeclaringTable().getName().getName());
+        if(primaryKeyIsForeignKeyTables.contains(column.getDeclaringTable().getName().getName())){
+            //derived id usage candidate
+            bean.setDerivedIdCandidate(true);
+        }
         m.setMemberName(uniqueAlgorithm(getFieldNames(bean), m.getMemberName(), null));
         bean.getFields().add(m);
     }
@@ -484,9 +522,10 @@ public class DbSchemaEjbGenerator {
          */
 //        #185253 I don't see a good reason to have one case when it's possible to use column name and anothe case when it's not possible
 //        comment code below for now, may need review or deletion in next release if there will be any negative feedback
-//        if (!containsColumns(key.getColumns(), getPrimaryOrCandidateKey(key.getDeclaringTable()))) {
-//            roleACmr = EntityMember.makeRelationshipFieldName(roleB.getRoleName(), colectionType, false);
-//        }
+//        #188550 add backward compartible option to have column names instead of tables names
+        if (useColumNamesInRelations && !containsColumns(key.getColumns(), getPrimaryOrCandidateKey(key.getDeclaringTable()))) {
+            roleACmr = EntityMember.makeRelationshipFieldName(roleB.getRoleName(), colectionType, false);
+        }
         
         roleACmr = uniqueAlgorithm(getFieldNames(roleAHelper), roleACmr, null);
         
@@ -525,7 +564,6 @@ public class DbSchemaEjbGenerator {
             UniqueKeyElement pk = getPrimaryOrCandidateKey(table);
             ForeignKeyElement[] fkeys = table.getForeignKeys();
             //sometimes database may contain duplicating foreign keys (or it may be an issue in db schema generation)
-            //TODO: uncomment to fix issue 177341
             fkeys = removeDuplicateFK(fkeys);
 
             for (int col = 0; col < cols.length; col++) {
