@@ -298,8 +298,9 @@ public class PersistenceUnitPanel extends SectionInnerPanel {
     
     private void initIncludeAllEntities(){
         boolean javaSE = Util.isJavaSE(project);
-        includeAllEntities.setEnabled(!javaSE);
-        includeAllEntities.setSelected(!javaSE && !persistenceUnit.isExcludeUnlistedClasses());
+        boolean isNotContainer = !Util.isContainerManaged(project);
+        includeAllEntities.setEnabled(!(javaSE || isNotContainer));
+        includeAllEntities.setSelected(!(javaSE || isNotContainer) && !persistenceUnit.isExcludeUnlistedClasses());
         includeAllEntities.setText(NbBundle.getMessage(PersistenceUnitPanel.class,
                 "LBL_IncludeAllEntities",//NOI18N
                 new Object[]{ProjectUtils.getInformation(project).getDisplayName()}));
@@ -419,6 +420,7 @@ public class PersistenceUnitPanel extends SectionInnerPanel {
         }
     }
     
+    @Override
     public void setValue(javax.swing.JComponent source, Object value) {
         if (source == nameTextField) {
             persistenceUnit.setName((String) value);
@@ -432,9 +434,14 @@ public class PersistenceUnitPanel extends SectionInnerPanel {
             }
         } else if (source == libraryComboBox){
             setProvider();
+            //store some common properties valid for all providers
+
+            //
             setTableGeneration();
         } else if (providerCombo == source){
             String prevProvider = persistenceUnit.getProvider();
+            //store some common properties valid for all providers
+            //
             setProvider();
             setDataSource();
             String curProvider = persistenceUnit.getProvider();
@@ -443,6 +450,7 @@ public class PersistenceUnitPanel extends SectionInnerPanel {
             }
         } else if (source == ddCreate || source == ddDropCreate || source == ddUnknown){
             ProviderUtil.setTableGeneration(persistenceUnit, getTableGeneration(), ProviderUtil.getProvider(persistenceUnit.getProvider(), project));
+            ProviderUtil.normalizeIfPossible(project, persistenceUnit);
         } else if (source == includeAllEntities){
             persistenceUnit.setExcludeUnlistedClasses(!includeAllEntities.isSelected());
         } else if (source == jtaCheckBox){
@@ -490,6 +498,7 @@ public class PersistenceUnitPanel extends SectionInnerPanel {
                 org.netbeans.modules.j2ee.persistence.dd.persistence.model_2_0.PersistenceUnit pu2=(org.netbeans.modules.j2ee.persistence.dd.persistence.model_2_0.PersistenceUnit) persistenceUnit;
                 pu2.setValidationMode(validationModes[2]);
             }
+            ProviderUtil.normalizeIfPossible(project, persistenceUnit);
         }
         performValidation();
     }
@@ -510,23 +519,27 @@ public class PersistenceUnitPanel extends SectionInnerPanel {
     }
     
     private void setProvider(){
-        
+
+        String tableGeneration = getTableGeneration();
+
         if (isContainerManaged && providerCombo.getSelectedItem() instanceof Provider) {
             Provider provider = (Provider) providerCombo.getSelectedItem();
             ProviderUtil.removeProviderProperties(persistenceUnit);
             
             if (!(provider instanceof DefaultProvider)) {
                 persistenceUnit.setProvider(provider.getProviderClass());
+                ProviderUtil.setTableGeneration(persistenceUnit, tableGeneration, provider);//preserv table generation property
                 setTableGeneration();
             }
-            ProviderUtil.makePortableIfPossible(project, persistenceUnit);
+            ProviderUtil.normalizeIfPossible(project, persistenceUnit);
             
         } else if (libraryComboBox.getSelectedItem() instanceof Provider){
             Provider provider = (Provider) libraryComboBox.getSelectedItem();
             ProviderUtil.removeProviderProperties(persistenceUnit);
             if (!(provider instanceof DefaultProvider)) {
                 ProviderUtil.setProvider(persistenceUnit, provider, getSelectedConnection(), getTableGeneration());
-            }
+                ProviderUtil.setTableGeneration(persistenceUnit, tableGeneration, provider);//preserv table generation property
+           }
         }
     }
     
