@@ -57,9 +57,12 @@ import java.util.Vector;
 import java.util.Iterator;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import javax.swing.JList;
 import org.netbeans.api.db.explorer.ConnectionManager;
 import org.netbeans.api.db.explorer.DatabaseConnection;
 import org.netbeans.api.db.explorer.JDBCDriver;
@@ -73,6 +76,9 @@ import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
 import org.netbeans.api.project.Sources;
 import org.netbeans.api.project.libraries.Library;
+import org.netbeans.api.project.libraries.LibraryManager;
+import org.netbeans.modules.j2ee.persistence.api.PersistenceScope;
+import org.netbeans.modules.j2ee.persistence.dd.PersistenceMetadata;
 import org.netbeans.modules.j2ee.persistence.dd.PersistenceUtils;
 import org.netbeans.modules.j2ee.persistence.dd.common.Persistence;
 import org.netbeans.modules.j2ee.persistence.dd.common.PersistenceUnit;
@@ -231,9 +237,9 @@ public class Util {
 
     public static Provider getDefaultProvider(Project project) {
         PersistenceProviderSupplier providerSupplier = project.getLookup().lookup(PersistenceProviderSupplier.class);
-        if((providerSupplier != null && providerSupplier.supportsDefaultProvider())) {
+        if ((providerSupplier != null && providerSupplier.supportsDefaultProvider())) {
             List<Provider> providers = providerSupplier.getSupportedProviders();
-            if( providers.size()>0 ){
+            if (providers.size() > 0) {
                 return providers.get(0);
             }
             Logger.getLogger(RelatedCMPWizard.class.getName()).log(Level.WARNING, "Default provider support is reported without any supported providers. See: " + providerSupplier);
@@ -259,6 +265,30 @@ public class Util {
         return providers;
     }
 
+    /**
+     * check all available providers and return default/first/or ECLIPSELINK if prefereed
+     * @param project
+     * @return
+     */
+    public static Provider getPreferredProvider(Project project){
+        //choose default/first provider
+        ArrayList<Provider> providers = getProviders(project);
+        int defIndex = 0;
+        if(providers.size()>1){//if it's possible to select preferred jpa2.0 provider, we'll select instead of jpa1.0 default one
+            String defProviderVersion = ProviderUtil.getVersion((Provider) providers.get(0));
+            boolean specialCase = Util.isJPAVersionSupported(project, Persistence.VERSION_2_0) && (defProviderVersion == null || defProviderVersion.equals(Persistence.VERSION_1_0));//jpa 2.0 is supported by default (or first) is jpa1.0 or udefined version provider
+            if(specialCase){
+                for (int i = 1; i<providers.size() ; i++){
+                    if(ProviderUtil.ECLIPSELINK_PROVIDER.equals(providers.get(i))){//eclipselink jpa2.0 is preferred provider
+                        defIndex = i;
+                        break;
+                    }
+                }
+            }
+        }
+        return providers!=null && providers.size()>0 ? providers.get(defIndex) : null;
+    }
+
     public static boolean isDefaultProvider(Project project, Provider provider) {
         return provider != null && provider.equals(getDefaultProvider(project));
     }
@@ -344,6 +374,7 @@ public class Util {
         Object result = DialogDisplayer.getDefault().notify(nd);
         //add necessary libraries before pu creation
         Library lib = null;
+        boolean libIsAdded = false;//used to check if lib was added to compile classpath
         if (result == createPUButton) {
             if (isContainerManaged) {
                 //TODO: verify if need to add library here
@@ -354,13 +385,14 @@ public class Util {
                 lib = PersistenceLibrarySupport.getLibrary(puJdbc.getSelectedProvider());
                 //TODO: verify if don't need to add library here
                 if (lib != null) {
+                    libIsAdded = true;
                     addLibraryToProject(project, lib);
                 }
                 JDBCDriver[] driver = JDBCDriverManager.getDefault().getDrivers(puJdbc.getPersistenceConnection().getDriverClass());
                 PersistenceLibrarySupport.addDriver(project, driver[0]);
             }
         }
-        String version = lib != null ? PersistenceUtils.getJPAVersion(lib) : PersistenceUtils.getJPAVersion(project);//use library if possible it will provide better result, TODO: may be usage of project should be removed and use 1.0 is no library was found
+        String version = (lib != null && libIsAdded) ? PersistenceUtils.getJPAVersion(lib) : PersistenceUtils.getJPAVersion(project);//use library if possible it will provide better result, TODO: may be usage of project should be removed and use 1.0 is no library was found
         if (result == createPUButton) {
             PersistenceUnit punit = null;
             if (Persistence.VERSION_2_0.equals(version)) {
@@ -386,8 +418,13 @@ public class Util {
                 }
             } else {
                 PersistenceUnitWizardPanelJdbc puJdbc = (PersistenceUnitWizardPanelJdbc) panel;
-                punit = ProviderUtil.buildPersistenceUnit(puJdbc.getPersistenceUnitName(), puJdbc.getSelectedProvider(), puJdbc.getPersistenceConnection(),version);
+                punit = ProviderUtil.buildPersistenceUnit(puJdbc.getPersistenceUnitName(), puJdbc.getSelectedProvider(), puJdbc.getPersistenceConnection(), version);
                 punit.setTransactionType("RESOURCE_LOCAL"); //NOI18N
+                // Explicitly add <exclude-unlisted-classes>false</exclude-unlisted-classes>
+                // See issue 142575 - desc 10
+                if (!Util.isJavaSE(project)) {
+                    punit.setExcludeUnlistedClasses(false);
+                }
             }
             punit.setName(panel.getPersistenceUnitName());
             ProviderUtil.setTableGeneration(punit, panel.getTableGeneration(), project);
@@ -410,18 +447,32 @@ public class Util {
      */
     public static PersistenceUnit buildPersistenceUnitUsingData(Project project, String puName,
             String preselectedDB, TableGeneration tableGeneration, Provider provider) {
+            return buildPersistenceUnitUsingData(project, puName, preselectedDB, tableGeneration, provider, null);
+    }
+    /**
+     * Builds a persistence unit using data passed as parameters. Does not save the created persistence unit
+     * nor create the persistence.xml file if it  does not exist.
+     * If some parameters are null, try to find default one or best match
+     * @param project the current project
+     * @param name name for pu, if null default will be used
+     * @param preselectedDB the name of the database connection that should be preselected in the wizard.
+     * @tableGeneration the table generation strategy that should be preselected in the wizard.
+     * @param puVersion pu will be created with passed as a parameter jpa version but will be limited by project/provider properties (can't create 2.0 in project and provider with 1.0 support only).
+     * @return the created PersistenceUnit or null if nothing was created, for example
+     * if wizard was cancelled.
+     */
+    public static PersistenceUnit buildPersistenceUnitUsingData(Project project, String puName,
+            String preselectedDB, TableGeneration tableGeneration, Provider provider, String puVersion) {
 
         boolean isContainerManaged = Util.isContainerManaged(project);
 
         if (provider == null) {
             //choose default/first provider
-            ArrayList<Provider> providers = getProviders(project);
-            //
-            provider = providers.get(0);
+            provider = getPreferredProvider(project);
         }
         //add necessary libraries before pu creation
         Library lib = null;
-
+        boolean libIsAdded = false;//used to check if lib was added to compile classpath
         if (isContainerManaged) {
             //TODO: verify if need to add library here
             lib = PersistenceLibrarySupport.getLibrary(provider);
@@ -430,11 +481,25 @@ public class Util {
             //TODO: verify if don't need to add library here
             if (lib != null) {
                 addLibraryToProject(project, lib);
+                libIsAdded = true;
             }
         }
 
-        String version = lib != null ? PersistenceUtils.getJPAVersion(lib) : PersistenceUtils.getJPAVersion(project);//use library if possible it will provide better result, TODO: may be usage of project should be removed and use 1.0 is no library was found
-
+        String    version = (lib != null && libIsAdded) ? PersistenceUtils.getJPAVersion(lib) : PersistenceUtils.getJPAVersion(project);//use library if possible it will provide better result, TODO: may be usage of project should be removed and use 1.0 is no library was found
+        if (provider != null && version != null) {
+            String provVersion = ProviderUtil.getVersion(provider);
+            if (provVersion != null) {
+                //even if project support jpa 2.0 etc, but selected provider is reported as jpa1.0 use jpa1.0
+                if (Double.parseDouble(version) > Double.parseDouble(provVersion)) {
+                    version = provVersion;
+                }
+            }
+        }
+        if(puVersion != null){
+            if (Double.parseDouble(version) > Double.parseDouble(puVersion)) {
+                version = puVersion;//if passed version less then supported we can use lower version.
+            }
+        }
         PersistenceUnit punit = null;
         if (Persistence.VERSION_2_0.equals(version)) {
             punit = new org.netbeans.modules.j2ee.persistence.dd.persistence.model_2_0.PersistenceUnit();
@@ -443,10 +508,12 @@ public class Util {
             punit = new org.netbeans.modules.j2ee.persistence.dd.persistence.model_1_0.PersistenceUnit();
         }
         if (isContainerManaged) {
-            if(preselectedDB == null || preselectedDB.trim().equals("")){
+            if (preselectedDB == null || preselectedDB.trim().equals("")) {
                 //find first with default/sample part in name
                 JPADataSourceProvider dsProvider = project.getLookup().lookup(JPADataSourceProvider.class);
-                if(dsProvider.getDataSources().size()>0)preselectedDB = dsProvider.getDataSources().get(0).getDisplayName();
+                if (dsProvider.getDataSources().size() > 0) {
+                    preselectedDB = dsProvider.getDataSources().get(0).getDisplayName();
+                }
             }
             if (preselectedDB != null && !"".equals(preselectedDB.trim())) {
                 punit.setJtaDataSource(preselectedDB);
@@ -454,25 +521,50 @@ public class Util {
             if (!(provider instanceof DefaultProvider)) {
                 punit.setProvider(provider.getProviderClass());
             }
+            // Explicitly add <exclude-unlisted-classes>false</exclude-unlisted-classes>
+            // See issue 142575 - desc 10
+            // also it shouldn't change default behavior as default for containers should be the same
+            punit.setExcludeUnlistedClasses(false);
         } else {
             DatabaseConnection connection = null;
-            if(preselectedDB != null && !preselectedDB.trim().equals("")){
+            if (preselectedDB != null && !preselectedDB.trim().equals("")) {
                 connection = ConnectionManager.getDefault().getConnection(preselectedDB);
             }
-            if(connection == null){
+            if (connection == null) {
                 ConnectionManager cm = ConnectionManager.getDefault();
                 DatabaseConnection[] connections = cm.getConnections();
-                connection = connections!=null && connections.length>0 ? connections[0] : null;
+                connection = connections != null && connections.length > 0 ? connections[0] : null;
             }
             punit = ProviderUtil.buildPersistenceUnit("tmp", provider, connection, version);
             punit.setTransactionType("RESOURCE_LOCAL"); //NOI18N
+            // Explicitly add <exclude-unlisted-classes>false</exclude-unlisted-classes>
+            // See issue 142575 - desc 10, and issue 180810
+            if (!Util.isJavaSE(project)) {
+                punit.setExcludeUnlistedClasses(false);
+            }
+        }
+        if (puName == null) {
+            puName = getCandidateName(project);
         }
-        if(puName == null) puName = getCandidateName(project);
         punit.setName(puName);
-        ProviderUtil.setTableGeneration(punit, tableGeneration !=null ? tableGeneration.name() : TableGeneration.NONE.name(), project);
+        ProviderUtil.setTableGeneration(punit, tableGeneration != null ? tableGeneration.name() : TableGeneration.NONE.name(), project);
         return punit;
     }
 
+    /**
+     *
+     * @return true if jpa version is supported by platform (may need to be extended to classpath check and possible library addition check but not in this method
+     * it's used to check server support in current realization)
+     */
+    public static boolean isJPAVersionSupported(Project project, String version){
+        JPAModuleInfo info = project.getLookup().lookup(JPAModuleInfo.class);
+        if(info!=null){
+            return !Boolean.FALSE.equals(info.isJPAVersionSupported(version));//null return considerd valid too and the same as true
+        }
+        return true;
+
+    }
+
     /**
      * Creates a persistence unit using the PU wizard and adds the created
      * persistence unit to the given project's <code>PUDataObject</code> and saves it.
@@ -511,28 +603,32 @@ public class Util {
      * @param project
      * @param pu
      */
-    public static void addPersistenceUnitToProject(Project project, PersistenceUnit persistenceUnit){
+    public static void addPersistenceUnitToProject(Project project, PersistenceUnit persistenceUnit) {
         String providerClass = persistenceUnit.getProvider();
-        if(providerClass != null){
-            Provider selectedProvider=ProviderUtil.getProvider(providerClass, project);
-            Library lib = PersistenceLibrarySupport.getLibrary(selectedProvider);
+        boolean libAdded = false;
+        Library lib = null;
+        if (providerClass != null) {
+            Provider selectedProvider = ProviderUtil.getProvider(providerClass, project);
+            lib = PersistenceLibrarySupport.getLibrary(selectedProvider);
             if (lib != null) {
-                if(!Util.isDefaultProvider(project, selectedProvider)) {
+                if (!Util.isDefaultProvider(project, selectedProvider)) {
                     Util.addLibraryToProject(project, lib);
-                } else if (selectedProvider.getAnnotationProcessor() != null){
+                    libAdded = true;
+                } else if (selectedProvider.getAnnotationProcessor() != null) {
                     Util.addLibraryToProject(project, lib, JavaClassPathConstants.PROCESSOR_PATH);
+                    libAdded = true;
                 }
             }
-            if(!isContainerManaged(project)){
+            if (!isContainerManaged(project)) {
                 DatabaseConnection connection = ProviderUtil.getConnection(persistenceUnit);
-                if( connection!=null ){
+                if (connection != null) {
                     JDBCDriver[] driver = JDBCDriverManager.getDefault().getDrivers(connection.getDriverClass());
                     PersistenceLibrarySupport.addDriver(project, driver[0]);
                 } else {
                     Logger.getLogger("global").log(Level.INFO, "Can't find connection for persistence unit"); //NOI18N
                 }
             }
-       }
+        }
 
         try {
             ProviderUtil.addPersistenceUnit(persistenceUnit, project);
@@ -541,7 +637,17 @@ public class Util {
             // already been warned about an invalid persistence.xml
             Logger.getLogger(RelatedCMPWizard.class.getName()).log(Level.FINE, "Invalid persistence.xml: " + ipx.getPath(), ipx); //NOI18N
         }
-   }
+        //need to add ap registration lib if exist
+        if (libAdded && lib != null) {
+            String projVersion = PersistenceUtils.getJPAVersion(project);
+            if( projVersion == null )projVersion = "1.0";//NOI18N minimum version, will not affect
+            double version = Math.max(Double.parseDouble(PersistenceUtils.getJPAVersion(lib)), Double.parseDouble(projVersion));
+            if (version > 1.0 && Util.isJPAVersionSupported(project, Double.toString(version))) {
+                Library mLib = LibraryManager.getDefault().getLibrary(lib.getName()+"modelgen");
+                if(mLib!=null) Util.addLibraryToProject(project, mLib, JavaClassPathConstants.PROCESSOR_PATH);//no real need to add modelgen to compile classpath
+            }
+        }
+    }
 
     /**
      * Creates a persistence unit with the default table generation strategy using the PU wizard and adds the created
@@ -577,17 +683,17 @@ public class Util {
      * @param classpathType
      */
     public static void addLibraryToProject(Project project, Library library, String classpathType) {
-        Sources sources=ProjectUtils.getSources(project);
-        SourceGroup groups[]=sources.getSourceGroups(JavaProjectConstants.SOURCES_TYPE_JAVA);
-        SourceGroup firstGroup=groups[0];
-        FileObject fo=firstGroup.getRootFolder();
+        Sources sources = ProjectUtils.getSources(project);
+        SourceGroup groups[] = sources.getSourceGroups(JavaProjectConstants.SOURCES_TYPE_JAVA);
+        SourceGroup firstGroup = groups[0];
+        FileObject fo = firstGroup.getRootFolder();
         try {
-                ProjectClassPathModifier.addLibraries(new Library[]{library}, fo, classpathType);
-            } catch (IOException ex) {
-                Logger.getLogger("global").log(Level.FINE, "Can't add library to the project", ex);
-            } catch (UnsupportedOperationException ex) {
-                Logger.getLogger("global").log(Level.FINE, "Can't add library to the project", ex);
-            }
+            ProjectClassPathModifier.addLibraries(new Library[]{library}, fo, classpathType);
+        } catch (IOException ex) {
+            Logger.getLogger("global").log(Level.FINE, "Can't add library to the project", ex);
+        } catch (UnsupportedOperationException ex) {
+            Logger.getLogger("global").log(Level.FINE, "Can't add library to the project", ex);
+        }
     }
 
     /**
@@ -608,11 +714,12 @@ public class Util {
             }
         }
     }
+
     /**
      *@return an initial name for a persistence unit, i.e. a name that
      * is unique.
      */
-    static private final String getCandidateName(Project project){
+    static private final String getCandidateName(Project project) {
         String candidateNameBase = ProjectUtils.getInformation(project).getName() + "PU"; //NOI18N
         try {
             if (!ProviderUtil.persistenceExists(project)) {
@@ -635,18 +742,20 @@ public class Util {
         }
         return candidateNameBase;
     }
+
     /**
      * @return true if the given <code>candidate</code> represents a unique
      * name within the names of the given <code>punits</code>, false otherwise.
      */
-    static private boolean isUnique(String candidate, PersistenceUnit[] punits){
-        for (PersistenceUnit punit : punits){
-            if (candidate.equals(punit.getName())){
+    static private boolean isUnique(String candidate, PersistenceUnit[] punits) {
+        for (PersistenceUnit punit : punits) {
+            if (candidate.equals(punit.getName())) {
                 return false;
             }
         }
         return true;
     }
+
     /**
      * An implementation of the PersistenceProviderSupplier that returns an empty list for supported
      * providers and doesn't support a default provider. Used when an implementation of
@@ -665,4 +774,87 @@ public class Util {
             return false;
         }
     }
+
+    public static String getPersistenceUnitAsString(Project project, String entity) throws IOException {
+        String persistenceUnit = null;
+        PersistenceScope persistenceScopes[] = PersistenceUtils.getPersistenceScopes(project);
+        if (persistenceScopes.length > 0) {
+            FileObject persXml = persistenceScopes[0].getPersistenceXml();
+            if (persXml != null) {
+                Persistence persistence = PersistenceMetadata.getDefault().getRoot(persXml);
+                PersistenceUnit units[] = persistence.getPersistenceUnit();
+                if (units.length > 0) {
+                    persistenceUnit = units[0].getName();
+                    if (units.length > 1) {//find best
+                        String forAll = null;
+                        String forOne = null;
+                        for (int i = 0; i < units.length && forOne == null; i++) {
+                            PersistenceUnit tmp = units[i];
+                            if (forAll == null && !tmp.isExcludeUnlistedClasses()) {
+                                forAll = tmp.getName();//first match sutable for all entities in the project
+                            }
+                            if (tmp.isExcludeUnlistedClasses()) {
+                                String[] classes = tmp.getClass2();
+                                for (String clas : classes) {
+                                    if (entity.equals(clas)) {
+                                        forOne = tmp.getName();
+                                        break;
+                                    }
+                                }
+                            }
+                        }
+                        //try again with less restrictions (i.e. for j2se even without exclude-unlisted-classes node, it's by default true)
+                        if (forOne == null && forAll != null) {//there is exist pu without exclude-unlisted-classes
+                            for (int i = 0; i < units.length && forOne == null; i++) {
+                                PersistenceUnit tmp = units[i];
+                                if (!tmp.isExcludeUnlistedClasses()) {//verify only pu without exclude-unlisted-classes as all other was examined in previos try
+                                    String[] classes = tmp.getClass2();
+                                    for (String clas : classes) {
+                                        if (entity.equals(clas)) {
+                                            forOne = tmp.getName();
+                                            break;
+                                        }
+                                    }
+                                }
+                            }
+                        }
+
+                        persistenceUnit = forOne != null ? forOne : (forAll != null ? forAll : persistenceUnit);
+                    }
+                }
+            }
+        }
+        return persistenceUnit;
+    }
+
+    //UI support
+    public static Set getSelectedItems(JList list, boolean enabledOnly) {
+        Set result = new HashSet();
+
+        int[] selected = list.getSelectedIndices();
+        for (int i = 0; i < selected.length; i++) {
+            Object item = list.getModel().getElementAt(selected[i]);
+            if (enabledOnly) {
+                if (!list.getCellRenderer().getListCellRendererComponent(list, item, selected[i], false, false).isEnabled()) {
+                    continue;
+                }
+            }
+            result.add(item);
+        }
+
+        return result;
+    }
+
+    public static Set getEnabledItems(JList list) {
+        Set result = new HashSet();
+        for (int i = 0; i < list.getModel().getSize(); i++) {
+            Object item = list.getModel().getElementAt(i);
+            if (!list.getCellRenderer().getListCellRendererComponent(list, item, i, false, false).isEnabled()) {
+                continue;
+            }
+            result.add(item);
+        }
+
+        return result;
+    }
 }
