@@ -44,32 +44,44 @@
 
 package org.netbeans.modules.j2ee.persistence.wizard.fromdb;
 
+import java.awt.Component;
 import java.awt.Dimension;
+import java.awt.Point;
+import java.awt.event.ActionEvent;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import javax.lang.model.element.TypeElement;
+import javax.swing.AbstractAction;
 import javax.swing.ComboBoxModel;
 import javax.swing.Icon;
 import javax.swing.JLabel;
+import javax.swing.JMenuItem;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
 import javax.swing.text.Document;
 import javax.swing.text.JTextComponent;
+import org.netbeans.api.db.explorer.ConnectionManager;
 import org.netbeans.api.java.classpath.ClassPath;
+import org.netbeans.api.java.project.JavaProjectConstants;
+import org.netbeans.api.java.source.ClasspathInfo;
+import org.netbeans.api.java.source.CompilationController;
+import org.netbeans.api.java.source.JavaSource;
+import org.netbeans.api.java.source.Task;
 import org.netbeans.api.project.Project;
 import org.netbeans.api.project.ProjectUtils;
 import org.netbeans.api.project.SourceGroup;
+import org.netbeans.api.project.Sources;
 import org.netbeans.modules.j2ee.core.api.support.SourceGroups;
 import org.netbeans.modules.j2ee.core.api.support.java.JavaIdentifiers;
 import org.netbeans.modules.j2ee.persistence.dd.common.Persistence;
 import org.netbeans.modules.j2ee.persistence.provider.InvalidPersistenceXmlException;
 import org.netbeans.modules.j2ee.persistence.provider.Provider;
 import org.netbeans.modules.j2ee.persistence.provider.ProviderUtil;
-import org.netbeans.modules.j2ee.persistence.spi.provider.PersistenceProviderSupplier;
 import org.netbeans.modules.j2ee.persistence.util.SourceLevelChecker;
 import org.netbeans.modules.j2ee.persistence.wizard.Util;
 import org.netbeans.modules.j2ee.persistence.wizard.library.PersistenceLibrarySupport;
@@ -103,13 +115,22 @@ public class EntityClassesPanel extends javax.swing.JPanel {
 
     private SelectedTables selectedTables;
     private final boolean puRequired;
+    private final JMenuItem allToUpdateItem;
+    private final JMenuItem allToRecreateItem;
 
 
-    private EntityClassesPanel(boolean puRequired) {
+    private EntityClassesPanel(boolean puRequired, boolean JAXBRequired) {
         this.puRequired = puRequired;
 
         initComponents();
 
+        if (JAXBRequired) {
+            generateJAXBCheckBox.setEnabled(false);
+        }
+
+        allToUpdateItem = tableActionsPopup.add(new AllToUpdateAction());
+        allToRecreateItem = tableActionsPopup.add(new AllToRecreateAction());
+
         classNamesTable.getParent().setBackground(classNamesTable.getBackground());
         classNamesTable.putClientProperty("terminateEditOnFocusLost", Boolean.TRUE); // NOI18N
 
@@ -138,6 +159,26 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         changeSupport.addChangeListener(listener);
     }
 
+    boolean isBeanValidationSupported() {
+        if (project == null) {
+            return false;
+        }
+        
+        final String notNullAnnotation = "javax.validation.constraints.NotNull";    //NOI18N
+        Sources sources=ProjectUtils.getSources(project);
+        SourceGroup groups[]=sources.getSourceGroups(JavaProjectConstants.SOURCES_TYPE_JAVA);
+        if(groups == null || groups.length<1){
+            return false;
+        }
+        SourceGroup firstGroup=groups[0];
+        FileObject fo=firstGroup.getRootFolder();
+        ClassPath compile=ClassPath.getClassPath(fo, ClassPath.COMPILE);
+        if (compile == null) {
+            return false;
+        }
+        return compile.findResource(notNullAnnotation.replace('.', '/')+".class")!=null;//NOI18N
+    }
+
     public void initialize(PersistenceGenerator persistenceGen, Project project, boolean cmp, FileObject targetFolder) {
         this.persistenceGen = persistenceGen;
         this.project = project;
@@ -183,6 +224,29 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         }
 
         updatePersistenceUnitButton(true);
+        Sources sources=ProjectUtils.getSources(project);
+        SourceGroup groups[]=sources.getSourceGroups(JavaProjectConstants.SOURCES_TYPE_JAVA);
+        SourceGroup firstGroup=groups[0];
+        FileObject fo=firstGroup.getRootFolder();
+        ClasspathInfo classpathInfo = ClasspathInfo.create(fo);
+        JavaSource javaSource = JavaSource.create(classpathInfo);
+        try {
+            javaSource.runUserActionTask(new Task<CompilationController>() {
+
+                @Override
+                public void run(CompilationController controller) throws IOException {
+                    controller.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
+                    TypeElement jc = controller.getElements().getTypeElement("javax.xml.bind.annotation.XmlTransient"); //NOI18N
+                    if(jc == null){
+                        generateJAXBCheckBox.setSelected(false);
+                        generateJAXBCheckBox.setEnabled(false);
+                    }
+                }
+            }, true);
+        } catch (IOException ex) {
+            //no need to throw exception as it just will not disable option possibly unsupported, it's not severe
+            LOGGER.log(Level.FINE, "Fail to check if jaxb is supported");//NOI18N
+        }
     }
 
     public void update(TableClosure tableClosure, String tableSourceName) {
@@ -205,7 +269,8 @@ public class EntityClassesPanel extends javax.swing.JPanel {
 
         TableUISupport.connectClassNames(classNamesTable, selectedTables);
         this.tableSourceName = tableSourceName;
-    }
+        updateSetAllButtons();
+     }
 
     public SelectedTables getSelectedTables() {
         return selectedTables;
@@ -227,6 +292,14 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         return generateFinderMethodsCheckBox.isSelected();
     }
 
+    public boolean getGenerateJAXB() {
+        return generateJAXBCheckBox.isSelected();
+    }
+
+    public boolean getGenerateValidationConstraints() {
+        return isBeanValidationSupported();
+    }
+    
     public boolean getCreatePersistenceUnit() {
         return createPUCheckbox.isVisible() && createPUCheckbox.isSelected();
     }
@@ -261,10 +334,13 @@ public class EntityClassesPanel extends javax.swing.JPanel {
             boolean showWarning = !cmp
                     && !ProviderUtil.persistenceExists(project);
 
+            boolean isContainerManaged = Util.isContainerManaged(project);
+            boolean canCreate = isContainerManaged || (ConnectionManager.getDefault().getConnections().length>0);//TODO  unhandled case if there is pu creation panel after this one, isn't the case for 7.0
+
             if(initial){
-                createPUCheckbox.setVisible(showWarning);
-                createPUCheckbox.setSelected(showWarning);
-                createPUCheckbox.setEnabled(!puRequired);
+                createPUCheckbox.setVisible(showWarning && canCreate);
+                createPUCheckbox.setSelected(showWarning && canCreate);
+                createPUCheckbox.setEnabled(!puRequired && canCreate);
             }
 
 
@@ -280,11 +356,15 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         if(warning.trim().length() == 0){//may need to show warning about sourc level
             if(getCreatePersistenceUnit()){
                 String sourceLevel = SourceLevelChecker.getSourceLevel(project);
-                if(sourceLevel !=null ){//by default except some minor cases jpa 2.0 is used in this wizard
+                if(sourceLevel !=null ){
                     if(!("1.6".equals(sourceLevel) || Double.parseDouble(sourceLevel)>=1.6)){
-                        ArrayList<Provider> providers = Util.getProviders(project);
-                        if(providers!=null && providers.size()>0 && Persistence.VERSION_2_0.equals(ProviderUtil.getVersion(providers.get(0)))){
-                            warning  = NbBundle.getMessage(RelatedCMPWizard.class, "ERR_WrongSourceLevel", sourceLevel);
+                        Provider provider = Util.getPreferredProvider(project);
+                        if(provider!=null && Persistence.VERSION_2_0.equals(ProviderUtil.getVersion(provider))){
+                            if(Util.isJPAVersionSupported(project, Persistence.VERSION_2_0)){
+                                warning  = NbBundle.getMessage(RelatedCMPWizard.class, "ERR_WrongSourceLevel", sourceLevel);
+                            } else {
+                                warning  = NbBundle.getMessage(RelatedCMPWizard.class, "ERR_UnsupportedJpaVersion", Persistence.VERSION_2_0);
+                            }
                         }
                     }
                 }
@@ -304,6 +384,24 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         }
     }
 
+    private void updateSetAllButtons(){
+        boolean update = false;
+        boolean recreate = false;
+        if(selectedTables!=null)
+        {
+            for (Table table : selectedTables.getTables()) {
+                if(!selectedTables.getUpdateType(table).equals(UpdateType.NEW)){
+                    if(selectedTables.getUpdateType(table).equals(UpdateType.UPDATE))recreate=true;
+                    else update=true;
+                    if(update && recreate)break;
+                }
+            }
+        }
+        tableActionsButton.setEnabled(update || recreate);
+        allToUpdateItem.setEnabled(update);
+        allToRecreateItem.setEnabled(recreate);
+    }
+
     private void updateSelectedTables() {
         if (selectedTables != null) {
             try {
@@ -322,6 +420,7 @@ public class EntityClassesPanel extends javax.swing.JPanel {
     // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
     private void initComponents() {
 
+        tableActionsPopup = new javax.swing.JPopupMenu();
         specifyNamesLabel = new javax.swing.JLabel();
         classNamesLabel = new javax.swing.JLabel();
         classNamesScrollPane = new javax.swing.JScrollPane();
@@ -335,8 +434,12 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         generateFinderMethodsCheckBox = new javax.swing.JCheckBox();
         cmpFieldsInInterfaceCheckBox = new javax.swing.JCheckBox();
         spacerPanel = new javax.swing.JPanel();
+        tableActionsButton = new javax.swing.JButton();
         createPUWarningLabel = new ShyLabel();
         createPUCheckbox = new javax.swing.JCheckBox();
+        generateJAXBCheckBox = new javax.swing.JCheckBox();
+
+        tableActionsPopup.setInvoker(tableActionsButton);
 
         setName(org.openide.util.NbBundle.getMessage(EntityClassesPanel.class, "LBL_EntityClasses")); // NOI18N
 
@@ -344,6 +447,7 @@ public class EntityClassesPanel extends javax.swing.JPanel {
 
         org.openide.awt.Mnemonics.setLocalizedText(classNamesLabel, org.openide.util.NbBundle.getMessage(EntityClassesPanel.class, "LBL_ClassNames")); // NOI18N
 
+        classNamesScrollPane.setMinimumSize(new java.awt.Dimension(23, 80));
         classNamesScrollPane.setViewportView(classNamesTable);
 
         org.openide.awt.Mnemonics.setLocalizedText(projectLabel, org.openide.util.NbBundle.getMessage(EntityClassesPanel.class, "LBL_Project")); // NOI18N
@@ -370,15 +474,31 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         org.openide.awt.Mnemonics.setLocalizedText(cmpFieldsInInterfaceCheckBox, org.openide.util.NbBundle.getMessage(EntityClassesPanel.class, "TXT_AddFieldsToInterface")); // NOI18N
         cmpFieldsInInterfaceCheckBox.setBorder(javax.swing.BorderFactory.createEmptyBorder(1, 1, 1, 1));
 
+        spacerPanel.setPreferredSize(new java.awt.Dimension(377, 24));
+
+        org.openide.awt.Mnemonics.setLocalizedText(tableActionsButton, "...");
+        tableActionsButton.setMaximumSize(new java.awt.Dimension(24, 24));
+        tableActionsButton.setMinimumSize(new java.awt.Dimension(24, 24));
+        tableActionsButton.setPreferredSize(new java.awt.Dimension(24, 24));
+        tableActionsButton.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                tableActionsButtonActionPerformed(evt);
+            }
+        });
+
         org.jdesktop.layout.GroupLayout spacerPanelLayout = new org.jdesktop.layout.GroupLayout(spacerPanel);
         spacerPanel.setLayout(spacerPanelLayout);
         spacerPanelLayout.setHorizontalGroup(
             spacerPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(0, 383, Short.MAX_VALUE)
+            .add(org.jdesktop.layout.GroupLayout.TRAILING, spacerPanelLayout.createSequentialGroup()
+                .addContainerGap(404, Short.MAX_VALUE)
+                .add(tableActionsButton, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 24, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
         );
         spacerPanelLayout.setVerticalGroup(
             spacerPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-            .add(0, 9, Short.MAX_VALUE)
+            .add(spacerPanelLayout.createSequentialGroup()
+                .add(tableActionsButton, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 20, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
+                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
         );
 
         org.openide.awt.Mnemonics.setLocalizedText(createPUWarningLabel, "  ");
@@ -394,6 +514,11 @@ public class EntityClassesPanel extends javax.swing.JPanel {
             }
         });
 
+        generateJAXBCheckBox.setSelected(true);
+        org.openide.awt.Mnemonics.setLocalizedText(generateJAXBCheckBox, org.openide.util.NbBundle.getMessage(EntityClassesPanel.class, "TXT_GenerateJAXBAnnotations")); // NOI18N
+        generateJAXBCheckBox.setToolTipText(org.openide.util.NbBundle.getMessage(EntityClassesPanel.class, "TXT_ToolTipJAXB")); // NOI18N
+        generateJAXBCheckBox.setBorder(javax.swing.BorderFactory.createEmptyBorder(1, 1, 1, 1));
+
         org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
         this.setLayout(layout);
         layout.setHorizontalGroup(
@@ -405,21 +530,26 @@ public class EntityClassesPanel extends javax.swing.JPanel {
                     .add(projectLabel)
                     .add(locationLabel)
                     .add(packageLabel))
-                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
+                .add(18, 18, 18)
                 .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
-                    .add(spacerPanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
-                    .add(packageComboBox, 0, 383, Short.MAX_VALUE)
-                    .add(locationComboBox, 0, 383, Short.MAX_VALUE)
-                    .add(org.jdesktop.layout.GroupLayout.TRAILING, projectTextField, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 383, Short.MAX_VALUE)
-                    .add(classNamesScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 383, Short.MAX_VALUE)))
-            .add(cmpFieldsInInterfaceCheckBox)
-            .add(generateFinderMethodsCheckBox)
+                    .add(spacerPanel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 428, Short.MAX_VALUE)
+                    .add(packageComboBox, 0, 428, Short.MAX_VALUE)
+                    .add(locationComboBox, 0, 428, Short.MAX_VALUE)
+                    .add(org.jdesktop.layout.GroupLayout.TRAILING, projectTextField, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 428, Short.MAX_VALUE)
+                    .add(classNamesScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 428, Short.MAX_VALUE)))
+            .add(layout.createSequentialGroup()
+                .add(generateJAXBCheckBox)
+                .addContainerGap())
+            .add(layout.createSequentialGroup()
+                .add(generateFinderMethodsCheckBox)
+                .addContainerGap())
             .add(layout.createSequentialGroup()
                 .add(createPUCheckbox)
                 .addContainerGap())
             .add(layout.createSequentialGroup()
-                .add(createPUWarningLabel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 441, Short.MAX_VALUE)
+                .add(cmpFieldsInInterfaceCheckBox)
                 .addContainerGap())
+            .add(createPUWarningLabel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 510, Short.MAX_VALUE)
         );
         layout.setVerticalGroup(
             layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
@@ -428,9 +558,9 @@ public class EntityClassesPanel extends javax.swing.JPanel {
                 .add(11, 11, 11)
                 .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                     .add(classNamesLabel)
-                    .add(classNamesScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 61, Short.MAX_VALUE))
+                    .add(classNamesScrollPane, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 80, Short.MAX_VALUE))
                 .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
-                .add(spacerPanel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
+                .add(spacerPanel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 24, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                 .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                 .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                     .add(projectTextField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
@@ -446,11 +576,13 @@ public class EntityClassesPanel extends javax.swing.JPanel {
                 .add(21, 21, 21)
                 .add(generateFinderMethodsCheckBox)
                 .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
+                .add(generateJAXBCheckBox)
+                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                 .add(cmpFieldsInInterfaceCheckBox)
                 .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                 .add(createPUCheckbox)
-                .add(11, 11, 11)
-                .add(createPUWarningLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
+                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
+                .add(createPUWarningLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 16, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                 .addContainerGap())
         );
     }// </editor-fold>//GEN-END:initComponents
@@ -466,6 +598,15 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         updatePersistenceUnitButton(false);
     }//GEN-LAST:event_createPUCheckboxItemStateChanged
 
+    private void tableActionsButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_tableActionsButtonActionPerformed
+        Component component = ((Component)evt.getSource());
+        Point loc = component.getLocationOnScreen();
+        loc.y += component.getHeight()/2;
+        loc.x += component.getWidth()/2;
+        tableActionsPopup.setLocation(loc);
+        tableActionsPopup.setVisible(true);
+    }//GEN-LAST:event_tableActionsButtonActionPerformed
+
     // Variables declaration - do not modify//GEN-BEGIN:variables
     private javax.swing.JLabel classNamesLabel;
     private javax.swing.JScrollPane classNamesScrollPane;
@@ -474,6 +615,7 @@ public class EntityClassesPanel extends javax.swing.JPanel {
     private javax.swing.JCheckBox createPUCheckbox;
     private javax.swing.JLabel createPUWarningLabel;
     private javax.swing.JCheckBox generateFinderMethodsCheckBox;
+    private javax.swing.JCheckBox generateJAXBCheckBox;
     private javax.swing.JComboBox locationComboBox;
     private javax.swing.JLabel locationLabel;
     private javax.swing.JComboBox packageComboBox;
@@ -482,6 +624,8 @@ public class EntityClassesPanel extends javax.swing.JPanel {
     private javax.swing.JTextField projectTextField;
     private javax.swing.JPanel spacerPanel;
     private javax.swing.JLabel specifyNamesLabel;
+    private javax.swing.JButton tableActionsButton;
+    private javax.swing.JPopupMenu tableActionsPopup;
     // End of variables declaration//GEN-END:variables
 
     public static final class WizardPanel implements WizardDescriptor.Panel, WizardDescriptor.FinishablePanel, ChangeListener {
@@ -495,6 +639,7 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         private Project project;
         private boolean cmp;
         private boolean puRequired;
+        private boolean JAXBRequired;
 
         private List<Provider> providers;
 
@@ -502,6 +647,11 @@ public class EntityClassesPanel extends javax.swing.JPanel {
             this(false);
         }
 
+        public WizardPanel(boolean persistenceUnitRequired, boolean JAXBRequired){
+            puRequired = persistenceUnitRequired;
+            this.JAXBRequired = JAXBRequired;
+        }
+
         public WizardPanel(boolean persistenceUnitRequired){
             puRequired = persistenceUnitRequired;
         }
@@ -509,7 +659,7 @@ public class EntityClassesPanel extends javax.swing.JPanel {
         @Override
         public EntityClassesPanel getComponent() {
             if (component == null) {
-                component = new EntityClassesPanel(puRequired);
+                component = new EntityClassesPanel(puRequired, JAXBRequired);
                 component.addChangeListener(this);
             }
             return component;
@@ -644,6 +794,8 @@ public class EntityClassesPanel extends javax.swing.JPanel {
             helper.setPackageName(getComponent().getPackageName());
             helper.setCmpFieldsInInterface(getComponent().getCmpFieldsInInterface());
             helper.setGenerateFinderMethods(getComponent().getGenerateFinderMethods());
+            helper.setGenerateJAXBAnnotations(getComponent().getGenerateJAXB());
+            helper.setGenerateValidationConstraints(getComponent().getGenerateValidationConstraints());
             helper.setCreatePU(getComponent().getCreatePersistenceUnit());
         }
 
@@ -681,4 +833,40 @@ public class EntityClassesPanel extends javax.swing.JPanel {
             return size;
         }
     }
+
+    private class AllToUpdateAction extends AbstractAction {
+
+        public AllToUpdateAction() {
+            super(NbBundle.getMessage(EntityClassesPanel.class, "LBL_UpdateAction"));
+        }
+
+        @Override
+        public void actionPerformed(ActionEvent e) {
+            for(Table table: selectedTables.getTables()){
+                if(UpdateType.RECREATE.equals(selectedTables.getUpdateType(table))){
+                    selectedTables.setUpdateType(table, UpdateType.UPDATE);
+                }
+            }
+            TableUISupport.connectClassNames(classNamesTable, selectedTables);
+            updateSetAllButtons();
+        }
+
+    }
+    private class AllToRecreateAction extends AbstractAction{
+        public AllToRecreateAction() {
+            super(NbBundle.getMessage(EntityClassesPanel.class, "LBL_RecreateAction"));
+        }
+
+        @Override
+        public void actionPerformed(ActionEvent e) {
+            for(Table table: selectedTables.getTables()){
+                if(UpdateType.UPDATE.equals(selectedTables.getUpdateType(table))){
+                    selectedTables.setUpdateType(table, UpdateType.RECREATE);
+                }
+            }
+            TableUISupport.connectClassNames(classNamesTable, selectedTables);
+            updateSetAllButtons();
+        }
+
+    }
 }
