@@ -42,8 +42,10 @@
 
 package org.netbeans.modules.j2ee.persistence.wizard.jpacontroller;
 
+import com.sun.source.tree.AnnotationTree;
 import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.CompilationUnitTree;
+import com.sun.source.tree.ExpressionTree;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -56,6 +58,7 @@ import javax.lang.model.type.DeclaredType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.Types;
+import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.api.java.source.ClasspathInfo;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.ElementHandle;
@@ -72,6 +75,7 @@ import org.netbeans.modules.j2ee.persistence.dd.PersistenceMetadata;
 import org.netbeans.modules.j2ee.persistence.dd.PersistenceUtils;
 import org.netbeans.modules.j2ee.persistence.dd.common.Persistence;
 import org.netbeans.modules.j2ee.persistence.dd.common.PersistenceUnit;
+import org.netbeans.modules.j2ee.persistence.entitygenerator.EntityClass;
 import org.netbeans.modules.j2ee.persistence.wizard.Util;
 import org.netbeans.modules.j2ee.persistence.wizard.jpacontroller.JpaControllerUtil.EmbeddedPkSupport;
 import org.openide.ErrorManager;
@@ -97,13 +101,12 @@ public class JpaControllerGenerator {
      * @param pkg
      * @param controllerFileObject
      * @param embeddedPkSupport
-     * @param managed - controller classe is expectd to be properly managed (for example by specification in faces-congic) so it will support persistence annotations
      * @throws IOException
      */
-    public static void generateJpaController(Project project, final String entityClass, final String controllerClass, String exceptionPackage, FileObject pkg, FileObject controllerFileObject, final EmbeddedPkSupport embeddedPkSupport, boolean managed) throws IOException {
-        final boolean isInjection = Util.isContainerManaged(project) && managed;
+        public static void generateJpaController(Project project, final String entityClass, final String controllerClass, String exceptionPackage, FileObject pkg, FileObject controllerFileObject, final EmbeddedPkSupport embeddedPkSupport) throws IOException {
+        final boolean isInjection = Util.isContainerManaged(project);
         final String simpleEntityName = JpaControllerUtil.simpleClassName(entityClass);
-        String persistenceUnit = getPersistenceUnitAsString(project, entityClass);
+        String persistenceUnit = Util.getPersistenceUnitAsString(project, entityClass);
         final String fieldName = JpaControllerUtil.fieldFromClassName(simpleEntityName);
 
         final List<ElementHandle<ExecutableElement>> idGetter = new ArrayList<ElementHandle<ExecutableElement>>();
@@ -121,12 +124,13 @@ public class JpaControllerGenerator {
             public void run(CompilationController controller) throws IOException {
                 controller.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
                 TypeElement jc = controller.getElements().getTypeElement(entityClass);
-                arrEntityClassFO[0] = org.netbeans.api.java.source.SourceUtils.getFile(jc, controller.getClasspathInfo());
+                ElementHandle<TypeElement> elementHandle = ElementHandle.create(jc);
+                arrEntityClassFO[0] = org.netbeans.api.java.source.SourceUtils.getFile(elementHandle, controller.getClasspathInfo());
                 fieldAccess[0] = JpaControllerUtil.isFieldAccess(jc);
                 for (ExecutableElement method : JpaControllerUtil.getEntityMethods(jc)) {
                     String methodName = method.getSimpleName().toString();
                     if (methodName.startsWith("get")) {
-                        Element f = fieldAccess[0] ? JpaControllerUtil.guessField(controller, method) : method;
+                        Element f = fieldAccess[0] ? JpaControllerUtil.guessField(method) : method;
                         if (f != null) {
                             if (JpaControllerUtil.isAnnotatedWith(f, "javax.persistence.Id") ||
                                     JpaControllerUtil.isAnnotatedWith(f, "javax.persistence.EmbeddedId")) {
@@ -156,61 +160,15 @@ public class JpaControllerGenerator {
         if (arrEntityClassFO[0] != null) {
             addImplementsClause(arrEntityClassFO[0], entityClass, "java.io.Serializable"); //NOI18N
         }
-        
+
+        ClassPath cp = Util.getFullClasspath(pkg);
+        boolean isAnnotation = cp.findResource("javax/faces/bean/ManagedBean.class") != null; //NOI18N
+
+        addImplementsClause(controllerFileObject, controllerClass, "java.io.Serializable"); //NOI18N
         controllerFileObject = generateJpaController(fieldName, pkg, idGetter.get(0), persistenceUnit, controllerClass, exceptionPackage,
                 entityClass, simpleEntityName, toOneRelMethods, toManyRelMethods, isInjection, fieldAccess[0], controllerFileObject, embeddedPkSupport, getPersistenceVersion(project));
     }
     
-    private static String getPersistenceUnitAsString(Project project, String entity) throws IOException {
-        String persistenceUnit = null;
-        PersistenceScope persistenceScopes[] = PersistenceUtils.getPersistenceScopes(project);
-        if (persistenceScopes.length > 0) {
-            FileObject persXml = persistenceScopes[0].getPersistenceXml();
-            if (persXml != null) {
-                Persistence persistence = PersistenceMetadata.getDefault().getRoot(persXml);
-                PersistenceUnit units[] = persistence.getPersistenceUnit();
-                if (units.length > 0) {
-                    persistenceUnit = units[0].getName();
-                    if(units.length>1) {//find best
-                        String forAll=null;
-                        String forOne=null;
-                        for(int i=0;i<units.length && forOne==null;i++) {
-                            PersistenceUnit tmp=units[i];
-                            if(forAll ==null && !tmp.isExcludeUnlistedClasses()) forAll=tmp.getName();//first match sutable for all entities in the project
-                            if(tmp.isExcludeUnlistedClasses()) {
-                                String []classes = tmp.getClass2();
-                                for(String clas:classes){
-                                    if(entity.equals(clas)) {
-                                        forOne = tmp.getName();
-                                        break;
-                                    }
-                                }
-                            }
-                        }
-                        //try again with less restrictions (i.e. for j2se even without exclude-unlisted-classes node, it's by default true)
-                        if(forOne==null && forAll!=null){//there is exist pu without exclude-unlisted-classes
-                            for(int i=0;i<units.length && forOne==null;i++) {
-                                PersistenceUnit tmp=units[i];
-                                if(!tmp.isExcludeUnlistedClasses()) {//verify only pu without exclude-unlisted-classes as all other was examined in previos try
-                                    String []classes = tmp.getClass2();
-                                    for(String clas:classes){
-                                        if(entity.equals(clas)) {
-                                            forOne = tmp.getName();
-                                            break;
-                                        }
-                                    }
-                                }
-                            }
-                        }
-
-                        persistenceUnit = forOne != null ? forOne : (forAll != null ? forAll : persistenceUnit);
-                    }
-                }
-            }
-        }
-        return persistenceUnit;
-    }
-
     private static String getPersistenceVersion(Project project) throws IOException {
         String version = Persistence.VERSION_1_0;
         PersistenceScope persistenceScopes[] = PersistenceUtils.getPersistenceScopes(project);
@@ -224,6 +182,37 @@ public class JpaControllerGenerator {
         return version;
     }
 
+     private static void addAnnotation(FileObject fileObject, final String className, final String annotationName, final String[] argNames, final Object[] argValues) throws IOException {
+        JavaSource javaSource = JavaSource.forFileObject(fileObject);
+        final boolean[] modified = new boolean[] { false };
+        ModificationResult modificationResult = javaSource.runModificationTask(new Task<WorkingCopy>() {
+            @Override
+            public void run(WorkingCopy workingCopy) throws Exception {
+                workingCopy.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
+                TypeElement typeElement = workingCopy.getElements().getTypeElement(className);
+                TypeMirror annotationType = workingCopy.getElements().getTypeElement(annotationName).asType();
+                if (!workingCopy.getTypes().isSubtype(typeElement.asType(), annotationType)) {
+                    ClassTree classTree = workingCopy.getTrees().getTree(typeElement);
+                    AnnotationInfo annotation = new AnnotationInfo(annotationName,argNames, argValues);
+                    GenerationUtils generationUtils = GenerationUtils.newInstance(workingCopy);
+                    List<ExpressionTree> arguments = new ArrayList<ExpressionTree>();
+                    int i = 0;
+                    if (argNames != null) {
+                        for (String arg : argNames) {
+                            arguments.add(generationUtils.createAnnotationArgument(arg, argValues[i++]));
+                        }
+                    }
+                    AnnotationTree annotationTree =  generationUtils.createAnnotation(annotation.getType(),arguments);
+                    ClassTree newClassTree = generationUtils.addAnnotation(classTree, annotationTree);
+                    modified[0] = true;
+                    workingCopy.rewrite(classTree, newClassTree);
+                }
+            }
+        });
+        if (modified[0]) {
+            modificationResult.commit();
+        }
+    }
     private static void addImplementsClause(FileObject fileObject, final String className, final String interfaceName) throws IOException {
         JavaSource javaSource = JavaSource.forFileObject(fileObject);
         final boolean[] modified = new boolean[] { false };
@@ -235,8 +224,9 @@ public class JpaControllerGenerator {
                 TypeMirror interfaceType = workingCopy.getElements().getTypeElement(interfaceName).asType();
                 if (!workingCopy.getTypes().isSubtype(typeElement.asType(), interfaceType)) {
                     ClassTree classTree = workingCopy.getTrees().getTree(typeElement);
-                    GenerationUtils.newInstance(workingCopy).addImplementsClause(classTree, interfaceName);
+                    ClassTree newClassTree = GenerationUtils.newInstance(workingCopy).addImplementsClause(classTree, interfaceName);
                     modified[0] = true;
+                    workingCopy.rewrite(classTree, newClassTree);
                 }
             }
         });
@@ -263,8 +253,11 @@ public class JpaControllerGenerator {
             final String version) throws IOException {
         
             final String[] idPropertyType = new String[1];
+            final String[] derivedIdPropertyType = new String[1];
             final String[] idGetterName = new String[1];
+            final String[] derivedIdGetterName = new String[1];
             final boolean[] embeddable = new boolean[] { false };
+            final boolean[] derived = new boolean[] {false};
             
             JavaSource controllerJavaSource = JavaSource.forFileObject(controllerFileObject);
             controllerJavaSource.runModificationTask(new Task<WorkingCopy>() {
@@ -281,6 +274,21 @@ public class JpaControllerGenerator {
                         idClass = (TypeElement) declaredType.asElement();
                         embeddable[0] = idClass != null && JpaControllerUtil.isEmbeddableClass(idClass);
                         idPropertyType[0] = idClass.getQualifiedName().toString();
+                        if(!embeddable[0] && JpaControllerUtil.haveId(idClass)){//NOI18N
+                            //handle derived id, case entity/relationship without composite keys
+                             derived[0] =  JpaControllerUtil.isRelationship(idGetterElement ,JpaControllerUtil.isFieldAccess(idClass)) != JpaControllerUtil.REL_NONE;
+                             if(derived[0]){
+                                ExecutableElement derivedIdGetterElement  = findPrimaryKeyGetter(workingCopy, idClass);
+                                derivedIdGetterName[0] = derivedIdGetterElement.getSimpleName().toString();
+                                TypeMirror derivedIdType = derivedIdGetterElement.getReturnType();
+                                TypeElement derivedIdClass = null;
+                                if (TypeKind.DECLARED == idType.getKind()) {
+                                    DeclaredType derivedDeclaredType = (DeclaredType) derivedIdType;
+                                    derivedIdClass = (TypeElement) derivedDeclaredType.asElement();
+                                    derivedIdPropertyType[0] = derivedIdClass.getQualifiedName().toString();
+                                 }
+                            }
+                        }
                     } else if (TypeKind.BOOLEAN == idType.getKind()) {
                         idPropertyType[0] = "boolean";
                     } else if (TypeKind.BYTE == idType.getKind()) {
@@ -312,23 +320,24 @@ public class JpaControllerGenerator {
                     
                     CompilationUnitTree modifiedImportCut = null;
                     
-                    AnnotationInfo[] annotations = null;
-                    if (isInjection) {
-                        annotations = new AnnotationInfo[1];
-                        annotations[0] = new AnnotationInfo("javax.annotation.Resource");
-                        modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addVariable(modifiedClassTree, workingCopy, "utx", "javax.transaction.UserTransaction", privateModifier, null, annotations);
-                        
-                        if (persistenceUnit == null) {
-                            annotations[0] = new AnnotationInfo("javax.persistence.PersistenceUnit");
-                        } else {
-                            annotations[0] = new AnnotationInfo("javax.persistence.PersistenceUnit", new String[]{"unitName"}, new Object[]{persistenceUnit});
-                        }
-                    } else {
-                        modifiedImportCut = JpaControllerUtil.TreeMakerUtils.createImport(workingCopy, modifiedImportCut, "javax.persistence.Persistence");
-                        MethodInfo mi = new MethodInfo("<init>", publicModifier, "void", null, null, null, "emf = Persistence.createEntityManagerFactory(\"" + persistenceUnit + "\");", null, null);
-                        modifiedClassTree = JpaControllerUtil.TreeMakerUtils.modifyDefaultConstructor(classTree, modifiedClassTree, workingCopy, mi);
+                    List<String> parameterTypes = new ArrayList<String>();
+                    List<String> parameterNames = new ArrayList<String>();
+                    String body = "";   //NOI18N
+                    boolean isUserTransaction = workingCopy.getClasspathInfo().getClassPath(ClasspathInfo.PathKind.COMPILE).findResource("javax/transaction/UserTransaction.class")!=null;  //NOI18N
+                    if (isUserTransaction) {
+                        modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addVariable(modifiedClassTree, workingCopy, "utx", "javax.transaction.UserTransaction", privateModifier, null, null);   //NOI18N
+                        parameterTypes.add("javax.transaction.UserTransaction");   //NOI18N
+                        parameterNames.add("utx");   //NOI18N
+                        body = "this.utx = utx;\n";   //NOI18N
+
                     }
-                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addVariable(modifiedClassTree, workingCopy, "emf", "javax.persistence.EntityManagerFactory", privateModifier, null, annotations);
+                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addVariable(modifiedClassTree, workingCopy, "emf", "javax.persistence.EntityManagerFactory", privateModifier, null, null);   //NOI18N
+                    parameterTypes.add("javax.persistence.EntityManagerFactory");   //NOI18N
+                    parameterNames.add("emf");   //NOI18N
+                    body += "this.emf = emf;";   //NOI18N
+                    MethodInfo mi = new MethodInfo("<init>", publicModifier, "void", null, parameterTypes.toArray(new String[parameterTypes.size()]),   //NOI18N
+                                                    parameterNames.toArray(new String[parameterNames.size()]), body, null, null);
+                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.modifyDefaultConstructor(classTree, modifiedClassTree, workingCopy, mi);
                     
                     MethodInfo methodInfo = new MethodInfo("getEntityManager", publicModifier, "javax.persistence.EntityManager", null, null, null, "return emf.createEntityManager();", null, null);
                     modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo);
@@ -366,13 +375,13 @@ public class JpaControllerGenerator {
                     for(Iterator<ElementHandle<ExecutableElement>> it = allRelMethods.iterator(); it.hasNext();) {
                         ElementHandle<ExecutableElement> handle = it.next();
                         ExecutableElement m = handle.resolve(workingCopy);
-                        int multiplicity = JpaControllerUtil.isRelationship(workingCopy, m, isFieldAccess);
+                        int multiplicity = JpaControllerUtil.isRelationship(m, isFieldAccess);
                         ExecutableElement otherSide = JpaControllerUtil.getOtherSideOfRelation(workingCopy, m, isFieldAccess);
 
                         if (otherSide != null) {
                             TypeElement relClass = (TypeElement)otherSide.getEnclosingElement();
                             boolean isRelFieldAccess = JpaControllerUtil.isFieldAccess(relClass);
-                            int otherSideMultiplicity = JpaControllerUtil.isRelationship(workingCopy, otherSide, isRelFieldAccess);
+                            int otherSideMultiplicity = JpaControllerUtil.isRelationship(otherSide, isRelFieldAccess);
                             TypeMirror t = m.getReturnType();
                             Types types = workingCopy.getTypes();
                             TypeMirror tstripped = JpaControllerUtil.stripCollection(t, types);
@@ -403,11 +412,12 @@ public class JpaControllerGenerator {
                             String relTypeReference = simpleRelType;
                             String mName = m.getSimpleName().toString();
                             String otherName = otherSide.getSimpleName().toString();
+                            String otherType = otherSide.getReturnType().toString();
                             String relFieldName = JpaControllerUtil.getPropNameFromMethod(mName);
                             String otherFieldName = JpaControllerUtil.getPropNameFromMethod(otherName);
                             
-                            boolean columnNullable = JpaControllerUtil.isFieldOptionalAndNullable(workingCopy, m, isFieldAccess);
-                            boolean relColumnNullable = JpaControllerUtil.isFieldOptionalAndNullable(workingCopy, otherSide, isFieldAccess);
+                            boolean columnNullable = JpaControllerUtil.isFieldOptionalAndNullable(m, isFieldAccess);
+                            boolean relColumnNullable = JpaControllerUtil.isFieldOptionalAndNullable(otherSide, isFieldAccess);
                             
                             String relFieldToAttach = isCollection ? relFieldName + relTypeReference + "ToAttach" : relFieldName;
                             String scalarRelFieldName = isCollection ? relFieldName + relTypeReference : relFieldName;
@@ -420,10 +430,11 @@ public class JpaControllerGenerator {
                                 modifiedImportCut = JpaControllerUtil.TreeMakerUtils.createImport(workingCopy, modifiedImportCut, relType);
                             }
                             
-                            ExecutableElement relIdGetterElement = JpaControllerUtil.getIdGetter(workingCopy, isFieldAccess, relClass);
-                            String refOrMergeString = getRefOrMergeString(relIdGetterElement, relFieldToAttach);
+                            ExecutableElement relIdGetterElement = JpaControllerUtil.getIdGetter(isFieldAccess, relClass);
+                            String refOrMergeString = null;
                             
                             if (isCollection) {
+                                refOrMergeString = getRefOrMergeString(relIdGetterElement, relFieldToAttach);
                                 initCollectionsInCreate.append("if (" + fieldName + "." + mName + "() == null) {\n" +
                                         fieldName + ".s" + mName.substring(1) + "(new " + simpleCollectionImplementationTypeName + "<" + relTypeReference + ">());\n" +
                                         "}\n");
@@ -440,6 +451,7 @@ public class JpaControllerGenerator {
                                         );
                             }
                             else {
+                                refOrMergeString = getRefOrMergeString(relIdGetterElement, scalarRelFieldName);
                                 initRelatedInCreate.append(relTypeReference + " " + scalarRelFieldName + " = " + fieldName + "." + mName +"();\n" +
                                     "if (" + scalarRelFieldName + " != null) {\n" +
                                     scalarRelFieldName + " = " + refOrMergeString +
@@ -469,7 +481,11 @@ public class JpaControllerGenerator {
                                                             //if 1:1, be sure to orphan the related entity's current related entity
                             if (otherSideMultiplicity == JpaControllerUtil.REL_TO_ONE){
                                 if (multiplicity != JpaControllerUtil.REL_TO_ONE || columnNullable) { //no need to declare relrelInstanceName if we have already examined it in the 1:1 orphan check
-                                    updateRelatedInCreate.append(simpleEntityName + " " + relrelInstanceName + " = " + scalarRelFieldName + "." + relrelGetterName + "();\n");
+                                    String retType = simpleEntityName;
+                                    if(!otherType.equals(entityClass)){
+                                        retType = otherType;
+                                    }
+                                    updateRelatedInCreate.append(retType + " " + relrelInstanceName + " = " + scalarRelFieldName + "." + relrelGetterName + "();\n");
                                 }
                                 if (multiplicity == JpaControllerUtil.REL_TO_ONE) {
                                     if (columnNullable) {
@@ -591,7 +607,11 @@ public class JpaControllerGenerator {
                                 updateRelatedInEditPost.append(
                                     "if(" + scalarRelFieldName + "New != null && !" + scalarRelFieldName + "New.equals(" + scalarRelFieldName + "Old)) {\n");
                                 if (multiplicity == JpaControllerUtil.REL_TO_ONE && otherSideMultiplicity == JpaControllerUtil.REL_TO_ONE && columnNullable) {
-                                    updateRelatedInEditPost.append(simpleEntityName + " " + relrelInstanceName + " = " + scalarRelFieldName + "New." + relrelGetterName + "();\n" + 
+                                    String tmpType = simpleEntityName;
+                                    if(!otherType.equals(entityClass)){
+                                        tmpType = otherType;
+                                    }
+                                    updateRelatedInEditPost.append(tmpType + " " + relrelInstanceName + " = " + scalarRelFieldName + "New." + relrelGetterName + "();\n" +
                                             "if (" + relrelInstanceName + " != null) {\n" + 
                                             relrelInstanceName + ".s" + mName.substring(1) + "(null);\n" + 
                                             relrelInstanceName + " = em.merge(" + relrelInstanceName + ");\n" + 
@@ -663,15 +683,15 @@ public class JpaControllerGenerator {
                     TypeElement entityType = workingCopy.getElements().getTypeElement(entityClass);
                     StringBuffer codeToPopulatePkFields = new StringBuffer();
                     if (embeddable[0]) {
-                        for (ExecutableElement pkMethod : embeddedPkSupport.getPkAccessorMethods(workingCopy, entityType)) {
-                            if (embeddedPkSupport.isRedundantWithRelationshipField(workingCopy, entityType, pkMethod)) {
+                        for (ExecutableElement pkMethod : embeddedPkSupport.getPkAccessorMethods(entityType)) {
+                            if (embeddedPkSupport.isRedundantWithRelationshipField(entityType, pkMethod)) {
                                 codeToPopulatePkFields.append(fieldName + "." +idGetterName[0] + "().s" + pkMethod.getSimpleName().toString().substring(1) + "(" +  //NOI18N
-                                    fieldName + "." + embeddedPkSupport.getCodeToPopulatePkField(workingCopy, entityType, pkMethod) + ");\n");
+                                    fieldName + "." + embeddedPkSupport.getCodeToPopulatePkField(entityType, pkMethod) + ");\n");
                             }
                         }
                     }
                     
-                    boolean isGenerated = JpaControllerUtil.isGenerated(workingCopy, idGetterElement, isFieldAccess);
+                    boolean isGenerated = JpaControllerUtil.isGenerated(idGetterElement, isFieldAccess);
                     bodyText = (embeddable[0] ? "if (" + fieldName + "." + idGetterName[0] + "() == null) {\n" +
                             fieldName + ".s" + idGetterName[0].substring(1) + "(new " + idClass.getSimpleName() + "());\n" + 
                             "}\n" : "") +
@@ -780,8 +800,17 @@ public class JpaControllerGenerator {
                         methodExceptionTypeList.add("java.lang.Exception");
                     }
                     String[] destroyExceptionTypes = methodExceptionTypeList.toArray(new String[methodExceptionTypeList.size()]);
-                    methodInfo = new MethodInfo("destroy", publicModifier, "void", destroyExceptionTypes, idPropertyType, new String[]{"id"}, bodyText, null, null);
-                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo);  
+                    String[] findDestroyType = derived[0] && derivedIdPropertyType[0]!=null ? derivedIdPropertyType : idPropertyType;
+                    methodInfo = new MethodInfo("destroy", publicModifier, "void", destroyExceptionTypes, findDestroyType, new String[]{"id"}, bodyText, null, null);
+                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo);
+
+                    //secondary destroy with derived type (entity type id)
+                    if(derived[0] && derivedIdPropertyType[0]!=null && !derivedIdPropertyType[0].equals(idPropertyType[0])){
+                        bodyText = "destroy( id." + derivedIdGetterName[0] + "() );";
+                        methodInfo = new MethodInfo("destroy", publicModifier, "void", destroyExceptionTypes, idPropertyType, new String[]{"id"}, bodyText, null, null);
+                        modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo);
+                    }
+                    //
                     
                     TypeInfo listOfEntityType = new TypeInfo("java.util.List", new String[]{entityClass});
                     
@@ -817,9 +846,16 @@ public class JpaControllerGenerator {
                     bodyText = "EntityManager em = getEntityManager();\n try{\n" + 
                         "return em.find(" + simpleEntityName + ".class, id);\n" + 
                         "} finally {\n em.close();\n}\n";
-                    methodInfo = new MethodInfo("find" + simpleEntityName, publicModifier, entityClass, null, idPropertyType, new String[]{"id"}, bodyText, null, null);
-                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo); 
-                    
+                    methodInfo = new MethodInfo("find" + simpleEntityName, publicModifier, entityClass, null, findDestroyType, new String[]{"id"}, bodyText, null, null);
+                    modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo);
+
+                    //secondary find with derived type (entity type id), first one above is with derived (i.e. column) type.
+                    if(derived[0] && derivedIdPropertyType[0]!=null && !derivedIdPropertyType[0].equals(idPropertyType[0])){
+                        bodyText = "return find" + simpleEntityName + "( id." + derivedIdGetterName[0] + "() );";
+                        methodInfo = new MethodInfo("find" + simpleEntityName, publicModifier, entityClass, null, idPropertyType, new String[]{"id"}, bodyText, null, null);
+                        modifiedClassTree = JpaControllerUtil.TreeMakerUtils.addMethod(modifiedClassTree, workingCopy, methodInfo); 
+                    }
+
                     bodyText = "EntityManager em = getEntityManager();\n try{\n" + 
                         (
                         Persistence.VERSION_2_0.equals(version) ?
@@ -852,5 +888,26 @@ public class JpaControllerGenerator {
         }
         return refOrMergeString;
     }
+    private static ExecutableElement findPrimaryKeyGetter(CompilationController controller, TypeElement bean) {
+        ExecutableElement[] methods = JpaControllerUtil.getEntityMethods(bean);
+        boolean isField = JpaControllerUtil.isFieldAccess(bean);
+        for (ExecutableElement method : methods) {
+            if (method.getSimpleName().toString().startsWith("get")) {//NOI18N
+                if (isId(method, isField)) {
+                    return method;
+                }
+            }
+        }
+        return null;
+    }
+    static boolean isId(ExecutableElement method, boolean isFieldAccess) {
+        Element element = isFieldAccess ? JpaControllerUtil.guessField(method) : method;
+        if (element != null) {
+            if (JpaControllerUtil.isAnnotatedWith(element, "javax.persistence.Id") || JpaControllerUtil.isAnnotatedWith(element, "javax.persistence.EmbeddedId")) { // NOI18N
+                return true;
+            }
+        }
+        return false;
+    }
 }
 
