@@ -126,7 +126,7 @@ public class JpaControllerIterator implements TemplateWizard.Iterator {
                     handle.start();
                     int progressStepCount = getProgressStepCount(entities.size());
                     progressContributor.start(progressStepCount);
-                    generateJpaControllers(progressContributor, progressPanel, entities, project, jpaControllerPackage, jpaControllerPackageFileObject, null, false, true);
+                    generateJpaControllers(progressContributor, progressPanel, entities, project, jpaControllerPackage, jpaControllerPackageFileObject, null, true);
                     progressContributor.progress(progressStepCount);
                 } catch (IOException ioe) {
                     Logger.getLogger(JpaControllerIterator.class.getName()).log(Level.INFO, null, ioe);
@@ -182,7 +182,7 @@ public class JpaControllerIterator implements TemplateWizard.Iterator {
         return EXCEPTION_CLASS_NAMES.length + entityCount + 2;
     }
 
-    public static FileObject[] generateJpaControllers(ProgressContributor progressContributor, ProgressPanel progressPanel, List<String> entities, Project project, String jpaControllerPackage, FileObject jpaControllerPackageFileObject, JpaControllerUtil.EmbeddedPkSupport embeddedPkSupport, boolean managed, boolean evenIfExists) throws IOException {
+    public static FileObject[] generateJpaControllers(ProgressContributor progressContributor, ProgressPanel progressPanel, List<String> entities, Project project, String jpaControllerPackage, FileObject jpaControllerPackageFileObject, JpaControllerUtil.EmbeddedPkSupport embeddedPkSupport, boolean evenIfExists) throws IOException {
         int progressIndex = 0;
         String progressMsg = NbBundle.getMessage(JpaControllerIterator.class, "MSG_Progress_Jpa_Exception_Pre"); //NOI18N
         progressContributor.progress(progressMsg, progressIndex++);
@@ -252,7 +252,7 @@ public class JpaControllerIterator implements TemplateWizard.Iterator {
             progressContributor.progress(progressMsg, progressIndex++);
             progressPanel.setText(progressMsg);
 
-            JpaControllerGenerator.generateJpaController(project, entityClass, controller, exceptionPackage, jpaControllerPackageFileObject, controllerFileObjects[i], embeddedPkSupport, managed);
+            JpaControllerGenerator.generateJpaController(project, entityClass, controller, exceptionPackage, jpaControllerPackageFileObject, controllerFileObjects[i], embeddedPkSupport);
         }
         PersistenceUtils.logUsage(JpaControllerIterator.class, "USG_PERSISTENCE_CONTROLLER_CREATED", new Integer[]{controllerFileObjects.length});
         return controllerFileObjects;
@@ -363,18 +363,5 @@ public class JpaControllerIterator implements TemplateWizard.Iterator {
         private ValidationPanel(WizardDescriptor.Panel delegate) {
             super(delegate);
         }
-//        public boolean isValid() {
-//            Project project = getProject();
-//            WizardDescriptor wizardDescriptor = getWizardDescriptor();
-//            
-////            // check that this project has a valid target server
-////            if (!org.netbeans.modules.j2ee.common.Util.isValidServerInstance(project)) {
-////                wizardDescriptor.putProperty("WizardPanel_errorMessage",
-////                        NbBundle.getMessage(JpaControllerIterator.class, "ERR_MissingServer")); // NOI18N
-////                return false;
-////            }
-//
-//            return super.isValid();
-//        }
     }
 }
