@@ -70,7 +70,6 @@ import javax.swing.Icon;
 import javax.swing.ImageIcon;
 import javax.swing.JFileChooser;
 import javax.swing.JOptionPane;
-import javax.swing.SwingUtilities;
 import javax.swing.filechooser.FileFilter;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
@@ -152,26 +151,32 @@ public final class LibrariesNode extends AbstractNode {
         this.librariesNodeActions = librariesNodeActions;
     }
 
+    @Override
     public String getDisplayName () {
         return this.displayName; 
     }
 
+    @Override
     public String getName () {
         return this.getDisplayName();
     }    
 
+    @Override
     public Image getIcon( int type ) {        
         return computeIcon( false, type );
     }
         
+    @Override
     public Image getOpenedIcon( int type ) {
         return computeIcon( true, type );
     }
 
+    @Override
     public Action[] getActions(boolean context) {        
         return this.librariesNodeActions;
     }
 
+    @Override
     public boolean canCopy() {
         return false;
     }
@@ -275,6 +280,7 @@ public final class LibrariesNode extends AbstractNode {
             this.project = project;
         }
 
+        @Override
         public void propertyChange(PropertyChangeEvent evt) {
             String propName = evt.getPropertyName();
             final boolean propRoots = ClassPath.PROP_ROOTS.equals(propName);
@@ -285,6 +291,7 @@ public final class LibrariesNode extends AbstractNode {
                     }
                 }
                 rp.post (new Runnable () {
+                    @Override
                     public void run () {
                         setKeys(getKeys());
                         if (propRoots) {
@@ -298,6 +305,7 @@ public final class LibrariesNode extends AbstractNode {
             }
         }
 
+        @Override
         protected void addNotify() {
             this.eval.addPropertyChangeListener (this);
             if (refHelper.getProjectLibraryManager() != null) {
@@ -308,6 +316,7 @@ public final class LibrariesNode extends AbstractNode {
             this.setKeys(getKeys ());
         }
 
+        @Override
         protected void removeNotify() {
             this.eval.removePropertyChangeListener(this);
             if (refHelper.getProjectLibraryManager() != null) {
@@ -324,6 +333,7 @@ public final class LibrariesNode extends AbstractNode {
             this.setKeys(Collections.<Key>emptySet());
         }
 
+        @Override
         protected Node[] createNodes(Key key) {
             Node[] result = null;
             switch (key.getType()) {
@@ -335,7 +345,15 @@ public final class LibrariesNode extends AbstractNode {
                         key.getEntryId(), webModuleElementName, cs, refHelper)};
                     break;
                 case Key.TYPE_LIBRARY:
-                    result = new Node[] {ActionFilterNode.create(PackageView.createPackageView(key.getSourceGroup()),
+                    result = new Node[] {ActionFilterNode.forLibrary(PackageView.createPackageView(key.getSourceGroup()),
+                        helper, key.getClassPathId(), key.getEntryId(), webModuleElementName, cs, refHelper)};
+                    break;
+                case Key.TYPE_FILE_REFERENCE:
+                    result = new Node[] {ActionFilterNode.forArchive(PackageView.createPackageView(key.getSourceGroup()),
+                        helper, eval, key.getClassPathId(), key.getEntryId(), webModuleElementName, cs, refHelper)};
+                    break;
+                case Key.TYPE_FILE:
+                    result = new Node[] {ActionFilterNode.forRoot(PackageView.createPackageView(key.getSourceGroup()),
                         helper, key.getClassPathId(), key.getEntryId(), webModuleElementName, cs, refHelper)};
                     break;
                 case Key.TYPE_OTHER:
@@ -356,7 +374,7 @@ public final class LibrariesNode extends AbstractNode {
             List<URL> rootsList = new ArrayList<URL>();
             List<Key> result = getKeys (projectSharedProps, projectPrivateProps, privateProps, classPathProperty, rootsList);
             if (platformProperty!=null) {
-                result.add (new Key());
+                result.add (Key.platform());
             }
             //XXX: Workaround: Remove this when there will be API for listening on nonexistent files
             // See issue: http://www.netbeans.org/issues/show_bug.cgi?id=33162
@@ -422,7 +440,7 @@ public final class LibrariesNode extends AbstractNode {
                                     NbBundle.getMessage (LibrariesNode.class,"TXT_LibraryPartFormat"),
                                     new Object[] {lib.getDisplayName(), displayName});
                                 SourceGroup sg = new LibrariesSourceGroup (root, displayName, libIcon, libIcon);
-                                result.add (new Key(sg,currentClassPath, propName));
+                                result.add (Key.library(sg,currentClassPath, propName));
                             }
                         }
                     }
@@ -434,7 +452,7 @@ public final class LibrariesNode extends AbstractNode {
                     if (ref[0] != null && ref[1] != null) {
                         AntArtifact artifact = (AntArtifact)ref[0];
                         URI uri = (URI)ref[1];
-                        result.add(new Key(artifact, uri, currentClassPath, propName));                 
+                        result.add(Key.project(artifact, uri, currentClassPath, propName));
                     }
                 }
                 else if (prop.startsWith(FILE_REF_PREFIX)) {
@@ -444,7 +462,7 @@ public final class LibrariesNode extends AbstractNode {
                         File file = helper.getAntProjectHelper().resolveFile(evaluatedRef);
                         SourceGroup sg = createFileSourceGroup(file,rootsList);
                         if (sg !=null) {
-                            result.add (new Key(sg,currentClassPath, propName));
+                            result.add (Key.fileReference(sg,currentClassPath, propName));
                         }
                     }
                 }
@@ -457,7 +475,7 @@ public final class LibrariesNode extends AbstractNode {
                     File file = helper.getAntProjectHelper().resolveFile(prop);
                     SourceGroup sg = createFileSourceGroup(file,rootsList);
                     if (sg !=null) {
-                        result.add ( new Key(sg,currentClassPath, propName));
+                        result.add (Key.file(sg,currentClassPath, propName));
                     }
                 }
             }
@@ -490,11 +508,15 @@ public final class LibrariesNode extends AbstractNode {
         }        
     }
 
+    //XXX: Leaking of implementation, should be pkg private
+    //the reason why it's public is wrongly designed Callback interface
     public static final class Key {
-        static final int TYPE_PLATFORM = 0;
-        static final int TYPE_LIBRARY = 1;
-        static final int TYPE_PROJECT = 2;
-        static final int TYPE_OTHER = 3;
+        static final int TYPE_PLATFORM = 0;         //platform
+        static final int TYPE_LIBRARY = 1;          //library
+        static final int TYPE_FILE_REFERENCE = 2;   //file added by ReferenceHelper ${reference.
+        static final int TYPE_PROJECT = 3;          //project
+        static final int TYPE_OTHER = 4;            //extension provided by Callback
+        static final int TYPE_FILE = 5;             //direct file not added by ReferenceHelper
 
         private int type;
         private String classPathId;
@@ -503,9 +525,26 @@ public final class LibrariesNode extends AbstractNode {
         private AntArtifact antArtifact;
         private URI uri;
         private String anID;
+                
+
+        private static Key platform() {
+            return new Key();
+        }
         
-        Key () {
-            type = TYPE_PLATFORM;
+        private static Key project(AntArtifact a, URI uri, String classPathId, String entryId) {
+            return new Key(a, uri, classPathId, entryId);
+        }
+        
+        private static Key library(SourceGroup sg, String classPathId, String entryId) {
+            return new Key(TYPE_LIBRARY, sg, classPathId, entryId);
+        }
+        
+        private static Key fileReference(SourceGroup sg, String classPathId, String entryId) {
+            return new Key(TYPE_FILE_REFERENCE, sg, classPathId, entryId);
+        }
+
+        private static Key file(SourceGroup sg, String classPathId, String entryId) {
+            return new Key(TYPE_FILE, sg, classPathId, entryId);
         }
 
         public Key (String anID) {
@@ -514,14 +553,19 @@ public final class LibrariesNode extends AbstractNode {
 
         }
 
-        Key (SourceGroup sg, String classPathId, String entryId) {
-            this.type = TYPE_LIBRARY;
+        private Key () {
+            type = TYPE_PLATFORM;
+        }
+
+        private Key (int type, SourceGroup sg, String classPathId, String entryId) {
+            assert type == TYPE_LIBRARY || type == TYPE_FILE_REFERENCE || type == TYPE_FILE;
+            this.type = type;
             this.sg = sg;
             this.classPathId = classPathId;
             this.entryId = entryId;
         }
 
-        Key (AntArtifact a, URI uri, String classPathId, String entryId) {
+        private Key (AntArtifact a, URI uri, String classPathId, String entryId) {
             this.type = TYPE_PROJECT;
             this.antArtifact = a;
             this.uri = uri;
@@ -558,10 +602,13 @@ public final class LibrariesNode extends AbstractNode {
         }
 
         
+        @Override
         public int hashCode() {
             int hashCode = this.type<<16;
             switch (this.type) {
                 case TYPE_LIBRARY:
+                case TYPE_FILE_REFERENCE:
+                case TYPE_FILE:
                     hashCode ^= this.sg == null ? 0 : this.sg.hashCode();
                     break;
                 case TYPE_PROJECT:
@@ -573,6 +620,7 @@ public final class LibrariesNode extends AbstractNode {
             return hashCode;
         }
 
+        @Override
         public boolean equals(Object obj) {
             if (!(obj instanceof Key)) {
                 return false;
@@ -583,6 +631,8 @@ public final class LibrariesNode extends AbstractNode {
             }
             switch (type) {
                 case TYPE_LIBRARY:
+                case TYPE_FILE_REFERENCE:
+                case TYPE_FILE:
                     return (this.sg == null ? other.sg == null : this.sg.equals(other.sg)) &&
                         (this.classPathId == null ? other.classPathId == null : this.classPathId.equals (other.classPathId)) &&
                         (this.entryId == null ? other.entryId == null : this.entryId.equals (other.entryId));
@@ -611,6 +661,7 @@ public final class LibrariesNode extends AbstractNode {
             this.sources = sources;
         }
 
+        @Override
         public void actionPerformed(ActionEvent e) {
             AntArtifactItem ai[] = AntArtifactItem.showAntArtifactItemChooser(
                     new String[] {JavaProjectConstants.ARTIFACT_TYPE_JAR, JavaProjectConstants.ARTIFACT_TYPE_FOLDER},
@@ -659,6 +710,7 @@ public final class LibrariesNode extends AbstractNode {
             this.filter = filter;
         }
 
+        @Override
         public void actionPerformed(ActionEvent e) {
             Set<Library> added = LibraryChooser.showDialog(
                     refHelper.getProjectLibraryManager(), filter,
@@ -700,6 +752,7 @@ public final class LibrariesNode extends AbstractNode {
             this.sources = sources;
         }
 
+        @Override
         public void actionPerformed(ActionEvent e) {
             org.netbeans.api.project.ant.FileChooser chooser;
             if (helper.isSharableProject()) {
@@ -745,14 +798,15 @@ public final class LibrariesNode extends AbstractNode {
             if (roots.length == 0) {
                 return;
             }
-            final FileObject projectSourcesArtifact = roots[0];
-            for (int i=0; i<filePaths.length;i++) {
-                try {
+            try {
+                final FileObject projectSourcesArtifact = roots[0];
+                final List<URI> toAdd = new ArrayList<URI>(filePaths.length);            
+                for (int i=0; i<filePaths.length;i++) {
                     //Check if the file is acceted by the FileFilter,
                     //user may enter the name of non displayed file into JFileChooser
                     File fl = PropertyUtils.resolveFile(base, filePaths[i]);
                     FileObject fo = FileUtil.toFileObject(fl);
-                    assert fo != null : fl;
+                    assert fo != null || !fl.canRead(): fl;
                     if (fo != null && fileFilter.accept(fl)) {
                         URI u;
                         boolean isArchiveFile = FileUtil.isArchiveFile(fo);
@@ -792,14 +846,19 @@ public final class LibrariesNode extends AbstractNode {
                                 throw new AssertionError(ex);
                             }
                         }
-                        Project prj = FileOwnerQuery.getOwner(helper.getProjectDirectory());
-                        ClassPathModifier modifierImpl = prj.getLookup().lookup(ClassPathModifier.class);
-                        assert modifierImpl != null : prj.getProjectDirectory();
-                        modifierImpl.addRoots(new URI[]{u}, findSourceGroup(projectSourcesArtifact, modifierImpl), ClassPath.COMPILE, ClassPathModifier.ADD_NO_HEURISTICS);
-                    }
-                } catch (IOException ioe) {
-                    Exceptions.printStackTrace(ioe);
+                        assert u != null;
+                        toAdd.add(u);
+                    }                    
                 }
+                final Project prj = FileOwnerQuery.getOwner(helper.getProjectDirectory());
+                final ClassPathModifier modifierImpl = prj.getLookup().lookup(ClassPathModifier.class);
+                assert modifierImpl != null : prj.getProjectDirectory();
+                modifierImpl.addRoots(toAdd.toArray(new URI[toAdd.size()]),
+                    findSourceGroup(projectSourcesArtifact, modifierImpl),
+                    ClassPath.COMPILE,
+                    ClassPathModifier.ADD_NO_HEURISTICS);
+            } catch (IOException ioe) {
+                Exceptions.printStackTrace(ioe);
             }
         }
 
@@ -828,6 +887,7 @@ public final class LibrariesNode extends AbstractNode {
             this.extensions.addAll(FileUtil.getMIMETypeExtensions("application/x-java-archive"));    //NOI18N
         }
 
+        @Override
         public boolean accept(final File f) {
             if (f.isDirectory()) {
                 return true;
@@ -851,6 +911,7 @@ public final class LibrariesNode extends AbstractNode {
             return false;
         }
 
+        @Override
         public String getDescription() {
             return this.description;
         }
