@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -52,6 +55,8 @@ import org.netbeans.api.project.Project;
 
 
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicBoolean;
+import org.netbeans.api.progress.ProgressUtils;
 import org.netbeans.api.project.ProjectManager;
 import org.openide.util.Exceptions;
 
@@ -93,29 +98,40 @@ final class RemoveClassPathRootAction extends NodeAction {
     }
 
     protected void performAction(final Node[] activatedNodes) {
-        final Set<Project> changedProjectsSet = new HashSet<Project>();
-        
-        ProjectManager.mutex().writeAccess(new Runnable() {
+        assert !(ProjectManager.mutex().isReadAccess() || ProjectManager.mutex().isReadAccess());   //Prevent to deadlock
+        final AtomicBoolean cancel = new AtomicBoolean();
+
+        final Runnable action = new Runnable() {
             public void run() {
-                for (int i = 0; i < activatedNodes.length; i++) {
-                    Removable removable = activatedNodes[i].getLookup().lookup(Removable.class);
-                    if (removable == null)
-                        continue;
-                    
-                    Project p = removable.remove();
-                    if (p != null)
-                        changedProjectsSet.add(p);
-                }
-                
-                for (Project p : changedProjectsSet) {
-                    try {
-                        ProjectManager.getDefault().saveProject(p);
-                    } catch (IOException e) {
-                        Exceptions.printStackTrace(e);
+                ProjectManager.mutex().writeAccess(new Runnable() {
+                    public void run() {
+                        if (cancel.get()) {
+                            return;
+                        }
+                        final Set<Project> changedProjectsSet = new HashSet<Project>();
+                        for (int i = 0; i < activatedNodes.length; i++) {
+                            Removable removable = activatedNodes[i].getLookup().lookup(Removable.class);
+                            if (removable == null)
+                                continue;
+
+                            Project p = removable.remove();
+                            if (p != null)
+                                changedProjectsSet.add(p);
+                        }
+
+                        for (Project p : changedProjectsSet) {
+                            try {
+                                ProjectManager.getDefault().saveProject(p);
+                            } catch (IOException e) {
+                                Exceptions.printStackTrace(e);
+                            }
+                        }
                     }
-                }
+                });
             }
-        });
+        };
+
+        ProgressUtils.runOffEventDispatchThread(action, NbBundle.getMessage(RemoveClassPathRootAction.class, "TXT_RemovingClassPathRoots"), cancel, true);
     }
 
     protected boolean enable(Node[] activatedNodes) {
