@@ -452,6 +452,9 @@ public final class FolderList extends javax.swing.JPanel {
 
     private static class Renderer extends DefaultListCellRenderer {
         public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
+            if (" ".equals(value)) { // NOI18N
+                return super.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
+            }
             File f = (File) value;
             String message = f.getAbsolutePath();
             Component result = super.getListCellRendererComponent(list, message, index, isSelected, cellHasFocus);
