@@ -42,21 +42,33 @@
 
 package org.netbeans.modules.java.api.common.queries;
 
+import javax.swing.Icon;
+import org.netbeans.api.annotations.common.NonNull;
+import org.netbeans.api.annotations.common.NullAllowed;
+import org.netbeans.api.project.Sources;
 import org.netbeans.modules.java.api.common.SourceRoots;
 import org.netbeans.api.java.queries.AnnotationProcessingQuery.Result;
+import org.netbeans.api.project.Project;
+import org.netbeans.api.project.ProjectInformation;
+import org.netbeans.modules.java.api.common.Roots;
+import org.netbeans.modules.java.api.common.ant.UpdateHelper;
 import org.netbeans.spi.java.queries.AnnotationProcessingQueryImplementation;
 import org.netbeans.spi.java.queries.BinaryForSourceQueryImplementation;
 import org.netbeans.spi.java.queries.JavadocForBinaryQueryImplementation;
 import org.netbeans.spi.java.queries.MultipleRootsUnitTestForSourceQueryImplementation;
 import org.netbeans.spi.java.queries.SourceForBinaryQueryImplementation;
-import org.netbeans.spi.java.queries.SourceLevelQueryImplementation;
+import org.netbeans.spi.java.queries.SourceLevelQueryImplementation2;
+import org.netbeans.spi.project.SourceGroupModifierImplementation;
 import org.netbeans.spi.project.support.ant.AntProjectHelper;
+import org.netbeans.spi.project.support.ant.AntProjectListener;
 import org.netbeans.spi.project.support.ant.PropertyEvaluator;
 import org.netbeans.spi.queries.FileBuiltQueryImplementation;
 import org.netbeans.spi.queries.FileEncodingQueryImplementation;
 import org.netbeans.spi.queries.SharabilityQueryImplementation;
 import org.openide.loaders.CreateFromTemplateAttributesProvider;
 import org.openide.util.Parameters;
+import org.openide.util.WeakListeners;
+import org.w3c.dom.Element;
 
 /**
  * Support class for creating different types of queries implementations.
@@ -89,20 +101,29 @@ public final class QuerySupport {
      * @param helper {@link AntProjectHelper} used for resolving files, e.g. output directory.
      * @param evaluator {@link PropertyEvaluator} used for obtaining project properties.
      * @param srcRoots a list of source roots.
-     * @param testRoots a list of test roots.
+     * @param testRoots a list of test roots, may be null if the project does not support tests.
      * @param binaryProperties array of property names of binary artifacts produced by this project, e.g. dist.jar
      * @param testBinaryProperties array of property names of test binary artifacts produced by this project, e.g. build.test.classes.dir
+     * If the testRoots parameter is null this parameter has to be null as well.
      * @return {@link SourceForBinaryQueryImplementation} to provide information about where Java sources can be found.
      * @see SourceForBinaryQueryImplementation
      * @since org.netbeans.modules.java.api.common/0 1.3
      */
-    public static SourceForBinaryQueryImplementation createCompiledSourceForBinaryQuery(AntProjectHelper helper,
-            PropertyEvaluator evaluator, SourceRoots srcRoots, SourceRoots testRoots, String[] binaryProperties, String[] testBinaryProperties) {
+    public static SourceForBinaryQueryImplementation createCompiledSourceForBinaryQuery(
+            @NonNull AntProjectHelper helper,
+            @NonNull PropertyEvaluator evaluator,
+            @NonNull SourceRoots srcRoots,
+            @NullAllowed SourceRoots testRoots,
+            @NonNull String[] binaryProperties,
+            @NullAllowed String[] testBinaryProperties) {
         Parameters.notNull("helper", helper); // NOI18N
         Parameters.notNull("evaluator", evaluator); // NOI18N
         Parameters.notNull("srcRoots", srcRoots); // NOI18N
         Parameters.notNull("binaryProperties", binaryProperties); // NOI18N
-
+        final boolean validTestParams = testRoots == null ? testBinaryProperties == null : testBinaryProperties != null;
+        if (!validTestParams) {
+            throw new IllegalArgumentException("Both testRoots and testBinaryProperties have to be null or non null");  //NOI18N
+        }
         return new CompiledSourceForBinaryQueryImpl(helper, evaluator, srcRoots, testRoots, binaryProperties, testBinaryProperties);
     }
 
@@ -156,18 +177,20 @@ public final class QuerySupport {
      * @param helper {@link AntProjectHelper} used for creating a query itself.
      * @param evaluator a {@link PropertyEvaluator property evaluator} to interpret paths with.
      * @param srcRoots a list of source roots to treat as sharable.
-     * @param testRoots a list of test roots to treat as sharable.
+     * @param testRoots a list of test roots to treat as sharable, may be null if the project does not support tests
      * @param additionalSourceRoots additional paths to treat as sharable (just pure property names, do not
      *          use <i>${</i> and <i>}</i> characters). Can be <code>null</code>.
      * @return a {@link SharabilityQueryImplementation} to provide information about files sharability.
      */
-    public static SharabilityQueryImplementation createSharabilityQuery(AntProjectHelper helper,
-            PropertyEvaluator evaluator, SourceRoots srcRoots, SourceRoots testRoots,
-            String... additionalSourceRoots) {
+    public static SharabilityQueryImplementation createSharabilityQuery(
+            final @NonNull AntProjectHelper helper,
+            final @NonNull PropertyEvaluator evaluator,
+            final @NonNull SourceRoots srcRoots,
+            final @NullAllowed SourceRoots testRoots,
+            final @NullAllowed String... additionalSourceRoots) {
         Parameters.notNull("helper", helper); // NOI18N
         Parameters.notNull("evaluator", evaluator); // NOI18N
         Parameters.notNull("srcRoots", srcRoots); // NOI18N
-        Parameters.notNull("testRoots", testRoots); // NOI18N
 
         return new SharabilityQueryImpl(helper, evaluator, srcRoots, testRoots, additionalSourceRoots);
     }
@@ -188,13 +211,26 @@ public final class QuerySupport {
      * Create a new query to find out specification source level of Java source files.
      * @param evaluator {@link PropertyEvaluator} used for obtaining needed properties.
      * @return a {@link SourceLevelQueryImplementation} to find out specification source level of Java source files.
+     * @deprecated Use {@link QuerySupport#createSourceLevelQuery(org.netbeans.spi.project.support.ant.PropertyEvaluator)}
      */
-    public static SourceLevelQueryImplementation createSourceLevelQuery(PropertyEvaluator evaluator) {
+    @Deprecated
+    public static org.netbeans.spi.java.queries.SourceLevelQueryImplementation createSourceLevelQuery(PropertyEvaluator evaluator) {
         Parameters.notNull("evaluator", evaluator); // NOI18N
 
         return new SourceLevelQueryImpl(evaluator);
     }
 
+    /**
+     * Create a new query to find out source level of Java source files (SourceLevelQueryImplementation2).
+     * @param evaluator {@link PropertyEvaluator} used for obtaining needed properties.
+     * @return a {@link SourceLevelQueryImplementation2} to find out source level of Java source files.
+     * @since 1.22
+     */
+    public static SourceLevelQueryImplementation2 createSourceLevelQuery2(@NonNull PropertyEvaluator evaluator) {
+        Parameters.notNull("evaluator", evaluator); // NOI18N
+        return new SourceLevelQueryImpl2(evaluator);
+    }
+
     /**
      * Create a new query to find Java package roots of unit tests for Java package root of sources and vice versa.
      * @param sourceRoots a list of source roots.
@@ -305,4 +341,71 @@ public final class QuerySupport {
             String annotationProcessingEnabledProperty, String annotationProcessingEnabledInEditorProperty, String runAllAnnotationProcessorsProperty, String annotationProcessorsProperty, String sourceOutputProperty, String processorOptionsProperty) {
         return new AnnotationProcessingQueryImpl(helper, evaluator, annotationProcessingEnabledProperty, annotationProcessingEnabledInEditorProperty, runAllAnnotationProcessorsProperty, annotationProcessorsProperty, sourceOutputProperty, processorOptionsProperty);
     }
+
+    public static ProjectInformation createProjectInformation(AntProjectHelper projectHelper, Project project, Icon icon) {
+        return new QuerySupport.AntHelper(projectHelper, project, icon, ProjectInfoImpl.DEFAULT_ELEMENT_NAME);
+    }
+
+    public static ProjectInformation createProjectInformation(UpdateHelper updateHelper, Project project, Icon icon) {
+        return new QuerySupport.AntUpdateHelper(updateHelper, project, icon, ProjectInfoImpl.DEFAULT_ELEMENT_NAME);
+    }
+
+    /**
+     * Returns {@link Sources} implementation designed for projects that supports adding
+     * or removing of the source roots. The returned instance also implements {@link SourceGroupModifierImplementation}
+     * @param project the {@link Project} for which the {@link Sources} should be created
+     * @param helper the {@link AntProjectHelper} of the project, used only to resolve files
+     * @param evaluator the {@link PropertyEvaluator} to evaluate the properties
+     * @param roots the array of {@link Roots} providing the roots of given type
+     * @return the {@link Sources} instance implementing also the {@link SourceGroupModifierImplementation} interface
+     * @since 1.21
+     */
+    public static Sources createSources(@NonNull final Project project,
+            @NonNull final AntProjectHelper helper,
+            @NonNull final PropertyEvaluator evaluator,
+            @NonNull final Roots... roots) {
+        Parameters.notNull("project", project); //NOI18N
+        Parameters.notNull("helper", helper);   //NOI18N
+        Parameters.notNull("evaluator", evaluator); //NOI18N
+        Parameters.notNull("roots", roots); //NOI18N
+        return new SourcesImpl(project, helper, evaluator, roots);
+    }
+    
+    private static class AntHelper extends ProjectInfoImpl {
+
+        private final AntProjectHelper projectHelper;
+
+        @SuppressWarnings("LeakingThisInConstructor")
+        public AntHelper(AntProjectHelper projectHelper, Project project, Icon icon, String elementName) {
+            super(project, icon, elementName);
+            this.projectHelper = projectHelper;
+
+            projectHelper.addAntProjectListener(WeakListeners.create(AntProjectListener.class, this, projectHelper));
+        }
+
+
+        @Override
+        protected Element getPrimaryConfigurationData() {
+            return projectHelper.getPrimaryConfigurationData(true);
+        }
+    }
+
+    private static class AntUpdateHelper extends ProjectInfoImpl {
+
+        private final UpdateHelper updateHelper;
+
+        @SuppressWarnings("LeakingThisInConstructor")
+        public AntUpdateHelper(UpdateHelper updateHelper, Project project, Icon icon, String elementName) {
+            super(project, icon, elementName);
+            this.updateHelper = updateHelper;
+
+            AntProjectHelper projectHelper = updateHelper.getAntProjectHelper();
+            projectHelper.addAntProjectListener(WeakListeners.create(AntProjectListener.class, this, projectHelper));
+        }
+
+        @Override
+        protected Element getPrimaryConfigurationData() {
+            return updateHelper.getPrimaryConfigurationData(true);
+        }
+    }
 }
