@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -88,21 +88,23 @@ import com.sun.source.tree.TryTree;
 import com.sun.source.tree.TypeCastTree;
 import com.sun.source.tree.TypeParameterTree;
 import com.sun.source.tree.UnaryTree;
+import com.sun.source.tree.UnionTypeTree;
 import com.sun.source.tree.VariableTree;
 import com.sun.source.tree.WhileLoopTree;
 import com.sun.source.tree.WildcardTree;
 import com.sun.source.util.TreePath;
-import com.sun.source.util.TreePathScanner;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicBoolean;
 import javax.lang.model.element.Element;
 import javax.lang.model.type.TypeMirror;
 import org.netbeans.api.annotations.common.CheckForNull;
 import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.api.java.source.support.CancellableTreePathScanner;
 import org.openide.nodes.AbstractNode;
 import org.openide.nodes.Children;
 import org.openide.nodes.Node;
@@ -119,10 +121,10 @@ public class TreeNode extends AbstractNode implements OffsetProvider {
     private CompilationInfo info;
     private boolean synthetic;
     
-    public static Node getTree(CompilationInfo info, TreePath tree) {
+    public static Node getTree(CompilationInfo info, TreePath tree, AtomicBoolean cancel) {
         List<Node> result = new ArrayList<Node>();
         
-        new FindChildrenTreeVisitor(info).scan(tree, result);
+        new FindChildrenTreeVisitor(info, cancel).scan(tree, result);
         
         return result.get(0);
     }
@@ -159,13 +161,22 @@ public class TreeNode extends AbstractNode implements OffsetProvider {
         return parent;
     }
 
-    /** Creates a new instance of TreeNode */
     public TreeNode(CompilationInfo info, TreePath tree, List<Node> nodes) {
         super(nodes.isEmpty() ? Children.LEAF: new NodeChilren(nodes), Lookups.singleton(tree.getLeaf()));
         this.tree = tree;
         this.info = info;
         this.synthetic = info.getTreeUtilities().isSynthetic(tree);
-        setDisplayName(tree.getLeaf().getKind().toString() + ":" + tree.getLeaf().toString()); //NOI18N
+        int start = (int) info.getTrees().getSourcePositions().getStartPosition(tree.getCompilationUnit(), tree.getLeaf());
+        int end   = (int) info.getTrees().getSourcePositions().getEndPosition(tree.getCompilationUnit(), tree.getLeaf());
+        String text;
+
+        if (start >= 0 && end >= 0 && end > start) {
+            text = info.getText().substring(start, end);
+        } else {
+            text = tree.getLeaf().toString();
+        }
+
+        setDisplayName(tree.getLeaf().getKind().toString() + ":" + text); //NOI18N
         setIconBaseWithExtension("org/netbeans/modules/java/debug/resources/tree.png"); //NOI18N
     }
 
@@ -201,23 +212,24 @@ public class TreeNode extends AbstractNode implements OffsetProvider {
         return -1;
     }
     
-    private static final class NodeChilren extends Children.Keys {
+    private static final class NodeChilren extends Children.Keys<Node> {
         
         public NodeChilren(List<Node> nodes) {
             setKeys(nodes);
         }
         
-        protected Node[] createNodes(Object key) {
-            return new Node[] {(Node) key};
+        protected Node[] createNodes(Node key) {
+            return new Node[] {key};
         }
         
     }
     
-    private static class FindChildrenTreeVisitor extends TreePathScanner<Void, List<Node>> {
+    private static class FindChildrenTreeVisitor extends CancellableTreePathScanner<Void, List<Node>> {
         
-        private CompilationInfo info;
+        private final CompilationInfo info;
         
-        public FindChildrenTreeVisitor(CompilationInfo info) {
+        public FindChildrenTreeVisitor(CompilationInfo info, AtomicBoolean cancel) {
+            super(cancel);
             this.info = info;
         }
         
@@ -384,6 +396,18 @@ public class TreeNode extends AbstractNode implements OffsetProvider {
             return null;
         }
 
+        @Override
+        public Void visitUnionType(UnionTypeTree tree, List<Node> d) {
+            List<Node> below = new ArrayList<Node>();
+
+            addCorrespondingType(below);
+            addCorrespondingComments(below);
+            super.visitUnionType(tree, below);
+
+            d.add(new TreeNode(info, getCurrentPath(), below));
+            return null;
+        }
+
         @Override
         public Void visitDoWhileLoop(DoWhileLoopTree tree, List<Node> d) {
             List<Node> below = new ArrayList<Node>();
@@ -816,7 +840,7 @@ public class TreeNode extends AbstractNode implements OffsetProvider {
             Element el = info.getTrees().getElement(getCurrentPath());
             
             if (el != null) {
-                below.add(new ElementNode(info, el, Collections.EMPTY_LIST));
+                below.add(new ElementNode(info, el, Collections.<Node>emptyList()));
             } else {
                 below.add(new NotFoundElementNode(NbBundle.getMessage(TreeNode.class, "Cannot_Resolve_Element")));
             }
