@@ -456,7 +456,7 @@ class BraceCompletion {
             // Search would stop on an extra opening left brace if found
             int braceBalance = 0; // balance of '{' and '}'
             int bracketBalance = -1; // balance of the brackets or parenthesis
-            int lastRBracketIndex = javaTS.index();
+            int numOfSemi = 0;
             boolean finished = false;
             while (!finished && javaTS.movePrevious()) {
                 JavaTokenId id = javaTS.token().id();
@@ -499,9 +499,31 @@ class BraceCompletion {
                     case RBRACE:
                         braceBalance--;
                         break;
+                        
+                    case SEMICOLON:
+                        numOfSemi++;
+                        break;
                 }
             }
 
+            if (bracketBalance == 0 && numOfSemi < 2) {
+                finished = false;
+                while (!finished && javaTS.movePrevious()) {
+                    switch (javaTS.token().id()) {
+                        case WHITESPACE:
+                        case LINE_COMMENT:
+                        case BLOCK_COMMENT:
+                        case JAVADOC_COMMENT:
+                            break;
+                        case FOR:
+                            bracketBalance--;
+                        default:
+                            finished = true;
+                            break;
+                    }
+                }
+            }
+            
             skipClosingBracket = bracketBalance != 0;
 
             //commented out due to #147683:
@@ -596,15 +618,16 @@ class BraceCompletion {
             return false;
         }
 
-        if (caretOffset == 1) {
-            char previousChar = doc.getChars(caretOffset - 1, 1)[0];
-
-            return previousChar == '\\';
+        for (int i = 2; caretOffset - i >= 0; i += 2) {
+            char[] previousChars = doc.getChars(caretOffset - i, 2);
+            if (previousChars[1] != '\\')
+                return false;
+            if (previousChars[0] != '\\')
+                return true;
         }
 
-        char[] previousChars = doc.getChars(caretOffset - 2, 2);
-
-        return previousChars[0] != '\\' && previousChars[1] == '\\';
+        char previousChar = doc.getChars(caretOffset - 1, 1)[0];
+        return previousChar == '\\';
     }
 
     /** 
