@@ -94,6 +94,7 @@ import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.SourceUtils;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.UiUtils;
 import org.netbeans.api.java.source.ui.ElementOpen;
 import org.netbeans.api.lexer.Token;
@@ -167,17 +168,12 @@ public class GoToSupport {
     }
     
     private static void performGoTo(final Document doc, final int offset, final boolean goToSource, final boolean javadoc) {
-        if (!javadoc) {
-            final AtomicBoolean cancel = new AtomicBoolean();
-            
-            ProgressUtils.runOffEventDispatchThread(new Runnable() {
-                public void run() {
-                    performGoToImpl(doc, offset, goToSource, javadoc, cancel);
-                }
-            }, NbBundle.getMessage(GoToSupport.class, goToSource ? "LBL_GoToSource" : "LBL_GoToDeclaration"), cancel, false);
-        } else {
-            performGoToImpl(doc, offset, goToSource, javadoc, null);
-        }
+        final AtomicBoolean cancel = new AtomicBoolean();
+        ProgressUtils.runOffEventDispatchThread(new Runnable() {
+            public void run() {
+                performGoToImpl(doc, offset, goToSource, javadoc, cancel);
+            }
+        }, NbBundle.getMessage(GoToSupport.class, javadoc ? "LBL_GoToJavadoc" : goToSource ? "LBL_GoToSource" : "LBL_GoToDeclaration"), cancel, false);
     }
 
     private static void performGoToImpl (final Document doc, final int offset, final boolean goToSource, final boolean javadoc, final AtomicBoolean cancel) {
@@ -374,15 +370,9 @@ public class GoToSupport {
             return null;
         }
 
-        TypeMirror parentTypeForAnonymous = null;
-
         if (controller.getElementUtilities().isSynthetic(el) && el.getKind() == ElementKind.CONSTRUCTOR) {
             //check for annonymous innerclasses:
-            TypeMirror[] classTypeRef = new TypeMirror[] {classType };
-
-            el = handlePossibleAnonymousInnerClass(controller, el, classTypeRef);
-
-            classType = parentTypeForAnonymous = classTypeRef[0];
+            el = handlePossibleAnonymousInnerClass(controller, el);
         }
 
         if (isError(el)) {
@@ -393,7 +383,7 @@ public class GoToSupport {
             return null;
         }
 
-        return new Context(classType, parentTypeForAnonymous, el);
+        return new Context(classType, el);
     }
 
     private static String computeTooltip(CompilationInfo controller, Context resolved, String key) {
@@ -401,8 +391,6 @@ public class GoToSupport {
 
         if (resolved.resolved.getKind() == ElementKind.CONSTRUCTOR && resolved.classType != null && resolved.classType.getKind() == TypeKind.DECLARED) {
             v.printExecutable(((ExecutableElement) resolved.resolved), (DeclaredType) resolved.classType, true);
-        } else if (resolved.resolved.getKind() == ElementKind.INTERFACE && resolved.parentTypeForAnonymous != null && resolved.parentTypeForAnonymous.getKind() == TypeKind.DECLARED) {
-            v.printType(((TypeElement) resolved.resolved), (DeclaredType) resolved.classType, true);
         } else  {
             v.visit(resolved.resolved, true);
         }
@@ -466,12 +454,9 @@ public class GoToSupport {
         return new int [] {ts.offset(), ts.offset() + t.length()};
     }
     
-    private static Element handlePossibleAnonymousInnerClass(CompilationInfo info, final Element el, TypeMirror[] classTypeRef) {
+    private static Element handlePossibleAnonymousInnerClass(CompilationInfo info, final Element el) {
         Element encl = el.getEnclosingElement();
         Element doubleEncl = encl != null ? encl.getEnclosingElement() : null;
-        TypeMirror classType = classTypeRef[0];
-
-        classTypeRef[0] = null;
         
         if (   doubleEncl != null
             && !doubleEncl.getKind().isClass()
@@ -481,29 +466,10 @@ public class GoToSupport {
             TreePath enclTreePath = info.getTrees().getPath(encl);
             Tree enclTree = enclTreePath != null ? enclTreePath.getLeaf() : null;
             
-            if (enclTree != null && enclTree.getKind() == Tree.Kind.CLASS && enclTreePath.getParentPath().getLeaf().getKind() == Tree.Kind.NEW_CLASS) {
+            if (enclTree != null && TreeUtilities.CLASS_TREE_KINDS.contains(enclTree.getKind()) && enclTreePath.getParentPath().getLeaf().getKind() == Tree.Kind.NEW_CLASS) {
                 NewClassTree nct = (NewClassTree) enclTreePath.getParentPath().getLeaf();
                 
                 if (nct.getClassBody() != null) {
-                    List<? extends TypeMirror> sup = classType != null && classType.getKind() == TypeKind.DECLARED
-                            ? info.getTypes().directSupertypes(classType) : Collections.<TypeMirror>emptyList();
-                    TypeElement jlObject = info.getElements().getTypeElement("java.lang.Object");
-
-                    if (jlObject != null) {
-                        TypeMirror jlObjectType = jlObject.asType();
-                        TypeMirror parent = null;
-
-                        for(TypeMirror tm : sup) {
-                            if (info.getTypes().isSameType(tm, jlObjectType)) {
-                                continue;
-                            }
-                            assert parent == null;
-                            parent = tm;
-                        }
-
-                        classTypeRef[0] = parent;
-                    }
-                    
                     Element parentElement = info.getTrees().getElement(new TreePath(enclTreePath, nct.getIdentifier()));
                     
                     if (parentElement == null || parentElement.getKind().isInterface()) {
@@ -555,7 +521,7 @@ public class GoToSupport {
         List<? extends Tree> decls = javac.getCompilationUnit().getTypeDecls();
         if (!decls.isEmpty()) {
             Tree clazz = decls.get(0);
-            if (clazz.getKind() == Kind.CLASS) {
+            if (TreeUtilities.CLASS_TREE_KINDS.contains(clazz.getKind())) {
                 clazzPath = new TreePath(cutPath, clazz);
                 Element clazzElm = trees.getElement(clazzPath);
                 if (isError(clazzElm)) {
@@ -584,7 +550,10 @@ public class GoToSupport {
     private static boolean isCaretInsideDeclarationName(CompilationInfo info, Tree t, TreePath path, int caret) {
         try {
             switch (t.getKind()) {
+                case ANNOTATION_TYPE:
                 case CLASS:
+                case ENUM:
+                case INTERFACE:
                 case METHOD:
                 case VARIABLE:
                     int[] span = org.netbeans.modules.java.editor.semantic.Utilities.findIdentifierSpan(path, info, info.getDocument());
@@ -765,7 +734,7 @@ public class GoToSupport {
         public Void visitVariable(VariableElement e, Boolean highlightName) {
             modifier(e.getModifiers());
             
-            result.append(getTypeName(e.asType(), true));
+            result.append(getTypeName(info, e.asType(), true));
             
             result.append(' ');
             
@@ -787,7 +756,7 @@ public class GoToSupport {
                     result.append(" in ");
 
                     //short typename:
-                    result.append(getTypeName(enclosing.asType(), true));
+                    result.append(getTypeName(info, enclosing.asType(), true));
                 }
             }
             
@@ -818,7 +787,7 @@ public class GoToSupport {
                 case METHOD:
                     modifier(e.getModifiers());
                     dumpTypeArguments(e.getTypeParameters());
-                    result.append(getTypeName(e.getReturnType(), true));
+                    result.append(getTypeName(info, e.getReturnType(), true));
                     result.append(' ');
                     boldStartCheck(highlightName);
                     result.append(e.getSimpleName());
@@ -868,7 +837,7 @@ public class GoToSupport {
                     result.append(", ");
                 }
                 
-                result.append(getTypeName(e.asType(), true));
+                result.append(getTypeName(info, e.asType(), true));
                 
                 addSpace = true;
             }
@@ -889,7 +858,7 @@ public class GoToSupport {
                     result.append(", ");
                 }
 
-                result.append(getTypeName(t, true));
+                result.append(getTypeName(info, t, true));
 
                 addSpace = true;
             }
@@ -913,7 +882,7 @@ public class GoToSupport {
                 VariableElement ve = listIt.next();
                 TypeMirror      type = typesIt != null ? typesIt.next() : ve.asType();
 
-                result.append(getTypeName(type, true));
+                result.append(getTypeName(info, type, true));
                 result.append(" ");
                 result.append(ve.getSimpleName());
 
@@ -936,7 +905,7 @@ public class GoToSupport {
                     result.append(", ");
                 }
                 
-                result.append(getTypeName(t, true));
+                result.append(getTypeName(info, t, true));
                 
                 addSpace = true;
             }
@@ -944,8 +913,8 @@ public class GoToSupport {
             
     }
     
-    private static String getTypeName(TypeMirror t, boolean fqn) {
-        return translate(Utilities.getTypeName(t, fqn).toString());
+    private static String getTypeName(CompilationInfo info, TypeMirror t, boolean fqn) {
+        return translate(Utilities.getTypeName(info, t, fqn).toString());
     }
     
     private static String[] c = new String[] {"&", "<", ">", "\n", "\""}; // NOI18N
@@ -986,11 +955,9 @@ public class GoToSupport {
 
     public static final class Context {
         public final TypeMirror classType;
-        public final TypeMirror parentTypeForAnonymous;
         public final Element resolved;
-        public Context(TypeMirror classType, TypeMirror parentTypeForAnonymous, Element resolved) {
+        public Context(TypeMirror classType, Element resolved) {
             this.classType = classType;
-            this.parentTypeForAnonymous = parentTypeForAnonymous;
             this.resolved = resolved;
         }
     }
