@@ -49,6 +49,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.EnumSet;
 import java.util.List;
+import java.util.concurrent.Future;
 import java.util.logging.Logger;
 import javax.swing.text.JTextComponent;
 import org.netbeans.api.java.source.Task;
@@ -57,7 +58,9 @@ import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.lib.editor.codetemplates.api.CodeTemplate;
 import org.netbeans.lib.editor.codetemplates.spi.CodeTemplateFilter;
+import org.openide.awt.StatusDisplayer;
 import org.openide.util.Exceptions;
+import org.openide.util.NbBundle;
 
 /**
  *
@@ -72,14 +75,18 @@ public class JavaCodeTemplateFilter implements CodeTemplateFilter, Task<Compilat
     private Tree.Kind ctx = null;
     
     private JavaCodeTemplateFilter(JTextComponent component, int offset) {
-        this.startOffset = offset;
-        this.endOffset = component.getSelectionStart() == offset ? component.getSelectionEnd() : -1;            
-        JavaSource js = JavaSource.forDocument(component.getDocument());
-        if (js != null) {
-            try {
-                js.runUserActionTask(this, true);
-            } catch (IOException ex) {
-                Exceptions.printStackTrace(ex);
+        if (Utilities.isJavaContext(component, offset)) {
+            this.startOffset = offset;
+            this.endOffset = component.getSelectionStart() == offset ? component.getSelectionEnd() : -1;            
+            JavaSource js = JavaSource.forDocument(component.getDocument());
+            if (js != null) {
+                try {
+                    Future<Void> task = js.runWhenScanFinished(this, true);
+                    if (!task.isDone())
+                        StatusDisplayer.getDefault().setStatusText(NbBundle.getMessage(JavaCodeTemplateFilter.class, "JCT-scanning-in-progress")); //NOI18N
+                } catch (IOException ex) {
+                    Exceptions.printStackTrace(ex);
+                }
             }
         }
     }
