@@ -45,7 +45,6 @@
 package org.netbeans.modules.editor.java;
 
 import com.sun.source.tree.*;
-import com.sun.source.tree.Tree.Kind;
 import com.sun.source.util.*;
 
 import java.io.IOException;
@@ -204,7 +203,7 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                             int cnt = 0;
                             for (TypeMirror tm : tu.getUncaughtExceptions(new TreePath(path, ((TryTree)path.getLeaf()).getBlock()))) {
                                 sb.append("catch ("); //NOI18N
-                                sb.append("${_GEN_UCE_TYPE_" + cnt++ + " type=" + Utilities.getTypeName(tm, true) + " default=" + Utilities.getTypeName(tm, false) + "}"); //NOI18N
+                                sb.append("${_GEN_UCE_TYPE_" + cnt++ + " type=" + Utilities.getTypeName(cInfo, tm, true) + " default=" + Utilities.getTypeName(cInfo, tm, false) + "}"); //NOI18N
                                 sb.append(" ${_GEN_UCE_NAME_" + cnt++ + " newVarName}){}"); //NOI18N
                             }
                             if (sb.length() > 0) {
@@ -356,7 +355,7 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                         tm = cInfo.getTypes().erasure(tm);
                         if (containsDeclaredType(tm))
                             param2types.put(param, tm);
-                        return Utilities.getTypeName(tm, true) + "." + ve.getSimpleName();
+                        return Utilities.getTypeName(cInfo, tm, true) + "." + ve.getSimpleName();
                     } else {
                         return valueOf((String)entry.getValue());
                     }                    
@@ -381,9 +380,8 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                         if (tpe != null)
                             return tpe.getSimpleName().toString();
                     }
-                    if (tm.getKind() == TypeKind.TYPEVAR)
-                        tm = ((TypeVariable)tm).getUpperBound();
-                    String value = Utilities.getTypeName(tm, true).toString();
+                    tm = resolveCapturedType(tm);
+                    String value = Utilities.getTypeName(cInfo, tm, true).toString();
                     if (value != null) {
                         param2hints.put(param, TYPE);
                         if (containsDeclaredType(tm))
@@ -396,9 +394,8 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
             } else if (ITERABLE_ELEMENT_TYPE.equals(entry.getKey())) {
                 TypeMirror tm = iterableElementType(param.getInsertTextOffset() + 1);
                 if (tm != null && tm.getKind() != TypeKind.ERROR) {
-                    if (tm.getKind() == TypeKind.TYPEVAR)
-                        tm = ((TypeVariable)tm).getUpperBound();
-                    String value = Utilities.getTypeName(tm, true).toString();
+                    tm = resolveCapturedType(tm);
+                    String value = Utilities.getTypeName(cInfo, tm, true).toString();
                     if (value != null) {
                         param2hints.put(param, ITERABLE_ELEMENT_TYPE);
                         if (containsDeclaredType(tm))
@@ -409,9 +406,8 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
             } else if (LEFT_SIDE_TYPE.equals(entry.getKey())) {
                 TypeMirror tm = assignmentSideType(param.getInsertTextOffset() + 1, true);
                 if (tm != null && tm.getKind() != TypeKind.ERROR) {
-                    if (tm.getKind() == TypeKind.TYPEVAR)
-                        tm = ((TypeVariable)tm).getUpperBound();
-                    String value = Utilities.getTypeName(tm, true).toString();
+                    tm = resolveCapturedType(tm);
+                    String value = Utilities.getTypeName(cInfo, tm, true).toString();
                     if (value != null) {
                         param2hints.put(param, LEFT_SIDE_TYPE);
                         if (containsDeclaredType(tm))
@@ -422,9 +418,8 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
             } else if (RIGHT_SIDE_TYPE.equals(entry.getKey())) {
                 TypeMirror tm = assignmentSideType(param.getInsertTextOffset() + 1, false);
                 if (tm != null && tm.getKind() != TypeKind.ERROR) {
-                    if (tm.getKind() == TypeKind.TYPEVAR)
-                        tm = ((TypeVariable)tm).getUpperBound();
-                    String value = Utilities.getTypeName(tm, true).toString();
+                    tm = resolveCapturedType(tm);
+                    String value = Utilities.getTypeName(cInfo, tm, true).toString();
                     if (value != null) {
                         param2hints.put(param, RIGHT_SIDE_TYPE);
                         if (containsDeclaredType(tm))
@@ -439,7 +434,8 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                     param2types.remove(param);
                     return ""; //NOI18N
                 } else if (tm.getKind() != TypeKind.ERROR) {
-                    String value = Utilities.getTypeName(tm, true).toString();
+                    tm = resolveCapturedType(tm);
+                    String value = Utilities.getTypeName(cInfo, tm, true).toString();
                     if (value != null) {
                         param2hints.put(param, CAST);
                         if (containsDeclaredType(tm))
@@ -458,9 +454,8 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
             } else if (UNCAUGHT_EXCEPTION_TYPE.equals(entry.getKey())) {
                 TypeMirror tm = uncaughtExceptionType(param.getInsertTextOffset() + 1);
                 if (tm != null && tm.getKind() != TypeKind.ERROR) {
-                    if (tm.getKind() == TypeKind.TYPEVAR)
-                        tm = ((TypeVariable)tm).getUpperBound();
-                    String value = Utilities.getTypeName(tm, true).toString();
+                    tm = resolveCapturedType(tm);
+                    String value = Utilities.getTypeName(cInfo, tm, true).toString();
                     if (value != null) {
                         param2hints.put(param, UNCAUGHT_EXCEPTION_TYPE);
                         if (containsDeclaredType(tm))
@@ -470,13 +465,13 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                 }
             }
         }
-        return null;
+        return name;
     }
     
     private VariableElement instanceOf(String typeName, String name) {
         try {
             if (cInfo != null) {
-                TypeMirror type = cInfo.getTreeUtilities().parseType(typeName, enclClass);
+                TypeMirror type = type(typeName);
                 VariableElement closest = null;
                 int distance = Integer.MAX_VALUE;
                 if (type != null) {
@@ -506,7 +501,7 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
         try {
             if (cInfo != null) {
                 final TreeUtilities tu = cInfo.getTreeUtilities();
-                TypeMirror type = tu.parseType(typeName, enclClass);
+                TypeMirror type = type(typeName);
                 VariableElement closest = null;
                 int distance = Integer.MAX_VALUE;
                 if (type != null) {
@@ -572,7 +567,7 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
     private String valueOf(String typeName) {
         try {
             if (cInfo != null) {
-                TypeMirror type = cInfo.getTreeUtilities().parseType(typeName, enclClass);
+                TypeMirror type = type(typeName);
                 if (type != null) {
                     if (type.getKind() == TypeKind.DECLARED)
                         return NULL;
@@ -610,7 +605,27 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
     }
 
     private TypeMirror type(String typeName) {
-        return cInfo != null ? cInfo.getTreeUtilities().parseType(typeName, enclClass) : null;
+        try {
+            typeName = typeName.trim();
+            if (cInfo != null && typeName.length() > 0) {
+                SourcePositions[] sourcePositions = new SourcePositions[1];
+                TreeUtilities tu = cInfo.getTreeUtilities();
+                StatementTree stmt = tu.parseStatement("{" + typeName + " a;}", sourcePositions); //NOI18N
+                if (!errChecker.containsErrors(stmt) && stmt.getKind() == Tree.Kind.BLOCK) {
+                    List<? extends StatementTree> stmts = ((BlockTree)stmt).getStatements();
+                    if (!stmts.isEmpty()) {
+                        StatementTree var = stmts.get(0);
+                        if (var.getKind() == Tree.Kind.VARIABLE) {
+                            tu.attributeTree(stmt, scope);
+                            return cInfo.getTrees().getTypeMirror(new TreePath(treePath, ((VariableTree)var).getType()));
+                        }
+                    }
+                }
+                return cInfo.getTreeUtilities().parseType(typeName, enclClass);
+            }
+        } catch (Exception e) {            
+        }
+        return null;
     }
     
     private TypeMirror iterableElementType(int caretOffset) {
@@ -739,11 +754,11 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                 TreePath path = tu.pathFor(new TreePath(treePath, stmt), caretOffset + 1, sourcePositions[0]);
                 TreePath decl = Utilities.getPathElementOfKind(Tree.Kind.VARIABLE, path);
                 if (decl != null) {
-                    Scope s = tu.attributeTreeTo(stmt, scope, decl.getLeaf());
+                    final Scope s = tu.attributeTreeTo(stmt, scope, decl.getLeaf());
                     TypeMirror type = cInfo.getTrees().getTypeMirror(decl);
                     boolean isConst = ((VariableTree)decl.getLeaf()).getModifiers().getFlags().containsAll(EnumSet.of(Modifier.FINAL, Modifier.STATIC));
                     final Element element = cInfo.getTrees().getElement(decl);
-                    ElementUtilities.ElementAcceptor acceptor = new ElementUtilities.ElementAcceptor() {
+                    final ElementUtilities.ElementAcceptor acceptor = new ElementUtilities.ElementAcceptor() {
                         public boolean accept(Element e, TypeMirror t) {
                             switch(e.getKind()) {
                                 case EXCEPTION_PARAMETER:
@@ -755,7 +770,34 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
                             }
                         }
                     };
-                    Iterator<String> names = Utilities.varNamesSuggestions(type, null, cInfo.getTypes(), cInfo.getElements(), cInfo.getElementUtilities().getLocalVars(s, acceptor), isConst).iterator();
+                    Iterable<? extends Element> loc = new Iterable<Element>() {
+                        @Override
+                        public Iterator<Element> iterator() {
+                            return new Iterator<Element>() {
+                                private Iterator<? extends Element> localsIt = locals.iterator();
+                                private Iterator<? extends Element> localVarsIt;
+                                @Override
+                                public boolean hasNext() {
+                                    if (localsIt != null) {
+                                        if (localsIt.hasNext())
+                                            return true;
+                                        localsIt = null;
+                                        localVarsIt = cInfo.getElementUtilities().getLocalVars(s, acceptor).iterator();
+                                    }
+                                    return localVarsIt.hasNext();
+                                }
+                                @Override
+                                public Element next() {
+                                    return localsIt != null ? localsIt.next() : localVarsIt.next();
+                                }
+                                @Override
+                                public void remove() {
+                                    throw new UnsupportedOperationException("Not supported yet."); //NOI18N
+                                }
+                            };
+                        }
+                    };
+                    Iterator<String> names = Utilities.varNamesSuggestions(type, null, cInfo.getTypes(), cInfo.getElements(), loc, isConst).iterator();
                     if (names.hasNext())
                         return names.next();
                 }
@@ -768,7 +810,7 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
     private String owningClassName() {
         try {
             if (cInfo != null) {
-                TreePath path = Utilities.getPathElementOfKind (Kind.CLASS, treePath);
+                TreePath path = Utilities.getPathElementOfKind (TreeUtilities.CLASS_TREE_KINDS, treePath);
                 if (path != null) {
                     ClassTree tree = (ClassTree) path.getLeaf();
                     String result = tree.getSimpleName().toString();
@@ -814,6 +856,15 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
         }
     }
     
+    private TypeMirror resolveCapturedType(TypeMirror type) {
+        if (type.getKind() == TypeKind.TYPEVAR) {
+            WildcardType wildcard = SourceUtils.resolveCapturedType(type);
+            if (wildcard != null)
+                return wildcard.getExtendsBound();
+        }
+        return type;
+    }
+    
     private boolean initParsing() {
         if (cInfo == null) {
             JTextComponent c = request.getComponent();
@@ -894,7 +945,7 @@ public class JavaCodeTemplateProcessor implements CodeTemplateProcessor {
         }
         return cInfo != null;
     }
-
+    
     public static final class Factory implements CodeTemplateProcessorFactory {
         
         public CodeTemplateProcessor createProcessor(CodeTemplateInsertRequest request) {
