@@ -78,6 +78,7 @@ import org.netbeans.api.editor.settings.SimpleValueNames;
 import org.netbeans.api.java.lexer.JavaTokenId;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.SourceUtils;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.lexer.InputAttributes;
 import org.netbeans.api.lexer.Language;
 import org.netbeans.api.lexer.LanguagePath;
@@ -86,7 +87,9 @@ import org.netbeans.api.lexer.TokenSequence;
 import org.netbeans.editor.ext.java.JavaTokenContext;
 import org.netbeans.modules.editor.NbEditorUtilities;
 import org.netbeans.modules.java.editor.options.CodeCompletionPanel;
+import org.netbeans.spi.editor.hints.Severity;
 import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileUtil;
 import org.openide.util.WeakListeners;
 
 /**
@@ -112,6 +115,7 @@ public final class Utilities {
     private static final AtomicBoolean inited = new AtomicBoolean(false);
     private static Preferences preferences;
     private static final PreferenceChangeListener preferencesTracker = new PreferenceChangeListener() {
+        @Override
         public void preferenceChange(PreferenceChangeEvent evt) {
             String settingName = evt == null ? null : evt.getKey();
             if (settingName == null || SimpleValueNames.COMPLETION_CASE_SENSITIVE.equals(settingName)) {
@@ -336,7 +340,7 @@ public final class Utilities {
         return getPathElementOfKind(EnumSet.of(kind), path);
     }
     
-    public static TreePath getPathElementOfKind(EnumSet<Tree.Kind> kinds, TreePath path) {
+    public static TreePath getPathElementOfKind(Set<Tree.Kind> kinds, TreePath path) {
         while (path != null) {
             if (kinds.contains(path.getLeaf().getKind()))
                 return path;
@@ -378,7 +382,6 @@ public final class Utilities {
             case INVALID_COMMENT_END:
             case JAVADOC_COMMENT:
             case LONG_LITERAL:
-            case STRING_LITERAL:
             case LINE_COMMENT:
             case BLOCK_COMMENT:
                 return false;
@@ -391,11 +394,19 @@ public final class Utilities {
         }
     }
     
-    public static CharSequence getTypeName(TypeMirror type, boolean fqn) {
-        return getTypeName(type, fqn, false);
+    @Deprecated public static CharSequence getTypeName(TypeMirror type, boolean fqn) {
+        return getTypeName(null, type, fqn, false);
     }
     
-    public static CharSequence getTypeName(TypeMirror type, boolean fqn, boolean varArg) {
+    @Deprecated public static CharSequence getTypeName(TypeMirror type, boolean fqn, boolean varArg) {
+        return getTypeName(null, type, fqn, varArg);
+    }
+    
+    public static CharSequence getTypeName(CompilationInfo info, TypeMirror type, boolean fqn) {
+        return getTypeName(info, type, fqn, false);
+    }
+    
+    public static CharSequence getTypeName(CompilationInfo info, TypeMirror type, boolean fqn, boolean varArg) {
 	if (type == null)
             return ""; //NOI18N
         return new TypeNameVisitor(varArg).visit(type, fqn);
@@ -412,12 +423,15 @@ public final class Utilities {
         while(path != null) {
             switch(path.getLeaf().getKind()) {
                 case BLOCK:
+                case ANNOTATION_TYPE:
                 case CLASS:
+                case ENUM:
+                case INTERFACE:
                     return refs;
                 case VARIABLE:
                     refs.add(trees.getElement(path));
                     TreePath parent = path.getParentPath();
-                    if (parent.getLeaf().getKind() == Tree.Kind.CLASS) {
+                    if (TreeUtilities.CLASS_TREE_KINDS.contains(parent.getLeaf().getKind())) {
                         boolean isStatic = ((VariableTree)path.getLeaf()).getModifiers().getFlags().contains(Modifier.STATIC);
                         for(Tree member : ((ClassTree)parent.getLeaf()).getMembers()) {
                             if (member.getKind() == Tree.Kind.VARIABLE && sourcePositions.getStartPosition(path.getCompilationUnit(), member) >= pos &&
@@ -440,7 +454,7 @@ public final class Utilities {
         List<String> result = new ArrayList<String>();
         if (type == null)
             return result;
-        List<String> vnct = varNamesForType(type, types, elements);
+        List<String> vnct = varNamesForType(type, types, elements, prefix);
         if (isConst) {
             List<String> ls = new ArrayList<String>(vnct.size());
             for (String s : vnct)
@@ -491,21 +505,21 @@ public final class Utilities {
         if (path == null)
             return false;
         TreePath parentPath = path.getParentPath();
-        if (path.getLeaf().getKind() == Tree.Kind.CLASS && parentPath.getLeaf().getKind() != Tree.Kind.COMPILATION_UNIT && parentPath.getLeaf().getKind() != Tree.Kind.CLASS)                
+        if (TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind()) && parentPath.getLeaf().getKind() != Tree.Kind.COMPILATION_UNIT && !TreeUtilities.CLASS_TREE_KINDS.contains(parentPath.getLeaf().getKind()))                
             return true;
         return inAnonymousOrLocalClass(parentPath);
     }
         
-    private static List<String> varNamesForType(TypeMirror type, Types types, Elements elements) {
+    private static List<String> varNamesForType(TypeMirror type, Types types, Elements elements, String prefix) {
         switch (type.getKind()) {
             case ARRAY:
                 TypeElement iterableTE = elements.getTypeElement("java.lang.Iterable"); //NOI18N
                 TypeMirror iterable = iterableTE != null ? types.getDeclaredType(iterableTE) : null;
                 TypeMirror ct = ((ArrayType)type).getComponentType();
                 if (ct.getKind() == TypeKind.ARRAY && iterable != null && types.isSubtype(ct, iterable))
-                    return varNamesForType(ct, types, elements);
+                    return varNamesForType(ct, types, elements, prefix);
                 List<String> vnct = new ArrayList<String>();
-                for (String name : varNamesForType(ct, types, elements))
+                for (String name : varNamesForType(ct, types, elements, prefix))
                     vnct.add(name.endsWith("s") ? name + "es" : name + "s"); //NOI18N
                 return vnct;
             case BOOLEAN:
@@ -531,8 +545,11 @@ public final class Utilities {
                     al.add(tn);
                     sb.append(tn.charAt(0));
                 }
-                if (sb.length() > 0)
-                    al.add(sb.toString());
+                if (sb.length() > 0) {
+                    String s = sb.toString();
+                    if (prefix == null || prefix.length() == 0 || s.startsWith(prefix))
+                        al.add(s);
+                }
                 return al;
             case DECLARED:
                 iterableTE = elements.getTypeElement("java.lang.Iterable"); //NOI18N
@@ -553,22 +570,25 @@ public final class Utilities {
                     if (tas.size() > 0) {
                         TypeMirror et = tas.get(0);
                         if (et.getKind() == TypeKind.ARRAY || (et.getKind() != TypeKind.WILDCARD && types.isSubtype(et, iterable))) {
-                            al.addAll(varNamesForType(et, types, elements));
+                            al.addAll(varNamesForType(et, types, elements, prefix));
                         } else {
-                            for (String name : varNamesForType(et, types, elements))
+                            for (String name : varNamesForType(et, types, elements, prefix))
                                 al.add(name.endsWith("s") ? name + "es" : name + "s"); //NOI18N
                         }
                     }
                 }
-                if (sb.length() > 0)
-                    al.add(sb.toString());
+                if (sb.length() > 0) {
+                    String s = sb.toString();
+                    if (prefix == null || prefix.length() == 0 || s.startsWith(prefix))
+                        al.add(s);
+                }
                 return al;
             case WILDCARD:
                 TypeMirror bound = ((WildcardType)type).getExtendsBound();
                 if (bound == null)
                     bound = ((WildcardType)type).getSuperBound();
                 if (bound != null)
-                    return varNamesForType(bound, types, elements);
+                    return varNamesForType(bound, types, elements, prefix);
         }
         return Collections.<String>emptyList();
     }
@@ -609,7 +629,7 @@ public final class Utilities {
         if (JavaTokenContext.getKeyword(varName) != null)
             return true;
         for (Element e : locals) {
-            if ((e.getKind() == ElementKind.LOCAL_VARIABLE || e.getKind() == ElementKind.PARAMETER || e.getKind() == ElementKind.EXCEPTION_PARAMETER) && varName.contentEquals(e.getSimpleName()))
+            if ((e.getKind().isField() || e.getKind() == ElementKind.LOCAL_VARIABLE || e.getKind() == ElementKind.PARAMETER || e.getKind() == ElementKind.EXCEPTION_PARAMETER) && varName.contentEquals(e.getSimpleName()))
                 return true;
         }
         return false;
@@ -872,6 +892,19 @@ public final class Utilities {
         return found;
     }
 
+    public static Set<Severity> disableErrors(FileObject file) {
+        if (file.getAttribute(DISABLE_ERRORS) != null) {
+            return EnumSet.allOf(Severity.class);
+        }
+        if (!file.canWrite() && FileUtil.getArchiveFile(file) != null) {
+            return EnumSet.allOf(Severity.class);
+        }
+
+        return EnumSet.noneOf(Severity.class);
+    }
+
+    private static final String DISABLE_ERRORS = "disable-java-errors";
+
     private Utilities() {
     }
     
