@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -41,25 +44,22 @@
 
 package org.netbeans.modules.java.editor;
 
+import java.awt.Dimension;
 import java.awt.Graphics;
 import java.awt.Point;
-import java.awt.Rectangle;
-import java.awt.image.BufferedImage;
 import java.util.concurrent.Callable;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 import javax.swing.JComponent;
 import javax.swing.JEditorPane;
 import javax.swing.JFrame;
 import javax.swing.SwingUtilities;
-import javax.swing.text.AbstractDocument;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
-import javax.swing.text.View;
 import org.netbeans.api.editor.EditorRegistry;
 import org.netbeans.editor.BaseKit;
 import org.netbeans.editor.EditorUI;
 import org.netbeans.editor.Utilities;
-import org.netbeans.editor.view.spi.EstimatedSpanView;
-import org.netbeans.editor.view.spi.LockView;
 import org.netbeans.modules.editor.java.JavaKit;
 import org.openide.util.Exceptions;
 import org.openide.util.RequestProcessor;
@@ -74,13 +74,13 @@ import org.openide.util.RequestProcessor;
  * @author  Tomas Pavek, Martin Roskanin
  */
 
-public class JavaEditorWarmUpTask implements Runnable{
+public class JavaEditorWarmUpTask implements Runnable {
     
     /**
      * Number of lines that an artificial document
      * for view hierarchy code optimization will have.
      * <br/>
-     * The number is hotspot's threshold for method compilation 1500 divied by 10 + 1
+     * The number is hotspot's threshold for method compilation 1500 divided by 10 + 1
      * since 1500 would be rather high line count. Anyway main effect of warmup
      * the class pre-loading should apply regardless of this value.
      */
@@ -106,10 +106,9 @@ public class JavaEditorWarmUpTask implements Runnable{
      * Number of paints to be simulated.
      */
     private static final int PAINT_COUNT = 1;
-    
 
-    private static final boolean debug
-        = Boolean.getBoolean("netbeans.debug.editor.warmup"); // NOI18N
+    // -J-Dorg.netbeans.modules.java.editor.JavaEditorWarmUpTask.level=FINE
+    private static final Logger LOG = Logger.getLogger(JavaEditorWarmUpTask.class.getName());
     
     private static final int STATUS_INIT = 0;
     private static final int STATUS_CREATE_PANE = 1;
@@ -117,6 +116,9 @@ public class JavaEditorWarmUpTask implements Runnable{
     private static final int STATUS_SWITCH_DOCUMENTS = 3;
     private static final int STATUS_TRAVERSE_VIEWS = 4;
     private static final int STATUS_RENDER_FRAME = 5;
+    private static final int STATUS_FINISHED = 6;
+    
+    private static final RequestProcessor RP = new RequestProcessor(JavaEditorWarmUpTask.class.getName(), 1, false, false);
     
     private int status = STATUS_INIT;
 
@@ -130,12 +132,10 @@ public class JavaEditorWarmUpTask implements Runnable{
 
     private long startTime;
     
-    public void run() {
+    public @Override void run() {
         switch (status) {
             case STATUS_INIT:
-                if (debug) {
-                    startTime = System.currentTimeMillis();
-                }
+                startTime = System.currentTimeMillis();
         
                 // Init of JavaKit and JavaOptions
                 javaKit = BaseKit.getKit(JavaKit.class);
@@ -154,11 +154,10 @@ public class JavaEditorWarmUpTask implements Runnable{
 
                 // Start of a code block that tries to force hotspot to compile
                 // the view hierarchy and related classes for faster performance
-                if (debug) {
-                    System.out.println("Kit instances initialized: " // NOI18N
-                        + (System.currentTimeMillis()-startTime));
-                    startTime = System.currentTimeMillis();
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, "Kit instances initialized: {0}", (System.currentTimeMillis() - startTime)); //NOI18N
                 }
+                startTime = System.currentTimeMillis();
 
                 
                 if (EditorRegistry.lastFocusedComponent() == null) { // no components opened yet
@@ -181,7 +180,7 @@ public class JavaEditorWarmUpTask implements Runnable{
                 }
 
                 status = STATUS_CREATE_DOCUMENTS;
-                RequestProcessor.getDefault().post(this);
+                RP.post(this);
                 break;
                 
             case STATUS_CREATE_DOCUMENTS:
@@ -193,7 +192,7 @@ public class JavaEditorWarmUpTask implements Runnable{
                     // Fill the document with data.
                     // Number of lines is more important here than number of columns in a line
                     // Do one big insert instead of many small inserts
-                    StringBuffer sb = new StringBuffer();
+                    StringBuilder sb = new StringBuilder();
                     for (int i = ARTIFICIAL_DOCUMENT_LINE_COUNT; i > 0; i--) {
                         sb.append("int ident = 1; // comment\n"); // NOI18N
                     }
@@ -222,115 +221,65 @@ public class JavaEditorWarmUpTask implements Runnable{
                 break;
                 
             case STATUS_TRAVERSE_VIEWS:
+                Dimension paneSize = pane.getPreferredSize();
+                Document doc = pane.getDocument();
+                int docLen = doc.getLength();
                 try {
-                    // Create buffered image for painting simulation
-                    BufferedImage bImage = new BufferedImage(
-                        IMAGE_WIDTH, IMAGE_HEIGHT, BufferedImage.TYPE_INT_RGB);
-                    bGraphics = bImage.getGraphics();
-                    bGraphics.setClip(0, 0, IMAGE_WIDTH, IMAGE_HEIGHT);
-
-                    // Do view-related operations
-                    AbstractDocument doc = (AbstractDocument)pane.getDocument();
-                    doc.readLock();
-                    try {
-                        final View rootView = Utilities.getDocumentView(pane);
-                        LockView lockView = LockView.get(rootView);
-                        lockView.lock();
-                        try {
-                            int viewCount = rootView.getViewCount();
-
-                            // Force switch the line views from estimated spans to exact measurements
-                            Runnable resetChildrenEstimatedSpans = new Runnable() {
-                                public void run() {
-                                    int cnt = rootView.getViewCount();                            
-                                    for (int j = 0; j < cnt; j++) {
-                                        View v = rootView.getView(j);
-                                        if (v instanceof EstimatedSpanView) {
-                                            ((EstimatedSpanView)v).setEstimatedSpan(false);
-                                        }
-                                    }
-                                }
-                            };
-                            if (rootView instanceof org.netbeans.lib.editor.view.GapDocumentView) {
-                                ((org.netbeans.lib.editor.view.GapDocumentView)rootView).
-                                    renderWithUpdateLayout(resetChildrenEstimatedSpans);
-                            } else { // not specialized instance => run normally
-                                resetChildrenEstimatedSpans.run();
-                            }
-
-                            // Get child allocation for each line
-                            for (int j = 0; j < viewCount; j++) {
-                                Rectangle alloc = new Rectangle(0, 0,
-                                    (int)rootView.getPreferredSpan(View.X_AXIS),
-                                    (int)rootView.getPreferredSpan(View.Y_AXIS)
-                                );
-                                rootView.getChildAllocation(j, alloc);
-                            }
-
-                            // Test modelToView and viewToModel
-                            if (false) { // Disabled because of #
-                                float rootViewYSpan = rootView.getPreferredSpan(View.Y_AXIS);
-                                float maybeLineSpan = rootViewYSpan / viewCount;
-                                Point point = new Point();
-                                point.x = 5; // likely somewhere inside the first char on the line
-                                for (int j = 0; j < viewCount; j++) {
-                                    pane.modelToView(rootView.getView(j).getStartOffset());
-
-                                    point.y = (int)(j * maybeLineSpan);
-                                    int pos = pane.viewToModel(point);
-                                }
-                            }
-
-                            int rootViewWidth = (int)rootView.getPreferredSpan(View.X_AXIS);
-                            int rootViewHeight = (int)rootView.getPreferredSpan(View.Y_AXIS);
-                            Rectangle alloc = new Rectangle(0, 0, rootViewWidth, rootViewHeight);
-
-                            // Paint into buffered image
-                            for (int i = PAINT_COUNT - 1; i >= 0; i--) {
-                                rootView.paint(bGraphics, alloc);
-                            }
-
-                        } finally {
-                            lockView.unlock();
-                        }
-                    } finally {
-                        doc.readUnlock();
+                    // Do model<=>view calculations several times
+                    int opCount = 10;
+                    for (int i = 0; i < opCount; i++) {
+                        pane.modelToView(docLen * i / opCount);
+                        pane.viewToModel(new Point(paneSize.height * i / opCount, paneSize.width * i / opCount));
                     }
                 } catch (BadLocationException e) {
                     Exceptions.printStackTrace(e);
                 }
-                    
+
                 status = STATUS_RENDER_FRAME;
                 SwingUtilities.invokeLater(this);
                 break;
 
             case STATUS_RENDER_FRAME:
+                JEditorPane p = pane;
                 frame = new JFrame();
-                EditorUI ui = Utilities.getEditorUI(pane);
+                EditorUI ui = Utilities.getEditorUI(p);
                 JComponent mainComp = null;
                 if (ui != null) {
                     mainComp = ui.getExtComponent();
                 }
                 if (mainComp == null) {
-                    mainComp = new javax.swing.JScrollPane(pane);
+                    mainComp = new javax.swing.JScrollPane(p);
                 }
                 frame.getContentPane().add(mainComp);
                 frame.pack();
                 frame.paint(bGraphics);
                 frame.getContentPane().removeAll();
                 frame.dispose();
-                pane.setEditorKit(null);
+                if (p != null) {
+                    p.setEditorKit(null);
+                }
 
                 // Candidates Annotations.getLineAnnotations()
 
-                if (debug) {
-                    System.out.println("View hierarchy initialized: " // NOI18N
-                        + (System.currentTimeMillis()-startTime));
-                    startTime = System.currentTimeMillis();
+                if (LOG.isLoggable(Level.FINE)) {
+                    LOG.log(Level.FINE, "View hierarchy initialized: {0}", (System.currentTimeMillis() - startTime)); //NOI18N
                 }
-                status = STATUS_INIT;
+                startTime = System.currentTimeMillis();
+                status = STATUS_FINISHED;
+                RP.post(this);
                 break;
-                
+
+            case STATUS_FINISHED:
+                this.pane = null;
+                this.frame = null;
+                this.emptyDoc = null;
+                this.longDoc = null;
+                this.bGraphics = null;
+                this.javaKit = null;
+                this.startTime = 0;
+                this.status = STATUS_INIT;
+                break;
+
             default:
                 throw new IllegalStateException();
         }
