@@ -43,6 +43,7 @@
  */
 package org.netbeans.modules.java.editor.codegen;
 
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.spi.editor.codegen.CodeGenerator;
 import com.sun.source.tree.BlockTree;
 import com.sun.source.tree.ClassTree;
@@ -50,7 +51,6 @@ import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.Scope;
 import com.sun.source.tree.StatementTree;
-import com.sun.source.tree.Tree;
 import com.sun.source.util.TreePath;
 import com.sun.source.util.Trees;
 import java.awt.Dialog;
@@ -67,10 +67,12 @@ import java.util.logging.Logger;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.element.Modifier;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.VariableElement;
 import javax.lang.model.type.DeclaredType;
 import javax.lang.model.type.TypeKind;
+import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.ElementFilter;
 import javax.lang.model.util.Elements;
 import javax.swing.text.JTextComponent;
@@ -78,6 +80,7 @@ import org.netbeans.api.java.source.Task;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.ElementHandle;
+import org.netbeans.api.java.source.ElementUtilities;
 import org.netbeans.api.java.source.GeneratorUtilities;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.ModificationResult;
@@ -108,7 +111,7 @@ public class DelegateMethodGenerator implements CodeGenerator {
             JTextComponent component = context.lookup(JTextComponent.class);
             CompilationController controller = context.lookup(CompilationController.class);
             TreePath path = context.lookup(TreePath.class);
-            path = path != null ? Utilities.getPathElementOfKind(Tree.Kind.CLASS, path) : null;
+            path = path != null ? Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path) : null;
             if (component == null || controller == null || path == null)
                 return ret;
             try {
@@ -116,21 +119,26 @@ public class DelegateMethodGenerator implements CodeGenerator {
             } catch (IOException ioe) {
                 return ret;
             }
+            TypeElement typeElement = (TypeElement) controller.getTrees().getElement(path);
+            if (typeElement == null || !typeElement.getKind().isClass())
+                return ret;
             List<ElementNode.Description> descriptions = computeUsableFieldsDescriptions(controller, path);
             if (!descriptions.isEmpty()) {
                 Collections.reverse(descriptions);
-                ret.add(new DelegateMethodGenerator(component, ElementNode.Description.create(descriptions)));
+                ret.add(new DelegateMethodGenerator(component, ElementHandle.create(typeElement), ElementNode.Description.create(descriptions)));
             }
             return ret;
         }
     }
 
     private JTextComponent component;
+    private ElementHandle<TypeElement> handle;
     private ElementNode.Description description;
     
     /** Creates a new instance of DelegateMethodGenerator */
-    private DelegateMethodGenerator(JTextComponent component, ElementNode.Description description) {
+    private DelegateMethodGenerator(JTextComponent component, ElementHandle<TypeElement> handle, ElementNode.Description description) {
         this.component = component;
+        this.handle = handle;
         this.description = description;
     }
 
@@ -155,15 +163,21 @@ public class DelegateMethodGenerator implements CodeGenerator {
                     ModificationResult mr = js.runModificationTask(new Task<WorkingCopy>() {
                         public void run(WorkingCopy copy) throws IOException {
                             copy.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
-                            TreePath path = copy.getTreeUtilities().pathFor(caretOffset);
-                            path = Utilities.getPathElementOfKind(Tree.Kind.CLASS, path);
-                            int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
-                            ElementHandle<? extends Element> handle = panel.getDelegateField();
-                            VariableElement delegate = handle != null ? (VariableElement)handle.resolve(copy) : null;
-                            ArrayList<ExecutableElement> methods = new ArrayList<ExecutableElement>();
-                            for (ElementHandle<? extends Element> elementHandle : panel.getDelegateMethods())
-                                methods.add((ExecutableElement)elementHandle.resolve(copy));
-                            generateDelegatingMethods(copy, path, delegate, methods, idx);
+                            Element e = handle.resolve(copy);
+                            TreePath path = e != null ? copy.getTrees().getPath(e) : copy.getTreeUtilities().pathFor(caretOffset);
+                            path = Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path);
+                            if (path == null) {
+                                String message = NbBundle.getMessage(DelegateMethodGenerator.class, "ERR_CannotFindOriginalClass"); //NOI18N
+                                org.netbeans.editor.Utilities.setStatusBoldText(component, message);
+                            } else {
+                                int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
+                                ElementHandle<? extends Element> handle = panel.getDelegateField();
+                                VariableElement delegate = handle != null ? (VariableElement)handle.resolve(copy) : null;
+                                ArrayList<ExecutableElement> methods = new ArrayList<ExecutableElement>();
+                                for (ElementHandle<? extends Element> elementHandle : panel.getDelegateMethods())
+                                    methods.add((ExecutableElement)elementHandle.resolve(copy));
+                                generateDelegatingMethods(copy, path, delegate, methods, idx);
+                            }
                         }
                     });
                     GeneratorUtils.guardedCommit(component, mr);
@@ -217,10 +231,6 @@ public class DelegateMethodGenerator implements CodeGenerator {
 
     static List<ElementNode.Description> computeUsableFieldsDescriptions(CompilationInfo info, TreePath path) {
         Elements elements = info.getElements();
-        TypeElement typeElement = (TypeElement) info.getTrees().getElement(path);
-        if (typeElement == null || !typeElement.getKind().isClass()) {
-            return Collections.emptyList();
-        }
         Trees trees = info.getTrees();
         Scope scope = trees.getScope(path);
         Map<Element, List<ElementNode.Description>> map = new LinkedHashMap<Element, List<ElementNode.Description>>();
@@ -228,21 +238,23 @@ public class DelegateMethodGenerator implements CodeGenerator {
         while (scope != null && (cls = scope.getEnclosingClass()) != null) {
             DeclaredType type = (DeclaredType) cls.asType();
             for (VariableElement field : ElementFilter.fieldsIn(elements.getAllMembers(cls))) {
-                if (!ERROR.contentEquals(field.getSimpleName()) && !field.asType().getKind().isPrimitive() && trees.isAccessible(scope,
+                TypeMirror fieldType = field.asType();
+                if (!ERROR.contentEquals(field.getSimpleName()) && !fieldType.getKind().isPrimitive()
+                        && (fieldType.getKind() != TypeKind.DECLARED || ((DeclaredType)fieldType).asElement() != cls) && trees.isAccessible(scope,
                         field, type)) {
                     List<ElementNode.Description> descriptions = map.get(field.getEnclosingElement());
                     if (descriptions == null) {
                         descriptions = new ArrayList<ElementNode.Description>();
                         map.put(field.getEnclosingElement(), descriptions);
                     }
-                    descriptions.add(ElementNode.Description.create(field, null, false, false));
+                    descriptions.add(ElementNode.Description.create(info, field, null, false, false));
                 }
             }
             scope = scope.getEnclosingScope();
         }
         List<ElementNode.Description> descriptions = new ArrayList<ElementNode.Description>();
         for (Map.Entry<Element, List<ElementNode.Description>> entry : map.entrySet()) {
-            descriptions.add(ElementNode.Description.create(entry.getKey(), entry.getValue(), false, false));
+            descriptions.add(ElementNode.Description.create(info, entry.getKey(), entry.getValue(), false, false));
         }
         
         return descriptions;
@@ -254,21 +266,26 @@ public class DelegateMethodGenerator implements CodeGenerator {
         if (field.asType().getKind() == TypeKind.DECLARED) {
             DeclaredType type = (DeclaredType) field.asType();
             Trees trees = controller.getTrees();
+            ElementUtilities eu = controller.getElementUtilities();
             Scope scope = controller.getTreeUtilities().scopeFor(caretOffset);
+            TypeElement origin = scope.getEnclosingClass();
             Map<Element, List<ElementNode.Description>> map = new LinkedHashMap<Element, List<ElementNode.Description>>();
             for (ExecutableElement method : ElementFilter.methodsIn(controller.getElements().getAllMembers((TypeElement) type.asElement()))) {
                 if (trees.isAccessible(scope, method, type)) {
-                    List<ElementNode.Description> descriptions = map.get(method.getEnclosingElement());
-                    if (descriptions == null) {
-                        descriptions = new ArrayList<ElementNode.Description>();
-                        map.put(method.getEnclosingElement(), descriptions);
+                    Element impl = eu.getImplementationOf(method, origin);
+                    if (impl == null || (!impl.getModifiers().contains(Modifier.FINAL) && impl.getEnclosingElement() != origin)) { 
+                        List<ElementNode.Description> descriptions = map.get(method.getEnclosingElement());
+                        if (descriptions == null) {
+                            descriptions = new ArrayList<ElementNode.Description>();
+                            map.put(method.getEnclosingElement(), descriptions);
+                        }
+                        descriptions.add(ElementNode.Description.create(controller, method, null, true, false));
                     }
-                    descriptions.add(ElementNode.Description.create(method, null, true, false));
                 }
             }
             List<ElementNode.Description> descriptions = new ArrayList<ElementNode.Description>();
             for (Map.Entry<Element, List<ElementNode.Description>> entry : map.entrySet()) {
-                descriptions.add(ElementNode.Description.create(entry.getKey(), entry.getValue(),
+                descriptions.add(ElementNode.Description.create(controller, entry.getKey(), entry.getValue(),
                         false, false));
             }
             if (!descriptions.isEmpty()) {
@@ -281,7 +298,7 @@ public class DelegateMethodGenerator implements CodeGenerator {
     }
     
     static void generateDelegatingMethods(WorkingCopy wc, TreePath path, VariableElement delegate, Iterable<? extends ExecutableElement> methods, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             TreeMaker make = wc.getTreeMaker();
