@@ -44,6 +44,7 @@
 package org.netbeans.modules.java.editor.codegen;
 
 import java.util.Map.Entry;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.spi.editor.codegen.CodeGenerator;
 import com.sun.source.tree.AnnotationTree;
 import com.sun.source.tree.BlockTree;
@@ -75,6 +76,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Random;
 import java.util.Set;
+import javax.lang.model.SourceVersion;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
@@ -123,7 +125,7 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
             JTextComponent component = context.lookup(JTextComponent.class);
             CompilationController controller = context.lookup(CompilationController.class);
             TreePath path = context.lookup(TreePath.class);
-            path = path != null ? Utilities.getPathElementOfKind(Tree.Kind.CLASS, path) : null;
+            path = path != null ? Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path) : null;
             if (component == null || controller == null || path == null)
                 return ret;
             try {
@@ -176,13 +178,13 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
         List<ElementNode.Description> descriptions = new ArrayList<ElementNode.Description>();
         for (VariableElement variableElement : ElementFilter.fieldsIn(typeElement.getEnclosedElements())) {
             if (!ERROR.contentEquals(variableElement.getSimpleName()) && !variableElement.getModifiers().contains(Modifier.STATIC))
-                descriptions.add(ElementNode.Description.create(variableElement, null, true, isUsed(cc, variableElement, equalsHashCode)));
+                descriptions.add(ElementNode.Description.create(cc, variableElement, null, true, isUsed(cc, variableElement, equalsHashCode)));
         }
         if (descriptions.isEmpty() || (equalsHashCode[0] != null && equalsHashCode[1] != null))
             return null;
         return new EqualsHashCodeGenerator(
             component,
-            ElementNode.Description.create(typeElement, descriptions, false, false),
+            ElementNode.Description.create(cc, typeElement, descriptions, false, false),
             equalsHashCode[0] == null,
             equalsHashCode[1] == null
         );
@@ -344,25 +346,31 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
                     ModificationResult mr = js.runModificationTask(new Task<WorkingCopy>() {
                         public void run(WorkingCopy copy) throws IOException {
                             copy.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
-                            TreePath path = copy.getTreeUtilities().pathFor(caretOffset);
-                            path = Utilities.getPathElementOfKind(Tree.Kind.CLASS, path);
-                            int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
-                            ArrayList<VariableElement> equalsElements = new ArrayList<VariableElement>();
-                            if( generateEquals ) {
-                                for (ElementHandle<? extends Element> elementHandle : panel.getEqualsVariables())
-                                    equalsElements.add((VariableElement)elementHandle.resolve(copy));
+                            Element e = description.getElementHandle().resolve(copy);
+                            TreePath path = e != null ? copy.getTrees().getPath(e) : copy.getTreeUtilities().pathFor(caretOffset);
+                            path = Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path);
+                            if (path == null) {
+                                String message = NbBundle.getMessage(EqualsHashCodeGenerator.class, "ERR_CannotFindOriginalClass"); //NOI18N
+                                org.netbeans.editor.Utilities.setStatusBoldText(component, message);
+                            } else {
+                                int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
+                                ArrayList<VariableElement> equalsElements = new ArrayList<VariableElement>();
+                                if( generateEquals ) {
+                                    for (ElementHandle<? extends Element> elementHandle : panel.getEqualsVariables())
+                                        equalsElements.add((VariableElement)elementHandle.resolve(copy));
+                                    }
+                                ArrayList<VariableElement> hashCodeElements = new ArrayList<VariableElement>();
+                                if( generateHashCode ) {
+                                    for (ElementHandle<? extends Element> elementHandle : panel.getHashCodeVariables())
+                                        hashCodeElements.add((VariableElement)elementHandle.resolve(copy));
                                 }
-                            ArrayList<VariableElement> hashCodeElements = new ArrayList<VariableElement>();
-                            if( generateHashCode ) {
-                                for (ElementHandle<? extends Element> elementHandle : panel.getHashCodeVariables())
-                                    hashCodeElements.add((VariableElement)elementHandle.resolve(copy));
+                                generateEqualsAndHashCode(
+                                    copy, path, 
+                                    generateEquals ? equalsElements : null, 
+                                    generateHashCode ? hashCodeElements : null, 
+                                    idx
+                                );
                             }
-                            generateEqualsAndHashCode(
-                                copy, path, 
-                                generateEquals ? equalsElements : null, 
-                                generateHashCode ? hashCodeElements : null, 
-                                idx
-                            );
                         }
                     });
                     GeneratorUtils.guardedCommit(component, mr);
@@ -383,7 +391,7 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
     }
     
     static void generateEqualsAndHashCode(WorkingCopy wc, TreePath path, Iterable<? extends VariableElement> equalsFields, Iterable<? extends VariableElement> hashCodeFields, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             TreeMaker make = wc.getTreeMaker();
@@ -410,7 +418,8 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
     private static MethodTree createEqualsMethod(WorkingCopy wc, Iterable<? extends VariableElement> equalsFields, DeclaredType type, Scope scope) {
         TreeMaker make = wc.getTreeMaker();
         Set<Modifier> mods = EnumSet.of(Modifier.PUBLIC);
-        List<VariableTree> params = Collections.singletonList(make.Variable(make.Modifiers(EnumSet.noneOf(Modifier.class)), "obj", make.Type(wc.getElements().getTypeElement("java.lang.Object").asType()), null)); //NOI18N
+        TypeElement objElement = wc.getElements().getTypeElement("java.lang.Object"); //NOI18N
+        List<VariableTree> params = Collections.singletonList(make.Variable(make.Modifiers(EnumSet.noneOf(Modifier.class)), "obj", objElement != null ? make.Type(objElement.asType()) : make.Identifier("Object"), null)); //NOI18N
         
         List<StatementTree> statements = new ArrayList<StatementTree>();
         //if (obj == null) return false;
@@ -580,7 +589,7 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
         EQUALS_PATTERNS.put(new SimpleAcceptor(KindOfType.ENUM), "this.{VAR} != other.{VAR}");
         EQUALS_PATTERNS.put(new SimpleAcceptor(KindOfType.ARRAY_PRIMITIVE), "! java.util.Arrays.equals(this.{VAR}, other.{VAR}");
         EQUALS_PATTERNS.put(new SimpleAcceptor(KindOfType.ARRAY), "! java.util.Arrays.deepEquals(this.{VAR}, other.{VAR}");
-        EQUALS_PATTERNS.put(new MethodExistsAcceptor("java.util.Objects", "equals"), "! java.util.Objects.equals(this.{VAR}, other.{VAR})");
+        EQUALS_PATTERNS.put(new MethodExistsAcceptor("java.util.Objects", "equals", SourceVersion.RELEASE_7), "! java.util.Objects.equals(this.{VAR}, other.{VAR})");
         EQUALS_PATTERNS.put(new SimpleAcceptor(KindOfType.STRING), "(this.{VAR} == null) ? (other.{VAR} != null) : !this.{VAR}.equals(other.{VAR})");
         EQUALS_PATTERNS.put(new SimpleAcceptor(KindOfType.OTHER), "this.{VAR} != other.{VAR} && (this.{VAR} == null || !this.{VAR}.equals(other.{VAR}))");
 
@@ -590,11 +599,11 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.LONG), "(int) (this.{VAR} ^ (this.{VAR} >>> 32))");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.FLOAT), "java.lang.Float.floatToIntBits(this.{VAR})");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.DOUBLE), "(int) (Double.doubleToLongBits(this.{VAR}) ^ (Double.doubleToLongBits(this.{VAR}) >>> 32))");
-        HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.BOOLEAN), "this.{VAR} ? 1 : 0");
+        HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.BOOLEAN), "(this.{VAR} ? 1 : 0)");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.ENUM), "(this.{VAR} != null ? this.{VAR}.hashCode() : 0)");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.ARRAY_PRIMITIVE), "java.util.Arrays.hashCode(this.{VAR}");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.ARRAY), "java.util.Arrays.deepHashCode(this.{VAR}");
-        HASH_CODE_PATTERNS.put(new MethodExistsAcceptor("java.util.Objects", "hashCode"), "java.util.Objects.hashCode(this.{VAR})");
+        HASH_CODE_PATTERNS.put(new MethodExistsAcceptor("java.util.Objects", "hashCode", SourceVersion.RELEASE_7), "java.util.Objects.hashCode(this.{VAR})");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.STRING), "(this.{VAR} != null ? this.{VAR}.hashCode() : 0)");
         HASH_CODE_PATTERNS.put(new SimpleAcceptor(KindOfType.OTHER), "(this.{VAR} != null ? this.{VAR}.hashCode() : 0)");
     }
@@ -624,13 +633,21 @@ public class EqualsHashCodeGenerator implements CodeGenerator {
     private static final class MethodExistsAcceptor implements Acceptor {
         private final String fqn;
         private final String methodName;
+        private final SourceVersion minimalVersion;
 
         public MethodExistsAcceptor(String fqn, String methodName) {
+            this(fqn, methodName, null);
+        }
+
+        public MethodExistsAcceptor(String fqn, String methodName, SourceVersion minimalVersion) {
             this.fqn = fqn;
             this.methodName = methodName;
+            this.minimalVersion = minimalVersion;
         }
 
         public boolean accept(CompilationInfo info, TypeMirror tm) {
+            if (minimalVersion != null && minimalVersion.compareTo(info.getSourceVersion()) > 0) return false;
+            
             TypeElement clazz = info.getElements().getTypeElement(fqn);
 
             if (clazz == null) {
