@@ -117,7 +117,7 @@ public class GeneratorUtils {
     }
     
     public static ClassTree insertClassMember(WorkingCopy copy, TreePath path, Tree member) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TreeUtilities tu = copy.getTreeUtilities();
         int idx = 0;
         for (Tree tree : ((ClassTree)path.getLeaf()).getMembers()) {
@@ -129,7 +129,7 @@ public class GeneratorUtils {
     }
 
     public static ClassTree insertMethodAfter(WorkingCopy copy, TreePath path, MethodTree member, MethodTree precedingMethod) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TreeUtilities tu = copy.getTreeUtilities();
         int idx = 0;
         for (Tree tree : ((ClassTree)path.getLeaf()).getMembers()) {
@@ -241,7 +241,7 @@ public class GeneratorUtils {
     }
 
     public static void generateAllAbstractMethodImplementations(WorkingCopy wc, TreePath path) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             TreeMaker make = wc.getTreeMaker();
@@ -257,7 +257,7 @@ public class GeneratorUtils {
     }
     
     public static void generateAbstractMethodImplementations(WorkingCopy wc, TreePath path, List<? extends ExecutableElement> elements, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             TreeMaker make = wc.getTreeMaker();
@@ -271,7 +271,7 @@ public class GeneratorUtils {
     }
     
     public static void generateAbstractMethodImplementation(WorkingCopy wc, TreePath path, ExecutableElement element, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             GeneratorUtilities gu = GeneratorUtilities.get(wc);
@@ -281,7 +281,7 @@ public class GeneratorUtils {
     }
     
     public static void generateMethodOverrides(WorkingCopy wc, TreePath path, List<? extends ExecutableElement> elements, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             TreeMaker make = wc.getTreeMaker();
@@ -295,7 +295,7 @@ public class GeneratorUtils {
     }
     
     public static void generateMethodOverride(WorkingCopy wc, TreePath path, ExecutableElement element, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             GeneratorUtilities gu = GeneratorUtilities.get(wc);
@@ -326,7 +326,7 @@ public class GeneratorUtils {
     }
     
     public static void generateGettersAndSetters(WorkingCopy wc, TreePath path, Iterable<? extends VariableElement> fields, int type, int index) {
-        assert path.getLeaf().getKind() == Tree.Kind.CLASS;
+        assert TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind());
         TypeElement te = (TypeElement)wc.getTrees().getElement(path);
         if (te != null) {
             TreeMaker make = wc.getTreeMaker();
@@ -346,7 +346,7 @@ public class GeneratorUtils {
         }
     }
     
-    public static boolean hasGetter(CompilationInfo info, VariableElement field, Map<String, List<ExecutableElement>> methods) {
+    public static boolean hasGetter(CompilationInfo info, TypeElement typeElement, VariableElement field, Map<String, List<ExecutableElement>> methods) {
         CharSequence name = field.getSimpleName();
         assert name.length() > 0;
         TypeMirror type = field.asType();
@@ -356,14 +356,16 @@ public class GeneratorUtils {
         List<ExecutableElement> candidates = methods.get(sb.toString());
         if (candidates != null) {
             for (ExecutableElement candidate : candidates) {
-                if (candidate.getParameters().isEmpty() && types.isSameType(candidate.getReturnType(), type))
+                if ((!candidate.getModifiers().contains(Modifier.ABSTRACT) || candidate.getEnclosingElement() == typeElement)
+                        && candidate.getParameters().isEmpty()
+                        && types.isSameType(candidate.getReturnType(), type))
                     return true;
             }
         }
         return false;
     }
     
-    public static boolean hasSetter(CompilationInfo info, VariableElement field, Map<String, List<ExecutableElement>> methods) {
+    public static boolean hasSetter(CompilationInfo info, TypeElement typeElement, VariableElement field, Map<String, List<ExecutableElement>> methods) {
         CharSequence name = field.getSimpleName();
         assert name.length() > 0;
         TypeMirror type = field.asType();
@@ -373,7 +375,10 @@ public class GeneratorUtils {
         List<ExecutableElement> candidates = methods.get(sb.toString());
         if (candidates != null) {
             for (ExecutableElement candidate : candidates) {
-                if (candidate.getReturnType().getKind() == TypeKind.VOID && candidate.getParameters().size() == 1 && types.isSameType(candidate.getParameters().get(0).asType(), type))
+                if ((!candidate.getModifiers().contains(Modifier.ABSTRACT) || candidate.getEnclosingElement() == typeElement)
+                        && candidate.getReturnType().getKind() == TypeKind.VOID
+                        && candidate.getParameters().size() == 1
+                        && types.isSameType(candidate.getParameters().get(0).asType(), type))
                     return true;
             }
         }
@@ -578,7 +583,7 @@ public class GeneratorUtils {
      * @return true if it does
      */ 
     private static boolean overridesPackagePrivateOutsidePackage(ExecutableElement ee, TypeElement impl) {
-        String elemPackageName = ee.getEnclosingElement().getEnclosingElement().getSimpleName().toString();
+        String elemPackageName = getPackageName(ee);
         String currentPackageName = getPackageName(impl);
         if(!ee.getModifiers().contains(Modifier.PRIVATE) && !ee.getModifiers().contains(Modifier.PUBLIC) && !ee.getModifiers().contains(Modifier.PROTECTED) && !currentPackageName.equals(elemPackageName))
             return true;
@@ -626,7 +631,10 @@ public class GeneratorUtils {
             int ret = 0;
             ModifiersTree modifiers = null;
             switch (tree.getKind()) {
+            case ANNOTATION_TYPE:
             case CLASS:
+            case ENUM:
+            case INTERFACE:
                 ret = 400;
                 modifiers = ((ClassTree)tree).getModifiers();
                 break;
@@ -660,7 +668,10 @@ public class GeneratorUtils {
         
         private static String getSortText(Tree tree) {
             switch (tree.getKind()) {
+            case ANNOTATION_TYPE:
             case CLASS:
+            case ENUM:
+            case INTERFACE:
                 return ((ClassTree)tree).getSimpleName().toString();
             case METHOD:
                 MethodTree mt = (MethodTree)tree;
