@@ -45,7 +45,6 @@ package org.netbeans.modules.java.editor.codegen;
 
 import org.netbeans.spi.editor.codegen.CodeGenerator;
 import com.sun.source.tree.ClassTree;
-import com.sun.source.tree.Tree;
 import com.sun.source.util.TreePath;
 import java.awt.Dialog;
 import java.io.IOException;
@@ -68,6 +67,7 @@ import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.ModificationResult;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.modules.editor.java.Utilities;
 import org.netbeans.modules.java.editor.codegen.ui.ElementNode;
@@ -93,7 +93,7 @@ public class GetterSetterGenerator implements CodeGenerator {
             JTextComponent component = context.lookup(JTextComponent.class);
             CompilationController controller = context.lookup(CompilationController.class);
             TreePath path = context.lookup(TreePath.class);
-            path = path != null ? Utilities.getPathElementOfKind(Tree.Kind.CLASS, path) : null;
+            path = path != null ? Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path) : null;
             if (component == null || controller == null || path == null)
                 return ret;
             try {
@@ -120,9 +120,9 @@ public class GetterSetterGenerator implements CodeGenerator {
             for (VariableElement variableElement : ElementFilter.fieldsIn(elements.getAllMembers(typeElement))) {
                 if (ERROR.contentEquals(variableElement.getSimpleName()))
                     continue;
-                ElementNode.Description description = ElementNode.Description.create(variableElement, null, true, false);
-                boolean hasGetter = GeneratorUtils.hasGetter(controller, variableElement, methods);
-                boolean hasSetter = variableElement.getModifiers().contains(Modifier.FINAL) || GeneratorUtils.hasSetter(controller, variableElement, methods);
+                ElementNode.Description description = ElementNode.Description.create(controller, variableElement, null, true, false);
+                boolean hasGetter = GeneratorUtils.hasGetter(controller, typeElement, variableElement, methods);
+                boolean hasSetter = variableElement.getModifiers().contains(Modifier.FINAL) || GeneratorUtils.hasSetter(controller, typeElement, variableElement, methods);
                 if (!hasGetter) {
                     List<ElementNode.Description> descriptions = gDescriptions.get(variableElement.getEnclosingElement());
                     if (descriptions == null) {
@@ -151,23 +151,23 @@ public class GetterSetterGenerator implements CodeGenerator {
             if (!gDescriptions.isEmpty()) {
                 List<ElementNode.Description> descriptions = new ArrayList<ElementNode.Description>();
                 for (Map.Entry<Element, List<ElementNode.Description>> entry : gDescriptions.entrySet())
-                    descriptions.add(ElementNode.Description.create(entry.getKey(), entry.getValue(), false, false));
+                    descriptions.add(ElementNode.Description.create(controller, entry.getKey(), entry.getValue(), false, false));
                 Collections.reverse(descriptions);
-                ret.add(new GetterSetterGenerator(component, ElementNode.Description.create(typeElement, descriptions, false, false), GeneratorUtils.GETTERS_ONLY));
+                ret.add(new GetterSetterGenerator(component, ElementNode.Description.create(controller, typeElement, descriptions, false, false), GeneratorUtils.GETTERS_ONLY));
             }
             if (!sDescriptions.isEmpty()) {
                 List<ElementNode.Description> descriptions = new ArrayList<ElementNode.Description>();
                 for (Map.Entry<Element, List<ElementNode.Description>> entry : sDescriptions.entrySet())
-                    descriptions.add(ElementNode.Description.create(entry.getKey(), entry.getValue(), false, false));
+                    descriptions.add(ElementNode.Description.create(controller, entry.getKey(), entry.getValue(), false, false));
                 Collections.reverse(descriptions);
-                ret.add(new GetterSetterGenerator(component, ElementNode.Description.create(typeElement, descriptions, false, false), GeneratorUtils.SETTERS_ONLY));
+                ret.add(new GetterSetterGenerator(component, ElementNode.Description.create(controller, typeElement, descriptions, false, false), GeneratorUtils.SETTERS_ONLY));
             }
             if (!gsDescriptions.isEmpty()) {
                 List<ElementNode.Description> descriptions = new ArrayList<ElementNode.Description>();
                 for (Map.Entry<Element, List<ElementNode.Description>> entry : gsDescriptions.entrySet())
-                    descriptions.add(ElementNode.Description.create(entry.getKey(), entry.getValue(), false, false));
+                    descriptions.add(ElementNode.Description.create(controller, entry.getKey(), entry.getValue(), false, false));
                 Collections.reverse(descriptions);
-                ret.add(new GetterSetterGenerator(component, ElementNode.Description.create(typeElement, descriptions, false, false), 0));
+                ret.add(new GetterSetterGenerator(component, ElementNode.Description.create(controller, typeElement, descriptions, false, false), 0));
             }
             return ret;
         }
@@ -212,13 +212,19 @@ public class GetterSetterGenerator implements CodeGenerator {
                     ModificationResult mr = js.runModificationTask(new Task<WorkingCopy>() {
                         public void run(WorkingCopy copy) throws IOException {
                             copy.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
-                            TreePath path = copy.getTreeUtilities().pathFor(caretOffset);
-                            path = Utilities.getPathElementOfKind(Tree.Kind.CLASS, path);
-                            int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
-                            ArrayList<VariableElement> variableElements = new ArrayList<VariableElement>();
-                            for (ElementHandle<? extends Element> elementHandle : panel.getVariables())
-                                variableElements.add((VariableElement)elementHandle.resolve(copy));
-                            GeneratorUtils.generateGettersAndSetters(copy, path, variableElements, type, idx);
+                            Element e = description.getElementHandle().resolve(copy);
+                            TreePath path = e != null ? copy.getTrees().getPath(e) : copy.getTreeUtilities().pathFor(caretOffset);
+                            path = Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path);
+                            if (path == null) {
+                                String message = NbBundle.getMessage(GetterSetterGenerator.class, "ERR_CannotFindOriginalClass"); //NOI18N
+                                org.netbeans.editor.Utilities.setStatusBoldText(component, message);
+                            } else {
+                                int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
+                                ArrayList<VariableElement> variableElements = new ArrayList<VariableElement>();
+                                for (ElementHandle<? extends Element> elementHandle : panel.getVariables())
+                                    variableElements.add((VariableElement)elementHandle.resolve(copy));
+                                GeneratorUtils.generateGettersAndSetters(copy, path, variableElements, type, idx);
+                            }
                         }
                     });
                     GeneratorUtils.guardedCommit(component, mr);
