@@ -62,6 +62,7 @@ import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.ModificationResult;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.modules.editor.java.Utilities;
 import org.netbeans.modules.java.editor.codegen.ui.ElementNode;
@@ -85,7 +86,7 @@ public class ImplementOverrideMethodGenerator implements CodeGenerator {
             JTextComponent component = context.lookup(JTextComponent.class);
             CompilationController controller = context.lookup(CompilationController.class);
             TreePath path = context.lookup(TreePath.class);
-            path = path != null ? Utilities.getPathElementOfKind(Tree.Kind.CLASS, path) : null;
+            path = path != null ? Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path) : null;
             if (component == null || controller == null || path == null)
                 return ret;
             try {
@@ -103,13 +104,13 @@ public class ImplementOverrideMethodGenerator implements CodeGenerator {
                     descriptions = new ArrayList<ElementNode.Description>();
                     map.put(method.getEnclosingElement(), descriptions);
                 }
-                descriptions.add(ElementNode.Description.create(method, null, true, false));
+                descriptions.add(ElementNode.Description.create(controller, method, null, true, false));
             }
             List<ElementNode.Description> implementDescriptions = new ArrayList<ElementNode.Description>();
             for (Map.Entry<Element, List<ElementNode.Description>> entry : map.entrySet())
-                implementDescriptions.add(ElementNode.Description.create(entry.getKey(), entry.getValue(), false, false));
+                implementDescriptions.add(ElementNode.Description.create(controller, entry.getKey(), entry.getValue(), false, false));
             if (!implementDescriptions.isEmpty())
-                ret.add(new ImplementOverrideMethodGenerator(component, ElementNode.Description.create(implementDescriptions), true));
+                ret.add(new ImplementOverrideMethodGenerator(component, ElementHandle.create(typeElement), ElementNode.Description.create(implementDescriptions), true));
             map = new LinkedHashMap<Element, List<ElementNode.Description>>();
             ArrayList<Element> orderedElements = new ArrayList<Element>();
             for (ExecutableElement method : GeneratorUtils.findOverridable(controller, typeElement)) {
@@ -121,24 +122,26 @@ public class ImplementOverrideMethodGenerator implements CodeGenerator {
                     if( !orderedElements.contains( e ) )
                         orderedElements.add( e );
                 }
-                descriptions.add(ElementNode.Description.create(method, null, true, false));
+                descriptions.add(ElementNode.Description.create(controller, method, null, true, false));
             }
             List<ElementNode.Description> overrideDescriptions = new ArrayList<ElementNode.Description>();
             for (Element e : orderedElements)
-                overrideDescriptions.add(ElementNode.Description.create(e, map.get( e ), false, false));
+                overrideDescriptions.add(ElementNode.Description.create(controller, e, map.get( e ), false, false));
             if (!overrideDescriptions.isEmpty())
-                ret.add(new ImplementOverrideMethodGenerator(component, ElementNode.Description.create(overrideDescriptions), false));
+                ret.add(new ImplementOverrideMethodGenerator(component, ElementHandle.create(typeElement), ElementNode.Description.create(overrideDescriptions), false));
             return ret;
         }
     }
 
     private JTextComponent component;
+    private ElementHandle<TypeElement> handle;
     private ElementNode.Description description;
     private boolean isImplement;
     
     /** Creates a new instance of OverrideMethodGenerator */
-    private ImplementOverrideMethodGenerator(JTextComponent component, ElementNode.Description description, boolean isImplement) {
+    private ImplementOverrideMethodGenerator(JTextComponent component, ElementHandle<TypeElement> handle, ElementNode.Description description, boolean isImplement) {
         this.component = component;
+        this.handle = handle;
         this.description = description;
         this.isImplement = isImplement;
     }
@@ -161,18 +164,22 @@ public class ImplementOverrideMethodGenerator implements CodeGenerator {
                     ModificationResult mr = js.runModificationTask(new Task<WorkingCopy>() {
                         public void run(WorkingCopy copy) throws IOException {
                             copy.toPhase(JavaSource.Phase.ELEMENTS_RESOLVED);
-                            TreePath path = copy.getTreeUtilities().pathFor(caretOffset);
-                            path = Utilities.getPathElementOfKind(Tree.Kind.CLASS, path);
-                            if (path == null)
-                                return;
-                            int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
-                            ArrayList<ExecutableElement> methodElements = new ArrayList<ExecutableElement>();
-                            for (ElementHandle<? extends Element> elementHandle : panel.getSelectedMethods())
-                                methodElements.add((ExecutableElement)elementHandle.resolve(copy));
-                            if (isImplement)
-                                GeneratorUtils.generateAbstractMethodImplementations(copy, path, methodElements, idx);
-                            else
-                                GeneratorUtils.generateMethodOverrides(copy, path, methodElements, idx);
+                            Element e = handle.resolve(copy);
+                            TreePath path = e != null ? copy.getTrees().getPath(e) : copy.getTreeUtilities().pathFor(caretOffset);
+                            path = Utilities.getPathElementOfKind(TreeUtilities.CLASS_TREE_KINDS, path);
+                            if (path == null) {
+                                String message = NbBundle.getMessage(ImplementOverrideMethodGenerator.class, "ERR_CannotFindOriginalClass"); //NOI18N
+                                org.netbeans.editor.Utilities.setStatusBoldText(component, message);
+                            } else {
+                                int idx = GeneratorUtils.findClassMemberIndex(copy, (ClassTree)path.getLeaf(), caretOffset);
+                                ArrayList<ExecutableElement> methodElements = new ArrayList<ExecutableElement>();
+                                for (ElementHandle<? extends Element> elementHandle : panel.getSelectedMethods())
+                                    methodElements.add((ExecutableElement)elementHandle.resolve(copy));
+                                if (isImplement)
+                                    GeneratorUtils.generateAbstractMethodImplementations(copy, path, methodElements, idx);
+                                else
+                                    GeneratorUtils.generateMethodOverrides(copy, path, methodElements, idx);
+                            }
                         }
                     });
                     GeneratorUtils.guardedCommit(component, mr);
