@@ -295,6 +295,7 @@ public class ImportClassPanel extends javax.swing.JPanel {
                     // copy of compilation unit.
                     if (imports.contains(njuImport)) {
                         cutCopy = make.CompilationUnit(
+                            cut.getPackageAnnotations(),
                             cut.getPackageName(),
                             imports,
                             cut.getTypeDecls(),
@@ -355,7 +356,6 @@ public class ImportClassPanel extends javax.swing.JPanel {
         private static int LIGHTER_COLOR_COMPONENT = DARKER_COLOR_COMPONENT;
                 
         
-        private Color denidedColor = new Color( 0x80, 0x80, 0x80 ); 
         private Color fgColor;
         private Color bgColor;
         private Color bgColorDarker;
@@ -393,9 +393,10 @@ public class ImportClassPanel extends javax.swing.JPanel {
             if ( value instanceof TypeDescription ) {
                 TypeDescription td = (TypeDescription)value;                
                  // setIcon(td.getIcon());
-                setText(td.qualifiedName);
                 if ( td.isDenied ) {
-                    setForeground( denidedColor );
+                    setText(JavaFixAllImports.NOT_VALID_IMPORT_HTML + td.qualifiedName);
+                } else {
+                    setText(td.qualifiedName);
                 }
                 setIcon( ElementIcons.getElementIcon( td.kind, null ) );
             }
