@@ -96,6 +96,9 @@ import org.openide.util.RequestProcessor;
  */
 public class JavaFixAllImports {
     
+    //-J-Dorg.netbeans.modules.java.editor.imports.JavaFixAllImports.invalid_import_html="<html><font color='#808080'>"
+    public static final String NOT_VALID_IMPORT_HTML = System.getProperty(JavaFixAllImports.class.getName() + ".invalid_import_html", "");
+    
     private static final String PREFS_KEY = JavaFixAllImports.class.getName();
     private static final String KEY_REMOVE_UNUSED_IMPORTS = "removeUnusedImports"; // NOI18N
     private static final JavaFixAllImports INSTANCE = new JavaFixAllImports();
@@ -234,7 +237,7 @@ public class JavaFixAllImports {
             currentToImport--;
         }
         // return a copy of the unit with changed imports section
-        return make.CompilationUnit(cut.getPackageName(), imports, cut.getTypeDecls(), cut.getSourceFile());
+        return make.CompilationUnit(cut.getPackageAnnotations(), cut.getPackageName(), imports, cut.getTypeDecls(), cut.getSourceFile());
     }
     
     private static void performFixImports(WorkingCopy wc, ImportData data, String[] selections, boolean removeUnusedImports) throws IOException {
@@ -326,15 +329,19 @@ public class JavaFixAllImports {
                     }
                     data.fqn2TE.put(e.getQualifiedName().toString(), e);
                 }
+                
+                if (data.defaults[index] != null)
+                    minImportanceLevel = Integer.MIN_VALUE;
 
                 for (TypeElement e : unfilteredVars) {
                     if (filteredVars.contains(e))
                         continue;
 
                     String fqn = e.getQualifiedName().toString();
-                    String dn = "<html><font color='#808080'><s>" + fqn;
+                    String dn = NOT_VALID_IMPORT_HTML + fqn;
 
                     data.variants[index][++i] = dn;
+                    data.icons[index][i] = ElementIcons.getElementIcon(e.getKind(), e.getModifiers());
                     int level = Utilities.getImportanceLevel(fqn);
                     if (level < minImportanceLevel) {
                         data.defaults[index] = data.variants[index][i];
@@ -414,9 +421,12 @@ public class JavaFixAllImports {
                         try {
                             js.runModificationTask(new Task<WorkingCopy>() {
                                 public void run(WorkingCopy wc) throws Exception {
-                                    cancel.setEnabled(false);
-                                    ((JDialog) d).setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
-                                    
+                                    SwingUtilities.invokeLater(new Runnable() {
+                                        public void run() {
+                                            cancel.setEnabled(false);
+                                            ((JDialog)d).setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
+                                        }
+                                    });                                    
                                     wc.toPhase(Phase.RESOLVED);
                                     if (stop.get()) return;
                                     performFixImports(wc, data, selections, removeUnusedImports);
@@ -427,7 +437,11 @@ public class JavaFixAllImports {
                         }
 
                         prefs.putBoolean(KEY_REMOVE_UNUSED_IMPORTS, removeUnusedImports);
-                        d.setVisible(false);
+                        SwingUtilities.invokeLater(new Runnable() {
+                            public void run() {
+                                d.setVisible(false);
+                            }
+                        });
                     }
                 });
             }
