@@ -65,6 +65,7 @@ import javax.swing.text.Document;
 import javax.swing.text.JTextComponent;
 import javax.swing.text.StyledDocument;
 import org.netbeans.api.editor.completion.Completion;
+import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.modules.editor.java.JavaCompletionItem;
 import org.netbeans.modules.java.editor.javadoc.TagRegistery.TagEntry;
 import org.netbeans.spi.editor.completion.CompletionItem;
@@ -214,21 +215,21 @@ final class JavadocCompletionItem implements CompletionItem {
                 null, JAVADOC_PARAM_ICON, 100);
     }
     
-    public static CompletionItem createExecutableItem(ExecutableElement e,
+    public static CompletionItem createExecutableItem(CompilationInfo info, ExecutableElement e,
             ExecutableType et, int startOffset, boolean isInherited,
             boolean isDeprecated) {
         
         CompletionItem delegate = JavaCompletionItem.createExecutableItem(
-                e, et, startOffset, isInherited, isDeprecated, false, false);
+                info, e, et, startOffset, isInherited, isDeprecated, false, false, false, false);
         return new JavadocExecutableItem(delegate, e, startOffset);
     }
     
-    public static CompletionItem createTypeItem(TypeElement elem,
+    public static CompletionItem createTypeItem(CompilationInfo info, TypeElement elem,
             int startOffset, boolean displayPkgName, boolean isDeprecated) {
         
         CompletionItem delegate = JavaCompletionItem.createTypeItem(
-                elem, (DeclaredType) elem.asType(), startOffset,
-                displayPkgName, isDeprecated, false, false, false);
+                info, elem, (DeclaredType) elem.asType(), startOffset,
+                displayPkgName, isDeprecated, false, false, false, false, false);
         return new JavadocTypeItem(delegate, startOffset);
     }
     
@@ -362,7 +363,20 @@ final class JavadocCompletionItem implements CompletionItem {
         }
 
         public boolean instantSubstitution(JTextComponent component) {
-            return delegate.instantSubstitution(component);
+            if (component != null) {
+                try {
+                    int caretOffset = component.getSelectionEnd();
+                    if (caretOffset > substitutionOffset) {
+                        String text = component.getDocument().getText(substitutionOffset, caretOffset - substitutionOffset);
+                        if (!getInsertPrefix().toString().startsWith(text)) {
+                            return false;
+                        }
+                    }
+                }
+                catch (BadLocationException ble) {}
+            }
+            defaultAction(component);
+            return true;
         }
 
         public int getSortPriority() {
@@ -404,9 +418,6 @@ final class JavadocCompletionItem implements CompletionItem {
                     case '.':
                         JTextComponent comp = (JTextComponent) evt.getSource();
                         delegate.defaultAction(comp);
-                        // ugly but should work for now
-                        complete(comp, String.valueOf(evt.getKeyChar()), comp.getCaretPosition());
-                        evt.consume();
                         break;
                 }
             }
