@@ -553,7 +553,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
             }
             
             completeTypeVarName(emd, prefix, substitutionOffset);
-        } else if (jdctx.jdoc.isClass()) {
+        } else if (jdctx.jdoc.isClass() || jdctx.jdoc.isInterface()) {
             completeTypeVarName(jdctx.jdoc, prefix, substitutionOffset);
         }
     }
@@ -568,7 +568,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
             }
         }
 
-        com.sun.javadoc.TypeVariable[] tparams = holder.isClass()
+        com.sun.javadoc.TypeVariable[] tparams = (holder.isClass() || holder.isInterface())
                 ? ((ClassDoc) holder).typeParameters()
                 : ((ExecutableMemberDoc) holder).typeParameters();
         
@@ -655,9 +655,9 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                     continue;
                 }
                 items.add(JavaCompletionItem.createTypeItem(
-                        typeElement, (DeclaredType) typeElement.asType(),
+                        jdctx.javac, typeElement, (DeclaredType) typeElement.asType(),
                         substitutionOffset, typeName != qualTypeName,
-                        elements.isDeprecated(typeElement), false, false, true));
+                        elements.isDeprecated(typeElement), false, false, false, true, false));
             }
         }
 
@@ -795,13 +795,13 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                 case ENUM_CONSTANT:
                 case FIELD:
                     TypeMirror tm = type.getKind() == TypeKind.DECLARED ? types.asMemberOf((DeclaredType)type, e) : e.asType();
-                    items.add(JavaCompletionItem.createVariableItem((VariableElement) e, tm, substitutionOffset, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), /*isOfSmartType(env, tm, smartTypes)*/false));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement) e, tm, substitutionOffset, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), /*isOfSmartType(env, tm, smartTypes)*/false, false));
                     break;
                 case CONSTRUCTOR:
                 case METHOD:
                     ExecutableType et = (ExecutableType)(type.getKind() == TypeKind.DECLARED ? types.asMemberOf((DeclaredType)type, e) : e.asType());
 //                    items.add(JavaCompletionItem.createExecutableItem((ExecutableElement) e, et, substitutionOffset, typeElem != e.getEnclosingElement(), elements.isDeprecated(e), inImport, /*isOfSmartType(env, et.getReturnType(), smartTypes)*/false));
-                    items.add(JavadocCompletionItem.createExecutableItem((ExecutableElement) e, et, substitutionOffset, typeElem != e.getEnclosingElement(), elements.isDeprecated(e)));
+                    items.add(JavadocCompletionItem.createExecutableItem(controller, (ExecutableElement) e, et, substitutionOffset, typeElem != e.getEnclosingElement(), elements.isDeprecated(e)));
                     break;
 //                case CLASS:
 //                case ENUM:
@@ -901,18 +901,18 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
         for (Element e : controller.getElementUtilities().getLocalMembersAndVars(scope, acceptor)) {
             switch (e.getKind()) {
                 case ENUM_CONSTANT:
-                    items.add(JavaCompletionItem.createVariableItem((VariableElement)e, e.asType(), substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, e.asType(), smartTypes)*/));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, e.asType(), substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, e.asType(), smartTypes)*/, false));
                     break;
                 case FIELD:
                     String name = e.getSimpleName().toString();
                     TypeMirror tm = asMemberOf(e, enclClass != null ? enclClass.asType() : null, types);
-                    items.add(JavaCompletionItem.createVariableItem((VariableElement)e, tm, substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, tm, smartTypes)*/));
+                    items.add(JavaCompletionItem.createVariableItem(controller, (VariableElement)e, tm, substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false/*isOfSmartType(env, tm, smartTypes)*/, false));
                     break;
                 case CONSTRUCTOR:
                 case METHOD:
                     ExecutableType et = (ExecutableType)asMemberOf(e, enclClass != null ? enclClass.asType() : null, types);
 //                    items.add(JavaCompletionItem.createExecutableItem((ExecutableElement)e, et, substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e), false, false/*isOfSmartType(env, et.getReturnType(), smartTypes)*/));
-                    items.add(JavadocCompletionItem.createExecutableItem((ExecutableElement) e, et, substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e)));
+                    items.add(JavadocCompletionItem.createExecutableItem(controller, (ExecutableElement) e, et, substitutionOffset, scope.getEnclosingClass() != e.getEnclosingElement(), elements.isDeprecated(e)));
                     break;
             }
         }
@@ -945,7 +945,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                 for(DeclaredType subtype : getSubtypesOf(baseType, prefix, jdctx)) {
                     TypeElement elem = (TypeElement)subtype.asElement();
                     if (Utilities.isShowDeprecatedMembers() || !elements.isDeprecated(elem))
-                        items.add(JavaCompletionItem.createTypeItem(elem, subtype, substitutionOffset, true, elements.isDeprecated(elem), false, false, false));
+                        items.add(JavaCompletionItem.createTypeItem(jdctx.javac, elem, subtype, substitutionOffset, true, elements.isDeprecated(elem), false, false, false, false, false));
                 }
             }
         } else {
@@ -982,7 +982,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                 case ENUM:
                 case INTERFACE:
                 case ANNOTATION_TYPE:
-                    items.add(JavadocCompletionItem.createTypeItem((TypeElement) e, substitutionOffset, false, elements.isDeprecated(e)));
+                    items.add(JavadocCompletionItem.createTypeItem(env.javac, (TypeElement) e, substitutionOffset, false, elements.isDeprecated(e)));
                     break;
             }                
         }
@@ -997,7 +997,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
             }
         };
         for (TypeElement e : controller.getElementUtilities().getGlobalTypes(acceptor)) {
-            items.add(JavadocCompletionItem.createTypeItem(e, substitutionOffset, false, elements.isDeprecated(e)));
+            items.add(JavadocCompletionItem.createTypeItem(env.javac, e, substitutionOffset, false, elements.isDeprecated(e)));
         }
     }
 
@@ -1028,7 +1028,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
             if (e.getKind().isClass() || e.getKind().isInterface()) {
                 String name = e.getSimpleName().toString();
                     if (Utilities.startsWith(name, prefix) && (Utilities.isShowDeprecatedMembers() || !elements.isDeprecated(e)) && trees.isAccessible(scope, (TypeElement)e) && isOfKindAndType(e.asType(), e, kinds, baseType, scope, trees, types)) {
-                        items.add(JavadocCompletionItem.createTypeItem((TypeElement) e, substitutionOffset, false, elements.isDeprecated(e)/*, isOfSmartType(env, e.asType(), smartTypes)*/));
+                        items.add(JavadocCompletionItem.createTypeItem(jdctx.javac, (TypeElement) e, substitutionOffset, false, elements.isDeprecated(e)/*, isOfSmartType(env, e.asType(), smartTypes)*/));
                 }
             }
         }
@@ -1048,7 +1048,7 @@ final class JavadocCompletionQuery extends AsyncCompletionQuery{
                         && trees.isAccessible(scope, (TypeElement)e)
                         && isOfKindAndType(e.asType(), e, kinds, baseType, scope, trees, types)
                         && !Utilities.isExcluded(Utilities.getElementName(e, true))) {
-                        items.add(JavadocCompletionItem.createTypeItem((TypeElement) e, substitutionOffset, false, elements.isDeprecated(e)/*, isOfSmartType(env, e.asType(), smartTypes)*/));
+                        items.add(JavadocCompletionItem.createTypeItem(jdctx.javac, (TypeElement) e, substitutionOffset, false, elements.isDeprecated(e)/*, isOfSmartType(env, e.asType(), smartTypes)*/));
                 }
             }
         }
