@@ -64,6 +64,7 @@ import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.ElementScanner6;
 import javax.swing.text.Document;
+
 import org.netbeans.api.java.lexer.JavadocTokenId;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.lexer.Token;
@@ -123,20 +124,28 @@ public final class JavadocImports {
             } else {
                 tags = Collections.emptyList();
             }
-            
             for (Tag tag : tags) {
-                JavaReference ref = findReference(tag, positions, jdTokenSequence);
-                if (ref != null && ref.fqn != null && ref.fqn.length() > 0) {
-                    String fqn = ref.fqn.toString();
-                    TypeMirror type = javac.getTreeUtilities().parseType(fqn, scope);
-                    if (type != null && (type.getKind() == TypeKind.DECLARED || type.getKind() == TypeKind.ERROR)) {
-                        DeclaredType declaredType = (DeclaredType) type;
-                        TypeElement foundElement = (TypeElement) declaredType.asElement();
-                        if (SourceVersion.isIdentifier(foundElement.getSimpleName())) {
-                            if (result == null) {
-                                result = new HashSet<TypeElement>();
+                List<JavaReference> refs = findReferences (tag, positions, jdTokenSequence);
+                if (refs != null) {
+                    for (JavaReference reference : refs) {
+                        if (reference.fqn != null) {
+                            String fqn = reference.fqn.toString ();
+                            TypeMirror type = javac.getTreeUtilities ().parseType (fqn, scope);
+                            if (type != null &&
+                                ( type.getKind () == TypeKind.DECLARED ||
+                                  type.getKind() == TypeKind.ERROR
+                                )
+                            ) {
+                                DeclaredType declaredType = (DeclaredType) type;
+                                TypeElement foundElement = (TypeElement) declaredType.asElement ();
+                                if (
+                                    SourceVersion.isIdentifier (foundElement.getSimpleName ())
+                                ) {
+                                    if (result == null)
+                                        result = new HashSet<TypeElement> ();
+                                    result.add (foundElement);
+                                }
                             }
-                            result.add(foundElement);
                         }
                     }
                 }
@@ -184,42 +193,44 @@ public final class JavadocImports {
             final boolean isTypeParam = toFind.getKind() == ElementKind.TYPE_PARAMETER;
 
             for (Tag tag : tags) {
-                JavaReference ref = findReference(tag, positions, jdTokenSequence);
+                List<JavaReference> references = findReferences (tag, positions, jdTokenSequence);
+                if (references != null) {
+                    for (JavaReference ref : references) {
 
-                if (ref != null) {
-                    Element referenced = ref.getReferencedElement(javac, scope);
-                    while (referenced != null) {
+                        Element referenced = ref.getReferencedElement(javac, scope);
+                        while (referenced != null) {
+                            if (referenced == toFind) {
+                                break;
+                            }
+                            referenced = referenced.getEnclosingElement();
+                        }
                         if (referenced == toFind) {
-                            break;
-                        }
-                        referenced = referenced.getEnclosingElement();
-                    }
-                    if (referenced == toFind) {
-                        int pos = -1;
-                        ElementKind rkind = referenced.getKind();
-                        if (ref.fqn != null && (rkind.isClass() || rkind.isInterface())) {
-                            String fqn = ((TypeElement) referenced).getQualifiedName().toString();
-                            String reffqn = ref.fqn.toString(); // NOI18N
-                            if (reffqn.startsWith(fqn)) {
-                                pos = ref.begin + fqn.length() - 1;
-                            } else {
-                                String simpleName = referenced.getSimpleName().toString();
-                                pos = ref.begin + simpleName.length() - 1;
+                            int pos = -1;
+                            ElementKind rkind = referenced.getKind();
+                            if (ref.fqn != null && (rkind.isClass() || rkind.isInterface())) {
+                                String fqn = ((TypeElement) referenced).getQualifiedName().toString();
+                                String reffqn = ref.fqn.toString(); // NOI18N
+                                if (reffqn.startsWith(fqn)) {
+                                    pos = ref.begin + fqn.length() - 1;
+                                } else {
+                                    String simpleName = referenced.getSimpleName().toString();
+                                    pos = ref.begin + simpleName.length() - 1;
+                                }
+                            } else if (rkind.isField() || rkind == ElementKind.METHOD || rkind == ElementKind.CONSTRUCTOR) {
+                                pos = ref.end - 1;
                             }
-                        } else if (rkind.isField() || rkind == ElementKind.METHOD || rkind == ElementKind.CONSTRUCTOR) {
-                            pos = ref.end - 1;
-                        }
-                        
-                        if (pos < 0) {
-                            continue;
-                        }
-                        
-                        jdTokenSequence.move(pos);
-                        if (jdTokenSequence.moveNext() && jdTokenSequence.token().id() == JavadocTokenId.IDENT) {
-                            if (result == null) {
-                                result = new ArrayList<Token>();
+
+                            if (pos < 0) {
+                                continue;
+                            }
+
+                            jdTokenSequence.move(pos);
+                            if (jdTokenSequence.moveNext() && jdTokenSequence.token().id() == JavadocTokenId.IDENT) {
+                                if (result == null) {
+                                    result = new ArrayList<Token>();
+                                }
+                                result.add(jdTokenSequence.token());
                             }
-                            result.add(jdTokenSequence.token());
                         }
                     }
                 } else if ((isParam || isTypeParam) && tag != null && "@param".equals(tag.name())) { // NOI18N
@@ -309,24 +320,33 @@ public final class JavadocImports {
                 scope = javac.getElementUtilities().enclosingTypeElement(el);
             }
 
-            Tag tag = positions.getTag(offset);
+            Tag tag = positions.getTag (offset);
             
-            JavaReference ref = tag != null
-                    ? findReference(tag, positions, jdTokenSequence)
+            List<JavaReference> references = tag != null
+                    ? findReferences (tag, positions, jdTokenSequence)
                     : null;
             
-            if (ref != null && scope != null) {
-                result = ref.getReferencedElement(javac, scope);
-                if (result != null && ref.fqn != null && offset < ref.begin + ref.fqn.length()) {
-                    result = result.getKind().isClass() || result.getKind().isInterface()
-                            ? result
-                            : result.getEnclosingElement();
-                    int elmNameLength = result.getSimpleName().length();
-                    while (result != null && offset < ref.begin + ref.fqn.length() - elmNameLength) {
-                        result = result.getEnclosingElement();
-                        elmNameLength += result != null
-                                ? result.getSimpleName().length() + 1
-                                : 0;
+            if (references != null && scope != null) {
+                for (JavaReference reference : references) {
+                    result = reference.getReferencedElement (javac, scope);
+                    if (result != null &&
+                        reference.fqn != null &&
+                        offset < reference.begin + reference.fqn.length ()
+                    ) {
+                        result = result.getKind ().isClass () ||
+                                 result.getKind ().isInterface ()
+                                    ? result : result.getEnclosingElement ();
+                        int elmNameLength = result.getSimpleName ().length ();
+                        while (
+                            result != null &&
+                            offset < reference.begin + reference.fqn.length () - elmNameLength
+                        ) {
+                            result = result.getEnclosingElement ();
+                            elmNameLength += result != null
+                                    ? result.getSimpleName ().length () + 1
+                                    : 0;
+                        }
+                        if (result != null) break;
                     }
                 }
             } else if (tag instanceof ParamTag && "@param".equals(tag.name())) { // NOI18N
@@ -370,27 +390,37 @@ public final class JavadocImports {
 
             Tag tag = positions.getTag(offset);
             
-            JavaReference ref = tag != null
-                    ? findReference(tag, positions, jdTokenSequence)
+            List<JavaReference> references = tag != null
+                    ? findReferences (tag, positions, jdTokenSequence)
                     : null;
             
-            if (ref != null && scope != null) {
-                Element elm = ref.getReferencedElement(javac, scope);
-                if (elm != null) {
-                    int fqnLength = ref.fqn != null? ref.fqn.length(): 0;
-                    if (ref.fqn != null && offset >= ref.begin && offset < ref.begin + fqnLength
-                            || ref.member != null && offset > ref.begin + fqnLength && offset < ref.end) {
-                        jdTokenSequence.move(offset);
-                        if (jdTokenSequence.moveNext()) {
-                            return jdTokenSequence.token().id() == JavadocTokenId.IDENT
-                                    ? jdTokenSequence.token()
+            if (references != null && scope != null) {
+                for (JavaReference reference : references) {
+                    Element elm = reference.getReferencedElement (javac, scope);
+                    if (elm != null) {
+                        int fqnLength = reference.fqn != null ?
+                            reference.fqn.length () : 0;
+                        if (reference.fqn != null &&
+                            offset >= reference.begin &&
+                            offset < reference.begin + fqnLength ||
+                            reference.member != null &&
+                            offset > reference.begin + fqnLength &&
+                            offset < reference.end
+                        ) {
+                            jdTokenSequence.move (offset);
+                            if (jdTokenSequence.moveNext ()) {
+                                return jdTokenSequence.token ().id () == JavadocTokenId.IDENT
+                                    ? jdTokenSequence.token ()
                                     : null;
+                            }
                         }
                     }
                 }
             } else {
                 // try to resolve @param name
-                Token<JavadocTokenId> token = findNameTokenOfParamTag(tag, positions, jdTokenSequence);
+                Token<JavadocTokenId> token = findNameTokenOfParamTag (
+                    tag, positions, jdTokenSequence
+                );
                 return token;
             }
 
@@ -490,7 +520,12 @@ public final class JavadocImports {
         return false;
     }
 
-    private static JavaReference findReference(Tag tag, DocPositions positions, TokenSequence<JavadocTokenId> jdTokenSequence) {
+    private static List<JavaReference> findReferences (
+        Tag                     tag,
+        DocPositions            positions,
+        TokenSequence<JavadocTokenId>
+                                jdTokenSequence
+    ) {
         if (tag == null || !isReferenceTag(tag)) {
             return null;
         }
@@ -504,7 +539,8 @@ public final class JavadocImports {
                 || !jdTokenSequence.moveNext()) {
             return null;
         }
-        return JavaReference.resolve(jdTokenSequence, jdTokenSequence.offset(), tagSpan[1]);
+        JavaReference reference = JavaReference.resolve (jdTokenSequence, jdTokenSequence.offset(), tagSpan[1]);
+        return reference.getAllReferences ();
     }
     
     private static boolean isReferenceTag(Tag tag) {
@@ -567,14 +603,24 @@ public final class JavadocImports {
             }
         }
         
-        private void resolveTags(DocPositions positions, TokenSequence<JavadocTokenId> jdTokenSequence, TypeElement scope) {
+        private void resolveTags (
+            DocPositions positions,
+            TokenSequence<JavadocTokenId> jdTokenSequence,
+            TypeElement scope
+        ) {
             for (Tag tag : positions.getTags()) {
-                JavaReference ref = findReference(tag, positions, jdTokenSequence);
-                if (ref != null && ref.fqn != null && ref.fqn.length() > 0) {
-                    String fqn = ref.fqn.toString();
-                    TypeMirror type = javac.getTreeUtilities().parseType(fqn, scope);
-                    if (type != null && type.getKind() == TypeKind.ERROR) {
-                        unresolved.add(fqn);
+                List<JavaReference> references = findReferences (tag, positions, jdTokenSequence);
+                if (references != null) {
+                    for (JavaReference reference : references) {
+                        if (reference.fqn != null && reference.fqn.length() > 0) {
+                            String fqn = reference.fqn.toString ();
+                            TypeMirror type = javac.getTreeUtilities ().parseType (fqn, scope);
+                            if (type != null &&
+                                type.getKind () == TypeKind.ERROR
+                            ) {
+                                unresolved.add (fqn);
+                            }
+                        }
                     }
                 }
             }
