@@ -43,15 +43,23 @@
  */
 package org.netbeans.modules.java.editor.rename;
 
+import com.sun.source.tree.BreakTree;
+import com.sun.source.tree.ContinueTree;
+import com.sun.source.tree.LabeledStatementTree;
+import com.sun.source.tree.StatementTree;
 import com.sun.source.tree.Tree.Kind;
 import com.sun.source.util.TreePath;
+import com.sun.source.util.TreePathScanner;
 import java.awt.Color;
 import java.awt.event.KeyEvent;
 import java.awt.event.KeyListener;
 import java.io.IOException;
+import java.lang.ref.Reference;
+import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.EnumSet;
 import java.util.HashSet;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.logging.Level;
@@ -60,12 +68,16 @@ import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
 import javax.lang.model.element.Modifier;
+import javax.lang.model.element.Name;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.util.ElementFilter;
+import javax.lang.model.util.ElementScanner6;
 import javax.swing.Action;
 import javax.swing.event.CaretEvent;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentListener;
+import javax.swing.event.UndoableEditEvent;
+import javax.swing.event.UndoableEditListener;
 import javax.swing.text.AttributeSet;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
@@ -73,6 +85,7 @@ import javax.swing.text.JTextComponent;
 import javax.swing.text.Position;
 import javax.swing.text.Position.Bias;
 import javax.swing.text.StyleConstants;
+import javax.swing.undo.AbstractUndoableEdit;
 import javax.swing.undo.CannotUndoException;
 import javax.swing.undo.UndoableEdit;
 import org.netbeans.api.editor.mimelookup.MimeLookup;
@@ -83,6 +96,7 @@ import org.netbeans.api.editor.settings.FontColorSettings;
 import org.netbeans.api.java.lexer.JavaTokenId;
 import org.netbeans.api.java.lexer.JavadocTokenId;
 import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.api.java.source.ElementUtilities;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.SourceUtils;
@@ -118,7 +132,7 @@ import org.openide.util.lookup.InstanceContent;
 public class InstantRenamePerformer implements DocumentListener, KeyListener {
     
     private static final Logger LOG = Logger.getLogger(InstantRenamePerformer.class.getName());
-    
+
     private SyncDocumentRegion region;
     private int span;
     private Document doc;
@@ -138,41 +152,47 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
     
     /** Creates a new instance of InstantRenamePerformer */
     private InstantRenamePerformer(JTextComponent target, Set<Token> highlights, int caretOffset) throws BadLocationException {
-	this.target = target;
-	doc = target.getDocument();
-	
-	MutablePositionRegion mainRegion = null;
-	List<MutablePositionRegion> regions = new ArrayList<MutablePositionRegion>();
-        
-	for (Token h : highlights) {
+        this.target = target;
+        doc = target.getDocument();
+
+        MutablePositionRegion mainRegion = null;
+        List<MutablePositionRegion> regions = new ArrayList<MutablePositionRegion>();
+
+        for (Token h : highlights) {
             // type parameter name is represented as html tag -> ignore surrounding <> in rename
             int delta = h.id() == JavadocTokenId.HTML_TAG ? 1 : 0;
-	    Position start = NbDocument.createPosition(doc, h.offset(null) + delta, Bias.Backward);
-	    Position end = NbDocument.createPosition(doc, h.offset(null) + h.length() - delta, Bias.Forward);
-	    MutablePositionRegion current = new MutablePositionRegion(start, end);
-	    
-	    if (isIn(current, caretOffset)) {
-		mainRegion = current;
-	    } else {
-		regions.add(current);
-	    }
-	}
-	
-	if (mainRegion == null) {
-	    throw new IllegalArgumentException("No highlight contains the caret.");
-	}
-	
-	regions.add(0, mainRegion);
-	
-	region = new SyncDocumentRegion(doc, regions);
-	
-        if (doc instanceof BaseDocument) {
-            ((BaseDocument) doc).setPostModificationDocumentListener(this);
+            Position start = NbDocument.createPosition(doc, h.offset(null) + delta, Bias.Backward);
+            Position end = NbDocument.createPosition(doc, h.offset(null) + h.length() - delta, Bias.Forward);
+            MutablePositionRegion current = new MutablePositionRegion(start, end);
+
+            if (isIn(current, caretOffset)) {
+                mainRegion = current;
+            } else {
+                regions.add(current);
+            }
         }
-        
-	target.addKeyListener(this);
-	
-	target.putClientProperty(InstantRenamePerformer.class, this);
+
+        if (mainRegion == null) {
+            throw new IllegalArgumentException("No highlight contains the caret.");
+        }
+
+        regions.add(0, mainRegion);
+
+        region = new SyncDocumentRegion(doc, regions);
+
+        if (doc instanceof BaseDocument) {
+            BaseDocument bdoc = ((BaseDocument) doc);
+            bdoc.setPostModificationDocumentListener(this);
+
+            UndoableEdit undo = new CancelInstantRenameUndoableEdit(this);
+            for (UndoableEditListener l : bdoc.getUndoableEditListeners()) {
+                l.undoableEditHappened(new UndoableEditEvent(doc, undo));
+            }
+        }
+
+        target.addKeyListener(this);
+
+        target.putClientProperty(InstantRenamePerformer.class, this);
 	
         requestRepaint();
         
@@ -202,6 +222,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             final boolean[] wasResolved = new boolean[1];
 
             Set<Token> changePoints = ComputeOffAWT.computeOffAWT(new Worker<Set<Token>>() {
+                @Override
                 public Set<Token> process(CompilationInfo info) {
                     try {
                         return computeChangePoints(info, caret, wasResolved);
@@ -250,6 +271,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
         final boolean[] insideJavadoc = {false};
         
         doc.render(new Runnable() {
+            @Override
             public void run() {
                 TokenSequence<JavaTokenId> ts = SourceUtils.getJavaTokenSequence(info.getTokenHierarchy(), caret);
                 
@@ -300,6 +322,19 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
                 : info.getTrees().getElement(path);
         
         if (el == null) {
+            if (EnumSet.of(Kind.LABELED_STATEMENT, Kind.BREAK, Kind.CONTINUE).contains(path.getLeaf().getKind())) {
+                Token<JavaTokenId> span = org.netbeans.modules.java.editor.semantic.Utilities.findIdentifierSpan(info, doc, path);
+                if (span != null && span.offset(null) <= adjustedCaret[0] && adjustedCaret[0] <= span.offset(null) + span.length()) {
+                    if (path.getLeaf().getKind() != Kind.LABELED_STATEMENT) {
+                        StatementTree tgt = info.getTreeUtilities().getBreakContinueTarget(path);
+                        path = tgt != null ? info.getTrees().getPath(info.getCompilationUnit(), tgt) : null;
+                    }
+                    if (path != null) {
+                        wasResolved[0] = true;
+                        return collectLabels(info, doc, path);
+                    }
+                }
+            }            
             wasResolved[0] = false;
             return null;
         }
@@ -313,6 +348,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             return null;
         
         doc.render(new Runnable() {
+            @Override
             public void run() {
                 wasResolved[0] = name.offset(null) <= caret && caret <= (name.offset(null) + name.length());
             }
@@ -326,7 +362,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             el = el.getEnclosingElement();
         }
         
-        if (allowInstantRename(el)) {
+        if (allowInstantRename(el, info.getElementUtilities())) {
             final Set<Token> points = new HashSet<Token>(new FindLocalUsagesQuery(true).findUsages(el, info, doc));
             
             if (el.getKind().isClass()) {
@@ -347,6 +383,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             final boolean[] overlapsWithGuardedBlocks = new boolean[1];
             
             doc.render(new Runnable() {
+                @Override
                 public void run() {
                     overlapsWithGuardedBlocks[0] = overlapsWithGuardedBlocks(doc, points);
                 }
@@ -365,12 +402,37 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
         return null;
     }
 
-    private static boolean allowInstantRename(Element e) {
+    private static Set<Token> collectLabels(final CompilationInfo info, final Document document, final TreePath labeledStatement) {
+        final Set<Token> result = new LinkedHashSet<Token>();
+        if (labeledStatement.getLeaf().getKind() == Kind.LABELED_STATEMENT) {
+            result.add(org.netbeans.modules.java.editor.semantic.Utilities.findIdentifierSpan(info, document, labeledStatement));
+            final Name label = ((LabeledStatementTree)labeledStatement.getLeaf()).getLabel();
+            new TreePathScanner <Void, Void>() {
+                @Override
+                public Void visitBreak(BreakTree node, Void p) {
+                    if (node.getLabel() != null && label.contentEquals(node.getLabel())) {
+                        result.add(org.netbeans.modules.java.editor.semantic.Utilities.findIdentifierSpan(info, document, getCurrentPath()));
+                    }
+                    return super.visitBreak(node, p);
+                }
+                @Override
+                public Void visitContinue(ContinueTree node, Void p) {
+                    if (node.getLabel() != null && label.contentEquals(node.getLabel())) {
+                        result.add(org.netbeans.modules.java.editor.semantic.Utilities.findIdentifierSpan(info, document, getCurrentPath()));
+                    }
+                    return super.visitContinue(node, p);
+                }
+            }.scan(labeledStatement, null);
+        }
+        return result;
+    }
+
+    private static boolean allowInstantRename(Element e, ElementUtilities eu) {
         if (org.netbeans.modules.java.editor.semantic.Utilities.isPrivateElement(e)) {
             return true;
         }
         
-        if (isInaccessibleOutsideOuterClass(e)) {
+        if (isInaccessibleOutsideOuterClass(e, eu)) {
             return true;
         }
         
@@ -404,28 +466,22 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
      * @return {@code true} if the member cannot be accessed outside the outer class
      * @see <a href="http://www.netbeans.org/issues/show_bug.cgi?id=169377">169377</a>
      */
-    private static boolean isInaccessibleOutsideOuterClass(Element e) {
+    private static boolean isInaccessibleOutsideOuterClass(Element e, ElementUtilities eu) {
         Element enclosing = e.getEnclosingElement();
         boolean isStatic = e.getModifiers().contains(Modifier.STATIC);
         ElementKind kind = e.getKind();
-        if (isStatic || kind == ElementKind.CLASS) {
+        if (isStatic || kind.isClass() || kind.isInterface() || kind.isField()) {
             // static declaration of nested class, interface, enum, ann type, method, field
             // or inner class
             return isAnyEncloserPrivate(e);
-        } else if (enclosing != null) {
+        } else if (enclosing != null && kind == ElementKind.METHOD) {
             // final is enum, ann type and some classes
             ElementKind enclosingKind = enclosing.getKind();
             boolean isEnclosingFinal = enclosing.getModifiers().contains(Modifier.FINAL)
                     // ann type is not final even if it cannot be subclassed
-                    || enclosingKind == ElementKind.ANNOTATION_TYPE
-                    // enum implementing an interface is not final even if it cannot be subclassed
-                    || enclosingKind == ElementKind.ENUM;
-            // do not try to rename members of class that extends or implements anything
-            // it would require deeper analyze
-            boolean isSubclass = enclosingKind == ElementKind.CLASS
-                    && ( !"java.lang.Object".equals(((TypeElement) enclosing).getSuperclass().toString())
-                            || !((TypeElement) enclosing).getInterfaces().isEmpty() );
-            return isEnclosingFinal && !isSubclass && isAnyEncloserPrivate(e);
+                    || enclosingKind == ElementKind.ANNOTATION_TYPE;
+            return isAnyEncloserPrivate(e) && !eu.overridesMethod((ExecutableElement) e) && !eu.implementsMethod((ExecutableElement)e) &&
+                    (isEnclosingFinal || !isOverridenInsideOutermostEnclosingClass((ExecutableElement)e, eu));
         }
         return false;
     }
@@ -442,6 +498,21 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
         return false;
     }
     
+    private static boolean isOverridenInsideOutermostEnclosingClass(final ExecutableElement ee, final ElementUtilities eu) {
+        final boolean[] ret = new boolean[] {false};
+        new ElementScanner6<Void, Void>() {
+            @Override
+            public Void visitType(TypeElement te, Void p) {
+                if (ret[0])
+                    return null;
+                if (te != ee.getEnclosingElement() && eu.getImplementationOf(ee, te) != null && !isAnyEncloserPrivate(te))
+                    ret[0] = true;
+                return super.visitType(te, p);
+            }            
+        }.scan(eu.outermostTypeElement(ee));
+        return ret[0];
+    }
+    
     private static boolean overlapsWithGuardedBlocks(Document doc, Set<Token> highlights) {
         if (!(doc instanceof GuardedDocument))
             return false;
@@ -466,7 +537,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
     
     
     public static void performInstantRename(JTextComponent target, Set<Token> highlights, int caretOffset) throws BadLocationException {
-	new InstantRenamePerformer(target, highlights, caretOffset);
+        new InstantRenamePerformer(target, highlights, caretOffset);
     }
 
     private boolean isIn(MutablePositionRegion region, int caretOffset) {
@@ -475,6 +546,7 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
     
     private boolean inSync;
     
+    @Override
     public synchronized void insertUpdate(DocumentEvent e) {
 	if (inSync)
 	    return ;
@@ -485,14 +557,15 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             return;
         }
         
-	inSync = true;
-	region.sync(0);
+        inSync = true;
+        region.sync(0);
         span = region.getFirstRegionLength();
-	inSync = false;
+        inSync = false;
         
-	requestRepaint();
+        requestRepaint();
     }
 
+    @Override
     public synchronized void removeUpdate(DocumentEvent e) {
 	if (inSync)
 	    return ;
@@ -505,10 +578,10 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
 
             if (e.getOffset() == region.getFirstRegionStartOffset() && region.getFirstRegionLength() > 0 && region.getFirstRegionLength() == span) {
                 if (LOG.isLoggable(Level.FINE)) {
-                    LOG.fine("e.getOffset()=" + e.getOffset());
-                    LOG.fine("region.getFirstRegionStartOffset()=" + region.getFirstRegionStartOffset());
-                    LOG.fine("region.getFirstRegionEndOffset()=" + region.getFirstRegionEndOffset());
-                    LOG.fine("span= " + span);
+                    LOG.log(Level.FINE, "e.getOffset()={0}", e.getOffset ());
+                    LOG.log(Level.FINE, "region.getFirstRegionStartOffset()={0}", region.getFirstRegionStartOffset ());
+                    LOG.log(Level.FINE, "region.getFirstRegionEndOffset()={0}", region.getFirstRegionEndOffset ());
+                    LOG.log(Level.FINE, "span= {0}", span);
                 }
                 JavaDeleteCharAction jdca = (JavaDeleteCharAction) target.getClientProperty(JavaDeleteCharAction.class);
                 
@@ -523,10 +596,10 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             
             if (e.getOffset() == region.getFirstRegionEndOffset() && region.getFirstRegionLength() > 0 && region.getFirstRegionLength() == span) {
                 if (LOG.isLoggable(Level.FINE)) {
-                    LOG.fine("e.getOffset()=" + e.getOffset());
-                    LOG.fine("region.getFirstRegionStartOffset()=" + region.getFirstRegionStartOffset());
-                    LOG.fine("region.getFirstRegionEndOffset()=" + region.getFirstRegionEndOffset());
-                    LOG.fine("span= " + span);
+                    LOG.log(Level.FINE, "e.getOffset()={0}", e.getOffset ());
+                    LOG.log(Level.FINE, "region.getFirstRegionStartOffset()={0}", region.getFirstRegionStartOffset ());
+                    LOG.log(Level.FINE, "region.getFirstRegionEndOffset()={0}", region.getFirstRegionEndOffset ());
+                    LOG.log(Level.FINE, "span= {0}", span);
                 }
             //XXX: moves the caret anyway:
 //                JavaDeleteCharAction jdca = (JavaDeleteCharAction) target.getClientProperty(JavaDeleteCharAction.class);
@@ -541,10 +614,10 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             }
             if (e.getOffset() == region.getFirstRegionEndOffset() && e.getOffset() == region.getFirstRegionStartOffset() && region.getFirstRegionLength() == 0 && region.getFirstRegionLength() == span) {
                 if (LOG.isLoggable(Level.FINE)) {
-                    LOG.fine("e.getOffset()=" + e.getOffset());
-                    LOG.fine("region.getFirstRegionStartOffset()=" + region.getFirstRegionStartOffset());
-                    LOG.fine("region.getFirstRegionEndOffset()=" + region.getFirstRegionEndOffset());
-                    LOG.fine("span= " + span);
+                    LOG.log(Level.FINE, "e.getOffset()={0}", e.getOffset ());
+                    LOG.log(Level.FINE, "region.getFirstRegionStartOffset()={0}", region.getFirstRegionStartOffset ());
+                    LOG.log(Level.FINE, "region.getFirstRegionEndOffset()={0}", region.getFirstRegionEndOffset ());
+                    LOG.log(Level.FINE, "span= {0}", span);
                 }
                 
                 JavaDeleteCharAction jdca = (JavaDeleteCharAction) target.getClientProperty(JavaDeleteCharAction.class);
@@ -573,31 +646,36 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             return ;
         }
         
-	inSync = true;
-	region.sync(0);
+        inSync = true;
+        region.sync(0);
         span = region.getFirstRegionLength();
-	inSync = false;
+        inSync = false;
         
-	requestRepaint();
+        requestRepaint();
     }
 
+    @Override
     public void changedUpdate(DocumentEvent e) {
     }
 
     public void caretUpdate(CaretEvent e) {
     }
 
+    @Override
     public void keyTyped(KeyEvent e) {
     }
 
+    @Override
     public synchronized void keyPressed(KeyEvent e) {
-	if (   (e.getKeyCode() == KeyEvent.VK_ESCAPE && e.getModifiers() == 0) 
-            || (e.getKeyCode() == KeyEvent.VK_ENTER  && e.getModifiers() == 0)) {
-	    release();
-	    e.consume();
-	}
+        if (   (e.getKeyCode() == KeyEvent.VK_ESCAPE && e.getModifiers() == 0) ||
+               (e.getKeyCode() == KeyEvent.VK_ENTER  && e.getModifiers() == 0)
+        ) {
+            release();
+            e.consume();
         }
+    }
 
+    @Override
     public void keyReleased(KeyEvent e) {
     }
 
@@ -607,19 +685,19 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
             return ;
         }
         
-	target.putClientProperty(InstantRenamePerformer.class, null);
+        target.putClientProperty(InstantRenamePerformer.class, null);
         if (doc instanceof BaseDocument) {
             ((BaseDocument) doc).setPostModificationDocumentListener(null);
         }
-	target.removeKeyListener(this);
-	target = null;
+        target.removeKeyListener(this);
+        target = null;
 
-	region = null;
+        region = null;
         attribs = null;
         
         requestRepaint();
 
-	doc = null;
+        doc = null;
     }
 
     private void undo() {
@@ -767,5 +845,26 @@ public class InstantRenamePerformer implements DocumentListener, KeyListener {
         
         return bag;
     }
+
+    private static class CancelInstantRenameUndoableEdit extends AbstractUndoableEdit {
+
+        private final Reference<InstantRenamePerformer> performer;
+
+        public CancelInstantRenameUndoableEdit(InstantRenamePerformer performer) {
+            this.performer = new WeakReference<InstantRenamePerformer>(performer);
+        }
+
+        @Override public boolean isSignificant() {
+            return false;
+        }
+
+        @Override public void undo() throws CannotUndoException {
+            InstantRenamePerformer perf = performer.get();
+
+            if (perf != null) {
+                perf.release();
+            }
+        }
+    }
     
 }
