@@ -45,10 +45,12 @@ package org.netbeans.modules.java.editor.semantic;
 
 import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.IdentifierTree;
+import com.sun.source.tree.ImportTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.NewClassTree;
 import com.sun.source.tree.Tree;
+import com.sun.source.tree.Tree.Kind;
 import com.sun.source.tree.TypeParameterTree;
 import com.sun.source.tree.VariableTree;
 import com.sun.source.util.TreePath;
@@ -57,6 +59,7 @@ import java.util.List;
 import java.util.Set;
 import java.util.Stack;
 import javax.lang.model.element.Element;
+import javax.lang.model.element.Modifier;
 import javax.swing.text.Document;
 import org.netbeans.api.java.lexer.JavaTokenId;
 import org.netbeans.api.java.source.CompilationInfo;
@@ -181,5 +184,23 @@ public class FindLocalUsagesQuery extends CancellableTreePathScanner<Void, Stack
         
         return super.visitNewClass(node, p);
     }
-    
+
+    @Override
+    public Void visitImport(ImportTree node, Stack<Tree> p) {
+        if (node.isStatic() && toFind.getModifiers().contains(Modifier.STATIC)) {
+            Tree qualIdent = node.getQualifiedIdentifier();
+            if (qualIdent.getKind() == Kind.MEMBER_SELECT) {
+                MemberSelectTree mst = (MemberSelectTree) qualIdent;
+                if (toFind.getSimpleName().contentEquals(mst.getIdentifier())) {
+                    Element el = info.getTrees().getElement(new TreePath(getCurrentPath(), mst.getExpression()));
+                    if (el != null && el.equals(toFind.getEnclosingElement())) {
+                        Token<JavaTokenId> t = Utilities.getToken(info, doc, new TreePath(getCurrentPath(), mst));
+                        if (t != null)
+                            usages.add(t);
+                    }
+                }
+            }
+        }
+        return super.visitImport(node, p);
+    }
 }
