@@ -43,19 +43,26 @@
  */
 package org.netbeans.modules.java.editor.semantic;
 
+import com.sun.source.tree.BreakTree;
 import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.CompilationUnitTree;
+import com.sun.source.tree.ContinueTree;
 import com.sun.source.tree.DoWhileLoopTree;
+import com.sun.source.tree.EnhancedForLoopTree;
 import com.sun.source.tree.ForLoopTree;
+import com.sun.source.tree.ImportTree;
 import com.sun.source.tree.LabeledStatementTree;
+import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.NewClassTree;
 import com.sun.source.tree.StatementTree;
 import com.sun.source.tree.Tree;
 import com.sun.source.tree.Tree.Kind;
+import com.sun.source.tree.TryTree;
 import com.sun.source.tree.WhileLoopTree;
 import com.sun.source.util.SourcePositions;
 import com.sun.source.util.TreePath;
+import com.sun.source.util.TreePathScanner;
 
 import java.awt.Color;
 import java.util.ArrayList;
@@ -72,6 +79,7 @@ import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
 import javax.lang.model.element.Modifier;
+import javax.lang.model.element.Name;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.util.ElementFilter;
 import javax.swing.event.DocumentEvent;
@@ -83,6 +91,7 @@ import org.netbeans.api.java.lexer.JavaTokenId;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.JavaParserResultTask;
 import org.netbeans.api.java.source.JavaSource.Phase;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.support.CaretAwareJavaSourceTaskFactory;
 import org.netbeans.api.lexer.Token;
 import org.netbeans.api.lexer.TokenSequence;
@@ -284,9 +293,28 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
         if (isCancelled())
             return null;
 
+        if (node.getBoolean(MarkOccurencesSettings.EXCEPTIONS, true)) {
+            //detect caret inside catch:
+            if (typePath != null && typePath.getParentPath().getLeaf().getKind() == Kind.VARIABLE
+                    && typePath.getParentPath().getParentPath().getLeaf().getKind() == Kind.CATCH) {
+                    MethodExitDetector med = new MethodExitDetector();
+
+                    setExitDetector(med);
+
+                    try {
+                        return med.process(info, doc, ((TryTree)typePath.getParentPath().getParentPath().getParentPath().getLeaf()).getBlock(), Collections.singletonList(typePath.getLeaf()));
+                    } finally {
+                        setExitDetector(null);
+                    }
+            }
+        }
+
+        if (isCancelled())
+            return null;
+        
         if (node.getBoolean(MarkOccurencesSettings.IMPLEMENTS, true)) {
             //detect caret inside the extends/implements clause:
-            if (typePath != null && typePath.getParentPath().getLeaf().getKind() == Kind.CLASS) {
+            if (typePath != null && TreeUtilities.CLASS_TREE_KINDS.contains(typePath.getParentPath().getLeaf().getKind())) {
                 ClassTree ctree = (ClassTree) typePath.getParentPath().getLeaf();
                 int bodyStart = Utilities.findBodyStart(ctree, cu, info.getTrees().getSourcePositions(), doc);
 
@@ -315,7 +343,7 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
 
             TokenSequence<JavaTokenId> ts = info.getTokenHierarchy().tokenSequence(JavaTokenId.language());
 
-            if (ts != null && tp.getLeaf().getKind() == Kind.CLASS) {
+            if (ts != null && TreeUtilities.CLASS_TREE_KINDS.contains(tp.getLeaf().getKind())) {
                 int bodyStart = Utilities.findBodyStart(tp.getLeaf(), cu, info.getTrees().getSourcePositions(), doc);
 
                 if (caretPosition < bodyStart) {
@@ -366,8 +394,17 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
 
         Tree tree =tp.getLeaf();
 
-        if (node.getBoolean(MarkOccurencesSettings.BREAK_CONTINUE, true) && (tree.getKind() == Kind.BREAK || tree.getKind() == Kind.CONTINUE)) {
-            return detectBreakOrContinueTarget(info, doc, tp);
+        if (node.getBoolean(MarkOccurencesSettings.BREAK_CONTINUE, true)) {
+            if (tree.getKind() == Kind.BREAK || tree.getKind() == Kind.CONTINUE) {
+                return detectBreakOrContinueTarget(info, doc, tp, caretPosition);
+            } else if (tree.getKind() == Kind.LABELED_STATEMENT) {
+                int[] span = Utilities.findIdentifierSpan(tp, info, doc);
+                if (span[0] <= caretPosition && caretPosition <= span[1]) {
+                    List<int[]> ret = detectLabel(info, doc, tp);
+                    ret.add(span);
+                    return ret;
+                }
+            }
         }
 
         Element el;
@@ -394,7 +431,7 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
         }
 
         if (   el != null
-                && (!(tree.getKind() == Kind.CLASS) || isIn(caretPosition, Utilities.findIdentifierSpan(info, doc, tp)))
+                && (!TreeUtilities.CLASS_TREE_KINDS.contains(tree.getKind()) || isIn(caretPosition, Utilities.findIdentifierSpan(info, doc, tp)))
                 && !Utilities.isNonCtorKeyword(tree)
                 && (!(tree.getKind() == Kind.METHOD) || isIn(caretPosition, Utilities.findIdentifierSpan(info, doc, tp)))
                 && isEnabled(node, el)
@@ -415,6 +452,36 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
             }
         }
 
+        if (tp.getParentPath() != null && tp.getParentPath().getLeaf().getKind() == Kind.IMPORT) {
+            ImportTree it = (ImportTree) tp.getParentPath().getLeaf();
+            if (it.isStatic() && tp.getLeaf().getKind() == Kind.MEMBER_SELECT) {
+                MemberSelectTree mst = (MemberSelectTree) tp.getLeaf();
+                if (!"*".contentEquals(mst.getIdentifier())) {
+                    List<int[]> bag = new ArrayList<int[]>();
+                    Token<JavaTokenId> tok = Utilities.getToken(info, doc, tp);
+                    if (tok != null)
+                        bag.add(new int[] {tok.offset(null), tok.offset(null) + tok.length()});
+                    el = info.getTrees().getElement(new TreePath(tp, mst.getExpression()));
+                    if (el != null) {
+                        FindLocalUsagesQuery fluq = new FindLocalUsagesQuery();
+                        setLocalUsages(fluq);
+                        try {
+                            for (Element element : el.getEnclosedElements()) {
+                                if (element.getModifiers().contains(Modifier.STATIC)) {
+                                    for (Token t : fluq.findUsages(element, info, doc)) {
+                                        bag.add(new int[] {t.offset(null), t.offset(null) + t.length()});
+                                    }
+                                }
+                            }
+                            return bag;
+                        } finally {
+                            setLocalUsages(null);
+                        }
+                    }
+                }
+            }
+        }
+        
         return null;
     }
 
@@ -537,7 +604,7 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
         return highlights;
     }
 
-    private List<int[]> detectBreakOrContinueTarget(CompilationInfo info, Document document, TreePath breakOrContinue) {
+    private List<int[]> detectBreakOrContinueTarget(CompilationInfo info, Document document, TreePath breakOrContinue, int caretPosition) {
         List<int[]> result = new ArrayList<int[]>();
         StatementTree target = info.getTreeUtilities().getBreakContinueTarget(breakOrContinue);
 
@@ -545,7 +612,7 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
             return null;
 
         TokenSequence<JavaTokenId> ts = info.getTokenHierarchy().tokenSequence(JavaTokenId.language());
-
+        
         ts.move((int) info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), target));
 
         if (ts.moveNext()) {
@@ -567,6 +634,10 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
                 if (((ForLoopTree) statement).getStatement().getKind() == Kind.BLOCK)
                     block = ((ForLoopTree) statement).getStatement();
                 break;
+            case ENHANCED_FOR_LOOP:
+                if (((EnhancedForLoopTree) statement).getStatement().getKind() == Kind.BLOCK)
+                    block = ((EnhancedForLoopTree) statement).getStatement();
+                break;
             case DO_WHILE_LOOP:
                 if (((DoWhileLoopTree) statement).getStatement().getKind() == Kind.BLOCK)
                     block = ((DoWhileLoopTree) statement).getStatement();
@@ -580,9 +651,37 @@ public class MarkOccurrencesHighlighter extends JavaParserResultTask {
                 result.add(new int[] {ts.offset(), ts.offset() + ts.token().length()});
             }
         }
+        
+        if (target.getKind() == Kind.LABELED_STATEMENT && isIn(caretPosition, Utilities.findIdentifierSpan(info, document, breakOrContinue))) {
+            result.addAll(detectLabel(info, document, info.getTrees().getPath(info.getCompilationUnit(), target)));
+        }
 
         return result;
     }
+    
+    private List<int[]> detectLabel(final CompilationInfo info, final Document document, final TreePath labeledStatement) {
+        final List<int[]> result = new ArrayList<int[]>();
+        if (labeledStatement.getLeaf().getKind() == Kind.LABELED_STATEMENT) {
+            final Name label = ((LabeledStatementTree)labeledStatement.getLeaf()).getLabel();
+            new TreePathScanner <Void, Void>() {
+                @Override
+                public Void visitBreak(BreakTree node, Void p) {
+                    if (node.getLabel() != null && label.contentEquals(node.getLabel())) {
+                        result.add(Utilities.findIdentifierSpan(getCurrentPath(), info, document));
+                    }
+                    return super.visitBreak(node, p);
+                }
+                @Override
+                public Void visitContinue(ContinueTree node, Void p) {
+                    if (node.getLabel() != null && label.contentEquals(node.getLabel())) {
+                        result.add(Utilities.findIdentifierSpan(getCurrentPath(), info, document));
+                    }
+                    return super.visitContinue(node, p);
+                }
+            }.scan(labeledStatement, null);
+        }
+        return result;
+    }
 
     static OffsetsBag getHighlightsBag(Document doc) {
         OffsetsBag bag = (OffsetsBag) doc.getProperty(MarkOccurrencesHighlighter.class);
