@@ -76,6 +76,7 @@ import com.sun.source.tree.Tree.Kind;
 import com.sun.source.tree.TypeCastTree;
 import com.sun.source.tree.TypeParameterTree;
 import com.sun.source.tree.UnaryTree;
+import com.sun.source.tree.UnionTypeTree;
 import com.sun.source.tree.VariableTree;
 import com.sun.source.tree.WildcardTree;
 import com.sun.source.util.SourcePositions;
@@ -113,6 +114,7 @@ import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.JavaParserResultTask;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.TreePathHandle;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.support.CancellableTreePathScanner;
 import org.netbeans.api.lexer.Token;
 import org.netbeans.api.lexer.TokenHierarchy;
@@ -128,6 +130,7 @@ import org.netbeans.spi.editor.hints.ErrorDescriptionFactory;
 import org.netbeans.spi.editor.hints.Fix;
 import org.netbeans.spi.editor.hints.HintsController;
 import org.netbeans.spi.editor.hints.LazyFixList;
+import org.netbeans.spi.editor.hints.Severity;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.loaders.DataObject;
@@ -701,6 +704,7 @@ public class SemanticHighlighter extends JavaParserResultTask {
             if (decl != null && (decl.getKind().isClass() || decl.getKind().isInterface())) {
                 //class use make look like read variable access:
                 if (type.contains(UseTypes.READ)) {
+                    type = EnumSet.copyOf(type);
                     type.remove(UseTypes.READ);
                     type.add(UseTypes.CLASS_USE);
                 }
@@ -962,11 +966,11 @@ public class SemanticHighlighter extends JavaParserResultTask {
                 //constructor:
                 TreePath tp = getCurrentPath();
                 
-                while (tp != null && tp.getLeaf().getKind() != Kind.CLASS) {
+                while (tp != null && !TreeUtilities.CLASS_TREE_KINDS.contains(tp.getLeaf().getKind())) {
                     tp = tp.getParentPath();
                 }
                 
-                if (tp != null && tp.getLeaf().getKind() == Kind.CLASS) {
+                if (tp != null && TreeUtilities.CLASS_TREE_KINDS.contains(tp.getLeaf().getKind())) {
                     name = ((ClassTree) tp.getLeaf()).getSimpleName().toString();
                 } else {
                     name = null;
@@ -1104,6 +1108,7 @@ public class SemanticHighlighter extends JavaParserResultTask {
                             boolean assign = false;
 
                             for (Element e : info.getElements().getAllMembers((TypeElement) decl)) {
+                                if (!e.getModifiers().contains(Modifier.STATIC)) continue;
                                 if (simpleName != null && !e.getSimpleName().equals(simpleName)) {
                                     continue;
                                 }
@@ -1406,6 +1411,14 @@ public class SemanticHighlighter extends JavaParserResultTask {
             return super.visitArrayType(node, p);
         }
 
+        @Override
+        public Void visitUnionType(UnionTypeTree node, EnumSet<UseTypes> p) {
+            for (Tree tree : node.getTypeAlternatives()) {
+                handlePossibleIdentifier(new TreePath(getCurrentPath(), tree), EnumSet.of(UseTypes.CLASS_USE));
+            }
+            return super.visitUnionType(node, p);
+        }
+
         @Override
         public Void visitNewArray(NewArrayTree tree, EnumSet<UseTypes> d) {
             if (tree.getType() != null) {
@@ -1487,7 +1500,7 @@ public class SemanticHighlighter extends JavaParserResultTask {
             }
             return super.visitWildcard(node, p);
         }
-        
+
         private void typeUsed(Element decl, TreePath expr, Collection<UseTypes> type) {
             if (decl != null && (expr == null || expr.getLeaf().getKind() == Kind.IDENTIFIER || expr.getLeaf().getKind() == Kind.PARAMETERIZED_TYPE)) {
                 if (decl.asType() != null && decl.asType().getKind() != TypeKind.ERROR) {
@@ -1542,6 +1555,11 @@ public class SemanticHighlighter extends JavaParserResultTask {
     static ErrorDescriptionSetter ERROR_DESCRIPTION_SETTER = new ErrorDescriptionSetter() {
         
         public void setErrors(Document doc, List<ErrorDescription> errors, List<TreePathHandle> allUnusedImports) {
+            FileObject file = NbEditorUtilities.getFileObject(doc);
+            if (file != null && org.netbeans.modules.editor.java.Utilities.disableErrors(file).contains(Severity.VERIFIER)) {
+                return;
+            }
+
             HintsController.setErrors(doc, "semantic-highlighter", errors);
         }
         
