@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -89,7 +92,7 @@ public class TokenList {
     }
     
     public void moveToOffset(long inputOffset) {
-        final int offset = info.getPositionConverter().getOriginalPosition((int) inputOffset);
+        final int offset = info.getSnapshot().getOriginalOffset((int) inputOffset);
 
         if (offset < 0)
             return ;
@@ -190,7 +193,7 @@ public class TokenList {
                     ;
 
                 if (next) {
-                    if (name.equals(ts.token().text().toString())) {
+                    if (name.equals(info.getTreeUtilities().decodeIdentifier(ts.token().text()).toString())) {
                         tree2Token.put(tp.getLeaf(), ts.token());
                     } else {
 //                            System.err.println("looking for: " + name + ", not found");
@@ -216,7 +219,7 @@ public class TokenList {
                 
                 Token t = ts.token();
 
-                if (t.id() == JavaTokenId.IDENTIFIER && tree.getName().toString().equals(t.text().toString())) {
+                if (t.id() == JavaTokenId.IDENTIFIER && tree.getName().toString().equals(info.getTreeUtilities().decodeIdentifier(t.text()).toString())) {
     //                System.err.println("visit ident 1");
                     tree2Token.put(tree, ts.token());
                 } else {
@@ -243,7 +246,7 @@ public class TokenList {
                 if (!tArgs.isEmpty()) {
                     int offset = (int) info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), tArgs.get(0));
                     
-                    offset = info.getPositionConverter().getOriginalPosition(offset);
+                    offset = info.getSnapshot().getOriginalOffset(offset);
                     
                     if (offset < 0)
                         return ;
