@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2011 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2011 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -61,8 +61,7 @@ import org.netbeans.api.java.lexer.JavaTokenId;
 import org.netbeans.api.lexer.Language;
 import org.netbeans.junit.NbTestCase;
 import org.netbeans.lib.editor.util.CharSequenceUtilities;
-import org.openide.modules.ModuleInfo;
-import org.openide.util.Lookup;
+import org.openide.awt.AcceleratorBinding;
 
 
 /**
@@ -80,7 +79,9 @@ public class JavaBraceCompletionUnitTest extends NbTestCase {
     @Override
     protected void setUp() throws Exception {
         super.setUp();
-        Lookup.getDefault().lookup(ModuleInfo.class);
+        Preferences prefs = MimeLookup.getLookup(JavaKit.JAVA_MIME_TYPE).lookup(Preferences.class);
+        prefs.putBoolean(SimpleValueNames.COMPLETION_PAIR_CHARACTERS, true);
+        Class.forName(AcceleratorBinding.class.getName(), true, AcceleratorBinding.class.getClassLoader());
     }
 
     // ------- Tests for completion of right parenthesis ')' -------------
@@ -203,99 +204,167 @@ public class JavaBraceCompletionUnitTest extends NbTestCase {
 
     public void testTypeAddRightBraceIfLeftBrace() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) {|"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {|\n" +
+                "    }\n" +
+                "}\n"
         );
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) {\n" +
-                "    |\n" +
-                "}"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {\n" +
+                "            |\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
         );
     }
 
     public void testTypeAddRightBraceIfLeftBraceWhiteSpace() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) { \t|"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { \t|\n" +
+                "    }\n" +
+                "}\n"
         );
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) { \t\n" +
-                "    |\n" +
-                "}"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { \t\n" +
+                "            |\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
         );
     }
 
     public void testTypeAddRightBraceIfLeftBraceLineComment() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) { // line-comment|"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { // line-comment|\n" +
+                "    }\n" +
+                "}\n"
         );
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) { // line-comment\n" +
-                "    |\n" +
-                "}"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { // line-comment\n" +
+                "            |\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
         );
     }
 
     public void testTypeAddRightBraceIfLeftBraceBlockComment() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) { /* block-comment */|"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { /* block-comment */|\n" +
+                "    }\n" +
+                "}\n"
         );
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) { /* block-comment */\n" +
-                "    |\n" +
-                "}"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { /* block-comment */\n" +
+                "            |\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
         );
     }
 
     public void testTypeAddRightBraceIfLeftBraceAlreadyPresent() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) {|\n" +
-                "}"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {|\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
         );
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) {\n" +
-                "    |\n" +
-                "}"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {\n" +
+                "            |\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
         );
     }
 
-    public void testTypeAddRightBraceCaretInComment() {
+    public void XtestTypeAddRightBraceCaretInComment() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) { /* unclosed-block-comment|\n" +
-                "  */"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { /* unclosed-block-comment|\n" +
+                "          */\n" +
+                "    }\n" +
+                "}\n"
         );
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) { /* unclosed-block-comment\n" +
-                "             * |\n" +
-                "  */"
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) { /* unclosed-block-comment\n" +
+                "                     * |\n" +
+                "          */\n" +
+                "    }\n" +
+                "}\n"
         );
     }
 
     public void testTypeAddRightBraceMultiLine() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) {| System.out.println(\n" +
-                "\"\");\n");
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {| System.out.println(\n" +
+                "        \"\");\n" +
+                "    }\n" +
+                "}\n"
+                );
 
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) {\n" +
-                "    System.out.println(\n" +
-                "\"\");\n");
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {\n" +
+                "            System.out.println(\n" +
+                "        \"\");\n" +
+                "    }\n" +
+                "}\n"
+                );
     }
 
     public void testTypeAddRightBraceSingleLine() {
         Context ctx = new Context(new JavaKit(),
-                "if (true) {| System.out.println(\"\");\n");
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {| System.out.println(\"\");\n" +
+                "    }\n" +
+                "}\n"
+                );
 
         ctx.typeChar('\n');
         ctx.assertDocumentTextEquals(
-                "if (true) {\n" +
-                "    System.out.println(\"\");\n" +
-                "}\n");
+                "class Test {\n" +
+                "    {\n" +
+                "        if (true) {\n" +
+                "            System.out.println(\"\");\n" +
+                "        }\n" +
+                "    }\n" +
+                "}\n"
+                );
     }
 
 
@@ -794,6 +863,66 @@ public class JavaBraceCompletionUnitTest extends NbTestCase {
         );
     }
 
+    public void testSkipWhenBalanced198194a() throws Exception {
+        Context ctx = new Context(new JavaKit(),
+                "for (int i = a(|); i < 10; i++)"
+        );
+        ctx.typeChar(')');
+        ctx.assertDocumentTextEquals(
+                "for (int i = a()|; i < 10; i++)"
+        );
+    }
+
+    public void testSkipWhenNotBalanced198194a() throws Exception {
+        Context ctx = new Context(new JavaKit(),
+                "for (int i = a(|; i < 10; i++)"
+        );
+        ctx.typeChar(')');
+        ctx.assertDocumentTextEquals(
+                "for (int i = a()|; i < 10; i++)"
+        );
+    }
+
+    public void testSkipWhenBalanced198194b() throws Exception {
+        Context ctx = new Context(new JavaKit(),
+                "for (int i = a(); i < 10; i = a(|))"
+        );
+        ctx.typeChar(')');
+        ctx.assertDocumentTextEquals(
+                "for (int i = a(); i < 10; i = a()|)"
+        );
+    }
+
+    public void testSkipWhenNotBalanced198194b() throws Exception {
+        Context ctx = new Context(new JavaKit(),
+                "for (int i = a(); i < 10; i = a(|)"
+        );
+        ctx.typeChar(')');
+        ctx.assertDocumentTextEquals(
+                "for (int i = a(); i < 10; i = a()|)"
+        );
+    }
+
+    public void testSkipWhenNotBalanced198194c() throws Exception {
+        Context ctx = new Context(new JavaKit(),
+                "for (int i = a(); i < 10; i++) a(|;"
+        );
+        ctx.typeChar(')');
+        ctx.assertDocumentTextEquals(
+                "for (int i = a(); i < 10; i++) a()|;"
+        );
+    }
+
+    public void testSkipWhenBalanced198194c() throws Exception {
+        Context ctx = new Context(new JavaKit(),
+                "for (int i = a(); i < 10; i++) a(|);"
+        );
+        ctx.typeChar(')');
+        ctx.assertDocumentTextEquals(
+                "for (int i = a(); i < 10; i++) a()|;"
+        );
+    }
+
     public void testKeepBalance148878() throws Exception {
         Context ctx = new Context(new JavaKit(),
                 "Map[|] m = new HashMap[1];"
