@@ -1,8 +1,11 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
- * 
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
- * 
+ *
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
+ *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
  * Development and Distribution License("CDDL") (collectively, the
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -510,7 +513,7 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
         TypeElement clazzC = info.getTopLevelElements().iterator().next();
         assertNotNull(clazzC);
 
-        TokenSequence<JavadocTokenId> jdts = JavadocCompletionUtils.findJavadocTokenSequence(info, clazzC);
+        TokenSequence<JavadocTokenId> jdts = JavadocCompletionUtils.findJavadocTokenSequence(info, null, clazzC);
         assertNotNull(jdts);
         assertTrue(jdts.moveNext());
 
@@ -518,7 +521,7 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
         Element defConstructor = clazzC.getEnclosedElements().get(0);
         assertNotNull(defConstructor);
         assertTrue(info.getElementUtilities().isSynthetic(defConstructor));
-        assertNull(JavadocCompletionUtils.findJavadocTokenSequence(info, defConstructor));
+        assertNull(JavadocCompletionUtils.findJavadocTokenSequence(info, null, defConstructor));
     }
 
     public void testIsInvalidDocInstance() throws Exception {
@@ -538,7 +541,7 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
                 "    int f5;\n" +
                 "    /**\n" +
                 "     */\n" +
-                "    int f_issue_159352;\n" +
+                "    int f6_issue_159352;\n" +
                 "    /**\n" +
                 "     * \n" +
                 "     */\n" +
@@ -553,19 +556,23 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
                 "    int f10_issue_139147;\n" +
                 "    /**  * */\n" +
                 "    int f11_issue_139147;\n" +
+                "    /*******\n" +
+                "     ***/\n" +
+                "    int f12_issue_183776;\n" +
                 "}\n";
         prepareTest(code);
 
         doIsInvalidJavadoc(1, null, null, null, false);
+        doIsTokenOfEmptyJavadoc(1, true);
         doIsInvalidJavadoc(2, null, null, null, false);
         doIsTokenOfEmptyJavadoc(2, true);
         doIsInvalidJavadoc(3, null, null, null, false);
-        doIsTokenOfEmptyJavadoc(3, false);
+        doIsTokenOfEmptyJavadoc(3, true);
         doIsInvalidJavadoc(4, null, null, null, false);
 
         Element fieldEl = info.getTopLevelElements().get(0).getEnclosedElements().get(4);
         assertNotNull(fieldEl);
-        TokenSequence<JavadocTokenId> jdts = JavadocCompletionUtils.findJavadocTokenSequence(info, fieldEl);
+        TokenSequence<JavadocTokenId> jdts = JavadocCompletionUtils.findJavadocTokenSequence(info, null, fieldEl);
         assertNotNull(jdts);
         doIsInvalidJavadoc(5, null, null, jdts, true);
 
@@ -573,15 +580,17 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
         doIsInvalidJavadoc(6, null, null, null, false);
         doIsTokenOfEmptyJavadoc(6, true);
         doIsInvalidJavadoc(7, null, null, null, false);
-        doIsTokenOfEmptyJavadoc(7, false);
+        doIsTokenOfEmptyJavadoc(7, true);
         doIsInvalidJavadoc(8, null, null, null, false);
-        doIsTokenOfEmptyJavadoc(8, false);
+        doIsTokenOfEmptyJavadoc(8, true);
         doIsInvalidJavadoc(9, null, null, null, false);
         doIsTokenOfEmptyJavadoc(9, true);
         doIsInvalidJavadoc(10, null, null, null, false);
         doIsTokenOfEmptyJavadoc(10, true);
         doIsInvalidJavadoc(11, null, null, null, false);
-        doIsTokenOfEmptyJavadoc(11, false);
+        doIsTokenOfEmptyJavadoc(11, true);
+        doIsInvalidJavadoc(12, null, null, null, false);
+        doIsTokenOfEmptyJavadoc(11, true);
     }
 
     private void doIsInvalidJavadoc(int fieldIndex, Element fieldEl, Doc jdoc, TokenSequence<JavadocTokenId> jdts, boolean isInvalid) {
@@ -589,7 +598,7 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
         assertNotNull(fieldEl);
         jdoc = jdoc != null ? jdoc : info.getElementUtilities().javaDocFor(fieldEl);
         assertNotNull(jdoc);
-        jdts = jdts != null ? jdts : JavadocCompletionUtils.findJavadocTokenSequence(info, fieldEl);
+        jdts = jdts != null ? jdts : JavadocCompletionUtils.findJavadocTokenSequence(info, null, fieldEl);
         assertNotNull(jdts);
         assertEquals(fieldEl.getSimpleName().toString(), isInvalid, JavadocCompletionUtils.isInvalidDocInstance(jdoc, jdts));
     }
@@ -597,7 +606,7 @@ public class JavadocCompletionUtilsTest extends JavadocTestSupport {
     private void doIsTokenOfEmptyJavadoc(int fieldIndex, boolean isEmpty) {
         Element fieldEl = info.getTopLevelElements().get(0).getEnclosedElements().get(fieldIndex);
         assertNotNull(fieldEl);
-        TokenSequence<JavadocTokenId> jdts = JavadocCompletionUtils.findJavadocTokenSequence(info, fieldEl);
+        TokenSequence<JavadocTokenId> jdts = JavadocCompletionUtils.findJavadocTokenSequence(info, null, fieldEl);
         assertNotNull(jdts);
         jdts.moveStart();
         if (jdts.moveNext()) {
