@@ -393,11 +393,20 @@ public class DetectorTest extends TestBase {
         performTest("TwoPackagePrivateConstructors");
     }
 
-    public void testExoticIdentifiers() throws Exception {
+    //Support for exotic identifiers has been removed 6999438
+    public void REMOVEDtestExoticIdentifiers() throws Exception {
         setSourceLevel("1.7");
         performTest("ExoticIdentifier");
     }
 
+    public void testStaticImport189226() throws Exception {
+        performTest("StaticImport189226");
+    }
+
+    public void testReadUseElseTernary191230() throws Exception {
+        performTest("ReadUseElseTernary191230");
+    }
+
     private void performTest(String fileName) throws Exception {
         performTest(fileName, new Performer() {
             public void compute(CompilationController parameter, Document doc, ErrorDescriptionSetter setter) {
