@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -50,7 +53,6 @@ import java.util.Map;
 import javax.swing.event.ChangeListener;
 import org.netbeans.api.java.queries.SourceForBinaryQuery;
 import org.netbeans.api.project.ProjectManager;
-import org.netbeans.modules.ant.freeform.spi.support.Util;
 import org.netbeans.spi.java.queries.SourceForBinaryQueryImplementation;
 import org.netbeans.spi.project.AuxiliaryConfiguration;
 import org.netbeans.spi.project.support.ant.AntProjectEvent;
@@ -60,6 +62,7 @@ import org.netbeans.spi.project.support.ant.PropertyEvaluator;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Mutex;
+import org.openide.xml.XMLUtil;
 import org.w3c.dom.Element;
 
 /**
@@ -96,11 +99,11 @@ final class SourceForBinaryQueryImpl implements SourceForBinaryQueryImplementati
         if (roots == null) {
             // Need to compute it. Easiest to compute them all at once.
             roots = new HashMap<URL,FileObject[]>();
-            Element java = aux.getConfigurationFragment(JavaProjectNature.EL_JAVA, JavaProjectNature.NS_JAVA_2, true);
+            Element java = aux.getConfigurationFragment(JavaProjectNature.EL_JAVA, JavaProjectNature.NS_JAVA_3, true);
             if (java == null) {
                 return null;
             }
-            for (Element compilationUnit : Util.findSubElements(java)) {
+            for (Element compilationUnit : XMLUtil.findSubElements(java)) {
                 assert compilationUnit.getLocalName().equals("compilation-unit") : compilationUnit;
                 List<URL> binaries = findBinaries(compilationUnit);
                 if (!binaries.isEmpty()) {
@@ -137,11 +140,11 @@ final class SourceForBinaryQueryImpl implements SourceForBinaryQueryImplementati
      */
     private List<URL> findBinaries(Element compilationUnitEl) {
         List<URL> binaries = new ArrayList<URL>();
-        for (Element builtToEl : Util.findSubElements(compilationUnitEl)) {
+        for (Element builtToEl : XMLUtil.findSubElements(compilationUnitEl)) {
             if (!builtToEl.getLocalName().equals("built-to")) { // NOI18N
                 continue;
             }
-            String text = Util.findText(builtToEl);
+            String text = XMLUtil.findText(builtToEl);
             String textEval = evaluator.evaluate(text);
             if (textEval == null) {
                 continue;
