@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -59,19 +62,31 @@ public class JavaProjectNatureTest extends NbTestCase {
         super(name);
     }
 
-    public void testUpgradeSchema() throws Exception {
+    public void testUpgradeSchema1to2() throws Exception {
+        upgradeSchemaTestImpl(JavaProjectNature.NS_JAVA_1, JavaProjectNature.NS_JAVA_2);
+    }
+
+    public void testUpgradeSchema2to3() throws Exception {
+        upgradeSchemaTestImpl(JavaProjectNature.NS_JAVA_2, JavaProjectNature.NS_JAVA_3);
+    }
+
+    public void testUpgradeSchema1to3() throws Exception {
+        upgradeSchemaTestImpl(JavaProjectNature.NS_JAVA_1, JavaProjectNature.NS_JAVA_3);
+    }
+
+    private void upgradeSchemaTestImpl(String from, String to) throws Exception {
         // Formatting has to be the same as Xerces' formatter produces for this test to pass:
         String xml1 = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
-                      "<java-data xmlns=\"http://www.netbeans.org/ns/freeform-project-java/1\">\n" +
+                      "<java-data xmlns=\""+from+"\">\n" +
                       "    <!-- Hello there. -->\n" +
                       "    <foo bar=\"baz\" quux=\"whatever\">hello</foo>\n" +
                       "    <x>OK</x>\n" +
                       "</java-data>\n";
-        String xml2expected = xml1.replaceAll("/1", "/2");
+        String xml2expected = xml1.replaceAll(from, to);
         Document doc1 = XMLUtil.parse(new InputSource(new StringReader(xml1)), false, true, null, null);
         Element el1 = doc1.getDocumentElement();
-        Element el2 = LookupProviderImpl.upgradeSchema(el1);
-        Document doc2 = XMLUtil.createDocument(JavaProjectNature.EL_JAVA, JavaProjectNature.NS_JAVA_2, null, null);
+        Element el2 = LookupProviderImpl.upgradeSchema(el1,to);
+        Document doc2 = XMLUtil.createDocument(JavaProjectNature.EL_JAVA, to, null, null);
         doc2.removeChild(doc2.getDocumentElement());
         doc2.appendChild(doc2.importNode(el2, true));
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
@@ -79,5 +94,4 @@ public class JavaProjectNatureTest extends NbTestCase {
         String xml2actual = baos.toString("UTF-8").replaceAll(System.getProperty("line.separator"), "\n");
         assertEquals("Correct upgrade result", xml2expected, xml2actual);
     }
-    
 }
