@@ -67,9 +67,7 @@ import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import javax.swing.JEditorPane;
 import javax.swing.SwingUtilities;
-import javax.swing.text.BadLocationException;
-import javax.swing.text.Document;
-import javax.swing.text.Position;
+import org.netbeans.api.java.source.ModificationResult;
 import org.netbeans.api.java.source.Task;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.ElementUtilities.ElementAcceptor;
@@ -78,8 +76,10 @@ import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.TreeMaker;
 import org.netbeans.api.java.source.TreePathHandle;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.api.java.source.support.CaretAwareJavaSourceTaskFactory;
+import org.netbeans.api.java.source.support.SelectionAwareJavaSourceTaskFactory;
 import org.netbeans.modules.java.editor.rename.InstantRenamePerformer;
 import org.netbeans.modules.java.hints.errors.Utilities;
 import org.netbeans.modules.java.hints.infrastructure.Pair;
@@ -110,30 +110,66 @@ public class ConvertAnonymousToInner extends AbstractHint {
         return EnumSet.of(Kind.NEW_CLASS);
     }
 
-    static Fix computeFix(CompilationInfo info, TreePath path, int pos) {
-        if (path.getLeaf().getKind() != Kind.NEW_CLASS)
-            return null;
+    static Fix computeFix(CompilationInfo info, int selStart, int selEnd, boolean onlyHeader) {
+        TreePath tp = findNCT(info, info.getTreeUtilities().pathFor((selStart + selEnd + 1) / 2), selStart, selEnd, onlyHeader);
+
+        if (tp == null) {
+            tp = findNCT(info, info.getTreeUtilities().pathFor((selStart + selEnd + 1) / 2 + 1), selStart, selEnd, onlyHeader);
+        }
         
-        NewClassTree nct = (NewClassTree) path.getLeaf();
-        
-        if (nct.getClassBody() == null) {
+        if (tp == null) {
             return null;
         }
         
-        if (pos != (-1)) {
-            long start = info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), nct.getClassBody());
-            
-            if (pos > start) {
-                return null;
+        return new FixImpl(TreePathHandle.create(tp, info), info.getJavaSource(), info.getFileObject());
+    }
+
+    private static TreePath findNCT(CompilationInfo info, TreePath tp, int selStart, int selEnd, boolean onlyHeader) {
+        while (tp != null) {
+            if (tp.getLeaf().getKind() != Kind.NEW_CLASS) {
+                tp = tp.getParentPath();
+                continue;
             }
+
+            NewClassTree nct = (NewClassTree) tp.getLeaf();
+
+            if (nct.getClassBody() == null) {
+                tp = tp.getParentPath();
+                continue;
+            }
+
+            if (selStart == selEnd) {
+                if (onlyHeader) {
+                    long start = info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), nct.getClassBody());
+
+                    if (selStart > start) {
+                        return null;
+                    }
+                }
+
+                break;
+            } else {
+                long start = info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), nct);
+                long end = info.getTrees().getSourcePositions().getEndPosition(info.getCompilationUnit(), nct);
+
+                if (start == selStart && end == selEnd) {
+                    break;
+                }
+            }
+
+            tp = tp.getParentPath();
         }
-        
-        return new FixImpl(TreePathHandle.create(path, info), info.getJavaSource(), info.getFileObject());
+
+        return tp;
     }
     
     public List<ErrorDescription> run(CompilationInfo compilationInfo, TreePath treePath) {
         int pos = CaretAwareJavaSourceTaskFactory.getLastPosition(compilationInfo.getFileObject());
-        Fix f = computeFix(compilationInfo, treePath, pos);
+        int[] selection = SelectionAwareJavaSourceTaskFactory.getLastSelection(compilationInfo.getFileObject());
+
+        if (selection == null) return null;
+        
+        Fix f = computeFix(compilationInfo, selection[0], selection[1], true);
         
         if (f == null)
             return null;
@@ -161,7 +197,6 @@ public class ConvertAnonymousToInner extends AbstractHint {
         private TreePathHandle tph;
         private JavaSource js;
         private FileObject file;
-        private Position instantRenamePosition;
         
         public FixImpl(TreePathHandle tph, JavaSource js, FileObject file) {
             this.tph = tph;
@@ -174,9 +209,13 @@ public class ConvertAnonymousToInner extends AbstractHint {
         }
 
         public ChangeInfo implement() throws IOException {
-            js.runModificationTask(this).commit();
+            ModificationResult mr = js.runModificationTask(this);
             
-            if (instantRenamePosition != null) {
+            mr.commit();
+            
+            final int[] newClassNameSpan = mr.getSpan(NEW_CLASS_TREE_TAG);
+            
+            if (newClassNameSpan != null) {
                 SwingUtilities.invokeLater(new Runnable() {
                     public void run() {
                         try {
@@ -185,7 +224,7 @@ public class ConvertAnonymousToInner extends AbstractHint {
                             if (arr == null) {
                                 return;
                             }
-                            arr[0].setCaretPosition(instantRenamePosition.getOffset());
+                            arr[0].setCaretPosition((newClassNameSpan[0] + newClassNameSpan[1]) / 2);
                             InstantRenamePerformer.invokeInstantRename(arr[0]);
                         } catch (DataObjectNotFoundException ex) {
                             Exceptions.printStackTrace(ex);
@@ -202,22 +241,6 @@ public class ConvertAnonymousToInner extends AbstractHint {
             TreePath tp = tph.resolve(parameter);
             
             convertAnonymousToInner(parameter, tp);
-            
-            final int instantRenamePositionOffset = (int) parameter.getTrees().getSourcePositions().getStartPosition(parameter.getCompilationUnit(), ((NewClassTree) tp.getLeaf()).getIdentifier());
-            
-            final Document doc = parameter.getDocument();
-            
-            if (doc != null) {
-                doc.render(new Runnable() {
-                    public void run() {
-                        try {
-                            instantRenamePosition = doc.createPosition(instantRenamePositionOffset);
-                        } catch (BadLocationException ex) {
-                            Logger.getLogger(ConvertAnonymousToInner.class.getName()).log(Level.INFO, null, ex);
-                        }
-                    }
-                });
-            }
         }
     }
 
@@ -336,7 +359,7 @@ public class ConvertAnonymousToInner extends AbstractHint {
                 
         TreePath tp = newClassToConvert;
 
-        while (tp != null && tp.getLeaf().getKind() != Kind.CLASS) {
+        while (tp != null && !TreeUtilities.CLASS_TREE_KINDS.contains(tp.getLeaf().getKind())) {
             tp = tp.getParentPath();
         }
         
@@ -443,7 +466,7 @@ public class ConvertAnonymousToInner extends AbstractHint {
                 }
             }
         } else if (errorConstructor) {
-	    Pair<List<? extends TypeMirror>, List<String>> resolvedArguments = Utilities.resolveArguments(copy, newClassToConvert, nct.getArguments());
+	    Pair<List<? extends TypeMirror>, List<String>> resolvedArguments = Utilities.resolveArguments(copy, newClassToConvert, nct.getArguments(), targetElement);
 
 	    if (resolvedArguments != null) {
 		nueSuperConstructorCallRealArguments = new LinkedList<ExpressionTree>();
@@ -494,10 +517,12 @@ public class ConvertAnonymousToInner extends AbstractHint {
         ClassTree clazz = make.Class(classModifiers, newClassName, Collections.<TypeParameterTree>emptyList(), superTypeElement.getKind().isClass() ? superTypeTree : null, superTypeElement.getKind().isClass() ? Collections.<Tree>emptyList() : Collections.<Tree>singletonList(superTypeTree), members);
         
         copy.rewrite(target, make.addClassMember(target, clazz));
-        
-        NewClassTree nueNCT = make.NewClass(/*!!!*/null, Collections.<ExpressionTree>emptyList(), make.Identifier(newClassName), constrRealArguments, null);
+
+        IdentifierTree classNameTree = make.Identifier(newClassName);
+        NewClassTree nueNCT = make.NewClass(/*!!!*/null, Collections.<ExpressionTree>emptyList(), classNameTree, constrRealArguments, null);
         
         copy.rewrite(nct, nueNCT);
+        copy.tag(classNameTree, NEW_CLASS_TREE_TAG);
     }
 
     public void cancel() {
@@ -537,4 +562,6 @@ public class ConvertAnonymousToInner extends AbstractHint {
         
         return new FindSuperConstructorCall().scan(nct, null);
     }
+
+    private static final String NEW_CLASS_TREE_TAG = "new-class-tree-tag";
 }
