@@ -94,7 +94,7 @@ public class StaticAccess extends AbstractHint {
             return null;
         }
         Element el = info.getTypes().asElement(tm);
-        if (el == null || el.getKind() != ElementKind.CLASS) {
+        if (el == null || (!el.getKind().isClass() && !el.getKind().isInterface())) {
             return null;
         }
         
@@ -135,10 +135,7 @@ public class StaticAccess extends AbstractHint {
             return null;
         }
         
-        int[] span = {
-            (int)info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), expression),
-            (int)info.getTrees().getSourcePositions().getEndPosition(info.getCompilationUnit(), expression),
-        };
+        int[] span = info.getTreeUtilities().findNameSpan(mst);
         
         if (span[0] == (-1) || span[1] == (-1)) {
             return null;
