@@ -30,9 +30,12 @@
  */
 package org.netbeans.modules.java.hints;
 
+import org.netbeans.spi.editor.hints.EnhancedFix;
 import com.sun.source.tree.CompilationUnitTree;
 import com.sun.source.tree.ImportTree;
 import com.sun.source.tree.MemberSelectTree;
+import com.sun.source.tree.MethodInvocationTree;
+import com.sun.source.tree.Tree;
 import com.sun.source.tree.Tree.Kind;
 import com.sun.source.util.TreePath;
 import java.util.ArrayList;
@@ -60,6 +63,7 @@ import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.Task;
 import org.netbeans.api.java.source.TreeMaker;
 import org.netbeans.api.java.source.TreePathHandle;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.modules.java.editor.imports.ComputeImports;
 import org.netbeans.modules.java.editor.imports.ComputeImports.Pair;
@@ -108,6 +112,10 @@ public class StaticImport extends AbstractHint {
         if (mitp == null || mitp.getLeaf().getKind() != Kind.METHOD_INVOCATION) {
             return null;
         }
+        List<? extends Tree> typeArgs = ((MethodInvocationTree) mitp.getLeaf()).getTypeArguments();
+        if (typeArgs != null && !typeArgs.isEmpty()) {
+            return null;
+        }
         Element e = info.getTrees().getElement(treePath);
         if (e == null || !e.getModifiers().contains(Modifier.STATIC) || e.getKind() != ElementKind.METHOD) {
             return null;
@@ -180,7 +188,7 @@ public class StaticImport extends AbstractHint {
         return info.getSourceVersion().compareTo(SourceVersion.RELEASE_5) >= 0;
     }
 
-    public static final class FixImpl implements Fix, Task<WorkingCopy> {
+    public static final class FixImpl implements EnhancedFix, Task<WorkingCopy> {
 
         private final TreePathHandle handle;
         private final String fqn;
@@ -236,6 +244,11 @@ public class StaticImport extends AbstractHint {
             CompilationUnitTree nue = JavaFixAllImports.addImports(cut, Collections.singletonList(fqn), make, true);
             copy.rewrite(cut, nue);
         }
+
+        @Override
+        public CharSequence getSortText() {
+            return "\uFFFFa";
+        }
     }
 
     // returns true if a METHOD is enclosed in element with simple name sn
@@ -341,7 +354,7 @@ public class StaticImport extends AbstractHint {
      * @return the first path which is a CLASS or null if none found
      */
     public static TreePath getContainingClass(TreePath tp) {
-        while (tp != null && tp.getLeaf().getKind() != Kind.CLASS) {
+        while (tp != null && !TreeUtilities.CLASS_TREE_KINDS.contains(tp.getLeaf().getKind())) {
             tp = tp.getParentPath();
         }
         return tp;
