@@ -144,7 +144,7 @@ public final class ChangeType implements ErrorRule<Void> {
 
                 resolved = org.netbeans.modules.java.hints.errors.Utilities.resolveCapturedType(info, resolved);
 
-                if (resolved == null || resolved.getKind() == TypeKind.VOID || resolved.getKind() == TypeKind.EXECUTABLE || resolved.getKind() == TypeKind.NULL) {
+                if (resolved == null || resolved.getKind() == TypeKind.VOID || resolved.getKind() == TypeKind.NONE ||resolved.getKind() == TypeKind.EXECUTABLE || resolved.getKind() == TypeKind.NULL) {
                 } else if (resolved.getKind() != TypeKind.ERROR &&
                 		expected.getKind() != TypeKind.ERROR) {
                     tm[0] = expected;
@@ -189,7 +189,7 @@ public final class ChangeType implements ErrorRule<Void> {
 
                 result.add(new ChangeTypeFix(info.getJavaSource(),
                         ((VariableTree) leaf[0]).getName().toString(), 
-                        Utilities.getTypeName(expressionType[0], false).toString(), offset));
+                        Utilities.getTypeName(info, expressionType[0], false).toString(), offset));
             }
         }
         
