@@ -43,7 +43,9 @@
  */
 package org.netbeans.modules.java.hints.errors;
 
+import java.util.Collection;
 import com.sun.source.tree.BlockTree;
+import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodInvocationTree;
@@ -73,11 +75,13 @@ import javax.lang.model.element.PackageElement;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
+import javax.lang.model.type.TypeVariable;
 import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.api.java.source.ClasspathInfo.PathKind;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.SourceUtils;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.modules.java.hints.errors.CreateClassFix.CreateInnerClassFix;
 import org.netbeans.modules.java.hints.errors.CreateClassFix.CreateOuterClassFix;
 import org.netbeans.modules.java.hints.infrastructure.ErrorHintsProvider;
@@ -102,7 +106,7 @@ public final class CreateElement implements ErrorRule<Void> {
     }
 
     public Set<String> getCodes() {
-        return new HashSet<String>(Arrays.asList("compiler.err.cant.resolve.location", "compiler.err.cant.resolve.location.args", "compiler.err.cant.apply.symbol", "compiler.err.cant.resolve", "compiler.err.cant.resolve.args")); // NOI18N
+        return new HashSet<String>(Arrays.asList("compiler.err.cant.resolve.location", "compiler.err.cant.resolve.location.args", "compiler.err.cant.apply.symbol", "compiler.err.cant.apply.symbol.1", "compiler.err.cant.resolve", "compiler.err.cant.resolve.args")); // NOI18N
     }
 
     public List<Fix> run(CompilationInfo info, String diagnosticKey, int offset, TreePath treePath, Data<Void> data) {
@@ -135,25 +139,28 @@ public final class CreateElement implements ErrorRule<Void> {
         TreePath firstInitializer = null;
         TreePath methodInvocation = null;
         TreePath newClass = null;
+        boolean baseType = false;
         boolean lookupMethodInvocation = true;
         boolean lookupNCT = true;
 
-        TreePath path = info.getTreeUtilities().pathFor(offset + 1);
+        TreePath path = info.getTreeUtilities().pathFor(Math.max((int) info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), errorPath.getLeaf()), offset) + 1);
 
         while(path != null) {
             Tree leaf = path.getLeaf();
             Kind leafKind = leaf.getKind();
 
+            if (!baseType && TreeUtilities.CLASS_TREE_KINDS.contains(leafKind) && parent != null && (((ClassTree)leaf).getExtendsClause() == parent.getLeaf() || ((ClassTree)leaf).getImplementsClause().contains(parent.getLeaf())))
+                baseType = true;
             if (parent != null && parent.getLeaf() == errorPath.getLeaf())
                 parent = path;
             if (leaf == errorPath.getLeaf() && parent == null)
                 parent = path;
-            if (leafKind == Kind.CLASS && firstClass == null)
+            if (TreeUtilities.CLASS_TREE_KINDS.contains(leafKind) && firstClass == null)
                 firstClass = path;
             if (leafKind == Kind.METHOD && firstMethod == null && firstClass == null)
                 firstMethod = path;
             //static/dynamic initializer:
-            if (   leafKind == Kind.BLOCK && path.getParentPath().getLeaf().getKind() == Kind.CLASS
+            if (   leafKind == Kind.BLOCK && TreeUtilities.CLASS_TREE_KINDS.contains(path.getParentPath().getLeaf().getKind())
                 && firstMethod == null && firstClass == null)
                 firstInitializer = path;
 
@@ -180,7 +187,7 @@ public final class CreateElement implements ErrorRule<Void> {
             path = path.getParentPath();
         }
 
-        if (parent == null || parent.getLeaf() == errorPath.getLeaf() || firstClass == null)
+        if (parent == null || parent.getLeaf() == errorPath.getLeaf())
             return Collections.<Fix>emptyList();
 
         Element e = info.getTrees().getElement(errorPath);
@@ -201,25 +208,29 @@ public final class CreateElement implements ErrorRule<Void> {
             return Collections.<Fix>emptyList();
         }
         String simpleName = name.toString();
-        TypeElement source = (TypeElement) info.getTrees().getElement(firstClass);
-        TypeElement target = null;
+        final TypeElement source = firstClass != null ? (TypeElement) info.getTrees().getElement(firstClass) : null;
+        Element target = null;
         boolean wasMemberSelect = false;
 
         if (errorPath.getLeaf().getKind() == Kind.MEMBER_SELECT) {
             TreePath exp = new TreePath(errorPath, ((MemberSelectTree) errorPath.getLeaf()).getExpression());
             TypeMirror targetType = info.getTrees().getTypeMirror(exp);
 
-            if (targetType != null && targetType.getKind() == TypeKind.DECLARED) {
-                Element expElement = info.getTrees().getElement(exp);
+            if (targetType != null) {
+                if (targetType.getKind() == TypeKind.DECLARED) {
+                    Element expElement = info.getTrees().getElement(exp);
 
-                if (isClassLikeElement(expElement)) {
-                    modifiers.add(Modifier.STATIC);
-                }
+                    if (isClassLikeElement(expElement)) {
+                        modifiers.add(Modifier.STATIC);
+                    }
 
-                Element targetElement = info.getTypes().asElement(targetType);
+                    Element targetElement = info.getTypes().asElement(targetType);
 
-                if (isClassLikeElement(targetElement)) {
-                    target = (TypeElement) targetElement;
+                    if (isClassLikeElement(targetElement)) {
+                        target = (TypeElement) targetElement;
+                    }
+                } else if (targetType.getKind() == TypeKind.PACKAGE) {
+                    target = info.getTrees().getElement(exp);
                 }
             }
 
@@ -227,7 +238,7 @@ public final class CreateElement implements ErrorRule<Void> {
         } else {
 	    Element enclosingElement = e.getEnclosingElement();
 	    if(enclosingElement != null && enclosingElement.getKind() == ElementKind.ANNOTATION_TYPE) //unresolved element inside annot.
-			target = (TypeElement) enclosingElement;
+			target = enclosingElement;
 	    else
 
 		if (errorPath.getLeaf().getKind() == Kind.IDENTIFIER) {
@@ -260,7 +271,10 @@ public final class CreateElement implements ErrorRule<Void> {
             return Collections.<Fix>emptyList();
         }
 
-        modifiers.addAll(getAccessModifiers(info, source, target));
+        if (target instanceof TypeElement)
+            modifiers.addAll(getAccessModifiers(info, source, (TypeElement) target));
+        else
+            modifiers.add(Modifier.PUBLIC);
 
         List<Fix> result = new ArrayList<Fix>();
 
@@ -274,11 +288,25 @@ public final class CreateElement implements ErrorRule<Void> {
             if (types == null || types.isEmpty()) {
                 return Collections.<Fix>emptyList();
             }
-            result.addAll(prepareCreateMethodFix(info, methodInvocation, modifiers, target, simpleName, mit.getArguments(), types));
+            result.addAll(prepareCreateMethodFix(info, methodInvocation, modifiers, (TypeElement) target, simpleName, mit.getArguments(), types));
         }
 
+        Set<ElementKind> fixTypes = EnumSet.noneOf(ElementKind.class);
+        TypeMirror[] superType = new TypeMirror[1];
+        int[] numTypeParameters = new int[1];
+        List<? extends TypeMirror> types = resolveType(fixTypes, info, parent, errorPath.getLeaf(), offset, superType, numTypeParameters);
+        ElementKind classType = getClassType(fixTypes);
+
+        if (target.getKind() == ElementKind.PACKAGE) {
+            result.addAll(prepareCreateOuterClassFix(info, null, target, modifiers, simpleName, null, superType[0], classType != null ? classType : ElementKind.CLASS, numTypeParameters[0]));
+            return result;
+        }
+        
+        //XXX: should reasonably consider all the found type candidates, not only the one:
+        final TypeMirror type = types != null && !types.isEmpty() && types.get(0) != null ? Utilities.resolveCapturedType(info, types.get(0)) : null;
+        TypeElement outermostTypeElement = source != null ? info.getElementUtilities().outermostTypeElement(source) : null;
+
         if (newClass != null) {
-            //create method:
             NewClassTree nct = (NewClassTree) newClass.getLeaf();
             Element clazz = info.getTrees().getElement(new TreePath(newClass, nct.getIdentifier()));
 
@@ -292,12 +320,13 @@ public final class CreateElement implements ErrorRule<Void> {
                 }
 
                 if (wasMemberSelect) {
-                    return prepareCreateInnerClassFix(info, newClass, target, modifiers, simpleName, nct.getArguments(), null, ElementKind.CLASS, numTypeArguments);
+                    return prepareCreateInnerClassFix(info, newClass, (TypeElement) target, modifiers, simpleName, nct.getArguments(), type, ElementKind.CLASS, numTypeArguments);
                 } else {
 		    List<Fix> currentResult = new LinkedList<Fix>();
 
-		    currentResult.addAll(prepareCreateOuterClassFix(info, newClass, source, EnumSet.noneOf(Modifier.class), simpleName, nct.getArguments(), null, ElementKind.CLASS, numTypeArguments));
-		    currentResult.addAll(prepareCreateInnerClassFix(info, newClass, info.getElementUtilities().outermostTypeElement(source), EnumSet.of(Modifier.PRIVATE, Modifier.STATIC), simpleName, nct.getArguments(), null, ElementKind.CLASS, numTypeArguments));
+		    currentResult.addAll(prepareCreateOuterClassFix(info, newClass, source, EnumSet.noneOf(Modifier.class), simpleName, nct.getArguments(), type, ElementKind.CLASS, numTypeArguments));
+                    if (!baseType || outermostTypeElement != source)
+		        currentResult.addAll(prepareCreateInnerClassFix(info, newClass, outermostTypeElement, EnumSet.of(outermostTypeElement != null && outermostTypeElement.getKind().isInterface() ? Modifier.PUBLIC : Modifier.PRIVATE, Modifier.STATIC), simpleName, nct.getArguments(), type, ElementKind.CLASS, numTypeArguments));
 		    
                     return currentResult;
                 }
@@ -313,44 +342,38 @@ public final class CreateElement implements ErrorRule<Void> {
         }
 
         //field like or class (type):
-        Set<ElementKind> fixTypes = EnumSet.noneOf(ElementKind.class);
-        TypeMirror[] superType = new TypeMirror[1];
-        int[] numTypeParameters = new int[1];
-        List<? extends TypeMirror> types = resolveType(fixTypes, info, parent, errorPath.getLeaf(), offset, superType, numTypeParameters);
-        ElementKind classType = getClassType(fixTypes);
-
         if (classType != null) {
             if (wasMemberSelect) {
-                result.addAll(prepareCreateInnerClassFix(info, null, target, modifiers, simpleName, null, superType[0], classType, numTypeParameters[0]));
+                 result.addAll(prepareCreateInnerClassFix(info, null, (TypeElement) target, modifiers, simpleName, null, superType[0], classType, numTypeParameters[0]));
             } else {
                 result.addAll(prepareCreateOuterClassFix(info, null, source, EnumSet.noneOf(Modifier.class), simpleName, null, superType[0], classType, numTypeParameters[0]));
-                result.addAll(prepareCreateInnerClassFix(info, null, info.getElementUtilities().outermostTypeElement(source), EnumSet.of(Modifier.PRIVATE, Modifier.STATIC), simpleName, null, superType[0], classType, numTypeParameters[0]));
+                if (!baseType || outermostTypeElement != source)
+                    result.addAll(prepareCreateInnerClassFix(info, null, outermostTypeElement, EnumSet.of(outermostTypeElement != null && outermostTypeElement.getKind().isInterface() ? Modifier.PUBLIC : Modifier.PRIVATE, Modifier.STATIC), simpleName, null, superType[0], classType, numTypeParameters[0]));
             }
         }
 
-        if (types == null || types.isEmpty()) {
+        if (type == null || type.getKind() == TypeKind.VOID || type.getKind() == TypeKind.OTHER || type.getKind() == TypeKind.EXECUTABLE) {
             return result;
         }
 
-        //XXX: should reasonably consider all the found type candidates, not only the one:
-        TypeMirror type = types.get(0);
-
-        if (type == null || type.getKind() == TypeKind.VOID || type.getKind() == TypeKind.EXECUTABLE) {
+        //currently, we cannot handle error types:
+        if (Utilities.containsErrorsRecursively(type)) {
             return result;
         }
 
-        //currently, we cannot handle error types, TYPEVARs and WILDCARDs:
-        if (Utilities.containsErrorsOrTypevarsRecursively(type)) {
-            return result;
+        Collection<TypeVariable> typeVars = Utilities.containedTypevarsRecursively(type);
+
+        if (!Utilities.allTypeVarsAccessible(typeVars, target)) {
+            fixTypes.remove(ElementKind.FIELD);
         }
 
-        if (fixTypes.contains(ElementKind.FIELD) && isTargetWritable(target, info)) { //IZ 111048 -- don't offer anything if target file isn't writable
+        if (fixTypes.contains(ElementKind.FIELD) && isTargetWritable((TypeElement) target, info)) { //IZ 111048 -- don't offer anything if target file isn't writable
             Element enclosingElement = e.getEnclosingElement();
             if (enclosingElement != null && enclosingElement.getKind() == ElementKind.ANNOTATION_TYPE) {
 //                FileObject targetFile = SourceUtils.getFile(target, info.getClasspathInfo());
                 FileObject targetFile = SourceUtils.getFile(ElementHandle.create(target), info.getClasspathInfo());
                 if (targetFile != null) {
-                    result.add(new CreateMethodFix(info, simpleName, modifiers, target, type, types, Collections.<String>emptyList(), targetFile));
+                    result.add(new CreateMethodFix(info, simpleName, modifiers, (TypeElement) target, type, types, Collections.<String>emptyList(), targetFile));
                 }
 
                 return result;
@@ -359,36 +382,34 @@ public final class CreateElement implements ErrorRule<Void> {
                 if (targetFile != null) {
                     if (target.getKind() == ElementKind.ENUM) {
                         if (source.equals(target)) {
-                            result.add(new CreateFieldFix(info, simpleName, modifiers, target, type, targetFile));
+                            result.add(new CreateFieldFix(info, simpleName, modifiers, (TypeElement) target, type, targetFile));
                         } else {
-                            result.add(new CreateEnumConstant(info, simpleName, modifiers, target, type, targetFile));
+                            result.add(new CreateEnumConstant(info, simpleName, modifiers, (TypeElement) target, type, targetFile));
                         }
                     } else {
                         if (firstMethod != null && info.getTrees().getElement(firstMethod).getKind() == ElementKind.CONSTRUCTOR && ErrorFixesFakeHint.isCreateFinalFieldsForCtor()) {
                             modifiers.add(Modifier.FINAL);
                         }
                         if (ErrorFixesFakeHint.enabled(ErrorFixesFakeHint.FixKind.CREATE_FINAL_FIELD_CTOR)) {
-                            result.add(new CreateFieldFix(info, simpleName, modifiers, target, type, targetFile));
+                            result.add(new CreateFieldFix(info, simpleName, modifiers, (TypeElement) target, type, targetFile));
                         }
                     }
                 }
             }
         }
 
-        if (!wasMemberSelect && (fixTypes.contains(ElementKind.LOCAL_VARIABLE) || types.contains(ElementKind.PARAMETER))) {
+        if (!wasMemberSelect && (fixTypes.contains(ElementKind.LOCAL_VARIABLE) || fixTypes.contains(ElementKind.PARAMETER))) {
             ExecutableElement ee = null;
 
             if (firstMethod != null) {
                 ee = (ExecutableElement) info.getTrees().getElement(firstMethod);
             }
 
-            if ((ee != null) && type != null) {
-                int identifierPos = (int) info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), errorPath.getLeaf());
-                if (ee != null && fixTypes.contains(ElementKind.PARAMETER) && !Utilities.isMethodHeaderInsideGuardedBlock(info, (MethodTree) firstMethod.getLeaf()))
-                    result.add(new AddParameterOrLocalFix(info, type, simpleName, true, identifierPos));
-                if (fixTypes.contains(ElementKind.LOCAL_VARIABLE) && ErrorFixesFakeHint.enabled(ErrorFixesFakeHint.FixKind.CREATE_LOCAL_VARIABLE))
-                    result.add(new AddParameterOrLocalFix(info, type, simpleName, false, identifierPos));
-            }
+            int identifierPos = (int) info.getTrees().getSourcePositions().getStartPosition(info.getCompilationUnit(), errorPath.getLeaf());
+            if (ee != null && fixTypes.contains(ElementKind.PARAMETER) && !Utilities.isMethodHeaderInsideGuardedBlock(info, (MethodTree) firstMethod.getLeaf()))
+                result.add(new AddParameterOrLocalFix(info, type, simpleName, true, identifierPos));
+            if ((firstMethod != null || firstInitializer != null) && fixTypes.contains(ElementKind.LOCAL_VARIABLE) && ErrorFixesFakeHint.enabled(ErrorFixesFakeHint.FixKind.CREATE_LOCAL_VARIABLE))
+                result.add(new AddParameterOrLocalFix(info, type, simpleName, false, identifierPos));
         }
 
         return result;
@@ -396,14 +417,20 @@ public final class CreateElement implements ErrorRule<Void> {
 
     private static List<Fix> prepareCreateMethodFix(CompilationInfo info, TreePath invocation, Set<Modifier> modifiers, TypeElement target, String simpleName, List<? extends ExpressionTree> arguments, List<? extends TypeMirror> returnTypes) {
         //create method:
-        Pair<List<? extends TypeMirror>, List<String>> formalArguments = Utilities.resolveArguments(info, invocation, arguments);
+        Pair<List<? extends TypeMirror>, List<String>> formalArguments = Utilities.resolveArguments(info, invocation, arguments, target);
 
         //return type:
         //XXX: should reasonably consider all the found type candidates, not only the one:
-        TypeMirror returnType = returnTypes != null ? returnTypes.get(0) : null;
+        TypeMirror returnType = returnTypes != null ? Utilities.resolveCapturedType(info, returnTypes.get(0)) : null;
 
         //currently, we cannot handle error types, TYPEVARs and WILDCARDs:
-        if (formalArguments == null || returnType != null && Utilities.containsErrorsOrTypevarsRecursively(returnType)) {
+        if (formalArguments == null || returnType != null && Utilities.containsErrorsRecursively(returnType)) {
+            return Collections.<Fix>emptyList();
+        }
+
+        Collection<TypeVariable> typeVars = Utilities.containedTypevarsRecursively(returnType);
+
+        if (!Utilities.allTypeVarsAccessible(typeVars, target)) {
             return Collections.<Fix>emptyList();
         }
 
@@ -418,8 +445,8 @@ public final class CreateElement implements ErrorRule<Void> {
         return Collections.<Fix>singletonList(new CreateMethodFix(info, simpleName, modifiers, target, returnType, formalArguments.getA(), formalArguments.getB(), targetFile));
     }
 
-    private static List<Fix> prepareCreateOuterClassFix(CompilationInfo info, TreePath invocation, TypeElement source, Set<Modifier> modifiers, String simpleName, List<? extends ExpressionTree> realArguments, TypeMirror superType, ElementKind kind, int numTypeParameters) {
-        Pair<List<? extends TypeMirror>, List<String>> formalArguments = invocation != null ? Utilities.resolveArguments(info, invocation, realArguments) : new Pair<List<? extends TypeMirror>, List<String>>(null, null);
+    private static List<Fix> prepareCreateOuterClassFix(CompilationInfo info, TreePath invocation, Element source, Set<Modifier> modifiers, String simpleName, List<? extends ExpressionTree> realArguments, TypeMirror superType, ElementKind kind, int numTypeParameters) {
+        Pair<List<? extends TypeMirror>, List<String>> formalArguments = invocation != null ? Utilities.resolveArguments(info, invocation, realArguments, null) : new Pair<List<? extends TypeMirror>, List<String>>(null, null);
 
         if (formalArguments == null) {
             return Collections.<Fix>emptyList();
@@ -432,14 +459,13 @@ public final class CreateElement implements ErrorRule<Void> {
             return Collections.<Fix>emptyList();
         }
 
-        TypeElement outer = info.getElementUtilities().outermostTypeElement(source);
-        PackageElement packageElement = (PackageElement) outer.getEnclosingElement();
+        PackageElement packageElement = (PackageElement) (source instanceof PackageElement ? source : info.getElementUtilities().outermostTypeElement(source).getEnclosingElement());
 
         return Collections.<Fix>singletonList(new CreateOuterClassFix(info, root, packageElement.getQualifiedName().toString(), simpleName, modifiers, formalArguments.getA(), formalArguments.getB(), superType, kind, numTypeParameters));
     }
 
     private static List<Fix> prepareCreateInnerClassFix(CompilationInfo info, TreePath invocation, TypeElement target, Set<Modifier> modifiers, String simpleName, List<? extends ExpressionTree> realArguments, TypeMirror superType, ElementKind kind, int numTypeParameters) {
-        Pair<List<? extends TypeMirror>, List<String>> formalArguments = invocation != null ? Utilities.resolveArguments(info, invocation, realArguments) : new Pair<List<? extends TypeMirror>, List<String>>(null, null);
+        Pair<List<? extends TypeMirror>, List<String>> formalArguments = invocation != null ? Utilities.resolveArguments(info, invocation, realArguments, target) : new Pair<List<? extends TypeMirror>, List<String>>(null, null);
 
         if (formalArguments == null) {
             return Collections.<Fix>emptyList();
@@ -495,7 +521,8 @@ public final class CreateElement implements ErrorRule<Void> {
      * @return true if target's file is writable
      */
     private static boolean isTargetWritable(TypeElement target, CompilationInfo info) {
-	FileObject fo = SourceUtils.getFile(ElementHandle.create(target.getEnclosingElement()), info.getClasspathInfo());
+        TypeElement outermostType = info.getElementUtilities().outermostTypeElement(target);
+        FileObject fo = SourceUtils.getFile(ElementHandle.create(outermostType), info.getClasspathInfo());
 	if(fo != null && fo.canWrite())
 	    return true;
 	else
@@ -508,14 +535,21 @@ public final class CreateElement implements ErrorRule<Void> {
             return EnumSet.of(Modifier.PUBLIC);
         }
 
-        TypeElement outterMostSource = info.getElementUtilities().outermostTypeElement(source);
+        TypeElement outterMostSource = source != null ? info.getElementUtilities().outermostTypeElement(source) : null;
         TypeElement outterMostTarget = info.getElementUtilities().outermostTypeElement(target);
 
-        if (outterMostSource.equals(outterMostTarget)) {
+        if (outterMostTarget.equals(outterMostSource)) {
             return EnumSet.of(Modifier.PRIVATE);
         }
 
-        Element sourcePackage = outterMostSource.getEnclosingElement();
+        Element sourcePackage;
+
+        if (outterMostSource != null) {
+            sourcePackage = outterMostSource.getEnclosingElement();
+        } else {
+            sourcePackage = info.getTrees().getElement(new TreePath(new TreePath(info.getCompilationUnit()), info.getCompilationUnit().getPackageName()));
+        }
+
         Element targetPackage = outterMostTarget.getEnclosingElement();
 
         if (sourcePackage.equals(targetPackage)) {
