@@ -43,6 +43,7 @@
  */
 package org.netbeans.modules.java.hints.errors;
 
+import com.sun.source.tree.ImportTree;
 import com.sun.source.tree.ArrayAccessTree;
 import com.sun.source.tree.AssertTree;
 import com.sun.source.tree.AssignmentTree;
@@ -93,6 +94,7 @@ import javax.lang.model.type.TypeMirror;
 import javax.lang.model.type.TypeVariable;
 import javax.swing.text.Document;
 import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.modules.java.editor.semantic.Utilities;
 import org.netbeans.modules.java.hints.infrastructure.ErrorHintsProvider;
 import org.openide.ErrorManager;
@@ -103,9 +105,9 @@ import static org.netbeans.modules.java.hints.errors.Utilities.getIterableGeneri
  * @author Jan Lahoda
  */
 public final class CreateElementUtilities {
-    
+
     private CreateElementUtilities() {}
-    
+
     public static List<? extends TypeMirror> resolveType(Set<ElementKind> types, CompilationInfo info, TreePath currentPath, Tree unresolved, int offset, TypeMirror[] typeParameterBound, int[] numTypeParameters) {
         switch (currentPath.getLeaf().getKind()) {
             case METHOD:
@@ -150,7 +152,10 @@ public final class CreateElementUtilities {
                 return computeTypeParameter(types, info, currentPath, unresolved, offset);
             case PARAMETERIZED_TYPE:
                 return computeParametrizedType(types, info, currentPath, unresolved, offset, typeParameterBound, numTypeParameters);
+            case ANNOTATION_TYPE:
             case CLASS:
+            case ENUM:
+            case INTERFACE:
                 return computeClass(types, info, currentPath, unresolved, offset);
                 
             case CONDITIONAL_EXPRESSION:
@@ -212,13 +217,15 @@ public final class CreateElementUtilities {
                         
             case ARRAY_TYPE:
                 return computeArrayType(types, info, currentPath, unresolved, offset);
+
+            case IMPORT:
+                return computeImport(types, info, currentPath, unresolved, offset);
                 
             case BLOCK:
             case BREAK:
             case CATCH:
             case COMPILATION_UNIT:
             case CONTINUE:
-            case IMPORT:
             case IDENTIFIER:
             case TYPE_CAST:
             case TRY:
@@ -565,6 +572,21 @@ public final class CreateElementUtilities {
         return null;
     }
     
+    private static List<? extends TypeMirror> computeImport(Set<ElementKind> types, CompilationInfo info, TreePath parent, Tree error, int offset) {
+        ImportTree tree = (ImportTree) parent.getLeaf();
+
+        if (tree.getQualifiedIdentifier() == error) {
+            types.add(ElementKind.ANNOTATION_TYPE);
+            types.add(ElementKind.CLASS);
+            types.add(ElementKind.ENUM);
+            types.add(ElementKind.INTERFACE);
+            
+            return Collections.singletonList(info.getElements().getTypeElement("java.lang.Object").asType());
+        }
+
+        return null;
+    }
+
     private static List<? extends TypeMirror> computeUnary(Set<ElementKind> types, CompilationInfo info, TreePath parent, Tree error, int offset) {
         UnaryTree tree = (UnaryTree) parent.getLeaf();
         
@@ -634,8 +656,15 @@ public final class CreateElementUtilities {
         ParameterizedTypeTree ptt = (ParameterizedTypeTree) parent.getLeaf();
         
         if (ptt.getType() == error) {
-            types.add(ElementKind.CLASS);
-            types.add(ElementKind.INTERFACE);
+            Tree gpt = parent.getParentPath().getLeaf();
+            if (TreeUtilities.CLASS_TREE_KINDS.contains(gpt.getKind()) && ((ClassTree)gpt).getExtendsClause() == ptt) {
+                types.add(ElementKind.CLASS);
+            } else if (TreeUtilities.CLASS_TREE_KINDS.contains(gpt.getKind()) && ((ClassTree)gpt).getImplementsClause().contains(ptt)) {
+                types.add(ElementKind.INTERFACE);
+            } else {
+                types.add(ElementKind.CLASS);
+                types.add(ElementKind.INTERFACE);
+            }
             
             if (numTypeParameters != null) {
                 numTypeParameters[0] = ptt.getTypeArguments().size();
@@ -781,6 +810,16 @@ public final class CreateElementUtilities {
             
             return Collections.singletonList(proposedType[0]);
         }
+
+        Tree id = nct.getIdentifier();
+
+        if (id.getKind() == Kind.PARAMETERIZED_TYPE) {
+            id = ((ParameterizedTypeTree) id).getType();
+        }
+
+        if (id == error) {
+            return resolveType(EnumSet.noneOf(ElementKind.class), info, parent.getParentPath(), nct, offset, null, null);
+        }
         
         return null;
     }
@@ -791,7 +830,7 @@ public final class CreateElementUtilities {
         return Collections.singletonList(info.getElements().getTypeElement("java.lang.Object").asType());
     }
     
-    private static final Set<Kind> STOP_LOOKING_FOR_METHOD = EnumSet.of(Kind.METHOD, Kind.CLASS, Kind.COMPILATION_UNIT);
+    private static final Set<Kind> STOP_LOOKING_FOR_METHOD = EnumSet.of(Kind.METHOD, Kind.ANNOTATION_TYPE, Kind.CLASS, Kind.ENUM, Kind.INTERFACE, Kind.COMPILATION_UNIT);
             
     private static TreePath findMethod(TreePath tp) {
         while (!STOP_LOOKING_FOR_METHOD.contains(tp.getLeaf().getKind())) {
