@@ -53,6 +53,7 @@ import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.Scope;
 import com.sun.source.tree.StatementTree;
+import com.sun.source.tree.ThrowTree;
 import com.sun.source.tree.Tree;
 import com.sun.source.tree.Tree.Kind;
 import com.sun.source.tree.TryTree;
@@ -84,7 +85,9 @@ import org.netbeans.api.java.source.ElementUtilities.ElementAcceptor;
 import org.netbeans.api.java.source.GeneratorUtilities;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
+import org.netbeans.api.java.source.ModificationResult;
 import org.netbeans.api.java.source.TreeMaker;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.TypeMirrorHandle;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.modules.java.editor.codegen.GeneratorUtils;
@@ -98,7 +101,7 @@ import org.openide.util.NbBundle;
  * @author Jan Lahoda
  */
 final class MagicSurroundWithTryCatchFix implements Fix {
-    
+
     private JavaSource js;
     private List<TypeMirrorHandle> thandles;
     private int offset;
@@ -136,7 +139,7 @@ final class MagicSurroundWithTryCatchFix implements Fix {
     }
 
     public ChangeInfo implement() throws IOException {
-        js.runModificationTask(new Task<WorkingCopy>() {
+        ModificationResult mr = js.runModificationTask(new Task<WorkingCopy>() {
             public void run(WorkingCopy wc) throws Exception {
                 wc.toPhase(Phase.RESOLVED);
                 TreePath currentPath = wc.getTreeUtilities().pathFor(offset + 1);
@@ -161,7 +164,7 @@ final class MagicSurroundWithTryCatchFix implements Fix {
 
                 while (catchTree != null
                         && catchTree.getLeaf().getKind() != Kind.TRY
-                        && catchTree.getLeaf().getKind() != Kind.CLASS
+                        && !TreeUtilities.CLASS_TREE_KINDS.contains(catchTree.getLeaf().getKind())
                         && catchTree.getLeaf().getKind() != Kind.CATCH)
                     catchTree = catchTree.getParentPath();
 
@@ -199,9 +202,9 @@ final class MagicSurroundWithTryCatchFix implements Fix {
                     new TransformerImpl(wc, thandles, streamAlike, statement).scan(blockTree, null);
                 }
             }
-        }).commit();
+        });
         
-        return null;
+        return Utilities.commitAndComputeChangeInfo(js.getFileObjects().iterator().next(), mr);
     }
     
     private final class TransformerImpl extends TreePathScanner<Void, Void> {
@@ -226,7 +229,7 @@ final class MagicSurroundWithTryCatchFix implements Fix {
             catches.addAll(tt.getCatches());
             
             if (!streamAlike) {
-                info.rewrite(tt, make.Try(tt.getBlock(), catches, tt.getFinallyBlock()));
+                info.rewrite(tt, make.Try(tt.getResources(), tt.getBlock(), catches, tt.getFinallyBlock()));
             } else {
                 VariableTree originalDeclaration = (VariableTree) statement.getLeaf();
                 VariableTree declaration = make.Variable(make.Modifiers(EnumSet.noneOf(Modifier.class)), originalDeclaration.getName(), originalDeclaration.getType(), make.Literal(null));
@@ -239,7 +242,7 @@ final class MagicSurroundWithTryCatchFix implements Fix {
                 
                 info.rewrite(originalDeclaration, assignment);
                 
-                TryTree nueTry = make.Try(tt.getBlock(), catches, finallyTree);
+                TryTree nueTry = make.Try(tt.getResources(), tt.getBlock(), catches, finallyTree);
                 
                 TreePath currentBlockCandidate = statement;
                 
@@ -410,7 +413,7 @@ final class MagicSurroundWithTryCatchFix implements Fix {
         // find the containing top level class
         ClassTree containingTopLevel = null;
         for (Tree t : statement) {
-            if (Kind.CLASS == t.getKind()) {
+            if (TreeUtilities.CLASS_TREE_KINDS.contains(t.getKind())) {
                 containingTopLevel = (ClassTree) t;
             }
         }
@@ -437,17 +440,56 @@ final class MagicSurroundWithTryCatchFix implements Fix {
         return make.ExpressionStatement(make.MethodInvocation(Collections.<ExpressionTree>emptyList(), make.MemberSelect(etExpression, "log"), Arrays.asList(levelExpression, make.Literal(null), make.Identifier(name))));
     }
         
+    private static StatementTree createRethrowAsRuntimeExceptionStatement(WorkingCopy info, TreeMaker make, String name) {
+        if (!ErrorFixesFakeHint.isRethrowAsRuntimeException()) {
+            return null;
+        }
+
+        TypeElement runtimeException = info.getElements().getTypeElement("java.lang.RuntimeException");
+
+        if (runtimeException == null) {
+            return null;
+        }
+
+        ExpressionTree exceptionName = make.QualIdent(runtimeException);
+        StatementTree result = make.Throw(make.NewClass(null, Collections.<ExpressionTree>emptyList(), exceptionName, Arrays.asList(make.Identifier(name)), null));
+
+        info.tag(exceptionName, Utilities.TAG_SELECT);
+        
+        return result;
+    }
+
+    private static StatementTree createRethrow(WorkingCopy info, TreeMaker make, String name) {
+        if (!ErrorFixesFakeHint.isRethrow()) {
+            return null;
+        }
+
+        ThrowTree result = make.Throw(make.Identifier(name));
+
+        info.tag(result.getExpression(), Utilities.TAG_SELECT);
+
+        return result;
+    }
+
     private static StatementTree createPrintStackTraceStatement(CompilationInfo info, TreeMaker make, String name) {
         return make.ExpressionStatement(make.MethodInvocation(Collections.<ExpressionTree>emptyList(), make.MemberSelect(make.Identifier(name), "printStackTrace"), Collections.<ExpressionTree>emptyList()));
     }
 
-    private static CatchTree createCatch(CompilationInfo info, TreeMaker make, TreePath statement, String name, TypeMirror type) {
+    private static CatchTree createCatch(WorkingCopy info, TreeMaker make, TreePath statement, String name, TypeMirror type) {
         StatementTree logStatement = createExceptionsStatement(info, make, name);
 
         if (logStatement == null) {
             logStatement = createLogStatement(info, make, statement, name);
         }
         
+        if (logStatement == null) {
+            logStatement = createRethrowAsRuntimeExceptionStatement(info, make, name);
+        }
+        
+        if (logStatement == null) {
+            logStatement = createRethrow(info, make, name);
+        }
+
         if (logStatement == null) {
             logStatement = createPrintStackTraceStatement(info, make, name);
         }
@@ -455,7 +497,7 @@ final class MagicSurroundWithTryCatchFix implements Fix {
         return make.Catch(make.Variable(make.Modifiers(EnumSet.noneOf(Modifier.class)), name, make.Type(type), null), make.Block(Collections.singletonList(logStatement), false));
     }
 
-    static List<CatchTree> createCatches(CompilationInfo info, TreeMaker make, List<TypeMirrorHandle> thandles, TreePath currentPath) {
+    static List<CatchTree> createCatches(WorkingCopy info, TreeMaker make, List<TypeMirrorHandle> thandles, TreePath currentPath) {
         String name = inferName(info, currentPath);
         List<CatchTree> catches = new ArrayList<CatchTree>();
 
