@@ -27,7 +27,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2010 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -75,7 +75,7 @@ import org.openide.util.NbBundle;
  * @author Jan Lahoda
  */
 public class MakeVariableFinal implements ErrorRule<Void> {
-    
+
     public MakeVariableFinal() {
     }
     
@@ -89,7 +89,7 @@ public class MakeVariableFinal implements ErrorRule<Void> {
 
     public List<Fix> run(CompilationInfo compilationInfo, String diagnosticKey, int offset, TreePath treePath, Data<Void> data) {
         Tree leaf = treePath.getLeaf();
-        
+
         if (leaf.getKind() == Kind.IDENTIFIER) {
             Element el = compilationInfo.getTrees().getElement(treePath);
             TreePath declaration = compilationInfo.getTrees().getPath(el);
@@ -158,5 +158,17 @@ public class MakeVariableFinal implements ErrorRule<Void> {
             
             return null;
         }
+
+        @Override
+        public int hashCode() {
+            return variable.hashCode();
+        }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (!(obj instanceof FixImpl)) return false;
+            return variable.equals(((FixImpl) obj).variable);
+        }
+        
     }
 }
