@@ -82,6 +82,7 @@ import org.netbeans.api.java.source.ElementHandle;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.java.source.TreePathHandle;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.TypeMirrorHandle;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.modules.editor.java.Utilities;
@@ -278,7 +279,7 @@ public final class UncaughtException implements ErrorRule<Void> {
                         }
                         
                         if (tm.getKind() != TypeKind.ERROR) {
-                            result.add(new AddThrowsClauseHintImpl(info.getJavaSource(), Utilities.getTypeName(tm, true).toString(), TypeMirrorHandle.create(tm), ElementHandle.create(method)));
+                            result.add(new AddThrowsClauseHintImpl(info.getJavaSource(), Utilities.getTypeName(info, tm, true).toString(), TypeMirrorHandle.create(tm), ElementHandle.create(method)));
                         }
                     }
                 }
@@ -291,7 +292,7 @@ public final class UncaughtException implements ErrorRule<Void> {
                 for (TypeMirror tm : uncaught) {
                     if (tm.getKind() != TypeKind.ERROR) {
                         thandles.add(TypeMirrorHandle.create(tm));
-                        fqns.add(Utilities.getTypeName(tm, true).toString());
+                        fqns.add(Utilities.getTypeName(info, tm, true).toString());
                     }
                 }
                 
@@ -325,7 +326,7 @@ public final class UncaughtException implements ErrorRule<Void> {
      */ 
     private boolean isThisParameter(TreePath path) {
 	//anonymous class must not be on the path to top
-	while(path.getLeaf().getKind() != Kind.CLASS && path.getLeaf().getKind() != Kind.COMPILATION_UNIT) {
+	while(!TreeUtilities.CLASS_TREE_KINDS.contains(path.getLeaf().getKind()) && path.getLeaf().getKind() != Kind.COMPILATION_UNIT) {
 	    if (path.getParentPath().getLeaf().getKind() == Kind.METHOD_INVOCATION) {
 		MethodInvocationTree mi = (MethodInvocationTree) path.getParentPath().getLeaf();
 		if(mi.getMethodSelect().getKind() == Kind.IDENTIFIER) {
@@ -342,7 +343,7 @@ public final class UncaughtException implements ErrorRule<Void> {
     private static boolean isInsideMethodOrInitializer(TreePath tp) {
         while (tp != null) {
             if (tp.getLeaf().getKind() == Kind.METHOD || 
-                    (tp.getLeaf().getKind() == Kind.BLOCK && tp.getParentPath().getLeaf().getKind() == Kind.CLASS))
+                    (tp.getLeaf().getKind() == Kind.BLOCK && TreeUtilities.CLASS_TREE_KINDS.contains(tp.getParentPath().getLeaf().getKind())))
                 return true;
             
             tp = tp.getParentPath();
