@@ -43,13 +43,29 @@
  */
 package org.netbeans.modules.java.hints.errors;
 
-import java.util.HashSet;
+import java.util.logging.Level;
+import java.io.CharConversionException;
+import org.openide.xml.XMLUtil;
+import java.util.logging.Logger;
+import javax.lang.model.element.Name;
+import com.sun.source.tree.ThrowTree;
+import java.util.Stack;
+import com.sun.source.tree.BreakTree;
+import com.sun.source.tree.ContinueTree;
+import com.sun.source.tree.IfTree;
+import com.sun.source.tree.ReturnTree;
+import com.sun.source.tree.TryTree;
+import com.sun.source.util.TreePathScanner;
+import org.netbeans.api.java.source.TreeUtilities;
+import org.openide.filesystems.FileUtil;
+import org.openide.util.NbBundle;
 import org.netbeans.modules.java.hints.infrastructure.Pair;
 import com.sun.source.tree.ArrayAccessTree;
 import com.sun.source.tree.ArrayTypeTree;
 import com.sun.source.tree.BinaryTree;
 import com.sun.source.tree.BlockTree;
 import com.sun.source.tree.CaseTree;
+import com.sun.source.tree.CatchTree;
 import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.IdentifierTree;
@@ -73,6 +89,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
@@ -81,18 +98,22 @@ import javax.lang.model.SourceVersion;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.element.Modifier;
 import javax.lang.model.element.TypeElement;
+import javax.lang.model.element.TypeParameterElement;
 import javax.lang.model.element.VariableElement;
 import javax.lang.model.type.ArrayType;
 import javax.lang.model.type.DeclaredType;
 import javax.lang.model.type.ExecutableType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
+import javax.lang.model.type.TypeVariable;
 import javax.lang.model.type.WildcardType;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Document;
 import javax.swing.text.Position;
 import org.netbeans.api.annotations.common.NonNull;
+import org.netbeans.api.annotations.common.NullAllowed;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.ElementUtilities.ElementAcceptor;
 import org.netbeans.api.java.source.GeneratorUtilities;
@@ -104,6 +125,8 @@ import org.netbeans.editor.GuardedDocument;
 import org.netbeans.editor.MarkBlock;
 import org.netbeans.modules.java.hints.jackpot.spi.HintContext;
 import org.netbeans.spi.editor.hints.ChangeInfo;
+import org.openide.DialogDisplayer;
+import org.openide.NotifyDescriptor;
 import org.openide.filesystems.FileObject;
 import org.openide.text.NbDocument;
 import org.openide.text.PositionRef;
@@ -123,6 +146,10 @@ public class Utilities {
     }
 
     public static String guessName(CompilationInfo info, TreePath tp) {
+        if (tp.getLeaf().getKind() == Kind.VARIABLE) {
+            return ((VariableTree) tp.getLeaf()).getName().toString();
+        }
+        
         ExpressionTree et = (ExpressionTree) tp.getLeaf();
         String name = getName(et);
         
@@ -224,6 +251,12 @@ public class Utilities {
             List<? extends TypeMirror> typeArguments = ((DeclaredType) iteratorMethodType.getReturnType()).getTypeArguments();
             if (!typeArguments.isEmpty()) {
                 designedType = typeArguments.get(0);
+            } else {
+                TypeElement jlObject = info.getElements().getTypeElement("java.lang.Object");
+
+                if (jlObject != null) {
+                    designedType = jlObject.asType();
+                }
             }
         } else if (iterableType.getKind() == TypeKind.ARRAY) {
             designedType = ((ArrayType) iterableType).getComponentType();
@@ -238,7 +271,7 @@ public class Utilities {
         if (tm.getKind().isPrimitive()) {
             return "" + Character.toLowerCase(tm.getKind().name().charAt(0));
         }
-        
+
         switch (tm.getKind()) {
             case DECLARED:
                 DeclaredType dt = (DeclaredType) tm;
@@ -326,6 +359,11 @@ public class Utilities {
         
     }
 
+    public static final String TAG_SELECT = "select";
+    public static ChangeInfo commitAndComputeChangeInfo(FileObject target, final ModificationResult diff) throws IOException {
+        return commitAndComputeChangeInfo(target, diff, TAG_SELECT);
+    }
+
     /**
      * Commits changes and provides selection bounds
      *
@@ -336,6 +374,13 @@ public class Utilities {
      * @throws java.io.IOException
      */
     public static ChangeInfo commitAndComputeChangeInfo(FileObject target, final ModificationResult diff, final Object tag) throws IOException {
+        if (!target.canWrite()) {
+            NotifyDescriptor nd = new NotifyDescriptor.Message(NbBundle.getMessage(Utilities.class, "ERR_ReadOnlyTargetFile", FileUtil.getFileDisplayName(target)), NotifyDescriptor.WARNING_MESSAGE);
+            DialogDisplayer.getDefault().notifyLater(nd);
+            
+            return null;
+        }
+        
         List<? extends Difference> differences = diff.getDifferences(target);
         ChangeInfo result = null;
         
@@ -358,10 +403,12 @@ public class Utilities {
                         doc.render(new Runnable() {
                             public void run() {
                                 try {
-                                    int[] span = diff.getSpan(tag);
-                                    if(span != null) {
-                                        pos[0] = fdoc.createPosition(span[0]);
-                                        pos[1] = fdoc.createPosition(span[1]);
+                                    if (tag != null) {
+                                        int[] span = diff.getSpan(tag);
+                                        if(span != null) {
+                                            pos[0] = fdoc.createPosition(span[0]);
+                                            pos[1] = fdoc.createPosition(span[1]);
+                                        }
                                     } else {
                                         pos[0] = NbDocument.createPosition(fdoc, start.getOffset(), Position.Bias.Backward);
                                         pos[1] = pos[0];
@@ -529,7 +576,7 @@ public class Utilities {
         List<TreePath> currentCluster = new LinkedList<TreePath>();
 
         for (TreePath t : trees) {
-            if (isConstantString(info, t)) {
+            if (isConstantString(info, t, true)) {
                 currentCluster.add(t);
             } else {
                 if (!currentCluster.isEmpty()) {
@@ -548,11 +595,17 @@ public class Utilities {
     }
 
     public static boolean isConstantString(CompilationInfo info, TreePath tp) {
+        return isConstantString(info, tp, false);
+    }
+
+    public static boolean isConstantString(CompilationInfo info, TreePath tp, boolean acceptsChars) {
         if (tp.getLeaf().getKind() == Kind.STRING_LITERAL) return true;
+        if (acceptsChars && tp.getLeaf().getKind() == Kind.CHAR_LITERAL) return true;
 
         Element el = info.getTrees().getElement(tp);
 
-        if (el != null && el.getKind() == ElementKind.FIELD && ((VariableElement) el).getConstantValue() instanceof String) {
+        if (el != null && (el.getKind() == ElementKind.FIELD || el.getKind() == ElementKind.LOCAL_VARIABLE)
+                && ((VariableElement) el).getConstantValue() instanceof String) {
             return true;
         }
 
@@ -568,13 +621,18 @@ public class Utilities {
 
         List<TreePath> part = sorted.get(0);
 
-        if (!part.isEmpty() && isConstantString(info, part.get(0))) {
-            return true;
+        for (TreePath c : part) {
+            if (isConstantString(info, c, acceptsChars))
+                return true;
         }
 
         return false;
     }
 
+    public static boolean isStringOrCharLiteral(Tree t) {
+        return t != null && (t.getKind() == Kind.STRING_LITERAL || t.getKind() == Kind.CHAR_LITERAL);
+    }
+
     public static @NonNull Collection<? extends TreePath> resolveFieldGroup(@NonNull CompilationInfo info, @NonNull TreePath variable) {
         Tree leaf = variable.getLeaf();
 
@@ -587,7 +645,11 @@ public class Utilities {
 
         switch (parentPath.getLeaf().getKind()) {
             case BLOCK: children = ((BlockTree) parentPath.getLeaf()).getStatements(); break;
-            case CLASS: children = ((ClassTree) parentPath.getLeaf()).getMembers(); break;
+            case ANNOTATION_TYPE:
+            case CLASS:
+            case ENUM:
+            case INTERFACE:
+                children = ((ClassTree) parentPath.getLeaf()).getMembers(); break;
             case CASE:  children = ((CaseTree) parentPath.getLeaf()).getStatements(); break;
             default:    children = Collections.singleton(leaf); break;
         }
@@ -731,7 +793,7 @@ public class Utilities {
     }
 
     public static TreePath findEnclosingMethodOrConstructor(HintContext ctx, TreePath from) {
-        while (from != null && from.getLeaf().getKind() != Kind.METHOD && from.getLeaf().getKind() != Kind.CLASS) {
+        while (from != null && from.getLeaf().getKind() != Kind.METHOD && !TreeUtilities.CLASS_TREE_KINDS.contains(from.getLeaf().getKind())) {
             from = from.getParentPath();
         }
 
@@ -750,7 +812,7 @@ public class Utilities {
                 enclosingMethodElement.getKind() == ElementKind.CONSTRUCTOR);
     }
 
-    public static Pair<List<? extends TypeMirror>, List<String>> resolveArguments(CompilationInfo info, TreePath invocation, List<? extends ExpressionTree> realArguments) {
+    public static Pair<List<? extends TypeMirror>, List<String>> resolveArguments(CompilationInfo info, TreePath invocation, List<? extends ExpressionTree> realArguments, Element target) {
         List<TypeMirror> argumentTypes = new LinkedList<TypeMirror>();
         List<String> argumentNames = new LinkedList<String>();
         Set<String>      usedArgumentNames = new HashSet<String>();
@@ -761,7 +823,13 @@ public class Utilities {
             //anonymous class?
             tm = Utilities.convertIfAnonymous(tm);
 
-            if (tm == null || containsErrorsOrTypevarsRecursively(tm)) {
+            if (tm == null || containsErrorsRecursively(tm)) {
+                return null;
+            }
+
+            Collection<TypeVariable> typeVars = Utilities.containedTypevarsRecursively(tm);
+
+            if (!allTypeVarsAccessible(typeVars, target)) {
                 return null;
             }
 
@@ -804,26 +872,261 @@ public class Utilities {
     //=>
     //ArrayList<Unknown> xxx;
     //xxx = new ArrayList<Unknown>();
-    public static boolean containsErrorsOrTypevarsRecursively(TypeMirror tm) {
+    public static boolean containsErrorsRecursively(TypeMirror tm) {
         switch (tm.getKind()) {
-            case WILDCARD:
-            case TYPEVAR:
             case ERROR:
                 return true;
             case DECLARED:
                 DeclaredType type = (DeclaredType) tm;
 
                 for (TypeMirror t : type.getTypeArguments()) {
-                    if (containsErrorsOrTypevarsRecursively(t))
+                    if (containsErrorsRecursively(t))
                         return true;
                 }
 
                 return false;
             case ARRAY:
-                return containsErrorsOrTypevarsRecursively(((ArrayType) tm).getComponentType());
+                return containsErrorsRecursively(((ArrayType) tm).getComponentType());
+            case WILDCARD:
+                if (((WildcardType) tm).getExtendsBound() != null && containsErrorsRecursively(((WildcardType) tm).getExtendsBound())) {
+                    return true;
+                }
+                if (((WildcardType) tm).getSuperBound() != null && containsErrorsRecursively(((WildcardType) tm).getSuperBound())) {
+                    return true;
+                }
+                return false;
             default:
                 return false;
         }
     }
 
+    public static boolean exitsFromAllBranchers(CompilationInfo info, TreePath from) {
+        ExitsFromAllBranches efab = new ExitsFromAllBranches(info);
+
+        return efab.scan(from, null) == Boolean.TRUE;
+    }
+
+    private static final class ExitsFromAllBranches extends TreePathScanner<Boolean, Void> {
+
+        private CompilationInfo info;
+        private final Set<Tree> seenTrees = new HashSet<Tree>();
+        private final Stack<Set<TypeMirror>> caughtExceptions = new Stack<Set<TypeMirror>>();
+
+        public ExitsFromAllBranches(CompilationInfo info) {
+            this.info = info;
+        }
+
+        @Override
+        public Boolean scan(Tree tree, Void p) {
+            seenTrees.add(tree);
+            return super.scan(tree, p);
+        }
+
+        @Override
+        public Boolean visitIf(IfTree node, Void p) {
+            return scan(node.getThenStatement(), null) == Boolean.TRUE && scan(node.getElseStatement(), null) == Boolean.TRUE;
+        }
+
+        @Override
+        public Boolean visitReturn(ReturnTree node, Void p) {
+            return true;
+        }
+
+        @Override
+        public Boolean visitBreak(BreakTree node, Void p) {
+            return !seenTrees.contains(info.getTreeUtilities().getBreakContinueTarget(getCurrentPath()));
+        }
+
+        @Override
+        public Boolean visitContinue(ContinueTree node, Void p) {
+            return !seenTrees.contains(info.getTreeUtilities().getBreakContinueTarget(getCurrentPath()));
+        }
+
+        @Override
+        public Boolean visitClass(ClassTree node, Void p) {
+            return false;
+        }
+
+        @Override
+        public Boolean visitTry(TryTree node, Void p) {
+            Set<TypeMirror> caught = new HashSet<TypeMirror>();
+
+            for (CatchTree ct : node.getCatches()) {
+                TypeMirror t = info.getTrees().getTypeMirror(new TreePath(new TreePath(getCurrentPath(), ct), ct.getParameter()));
+
+                if (t != null) {
+                    caught.add(t);
+                }
+            }
+
+            caughtExceptions.push(caught);
+            
+            try {
+                return scan(node.getBlock(), p) == Boolean.TRUE || scan(node.getFinallyBlock(), p) == Boolean.TRUE;
+            } finally {
+                caughtExceptions.pop();
+            }
+        }
+
+        @Override
+        public Boolean visitThrow(ThrowTree node, Void p) {
+            TypeMirror type = info.getTrees().getTypeMirror(new TreePath(getCurrentPath(), node.getExpression()));
+            boolean isCaught = false;
+
+            OUTER: for (Set<TypeMirror> caught : caughtExceptions) {
+                for (TypeMirror c : caught) {
+                    if (info.getTypes().isSubtype(type, c)) {
+                        isCaught = true;
+                        break OUTER;
+                    }
+                }
+            }
+
+            return super.visitThrow(node, p) == Boolean.TRUE || !isCaught;
+        }
+
+    }
+
+    public static @NonNull Collection<TypeVariable> containedTypevarsRecursively(@NullAllowed TypeMirror tm) {
+        if (tm == null) {
+            return Collections.emptyList();
+        }
+
+        Collection<TypeVariable> typeVars = new LinkedList<TypeVariable>();
+
+        containedTypevarsRecursively(tm, typeVars);
+
+        return typeVars;
+    }
+
+    private static void containedTypevarsRecursively(@NonNull TypeMirror tm, @NonNull Collection<TypeVariable> typeVars) {
+        switch (tm.getKind()) {
+            case TYPEVAR:
+                typeVars.add((TypeVariable) tm);
+                break;
+            case DECLARED:
+                DeclaredType type = (DeclaredType) tm;
+                for (TypeMirror t : type.getTypeArguments()) {
+                    containedTypevarsRecursively(t, typeVars);
+                }
+
+                break;
+            case ARRAY:
+                containedTypevarsRecursively(((ArrayType) tm).getComponentType(), typeVars);
+                break;
+            case WILDCARD:
+                if (((WildcardType) tm).getExtendsBound() != null) {
+                    containedTypevarsRecursively(((WildcardType) tm).getExtendsBound(), typeVars);
+                }
+                if (((WildcardType) tm).getSuperBound() != null) {
+                    containedTypevarsRecursively(((WildcardType) tm).getSuperBound(), typeVars);
+                }
+                break;
+        }
+    }
+
+    public static boolean allTypeVarsAccessible(Collection<TypeVariable> typeVars, Element target) {
+        if (target == null) {
+            return typeVars.isEmpty();
+        }
+        
+        Set<TypeVariable> targetTypeVars = new HashSet<TypeVariable>();
+
+        OUTER: while (target.getKind() != ElementKind.PACKAGE) {
+            Iterable<? extends TypeParameterElement> tpes;
+
+            switch (target.getKind()) {
+                case ANNOTATION_TYPE:
+                case CLASS:
+                case ENUM:
+                case INTERFACE:
+                    tpes = ((TypeElement) target).getTypeParameters();
+                    break;
+                case METHOD:
+                case CONSTRUCTOR:
+                    tpes = ((ExecutableElement) target).getTypeParameters();
+                    break;
+                default:
+                    break OUTER;
+            }
+
+            for (TypeParameterElement tpe : tpes) {
+                targetTypeVars.add((TypeVariable) tpe.asType());
+            }
+
+            if (target.getModifiers().contains(Modifier.STATIC)) {
+                break;
+            }
+
+            target = target.getEnclosingElement();
+        }
+
+        return targetTypeVars.containsAll(typeVars);
+    }
+
+    public static String target2String(TypeElement target) {
+        final Name qualifiedName = target.getQualifiedName(); //#130759
+        if (qualifiedName == null) {
+            Logger.getLogger(Utilities.class.getName()).warning("Target qualified name could not be resolved."); //NOI18N
+            return ""; //NOI18N
+        } else {
+            String qnString = qualifiedName.toString();
+            if (qnString.length() == 0) {
+                //probably an anonymous class
+                qnString = target.asType().toString();
+            }
+
+            try {
+                qnString = XMLUtil.toElementContent(qnString);
+            } catch (CharConversionException ex) {
+                Logger.getLogger(Utilities.class.getName()).log(Level.FINE, null, ex);
+            }
+
+            return qnString;
+        }
+    }
+
+    public static Visibility effectiveVisibility(TreePath tp) {
+        Visibility result = null;
+
+        while (tp != null) {
+            Visibility current = Visibility.forTree(tp.getLeaf());
+
+            if (current != null) {
+                if (result != null) result = result.enclosedBy(current);
+                else result = current;
+            }
+            
+            tp = tp.getParentPath();
+        }
+
+        return result;
+    }
+
+    public enum Visibility {
+        PRIVATE,
+        PACKAGE_PRIVATE,
+        PROTECTED,
+        PUBLIC;
+        public Visibility enclosedBy(Visibility encl) {
+            return Visibility.values()[Math.min(ordinal(), encl.ordinal())];
+        }
+        public static Visibility forModifiers(ModifiersTree mt) {
+            if (mt.getFlags().contains(Modifier.PUBLIC)) return PUBLIC;
+            if (mt.getFlags().contains(Modifier.PROTECTED)) return PROTECTED;
+            if (mt.getFlags().contains(Modifier.PRIVATE)) return PRIVATE;
+            return PACKAGE_PRIVATE;
+        }
+        public static Visibility forTree(Tree t) {
+            switch (t.getKind()) {
+                case ANNOTATION_TYPE:
+                case CLASS:
+                case ENUM:
+                case INTERFACE: return forModifiers(((ClassTree) t).getModifiers());
+                case VARIABLE: return forModifiers(((VariableTree) t).getModifiers());
+                case METHOD: return forModifiers(((MethodTree) t).getModifiers());
+                default: return null;
+            }
+        }
+    }
 }
