@@ -38,6 +38,7 @@ import com.sun.source.tree.BinaryTree;
 import com.sun.source.tree.BlockTree;
 import com.sun.source.tree.CaseTree;
 import com.sun.source.tree.CatchTree;
+import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.CompoundAssignmentTree;
 import com.sun.source.tree.ConditionalExpressionTree;
 import com.sun.source.tree.DoWhileLoopTree;
@@ -51,6 +52,7 @@ import com.sun.source.tree.InstanceOfTree;
 import com.sun.source.tree.LiteralTree;
 import com.sun.source.tree.MemberSelectTree;
 import com.sun.source.tree.MethodInvocationTree;
+import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.ModifiersTree;
 import com.sun.source.tree.NewArrayTree;
 import com.sun.source.tree.NewClassTree;
@@ -72,6 +74,7 @@ import com.sun.source.tree.WhileLoopTree;
 import com.sun.source.util.SourcePositions;
 import com.sun.source.util.TreePath;
 import com.sun.source.util.TreeScanner;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
@@ -112,36 +115,29 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
     private Set<VariableElement> variablesWithAllowedRemap = Collections.emptySet();
     private State bindState = State.empty();
     private boolean allowVariablesRemap = false;
+    private boolean nocheckOnAllowVariablesRemap = false;
     private AtomicBoolean cancel;
-
+    private static final String CLASS = "class"; //NOI18N
+    private final Set<Options> options;
 
     private Map<String, TypeMirror> designedTypeHack;
 
-    private CopyFinder(TreePath searchingFor, CompilationInfo info, AtomicBoolean cancel) {
+    private CopyFinder(TreePath searchingFor, CompilationInfo info, AtomicBoolean cancel, Options... options) {
         this.searchingFor = searchingFor;
         this.info = info;
         this.cancel = cancel;
+        this.options = EnumSet.noneOf(Options.class);
+        this.options.addAll(Arrays.asList(options));
     }
 
     public static Map<TreePath, VariableAssignments> computeDuplicates(CompilationInfo info, TreePath searchingFor, TreePath scope, AtomicBoolean cancel, Map<String, TypeMirror> designedTypeHack) {
         return computeDuplicates(info, searchingFor, scope, true, cancel, designedTypeHack);
     }
 
-    public static Map<TreePath, VariableAssignments> computeDuplicates(final CompilationInfo info, TreePath searchingFor, TreePath scope, boolean fullElementVerify, AtomicBoolean cancel, Map<String, TypeMirror> designedTypeHack) {
+    public static Map<TreePath, VariableAssignments> computeDuplicates(final CompilationInfo info, TreePath searchingFor, TreePath scope, boolean fullElementVerify, AtomicBoolean cancel, Map<String, TypeMirror> designedTypeHack, Options... options) {
         CopyFinder f =   fullElementVerify
-                       ? new CopyFinder(searchingFor, info, cancel)
-                       : new CopyFinder(searchingFor, info, cancel) {
-            @Override
-            protected VerifyResult verifyElements(TreePath node, TreePath p) {
-                return getSimpleName(node.getLeaf()).contentEquals(getSimpleName(p.getLeaf())) ? VerifyResult.MATCH : VerifyResult.NO_MATCH_CONTINUE;
-            }
-            @Override
-            protected Iterable<? extends TreePath> prepareThis(TreePath tp) {
-                ExpressionTree thisTree = info.getTreeUtilities().parseExpression("this", new SourcePositions[1]);
-
-                return Collections.singleton(new TreePath(tp, thisTree));
-            }
-        };
+                       ? new CopyFinder(searchingFor, info, cancel, options)
+                       : new UnattributedCopyFinder(searchingFor, info, cancel, options);
 
         f.designedTypeHack = designedTypeHack;
 
@@ -155,11 +151,9 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
             return null;
         }
 
-        CopyFinder f = new CopyFinder(searchingFor, info, cancel);
+        CopyFinder f = new CopyFinder(searchingFor, info, cancel, Options.ALLOW_VARIABLES_IN_PATTERN);
 
         f.allowGoDeeper = false;
-
-
         f.designedTypeHack = designedTypeHack;
 
         if (f.scan(scope, searchingFor)) {
@@ -178,24 +172,17 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
     }
 
     public static boolean isDuplicate(final CompilationInfo info, TreePath one, TreePath second, boolean fullElementVerify, HintContext inVariables, boolean fillInVariables, AtomicBoolean cancel) {
+        return isDuplicate(info, one, second, fullElementVerify, inVariables, fillInVariables, null, cancel);
+    }
+
+    public static boolean isDuplicate(final CompilationInfo info, TreePath one, TreePath second, boolean fullElementVerify, HintContext inVariables, boolean fillInVariables, Set<VariableElement> variablesWithAllowedRemap, AtomicBoolean cancel, Options... options) {
         if (one.getLeaf().getKind() != second.getLeaf().getKind()) {
             return false;
         }
 
         CopyFinder f =   fullElementVerify
-                       ? new CopyFinder(one, info, cancel)
-                       : new CopyFinder(one, info, cancel) {
-            @Override
-            protected VerifyResult verifyElements(TreePath node, TreePath p) {
-                return getSimpleName(node.getLeaf()).contentEquals(getSimpleName(p.getLeaf())) ? VerifyResult.MATCH : VerifyResult.NO_MATCH_CONTINUE;
-            }
-            @Override
-            protected Iterable<? extends TreePath> prepareThis(TreePath tp) {
-                ExpressionTree thisTree = info.getTreeUtilities().parseExpression("this", new SourcePositions[1]);
-
-                return Collections.singleton(new TreePath(tp, thisTree));
-            }
-        };
+                       ? new CopyFinder(one, info, cancel, options)
+                       : new UnattributedCopyFinder(one, info, cancel, options);
 
         if (inVariables != null) {
             if (fillInVariables) {
@@ -208,6 +195,9 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         }
 
         f.allowGoDeeper = false;
+        f.variablesWithAllowedRemap = variablesWithAllowedRemap != null ? new HashSet<VariableElement>(variablesWithAllowedRemap) : Collections.<VariableElement>emptySet();
+        f.allowVariablesRemap = variablesWithAllowedRemap != null;
+        f.nocheckOnAllowVariablesRemap = variablesWithAllowedRemap != null;
 
         return f.scan(second, one);
     }
@@ -355,7 +345,7 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         if (p != null && p.getLeaf().getKind() == Kind.IDENTIFIER) {
             String ident = ((IdentifierTree) p.getLeaf()).getName().toString();
 
-            if (ident.startsWith("$")) {
+            if (ident.startsWith("$") && options.contains(Options.ALLOW_VARIABLES_IN_PATTERN)) {
                 if (bindState.variables2Names.containsKey(ident)) {
                     if (node.getKind() == Kind.IDENTIFIER)
                         return ((IdentifierTree) node).getName().toString().equals(bindState.variables2Names.get(ident));
@@ -366,7 +356,7 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
                 TreePath currentPath = new TreePath(getCurrentPath(), node);
                 TypeMirror designed = designedTypeHack != null ? designedTypeHack.get(ident) : null;//info.getTrees().getTypeMirror(p);
 
-                boolean bind = true;
+                boolean bind;
 
                 if (designed != null && designed.getKind() != TypeKind.ERROR) {
                     TypeMirror real = info.getTrees().getTypeMirror(currentPath);
@@ -375,6 +365,8 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
                         bind = info.getTypes().isAssignable(real, designed);
                     else
                         bind = false;
+                } else {
+                    bind = designed == null;
                 }
 
                 if (bind) {
@@ -387,8 +379,10 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
                         boolean oldAllowGoDeeper = allowGoDeeper;
 
                         try {
+                            options.remove(Options.ALLOW_VARIABLES_IN_PATTERN);
                             return scan(node, original);
                         } finally {
+                            options.add(Options.ALLOW_VARIABLES_IN_PATTERN);
                             allowGoDeeper = oldAllowGoDeeper;
                         }
                     }
@@ -418,7 +412,7 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
                 TypeMirror currType = info.getTrees().getTypeMirror(currPath);
                 TypeMirror pType = ((VariableElement) remappable).asType();
 
-                if (currType != null && pType != null && isSameTypeForVariableRemap(currType, pType)) {
+                if (currType != null && pType != null && (nocheckOnAllowVariablesRemap || isSameTypeForVariableRemap(currType, pType))) {
                     bindState.variablesRemapToTrees.put(remappable, currPath);
                     return true;
                 }
@@ -507,7 +501,7 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         if (p.getLeaf().getKind() == Kind.IDENTIFIER) {
             String ident = ((IdentifierTree) p.getLeaf()).getName().toString();
 
-            if (ident.startsWith("$")) {
+            if (ident.startsWith("$") && options.contains(Options.ALLOW_VARIABLES_IN_PATTERN)) {
                 return scan(node, p);
             }
         }
@@ -707,6 +701,10 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
             return true;
         }
 
+        if (patternOffset >= pattern.size()) {
+            return false;
+        }
+        
         if (Utilities.isMultistatementWildcardTree(pattern.get(patternOffset))) {
             if (patternOffset + 1 == pattern.size()) {
                 List<TreePath> tps = new LinkedList<TreePath>();
@@ -789,9 +787,54 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         return scan(node.getBlock(), ef.getBlock(), p);
     }
 
-//    public Boolean visitClass(ClassTree node, TreePath p) {
-//        throw new UnsupportedOperationException("Not supported yet.");
-//    }
+    public Boolean visitClass(ClassTree node, TreePath p) {
+        if (p == null)
+            return super.visitClass(node, p);
+
+        ClassTree t = (ClassTree) p.getLeaf();
+
+        String name = t.getSimpleName().toString();
+
+        if (!name.isEmpty()) {
+            if (!scan(node.getModifiers(), t.getModifiers(), p))
+                return false;
+
+            if (name.startsWith("$")) { //XXX: there should be a utility method for this check
+                String existingName = bindState.variables2Names.get(name);
+                String currentName = node.getSimpleName().toString();
+
+                if (existingName != null) {
+                    if (!existingName.equals(name)) {
+                        return false;
+                    }
+                } else {
+                    //XXX: putting the variable into both variables and variable2Names.
+                    //variables is needed by the declarative hints to support conditions like
+                    //referencedIn($variable, $statements$):
+                    //causes problems in JavaFix, see visitIdentifier there.
+                    bindState.variables.put(name, getCurrentPath());
+                    bindState.variables2Names.put(name, currentName);
+                }
+            } else {
+                if (!node.getSimpleName().contentEquals(name))
+                    return false;
+            }
+
+            if (!checkLists(node.getTypeParameters(), t.getTypeParameters(), p))
+                return false;
+
+            if (!scan(node.getExtendsClause(), t.getExtendsClause(), p))
+                return false;
+
+            if (!checkLists(node.getImplementsClause(), t.getImplementsClause(), p))
+                return false;
+        } else {
+            if (node.getSimpleName().length() != 0)
+                return false;
+        }
+
+        return checkLists(Utilities.filterHidden(getCurrentPath(), node.getMembers()), Utilities.filterHidden(p, t.getMembers()), p);
+    }
 
     public Boolean visitConditionalExpression(ConditionalExpressionTree node, TreePath p) {
         if (p == null) {
@@ -889,20 +932,7 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
                     return true;
                 }
 
-                for (TreePath thisPath : prepareThis(getCurrentPath())) {
-                    State origState = State.copyOf(bindState);
-                    try {
-                        MemberSelectTree t = (MemberSelectTree) p.getLeaf();
-
-                        if (scan(thisPath.getLeaf(), t.getExpression(), p) == Boolean.TRUE) {
-                            return true;
-                        }
-                    } finally {
-                        bindState = origState;
-                    }
-                }
-
-                return false;
+                return deepVerifyIdentifier2MemberSelect(getCurrentPath(), p);
             case MATCH:
                 return true;
             default:
@@ -912,6 +942,23 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         }
     }
 
+    private boolean deepVerifyIdentifier2MemberSelect(TreePath identifier, TreePath memberSelect) {
+        for (TreePath thisPath : prepareThis(identifier)) {
+            State origState = State.copyOf(bindState);
+            try {
+                MemberSelectTree t = (MemberSelectTree) memberSelect.getLeaf();
+
+                if (scan(thisPath.getLeaf(), t.getExpression(), memberSelect) == Boolean.TRUE) {
+                    return true;
+                }
+            } finally {
+                bindState = origState;
+            }
+        }
+
+        return false;
+    }
+    
     public Boolean visitIf(IfTree node, TreePath p) {
         if (p == null)
             return super.visitIf(node, p);
@@ -963,10 +1010,56 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         return nodeValue.equals(ltValue);
     }
 
-//    public Boolean visitMethod(MethodTree node, TreePath p) {
-//        throw new UnsupportedOperationException("Not supported yet.");
-//    }
+    public Boolean visitMethod(MethodTree node, TreePath p) {
+        if (p == null)
+            return super.visitMethod(node, p);
 
+        MethodTree t = (MethodTree) p.getLeaf();
+
+        if (!scan(node.getModifiers(), t.getModifiers(), p))
+            return false;
+
+        if (!checkLists(node.getTypeParameters(), t.getTypeParameters(), p))
+            return false;
+
+        if (!scan(node.getReturnType(), t.getReturnType(), p))
+            return false;
+
+        String name = t.getName().toString();
+
+        if (name.startsWith("$")) { //XXX: there should be a utility method for this check
+            String existingName = bindState.variables2Names.get(name);
+            String currentName = node.getName().toString();
+
+            if (existingName != null) {
+                if (!existingName.equals(name)) {
+                    return false;
+                }
+            } else {
+                //XXX: putting the variable into both variables and variable2Names.
+                //variables is needed by the declarative hints to support conditions like
+                //referencedIn($variable, $statements$):
+                //causes problems in JavaFix, see visitIdentifier there.
+                bindState.variables.put(name, getCurrentPath());
+                bindState.variables2Names.put(name, currentName);
+            }
+        } else {
+            if (!node.getName().contentEquals(name))
+                return false;
+        }
+
+        if (!checkLists(node.getParameters(), t.getParameters(), p))
+            return false;
+
+        if (!checkLists(node.getThrows(), t.getThrows(), p))
+            return false;
+
+        if (!scan(node.getBody(), t.getBody(), p))
+            return false;
+
+        return scan(node.getDefaultValue(), t.getDefaultValue(), p);
+    }
+    
     public Boolean visitModifiers(ModifiersTree node, TreePath p) {
         if (p == null)
             return super.visitModifiers(node, p);
@@ -1039,23 +1132,20 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         if (p == null)
             return super.visitMemberSelect(node, p);
 
-        if (Utilities.isPureMemberSelect(node, true) && Utilities.isPureMemberSelect(p.getLeaf(), true)) {
-            switch (verifyElements(getCurrentPath(), p)) {
-                case MATCH_CHECK_DEEPER:
-                    if (node.getKind() == p.getLeaf().getKind()) {
-                        //to bind any free variables inside:
-                        MemberSelectTree t = (MemberSelectTree) p.getLeaf();
+        switch (verifyElements(getCurrentPath(), p)) {
+            case MATCH_CHECK_DEEPER:
+                if (node.getKind() == p.getLeaf().getKind()) {
+                    //to bind any free variables inside:
+                    MemberSelectTree t = (MemberSelectTree) p.getLeaf();
 
-                        return scan(node.getExpression(), t.getExpression(), p) == Boolean.TRUE;
-                    } else {
-                        //TODO: what to do here?
-                        return true;
-                    }
-                case MATCH:
-                    return true;
-                case NO_MATCH:
-                    return false;
-            }
+                    return scan(node.getExpression(), t.getExpression(), p) == Boolean.TRUE;
+                } else {
+                    return deepVerifyIdentifier2MemberSelect(p, getCurrentPath());
+                }
+            case MATCH:
+                return true;
+            case NO_MATCH:
+                return false;
         }
 
         if (node.getKind() != p.getLeaf().getKind()) {
@@ -1127,6 +1217,10 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
 
         TryTree at = (TryTree) p.getLeaf();
 
+        if (!checkLists(node.getResources(), at.getResources(), p)) {
+            return false;
+        }
+        
         if (!scan(node.getBlock(), at.getBlock(), p)) {
             return false;
         }
@@ -1291,7 +1385,7 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         VerifyResult matchingResult;
         
         if (!nodeEl.getModifiers().contains(Modifier.STATIC)) {
-            if (nodeEl.getKind().isClass() && info.getElementUtilities().enclosingTypeElement(nodeEl) == null) {
+            if ((nodeEl.getKind().isClass() || nodeEl.getKind().isInterface()) && info.getElementUtilities().enclosingTypeElement(nodeEl) == null) {
                 //top-level class:
                 matchingResult = VerifyResult.MATCH;
             } else {
@@ -1308,6 +1402,12 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
         if (nodeEl == null || pEl == null)
             return VerifyResult.NO_MATCH;
 
+        if (nodeEl.getKind() == pEl.getKind() && nodeEl.getKind() == ElementKind.FIELD
+                && CLASS.contentEquals(((VariableElement)nodeEl).getSimpleName())
+                && CLASS.contentEquals(((VariableElement)pEl).getSimpleName())) {
+            return VerifyResult.MATCH_CHECK_DEEPER;
+        }
+
         if (nodeEl.getKind() == pEl.getKind() && nodeEl.getKind() == ElementKind.METHOD) {
             if (info.getElements().overrides((ExecutableElement) nodeEl, (ExecutableElement) pEl, (TypeElement) nodeEl.getEnclosingElement())) {
                 return VerifyResult.MATCH_CHECK_DEEPER;
@@ -1454,4 +1554,30 @@ public class CopyFinder extends TreeScanner<Boolean, TreePath> {
             return new State(variables, multiVariables, variables2Names, null, null);
         }
     }
+
+    private static final class UnattributedCopyFinder extends CopyFinder {
+        private UnattributedCopyFinder(TreePath searchingFor, CompilationInfo info, AtomicBoolean cancel, Options... options) {
+            super(searchingFor, info, cancel, options);
+        }
+        @Override
+        protected VerifyResult verifyElements(TreePath node, TreePath p) {
+            if (getSimpleName(node.getLeaf()).contentEquals(getSimpleName(p.getLeaf()))) {
+                boolean pureSelect = Utilities.isPureMemberSelect(node.getLeaf(), true) && Utilities.isPureMemberSelect(p.getLeaf(), true);
+                
+                return pureSelect ? VerifyResult.MATCH : VerifyResult.MATCH_CHECK_DEEPER;
+            } else {
+                return VerifyResult.NO_MATCH_CONTINUE;
+            }
+        }
+        @Override
+        protected Iterable<? extends TreePath> prepareThis(TreePath tp) {
+            ExpressionTree thisTree = super.info.getTreeUtilities().parseExpression("this", new SourcePositions[1]);
+
+            return Collections.singleton(new TreePath(tp, thisTree));
+        }
+    }
+
+    public enum Options {
+        ALLOW_VARIABLES_IN_PATTERN
+    }
 }
