@@ -26,34 +26,32 @@
  *
  * Contributor(s):
  *
- * Portions Copyrighted 2007 Sun Microsystems, Inc.
+ * Portions Copyrighted 2007-2010 Sun Microsystems, Inc.
  */
 package org.netbeans.modules.java.hints.introduce;
 
-import java.beans.PropertyChangeEvent;
 import java.io.IOException;
 import java.util.EnumMap;
 import java.util.Map;
 import java.util.concurrent.atomic.AtomicBoolean;
+import javax.swing.JMenuItem;
 import org.netbeans.api.java.source.CompilationController;
 import org.netbeans.api.java.source.Task;
 import org.netbeans.api.java.source.JavaSource;
 import org.netbeans.api.java.source.JavaSource.Phase;
 import org.netbeans.api.progress.ProgressUtils;
+import org.netbeans.modules.editor.MainMenuAction;
 import org.netbeans.modules.java.hints.infrastructure.HintAction;
 import org.netbeans.spi.editor.hints.Fix;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
+import org.openide.util.actions.Presenter;
 
 public final class IntroduceAction extends HintAction {
     
-    private IntroduceKind type;
-    private static String INTRODUCE_CONSTANT = "introduce-constant";//NOI18N
-    private static String INTRODUCE_VARIABLE = "introduce-variable";//NOI18N
-    private static String INTRODUCE_METHOD = "introduce-method";//NOI18N
-    private static String INTRODUCE_FIELD = "introduce-field";//NOI18N
+    private final IntroduceKind type;
 
     /** Property identifier for menu text, neccessary for display in menu */
     private static final String MENU_TEXT = "menuText"; //NOI18N
@@ -62,28 +60,29 @@ public final class IntroduceAction extends HintAction {
     
 
     private IntroduceAction(IntroduceKind type) {
+        super(type.getKey());
         this.type = type;
         switch (type) {
             case CREATE_CONSTANT:
-                putValue(NAME, INTRODUCE_CONSTANT);
+                putValue(NAME, type.getKey());
                 putValue(SHORT_DESCRIPTION, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceConstantAction"));
                 putValue(MENU_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceConstantAction"));
                 putValue(POPUP_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceConstantAction"));
                 break;
             case CREATE_VARIABLE:
-                putValue(NAME, INTRODUCE_VARIABLE);
+                putValue(NAME, type.getKey());
                 putValue(SHORT_DESCRIPTION, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceVariableAction"));
                 putValue(MENU_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceVariableAction"));
                 putValue(POPUP_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceVariableAction"));
                 break;
             case CREATE_FIELD:
-                putValue(NAME, INTRODUCE_FIELD);
+                putValue(NAME, type.getKey());
                 putValue(SHORT_DESCRIPTION, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceFieldAction"));
                 putValue(MENU_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceFieldAction"));
                 putValue(POPUP_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceFieldAction"));
                 break;
             case CREATE_METHOD:
-                putValue(NAME, INTRODUCE_METHOD);
+                putValue(NAME, type.getKey());
                 putValue(SHORT_DESCRIPTION, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceMethodAction"));
                 putValue(MENU_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceMethodAction"));
                 putValue(POPUP_TEXT, NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceMethodAction"));
@@ -93,12 +92,6 @@ public final class IntroduceAction extends HintAction {
         setEnabled(true);
     }
 
-    @Override
-    public void propertyChange(PropertyChangeEvent evt) {
-    }
-
-
-    
     protected void perform(JavaSource js, int[] selection) {
         String error = doPerformAction(js, selection);
         
@@ -159,7 +152,7 @@ public final class IntroduceAction extends HintAction {
 
         return "ERR_Invalid_Selection"; //XXX  //NOI18N
     }
-    
+
     public static IntroduceAction createVariable() {
         return new IntroduceAction(IntroduceKind.CREATE_VARIABLE);
     }
@@ -175,5 +168,49 @@ public final class IntroduceAction extends HintAction {
     public static IntroduceAction createMethod() {
         return new IntroduceAction(IntroduceKind.CREATE_METHOD);
     }
-    
+
+    public static Object createVariableGlobal() {
+        return new GlobalActionImpl(NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceVariableAction"), IntroduceKind.CREATE_VARIABLE.getKey());
+    }
+
+    public static Object createConstantGlobal() {
+        return new GlobalActionImpl(NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceConstantAction"), IntroduceKind.CREATE_CONSTANT.getKey());
+    }
+
+    public static Object createFieldGlobal() {
+        return new GlobalActionImpl(NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceFieldAction"), IntroduceKind.CREATE_FIELD.getKey());
+    }
+
+    public static Object createMethodGlobal() {
+        return new GlobalActionImpl(NbBundle.getMessage(IntroduceAction.class, "CTL_IntroduceMethodAction"), IntroduceKind.CREATE_METHOD.getKey());
+    }
+
+    private static final class GlobalActionImpl extends MainMenuAction implements Presenter.Popup {
+
+        private final String menuItemText;
+        private final String actionName;
+
+        public GlobalActionImpl(String menu, String action) {
+            this.menuItemText = menu;
+            this.actionName = action;
+            setMenu();
+        }
+
+        @Override
+        protected String getMenuItemText() {
+            return menuItemText;
+        }
+
+        @Override
+        protected String getActionName() {
+            return actionName;
+        }
+
+        @Override
+        public JMenuItem getPopupPresenter() {
+            return getMenuPresenter();
+        }
+
+    }
+
 }
