@@ -54,6 +54,7 @@ import com.sun.source.tree.IdentifierTree;
 import com.sun.source.tree.ImportTree;
 import com.sun.source.tree.LiteralTree;
 import com.sun.source.tree.MemberSelectTree;
+import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.ModifiersTree;
 import com.sun.source.tree.NewArrayTree;
@@ -70,6 +71,7 @@ import com.sun.source.util.TreePathScanner;
 import com.sun.source.util.TreeScanner;
 import com.sun.source.util.Trees;
 import com.sun.tools.javac.api.JavacTaskImpl;
+import com.sun.tools.javac.code.Flags;
 import com.sun.tools.javac.main.JavaCompiler;
 import com.sun.tools.javac.parser.EndPosParser;
 import com.sun.tools.javac.parser.JavacParser;
@@ -77,21 +79,24 @@ import com.sun.tools.javac.parser.Lexer;
 import com.sun.tools.javac.parser.Parser;
 import com.sun.tools.javac.parser.ParserFactory;
 import com.sun.tools.javac.parser.Scanner;
+import com.sun.tools.javac.parser.ScannerFactory;
 import com.sun.tools.javac.parser.Token;
+import com.sun.tools.javac.tree.JCTree;
+import com.sun.tools.javac.tree.JCTree.JCCatch;
+import com.sun.tools.javac.tree.JCTree.JCCompilationUnit;
 import com.sun.tools.javac.tree.JCTree.JCExpression;
+import com.sun.tools.javac.tree.JCTree.JCMethodDecl;
 import com.sun.tools.javac.tree.JCTree.JCModifiers;
 import com.sun.tools.javac.tree.JCTree.JCStatement;
 import com.sun.tools.javac.util.CancelService;
 import com.sun.tools.javac.util.Context;
 import com.sun.tools.javac.util.Log;
 import com.sun.tools.javac.util.Names;
+import com.sun.tools.javac.util.Position.LineMap;
 import java.io.File;
 import java.io.IOException;
 import java.net.URI;
-import java.net.URL;
 import java.nio.CharBuffer;
-import java.util.Arrays;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
 import java.util.HashMap;
@@ -102,8 +107,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
-import java.util.logging.Level;
-import java.util.logging.Logger;
 import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.element.AnnotationValue;
 import javax.lang.model.element.AnnotationValueVisitor;
@@ -127,23 +130,17 @@ import org.netbeans.api.annotations.common.NonNull;
 import org.netbeans.api.java.classpath.ClassPath;
 import org.netbeans.api.java.platform.JavaPlatform;
 import org.netbeans.api.java.platform.JavaPlatformManager;
-import org.netbeans.api.java.queries.SourceForBinaryQuery;
-import org.netbeans.api.java.queries.SourceForBinaryQuery.Result2;
 import org.netbeans.api.java.source.ClasspathInfo;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.SourceUtils;
 import org.netbeans.api.java.source.TreeMaker;
-import org.netbeans.modules.java.hints.jackpot.spi.ClassPathBasedHintProvider;
-import org.netbeans.modules.java.hints.jackpot.spi.HintDescription;
-import org.netbeans.modules.java.hints.jackpot.spi.HintProvider;
+import org.netbeans.modules.java.hints.jackpot.impl.JackpotTrees.CatchWildcard;
+import org.netbeans.modules.java.hints.jackpot.impl.JackpotTrees.ModifiersWildcard;
 import org.netbeans.modules.java.source.JavaSourceAccessor;
 import org.netbeans.modules.java.source.builder.TreeFactory;
 import org.netbeans.modules.java.source.parsing.FileObjects;
 import org.netbeans.modules.java.source.pretty.ImportAnalysis2;
 import org.netbeans.modules.java.source.transform.ImmutableTreeTranslator;
-import org.netbeans.spi.java.classpath.support.ClassPathSupport;
-import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileStateInvalidException;
 import org.openide.util.Exceptions;
 import org.openide.util.Lookup;
 import org.openide.util.NbCollections;
@@ -432,16 +429,9 @@ public class Utilities {
     }
 
     private static Tree fixTree(Context c, Tree patternTree) {
-        TreeFactory make = TreeFactory.instance(c);
         FixTree fixTree = new FixTree();
 
-        //TODO: workaround, ImmutableTreeTranslator needs a CompilationUnitTree (rewriteChildren(BlockTree))
-        //but sometimes no CompilationUnitTree (e.g. during BatchApply):
-        CompilationUnitTree cut = make.CompilationUnit(null, Collections.<ImportTree>emptyList(), Collections.<Tree>emptyList(), null);
-        ImportAnalysis2 ia = new ImportAnalysis2(c);
-
-        ia.setImports(Collections.<ImportTree>emptyList());
-        fixTree.attach(c, ia, cut, null);
+        fixTree.attach(c, new NoImports(c), null);
 
         return fixTree.translate(patternTree);
     }
@@ -479,9 +469,9 @@ public class Utilities {
         try {
             CharBuffer buf = CharBuffer.wrap((stmt+"\u0000").toCharArray(), 0, stmt.length());
             ParserFactory factory = ParserFactory.instance(context);
-            Scanner.Factory scannerFactory = Scanner.Factory.instance(context);
+            ScannerFactory scannerFactory = ScannerFactory.instance(context);
             Names names = Names.instance(context);
-            Parser parser = new JackpotJavacParser(factory, scannerFactory.newScanner(buf), false, false, CancelService.instance(context), names);
+            Parser parser = new JackpotJavacParser(context, factory, scannerFactory.newScanner(buf, false), false, false, CancelService.instance(context), names);
             if (parser instanceof JavacParser) {
 //                if (pos != null)
 //                    pos[0] = new ParserSourcePositions((JavacParser)parser);
@@ -501,10 +491,10 @@ public class Utilities {
         try {
             CharBuffer buf = CharBuffer.wrap((expr+"\u0000").toCharArray(), 0, expr.length());
             ParserFactory factory = ParserFactory.instance(context);
-            Scanner.Factory scannerFactory = Scanner.Factory.instance(context);
+            ScannerFactory scannerFactory = ScannerFactory.instance(context);
             Names names = Names.instance(context);
-            Scanner scanner = scannerFactory.newScanner(buf);
-            Parser parser = new JackpotJavacParser(factory, scanner, false, false, CancelService.instance(context), names);
+            Scanner scanner = scannerFactory.newScanner(buf, false);
+            Parser parser = new JackpotJavacParser(context, factory, scanner, false, false, CancelService.instance(context), names);
             if (parser instanceof JavacParser) {
 //                if (pos != null)
 //                    pos[0] = new ParserSourcePositions((JavacParser)parser);
@@ -692,7 +682,7 @@ public class Utilities {
         SourceUtils.waitScanFinished();
     }
 
-    public static Set<? extends String> findSuppressedWarnings(CompilationInfo info, TreePath path) {
+    public static @NonNull Set<? extends String> findSuppressedWarnings(@NonNull CompilationInfo info, @NonNull TreePath path) {
         //TODO: cache?
         Set<String> keys = new HashSet<String>();
 
@@ -703,7 +693,10 @@ public class Utilities {
                 case METHOD:
                     handleSuppressWarnings(info, path, ((MethodTree) leaf).getModifiers(), keys);
                     break;
+                case ANNOTATION_TYPE:
                 case CLASS:
+                case ENUM:
+                case INTERFACE:
                     handleSuppressWarnings(info, path, ((ClassTree) leaf).getModifiers(), keys);
                     break;
                 case VARIABLE:
@@ -810,11 +803,7 @@ public class Utilities {
 
         GeneralizePatternITT itt = new GeneralizePatternITT(gp.tree2Variable);
 
-        //TODO: workaround, ImmutableTreeTranslator needs a CompilationUnitTree (rewriteChildren(BlockTree))
-        //but sometimes no CompilationUnitTree (e.g. during BatchApply):
-        CompilationUnitTree cut = TreeFactory.instance(c).CompilationUnit(null, Collections.<ImportTree>emptyList(), Collections.<Tree>emptyList(), null);
-
-        itt.attach(c, new NoImports(c), cut, null);
+        itt.attach(c, new NoImports(c), null);
 
         return itt.translate(original.getLeaf());
     }
@@ -1014,13 +1003,15 @@ public class Utilities {
 
     private static class JackpotJavacParser extends EndPosParser {
 
-        public JackpotJavacParser(ParserFactory fac,
+        private final Context ctx;
+        public JackpotJavacParser(Context ctx, ParserFactory fac,
                          Lexer S,
                          boolean keepDocComments,
                          boolean keepLineMap,
                          CancelService cancelService,
                          Names names) {
-            super(fac, S, keepDocComments, keepLineMap, cancelService);
+            super(fac, new PushbackLexer(S), keepDocComments, keepLineMap, cancelService);
+            this.ctx = ctx;
 
             newAnonScope(names.empty, -1);
         }
@@ -1042,9 +1033,149 @@ public class Utilities {
             return super.modifiersOpt(partial);
         }
 
+        @Override
+        protected JCCatch catchClause() {
+            if (S.token() == Token.CATCH) {
+//                S.pushState();
+                
+                Token peeked;
+                String ident;
+                
+//                try {
+                    S.nextToken();
 
+                    peeked =  S.token();
+                    ident = S.stringVal();
+//                } finally {
+//                    S.popState();
+//                }
+                
+                if (   peeked == Token.IDENTIFIER
+                    && Utilities.isMultistatementWildcard(ident)) {
+                    accept(Token.CATCH);
+                    
+                    com.sun.tools.javac.util.Name name = S.name();
+
+                    accept(Token.IDENTIFIER);
+
+                    return new CatchWildcard(ctx, name, F.Ident(name));
+                } else {
+                    ((PushbackLexer) S).add(Token.CATCH);
+                    ((PushbackLexer) S).add(null);
+                    S.nextToken();
+                }
+            }
+            return super.catchClause();
+        }
+
+        @Override
+        protected JCTree resource() {
+            if (S.token() == Token.IDENTIFIER && S.stringVal().startsWith("$")) {
+                //XXX: should inspect the next token, not next character:
+                char[] maybeSemicolon = S.getRawCharacters(S.endPos(), S.endPos() + 1);
+                
+                if (maybeSemicolon[0] == ';' || maybeSemicolon[0] == ')') {
+                    int pos = S.pos();
+                    com.sun.tools.javac.util.Name name = S.name();
+                    
+                    S.nextToken();
+                    
+                    return F.at(pos).Ident(name);
+                }
+            }
+            return super.resource();
+        }
+        
     }
 
+    private static final class PushbackLexer implements Lexer {
+
+        private final Lexer delegate;
+        private final List<Token> buffer;
+        private Token currentBufferToken;
+
+        public PushbackLexer(Lexer delegate) {
+            this.delegate = delegate;
+            this.buffer = new LinkedList<Token>();
+        }
+
+        public void add(Token token) {
+            buffer.add(token);
+        }
+        
+        public void token(Token token) {
+            delegate.token(token);
+        }
+
+        public Token token() {
+            if (currentBufferToken != null) return currentBufferToken;
+            return delegate.token();
+        }
+
+        public String stringVal() {
+            return delegate.stringVal();
+        }
+
+        public void resetDeprecatedFlag() {
+            delegate.resetDeprecatedFlag();
+        }
+
+        public int radix() {
+            return delegate.radix();
+        }
+
+        public int prevEndPos() {
+            return delegate.prevEndPos();
+        }
+
+        public int pos() {
+            return delegate.pos();
+        }
+
+        public void nextToken() {
+            if (!buffer.isEmpty()) currentBufferToken = buffer.remove(0);
+            else delegate.nextToken();
+        }
+
+        public com.sun.tools.javac.util.Name name() {
+            return delegate.name();
+        }
+
+        public char[] getRawCharacters(int beginIndex, int endIndex) {
+            return delegate.getRawCharacters(beginIndex, endIndex);
+        }
+
+        public char[] getRawCharacters() {
+            return delegate.getRawCharacters();
+        }
+
+        public LineMap getLineMap() {
+            return delegate.getLineMap();
+        }
+
+        public void errPos(int pos) {
+            delegate.errPos(pos);
+        }
+
+        public int errPos() {
+            return delegate.errPos();
+        }
+
+        public int endPos() {
+            return delegate.endPos();
+        }
+
+        public String docComment() {
+            return delegate.docComment();
+        }
+
+        public boolean deprecatedFlag() {
+            return delegate.deprecatedFlag();
+        }
+        
+        
+    }
+    
     private static final class DummyJFO extends SimpleJavaFileObject {
         private DummyJFO() {
             super(URI.create("dummy.java"), JavaFileObject.Kind.SOURCE);
@@ -1054,4 +1185,50 @@ public class Utilities {
             return "";
         }
     };
+
+    /**
+     * Only for members (i.e. generated constructor):
+     */
+    public static List<? extends Tree> filterHidden(TreePath basePath, Iterable<? extends Tree> members) {
+        List<Tree> result = new LinkedList<Tree>();
+
+        for (Tree t : members) {
+            if (!isSynthetic(basePath != null ? basePath.getCompilationUnit() : null, t)) {
+                result.add(t);
+            }
+        }
+
+        return result;
+    }
+
+    private static boolean isSynthetic(CompilationUnitTree cut, Tree leaf) throws NullPointerException {
+        JCTree tree = (JCTree) leaf;
+
+        if (tree.pos == (-1))
+            return true;
+
+        if (leaf.getKind() == Kind.METHOD) {
+            //check for synthetic constructor:
+            return (((JCMethodDecl)leaf).mods.flags & Flags.GENERATEDCONSTR) != 0L;
+        }
+
+        //check for synthetic superconstructor call:
+        if (cut != null && leaf.getKind() == Kind.EXPRESSION_STATEMENT) {
+            ExpressionStatementTree est = (ExpressionStatementTree) leaf;
+
+            if (est.getExpression().getKind() == Kind.METHOD_INVOCATION) {
+                MethodInvocationTree mit = (MethodInvocationTree) est.getExpression();
+
+                if (mit.getMethodSelect().getKind() == Kind.IDENTIFIER) {
+                    IdentifierTree it = (IdentifierTree) mit.getMethodSelect();
+
+                    if ("super".equals(it.getName().toString())) {
+                        return ((JCCompilationUnit) cut).endPositions.get(tree) == (-1);
+                    }
+                }
+            }
+        }
+
+        return false;
+    }
 }
