@@ -47,6 +47,7 @@ import com.sun.javadoc.Tag;
 import com.sun.source.tree.AssignmentTree;
 import com.sun.source.tree.BinaryTree;
 import com.sun.source.tree.BlockTree;
+import com.sun.source.tree.CatchTree;
 import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.CompoundAssignmentTree;
 import com.sun.source.tree.ExpressionStatementTree;
@@ -64,6 +65,7 @@ import com.sun.source.tree.Scope;
 import com.sun.source.tree.StatementTree;
 import com.sun.source.tree.Tree;
 import com.sun.source.tree.Tree.Kind;
+import com.sun.source.tree.TryTree;
 import com.sun.source.util.SourcePositions;
 import com.sun.source.util.TreePath;
 import com.sun.source.util.TreePathScanner;
@@ -86,6 +88,7 @@ import javax.lang.model.type.TypeMirror;
 import org.netbeans.api.java.source.CompilationInfo;
 import org.netbeans.api.java.source.SourceUtils;
 import org.netbeans.api.java.source.TreePathHandle;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.api.java.source.TypeMirrorHandle;
 import org.netbeans.api.java.source.WorkingCopy;
 import org.netbeans.api.project.FileOwnerQuery;
@@ -466,25 +469,29 @@ public abstract class JavaFix {
                 wc.rewrite(tp.getLeaf(), parsed);
             } else {
                 if (isFakeBlock(parsed)) {
-                    TreePath parent = tp.getParentPath();
-                    List<? extends StatementTree> statements = ((BlockTree) parsed).getStatements();
-
-                    statements = statements.subList(1, statements.size() - 1);
-
-                    if (parent.getLeaf().getKind() == Kind.BLOCK) {
-                        List<StatementTree> newStatements = new LinkedList<StatementTree>();
-
-                        for (StatementTree st : ((BlockTree) parent.getLeaf()).getStatements()) {
-                            if (st == tp.getLeaf()) {
-                                newStatements.addAll(statements);
-                            } else {
-                                newStatements.add(st);
-                            }
-                        }
-
-                        wc.rewrite(parent.getLeaf(), wc.getTreeMaker().Block(newStatements, ((BlockTree) parent.getLeaf()).isStatic()));
+                    if (tp.getLeaf().getKind() == Kind.BLOCK && parametersMulti.containsKey("$$1$")) {
+                        wc.rewrite(tp.getLeaf(), parsed);
                     } else {
-                        wc.rewrite(tp.getLeaf(), wc.getTreeMaker().Block(statements, false));
+                        TreePath parent = tp.getParentPath();
+                        List<? extends StatementTree> statements = ((BlockTree) parsed).getStatements();
+
+                        statements = statements.subList(1, statements.size() - 1);
+
+                        if (parent.getLeaf().getKind() == Kind.BLOCK) {
+                            List<StatementTree> newStatements = new LinkedList<StatementTree>();
+
+                            for (StatementTree st : ((BlockTree) parent.getLeaf()).getStatements()) {
+                                if (st == tp.getLeaf()) {
+                                    newStatements.addAll(statements);
+                                } else {
+                                    newStatements.add(st);
+                                }
+                            }
+
+                            wc.rewrite(parent.getLeaf(), wc.getTreeMaker().Block(newStatements, ((BlockTree) parent.getLeaf()).isStatic()));
+                        } else {
+                            wc.rewrite(tp.getLeaf(), wc.getTreeMaker().Block(statements, false));
+                        }
                     }
                 } else if (isFakeClass(parsed)) {
                     TreePath parent = tp.getParentPath();
@@ -492,7 +499,7 @@ public abstract class JavaFix {
 
                     members = members.subList(1, members.size());
 
-                    assert parent.getLeaf().getKind() == Kind.CLASS;
+                    assert TreeUtilities.CLASS_TREE_KINDS.contains(parent.getLeaf().getKind());
                     
                     List<Tree> newMembers = new LinkedList<Tree>();
 
@@ -665,6 +672,14 @@ public abstract class JavaFix {
                     wc.rewrite(node, nue);
                     return super.visitParameterizedType(node, p);
                 }
+                @Override
+                public Void visitTry(TryTree node, Void p) {
+                    List<? extends CatchTree> catches = (List<? extends CatchTree>) resolveMultiParameters(node.getCatches());
+                    TryTree nue = wc.getTreeMaker().Try(node.getResources(), node.getBlock(), catches, node.getFinallyBlock());
+
+                    wc.rewrite(node, nue);
+                    return super.visitTry(node, p);
+                }
                 private <T extends Tree> List<T> resolveMultiParameters(List<T> list) {
                     if (!Utilities.containsMultistatementTrees(list)) return list;
 
@@ -763,7 +778,7 @@ public abstract class JavaFix {
         OPERATOR_PRIORITIES.put(Kind.XOR_ASSIGNMENT, 15);
     }
 
-    private static boolean requiresParenthesis(Tree inner, Tree original, Tree outter) {
+    protected static boolean requiresParenthesis(Tree inner, Tree original, Tree outter) {
         if (!ExpressionTree.class.isAssignableFrom(inner.getKind().asInterface())) return false;
         if (!ExpressionTree.class.isAssignableFrom(outter.getKind().asInterface())) return false;
 
