@@ -65,6 +65,7 @@ import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.Modifier;
 import javax.lang.model.element.VariableElement;
 import org.netbeans.api.java.source.CompilationInfo;
+import org.netbeans.api.java.source.TreeUtilities;
 import org.netbeans.modules.java.hints.errors.Utilities;
 import org.netbeans.modules.java.hints.jackpot.code.spi.Constraint;
 import org.netbeans.modules.java.hints.jackpot.code.spi.Hint;
@@ -181,7 +182,7 @@ public class Tiny {
 
         TreePath up = ctx.getPath().getParentPath();
 
-        while (up != null && up.getLeaf().getKind() != Kind.METHOD && up.getLeaf().getKind() != Kind.CLASS) {
+        while (up != null && up.getLeaf().getKind() != Kind.METHOD && !TreeUtilities.CLASS_TREE_KINDS.contains(up.getLeaf().getKind())) {
             if (up.getLeaf().getKind() == Kind.SYNCHRONIZED) {
                 return null;
             }
@@ -260,6 +261,7 @@ public class Tiny {
     @TriggerPattern(value="$lock.lock(); $statements$; $lock.unlock();",
                     constraints=@Constraint(variable="$lock", type="java.util.concurrent.locks.Lock"))
     public static ErrorDescription unlockOutsideTryFinally(HintContext ctx) {
+        if (ctx.getMultiVariables().get("$statements$").isEmpty()) return null; //#186434
         String fixDisplayName = NbBundle.getMessage(Tiny.class, "FIX_UnlockOutsideTryFinally");
         Fix f = JavaFix.rewriteFix(ctx, fixDisplayName, ctx.getPath(), "$lock.lock(); try {$statements$;} finally {$lock.unlock();}");
         String displayName = NbBundle.getMessage(Tiny.class, "ERR_UnlockOutsideTryFinally");
@@ -335,19 +337,35 @@ public class Tiny {
 
         TreePath inspect = ctx.getPath();
 
-        while (inspect != null && inspect.getLeaf().getKind() != Kind.CLASS) {
+        while (inspect != null && !TreeUtilities.CLASS_TREE_KINDS.contains(inspect.getLeaf().getKind())) {
             if (inspect.getLeaf().getKind() == Kind.SYNCHRONIZED) {
                 Element current = ctx.getInfo().getTrees().getElement(new TreePath(inspect, ((SynchronizedTree) inspect.getLeaf()).getExpression()));
 
-                if (syncedOn.equals(current)) {
+                if (current == null || !VARIABLES.contains(current.getKind()) || equals(syncedOn, (VariableElement) current)) {
                     return null;
                 }
             }
 
             if (inspect.getLeaf().getKind() == Kind.METHOD) {
-                if (((MethodTree) inspect.getLeaf()).getModifiers().getFlags().contains(Modifier.SYNCHRONIZED)) {
-                    if (syncedOn.equals(attributeThis(ctx.getInfo(), inspect))) {
-                        return null;
+                Set<Modifier> mods = ((MethodTree) inspect.getLeaf()).getModifiers().getFlags();
+
+                if (mods.contains(Modifier.SYNCHRONIZED)) {
+                    if (mods.contains(Modifier.STATIC)) {
+                        if (syncedOn.getSimpleName().contentEquals("class")) {
+                            Element meth = ctx.getInfo().getTrees().getElement(inspect);
+
+                            if (meth == null || meth.getKind() != ElementKind.METHOD) {
+                                return null;
+                            }
+
+                            if (syncedOn.getEnclosingElement().equals(meth.getEnclosingElement())) {
+                                return null;
+                            }
+                        }
+                    } else {
+                        if (equals(syncedOn, attributeThis(ctx.getInfo(), inspect))) {
+                            return null;
+                        }
                     }
                 }
 
@@ -361,14 +379,25 @@ public class Tiny {
 
         return ErrorDescriptionFactory.forName(ctx, ctx.getPath(), displayName);
     }
+
+    private static boolean equals(VariableElement var1, VariableElement var2) {
+        if (   var1.getSimpleName() == var2.getSimpleName()
+            && var1.getSimpleName().contentEquals("class")) {
+            return var1.getEnclosingElement().equals(var2.getEnclosingElement());
+        } else {
+            return var1.equals(var2);
+        }
+    }
     
-    @Hint(category="thread", suppressWarnings="CallToNativeMethodWhileLocked")
+    @Hint(category="thread", suppressWarnings="SleepWhileHoldingLock")
     @TriggerPatterns({
         @TriggerPattern(value="java.lang.Thread.sleep($to)",
                         constraints=@Constraint(variable="$to", type="long")),
         @TriggerPattern(value="java.lang.Thread.sleep($to, $nanos)",
-                        constraints=@Constraint(variable="$to", type="long"),
-                        constraints=@Constraint(variable="$nanos", type="int"))
+                        constraints={
+                            @Constraint(variable="$to", type="long"),
+                            @Constraint(variable="$nanos", type="int")
+                        })
     })
     public static ErrorDescription sleepInSync(HintContext ctx) {
         if (!isSynced(ctx, ctx.getPath())) {
@@ -380,13 +409,15 @@ public class Tiny {
         return ErrorDescriptionFactory.forName(ctx, ctx.getPath(), displayName);
     }
 
-    @Hint(category="thread", suppressWarnings="SleepWhileHoldingLock")
+    @Hint(category="thread", suppressWarnings="SleepWhileInLoop")
     @TriggerPatterns({
         @TriggerPattern(value="java.lang.Thread.sleep($to)",
                         constraints=@Constraint(variable="$to", type="long")),
         @TriggerPattern(value="java.lang.Thread.sleep($to, $nanos)",
-                        constraints=@Constraint(variable="$to", type="long"),
-                        constraints=@Constraint(variable="$nanos", type="int"))
+                        constraints={
+                            @Constraint(variable="$to", type="long"),
+                            @Constraint(variable="$nanos", type="int")
+                        })
     })
     public static ErrorDescription sleepInLoop(HintContext ctx) {
         if (findLoop(ctx.getPath()) == null) {
@@ -421,7 +452,7 @@ public class Tiny {
     }
 
     private static boolean isSynced(HintContext ctx, TreePath inspect) {
-        while (inspect != null && inspect.getLeaf().getKind() != Kind.CLASS) {
+        while (inspect != null && !TreeUtilities.CLASS_TREE_KINDS.contains(inspect.getLeaf().getKind())) {
             if (inspect.getLeaf().getKind() == Kind.SYNCHRONIZED) {
                 return true;
             }
@@ -443,7 +474,7 @@ public class Tiny {
     private static final Set<Kind> LOOP_KINDS = EnumSet.of(Kind.DO_WHILE_LOOP, Kind.ENHANCED_FOR_LOOP, Kind.FOR_LOOP, Kind.WHILE_LOOP);
 
     private static TreePath findLoop(TreePath inspect) {
-        while (inspect != null && inspect.getLeaf().getKind() != Kind.CLASS && !LOOP_KINDS.contains(inspect.getLeaf().getKind())) {
+        while (inspect != null && !TreeUtilities.CLASS_TREE_KINDS.contains(inspect.getLeaf().getKind()) && !LOOP_KINDS.contains(inspect.getLeaf().getKind())) {
             inspect = inspect.getParentPath();
         }
 
